%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v23.07     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                         23 - July - 2023                         %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%CASE89PEGASE  Power flow data for small part of European system.
%   Please see CASEFORMAT for details on the case file format.
%
%   This case accurately represents the size and complexity of part of the
%   European high voltage transmission network. The network contains 89
%   buses, 12 generators, and 210 branches and it operates at 380, 220, and
%   150 kV. Please note that the data are fictitious and do not correspond
%   to real world data. They can thus be used to validate methods and tools
%   but should not be used for operation and planning of the European grid.
%
%   The data stems from the Pan European Grid Advanced Simulation and State
%   Estimation (PEGASE) project, part of the 7th Framework Program of the
%   European Union (http://www.fp7-pegase.com/). When publishing results
%   based on this data, please cite:
%
%     S. Fliscounakis, P. Panciatici, F. Capitanescu, and L. Wehenkel,
%     "Contingency ranking with respect to overloads in very large power
%     systems taking into account uncertainty, preventive and corrective
%     actions", Power Systems, IEEE Trans. on, (28)4:4909-4917, 2013.
%     http://dx.doi.org/10.1109/TPWRS.2013.2251015
%
%   Remarks:
%
%   1. Line flow limits are 20 MVA (at 1 p.u. voltage) greater than the
%   current flow limits found in PEGASE data.
%  
%   2. PEGASE data contains asymmetric shunt conductance and susceptance in
%   the PI transmission line model of branches. Thus total line charging
%   susceptance of branches is set to 0 p.u. and the nodal representation
%   of shunt condutance and susceptance is used. As a result, power flow
%   equations are left unchanged compared with original PEGASE data.
%   However, line flow constraints in the optimal flow problem are
%   modified.
%
%   3. Identical linear costs are used for all generators to form a loss
%   minimizing OPF objective function.
%
%   4. Since some parts of the network are aggregated, some generators
%   (e.g. with negative PMIN) represent aggregations of multiple loads
%   and generators.
%
%   Cédric Josz, Stéphane Fliscounakis, Jean Maeght, Patrick Panciatici
%   firstname.lastname@rte-france.com
%   Réseau de Transport d'Electricité (French Transmission System Operator)
%   Département Expertise Système, Immeuble "Le Colbert"
%   9 rue de la Porte de Buc, 78000 Versailles Cedex, France
%   March 18th, 2015
%
%   Copyright (c) 2015 by Cédric Josz, Stéphane Fliscounakis, Jean Maeght,
%   and Patrick Panciatici
%   Licensed under the Creative Commons Attribution 4.0 International license,
%   http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case89_pegase
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	89	 1	 0.0	 0.0	 0.199111	 4.530599	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	228	 1	 -23.43	 57.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	271	 1	 96.7	 26.8	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	317	 1	 -0.0	 -0.0	 0.045946	 -1.82203	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	659	 1	 -0.0	 -0.0	 0.174507	 73.977052	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	792	 1	 295.3	 41.9	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	913	 3	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	955	 1	 244.2	 152.7	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	1037	 1	 -0.0	 0.0	 0.0	 0.55	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1163	 1	 -0.0	 -0.0	 0.0	 16.04	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1317	 1	 149.3	 -2.0	 0.0	 20.77	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1367	 1	 0.0	 -0.0	 0.175687	 -1.509401	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1445	 1	 238.4	 210.9	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	1531	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	1579	 1	 -0.0	 0.0	 0.0	 16.56	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1611	 1	 274.1	 166.5	 0.0	 0.56	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	1616	 1	 0.0	 0.0	 0.0	 14.45	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1676	 1	 -0.0	 0.0	 0.171586	 -1.4632	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1815	 1	 63.66	 9.7	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	1968	 1	 118.4	 137.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	2107	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2154	 1	 -357.45	 33.05	 0.29	 -5.6	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2168	 1	 8.6	 -1.48	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	2267	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2268	 1	 0.0	 -0.0	 0.183167	 22.675025	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2299	 1	 402.1	 110.2	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	2441	 1	 0.0	 -0.0	 0.242534	 1.143584	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2449	 1	 301.9	 -103.2	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	2520	 1	 -0.0	 -0.0	 0.057433	 3.80797	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2870	 1	 -0.0	 0.0	 0.0	 0.62	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2908	 1	 203.8	 61.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	3097	 1	 361.91	 3.66	 0.0	 9.39	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	3242	 1	 296.1	 82.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	3279	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	3493	 1	 226.3	 61.1	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	3506	 1	 0.0	 0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	3659	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	4014	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4423	 1	 -0.0	 -0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4427	 1	 296.8	 77.7	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4495	 1	 336.3	 104.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4586	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4665	 1	 390.5	 62.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4929	 1	 37.0	 8.7	 0.070441	 50.913893	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	5097	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	5155	 1	 411.3	 168.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	5210	 1	 347.61	 74.37	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	5416	 1	 0.0	 0.0	 0.0	 25.13	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	5509	 1	 0.0	 0.0	 0.314057	 17.296509	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	5587	 1	 -0.0	 -0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	5762	 1	 0.0	 0.0	 0.0	 2.23	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	5776	 1	 222.7	 80.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	5848	 1	 0.0	 -0.0	 0.29	 -0.42	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	5996	 1	 -0.0	 -0.0	 0.164188	 4.023827	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6069	 1	 -456.66	 -131.97	 0.285753	 35.371068	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6233	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6293	 1	 -0.0	 0.0	 0.0	 33.66	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6542	 1	 355.98	 -147.98	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	6704	 1	 -0.0	 -0.0	 0.211099	 0.672832	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6798	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6826	 1	 326.9	 -82.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	6833	 1	 0.0	 0.0	 0.246363	 4.841277	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7051	 1	 0.0	 0.0	 0.0	 21.19	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7180	 1	 -0.0	 0.0	 0.234234	 4.220723	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7279	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	7526	 1	 -179.73	 -63.08	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7563	 1	 531.7	 -12.8	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	7637	 1	 0.0	 0.0	 0.29	 6.18	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7762	 1	 -0.0	 0.0	 0.304243	 48.453399	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7829	 1	 -114.36	 30.04	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	7960	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8103	 1	 39.34	 -10.7	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	8179	 1	 -0.0	 0.0	 0.194464	 19.1468	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8181	 1	 0.0	 -0.0	 0.210824	 6.620599	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8229	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	8329	 1	 0.0	 0.0	 0.149712	 2.04987	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8335	 1	 637.92	 139.57	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	8420	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	8574	 1	 -0.0	 0.0	 0.447839	 20.994738	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8581	 1	 -1299.13	 -140.85	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8605	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8847	 1	 -0.0	 0.0	 0.18076	 -0.881251	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8921	 1	 0.0	 0.0	 0.0	 16.37	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8964	 1	 925.91	 147.97	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	9024	 1	 0.0	 0.0	 0.141019	 25.246	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	9025	 1	 0.0	 -0.0	 0.205903	 3.0768	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	9064	 1	 0.0	 -0.0	 0.0	 15.26	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	9192	 1	 17.92	 23.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	9239	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin
mpc.gen = [
	913	 1133.335	 251.085	 772.11	 -269.94	 1.0	 100.0	 1	 1700.0	 566.67; % NUC
	2107	 1000.0	 202.14	 661.9	 -257.62	 1.0	 100.0	 1	 1500.0	 500.0; % COW
	2267	 333.335	 74.665	 228.16	 -78.83	 1.0	 100.0	 1	 500.0	 166.67; % NG
	3659	 1333.335	 330.815	 943.64	 -282.01	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	4586	 -313.8	 31.575	 92.96	 -29.81	 1.0	 100.0	 1	 100.0	 -727.6; % NG
	5097	 14.155	 2.4	 8.91	 -4.11	 1.0	 100.0	 1	 21.23	 7.08; % NG
	6233	 800.0	 177.855	 545.68	 -189.97	 1.0	 100.0	 1	 1200.0	 400.0; % NUC
	6798	 666.665	 123.065	 429.61	 -183.48	 1.0	 100.0	 1	 1000.0	 333.33; % NG
	7279	 -404.465	 4.07	 14.78	 -6.64	 1.0	 100.0	 1	 100.0	 -908.93; % NG
	7960	 400.0	 90.49	 274.2	 -93.22	 1.0	 100.0	 1	 600.0	 200.0; % COW
	8605	 400.0	 90.145	 273.94	 -93.65	 1.0	 100.0	 1	 600.0	 200.0; % NG
	9239	 400.0	 90.49	 274.2	 -93.22	 1.0	 100.0	 1	 600.0	 200.0; % COW
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.000000	   6.586541	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  34.794851	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.293854	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.583236	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.762466	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.707032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.398333	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  37.992337	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.760837	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.517790	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.271293	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.655344	   0.000000; % COW
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	3097	 659	 0.00073	 0.00905	 0.0	 1205.0	 3480	 3480	 0.0	 0.0	 1	 -30.0	 30.0;
	9024	 4929	 0.00192	 0.02296	 0.0	 909.0	 1371	 1371	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 6542	 0.01431	 0.05899	 0.0	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	6542	 1445	 0.02607	 0.07168	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 6833	 0.00054	 0.00465	 0.0	 1600.0	 6748	 6748	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 2268	 0.00126	 0.01124	 0.0	 1633.0	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 7180	 0.00048	 0.00527	 0.0	 1567.0	 5970	 5970	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 6293	 0.00082	 0.00938	 0.0	 1600.0	 3355	 3355	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 9192	 0.00028	 0.003502	 0.0	 8992	 8992	 8992	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 3493	 0.691467	 4.414711	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 955	 0.02004	 0.0916	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 228	 0.841911	 4.768444	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 6826	 0.026	 0.08948	 0.0	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 8964	 0.002631	 0.011889	 0.0	 319.0	 2595	 2595	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 5776	 0.7232	 1.944	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	9192	 955	 0.156169	 0.546756	 0.0	 56	 56	 56	 0.0	 0.0	 1	 -30.0	 30.0;
	9192	 6826	 0.168809	 0.580622	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	9192	 8964	 0.019222	 0.068209	 0.0	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	8574	 1616	 0.00039	 0.00386	 0.0	 1435.0	 8142	 8142	 0.0	 0.0	 1	 -30.0	 30.0;
	8574	 1163	 0.00096	 0.01138	 0.0	 1468.0	 2766	 2766	 0.0	 0.0	 1	 -30.0	 30.0;
	8574	 9064	 0.00037	 0.00325	 0.0	 1435.0	 9657	 9657	 0.0	 0.0	 1	 -30.0	 30.0;
	8574	 8921	 0.00029	 0.00339	 0.0	 1600.0	 9284	 9284	 0.0	 0.0	 1	 -30.0	 30.0;
	3493	 2299	 0.009458	 0.158871	 0.0	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	2299	 4423	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6826	 2299	 0.312951	 7.130667	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 2299	 0.247649	 1.075911	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 2299	 0.06056	 0.18612	 0.0	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 2299	 2.142489	 4.347733	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 2299	 0.07132	 1.068889	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 2299	 0.02268	 0.08652	 0.0	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 2299	 2.007778	 4.494222	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 2299	 0.006178	 0.028938	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 2299	 0.027711	 0.260951	 0.0	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	3493	 5587	 0.0	 0.000222	 0.0	 319.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4586	 3493	 0.00692	 0.337378	 0.0	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 3493	 0.025991	 0.10048	 0.0	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	6826	 3493	 0.083711	 0.8648	 0.0	 37	 37	 37	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 3493	 0.447378	 1.862089	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 3493	 0.062169	 0.153191	 0.0	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 3493	 2.492533	 4.725778	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 3493	 0.020271	 0.08244	 0.0	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 3493	 0.11416	 1.777556	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 3493	 0.574978	 2.992578	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 3493	 1.887067	 4.964444	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 3493	 0.250778	 0.817422	 0.0	 37	 37	 37	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 3493	 0.007049	 0.029609	 0.0	 1038	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	5587	 4586	 0.003049	 0.020218	 0.0	 1545	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	4423	 4586	 0.002911	 0.020262	 0.0	 1544	 1544	 1544	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 2870	 4e-05	 0.00041	 0.0	 777.0	 76679	 76679	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 659	 0.00087	 0.01087	 0.0	 1303.0	 2897	 2897	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 1037	 4e-05	 0.00046	 0.0	 777.0	 68410	 68410	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 659	 0.00095	 0.00924	 0.0	 1501.0	 3401	 3401	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 5210	 0.528017	 2.636157	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 1445	 0.032031	 0.128659	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	1616	 7762	 0.00044	 0.0032	 0.0	 1665.0	 9780	 9780	 0.0	 0.0	 1	 -30.0	 30.0;
	1616	 2520	 0.00046	 0.00489	 0.0	 1731.0	 6432	 6432	 0.0	 0.0	 1	 -30.0	 30.0;
	9064	 7762	 0.0003	 0.00352	 0.0	 1600.0	 8942	 8942	 0.0	 0.0	 1	 -30.0	 30.0;
	9064	 89	 0.00051	 0.00454	 0.0	 1665.0	 6915	 6915	 0.0	 0.0	 1	 -30.0	 30.0;
	1317	 659	 0.00068	 0.00746	 0.0	 1633.0	 4217	 4217	 0.0	 0.0	 1	 -30.0	 30.0;
	1317	 8605	 0.00093	 0.01022	 0.0	 1764.0	 3079	 3079	 0.0	 0.0	 1	 -30.0	 30.0;
	8605	 1367	 4e-05	 0.0004	 0.0	 1501.0	 78577	 78577	 0.0	 0.0	 1	 -30.0	 30.0;
	8605	 8921	 0.00078	 0.00698	 0.0	 1764.0	 4498	 4498	 0.0	 0.0	 1	 -30.0	 30.0;
	1163	 1676	 4e-05	 0.00043	 0.0	 1600.0	 73144	 73144	 0.0	 0.0	 1	 -30.0	 30.0;
	1163	 7051	 0.00025	 0.00309	 0.0	 1698.0	 10190	 10190	 0.0	 0.0	 1	 -30.0	 30.0;
	913	 7762	 0.00047	 0.00538	 0.0	 1633.0	 5849	 5849	 0.0	 0.0	 1	 -30.0	 30.0;
	2107	 7762	 0.00046	 0.00548	 0.0	 1764.0	 5744	 5744	 0.0	 0.0	 1	 -30.0	 30.0;
	2107	 5996	 0.00016	 0.00173	 0.0	 1863.0	 18181	 18181	 0.0	 0.0	 1	 -30.0	 30.0;
	2107	 6293	 0.00166	 0.01471	 0.0	 1764.0	 2134	 2134	 0.0	 0.0	 1	 -30.0	 30.0;
	913	 7762	 0.00051	 0.00512	 0.0	 1797.0	 6140	 6140	 0.0	 0.0	 1	 -30.0	 30.0;
	6704	 8921	 0.00021	 0.00248	 0.0	 1534.0	 12692	 12692	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 4586	 0.004391	 0.021689	 0.0	 306.0	 1428	 1428	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 6293	 0.00024	 0.00289	 0.0	 1665.0	 10893	 10893	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 3506	 0.0	 0.000222	 0.0	 358.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 8964	 0.01788	 0.100471	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	3506	 2908	 0.006458	 0.039982	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 6826	 0.106151	 0.993333	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 5776	 0.699778	 3.232311	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	8964	 6826	 0.257058	 0.43592	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 6826	 0.002769	 0.011449	 0.0	 2682	 2682	 2682	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 8329	 0.00034	 0.00305	 0.0	 1600.0	 10293	 10293	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 7051	 0.00123	 0.01255	 0.0	 1863.0	 2505	 2505	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 9239	 6e-05	 0.00065	 0.0	 1435.0	 48391	 48391	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 7960	 6e-05	 0.00063	 0.0	 1534.0	 49913	 49913	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 6233	 6e-05	 0.00055	 0.0	 1764.0	 57093	 57093	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 5416	 0.00079	 0.00968	 0.0	 1369.0	 3253	 3253	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 6798	 7e-05	 0.00079	 0.0	 39828	 39828	 39828	 0.0	 0.0	 1	 -30.0	 30.0;
	792	 3279	 0.0	 0.000222	 0.0	 397.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 792	 2.064178	 7.545333	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	7279	 792	 0.153711	 0.482489	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 792	 0.015809	 0.12368	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 792	 0.057978	 0.363422	 0.0	 86	 86	 86	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 792	 0.6932	 2.196889	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 792	 0.560356	 2.395867	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	5416	 2267	 0.00024	 0.00213	 0.0	 777.0	 14737	 14737	 0.0	 0.0	 1	 -30.0	 30.0;
	5416	 7637	 0.00093	 0.00884	 0.0	 1303.0	 3554	 3554	 0.0	 0.0	 1	 -30.0	 30.0;
	8964	 2168	 0.0	 0.000222	 0.0	 332.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3659	 5996	 0.00018	 0.00204	 0.0	 1797.0	 15425	 15425	 0.0	 0.0	 1	 -30.0	 30.0;
	5762	 5996	 0.00018	 0.00208	 0.0	 777.0	 15130	 15130	 0.0	 0.0	 1	 -30.0	 30.0;
	3242	 5097	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 3242	 0.02068	 0.093391	 0.0	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 3242	 0.777778	 7.408	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	3242	 7279	 0.00884	 0.07292	 0.0	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 3242	 0.131671	 8.295556	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	3242	 1611	 0.082462	 0.568222	 0.0	 56	 56	 56	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 1611	 0.0042	 0.02624	 0.0	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	8181	 8179	 0.00031	 0.00317	 0.0	 1271.0	 9918	 9918	 0.0	 0.0	 1	 -30.0	 30.0;
	8181	 7762	 0.00043	 0.00498	 0.0	 1501.0	 6320	 6320	 0.0	 0.0	 1	 -30.0	 30.0;
	9025	 7762	 0.00042	 0.00508	 0.0	 1731.0	 6197	 6197	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 4427	 0.110671	 0.773067	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 7279	 0.00912	 0.037609	 0.0	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 8335	 0.098049	 0.598711	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 5155	 0.019031	 1.160356	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 271	 0.024071	 0.915733	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 7563	 1.484267	 4.479111	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 7563	 0.011578	 0.063271	 0.0	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 7563	 0.654889	 1.839111	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 1611	 0.022049	 0.10076	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 7279	 0.459867	 2.604711	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 8335	 2.320222	 6.088	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 5155	 0.006369	 0.048089	 0.0	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 271	 0.006631	 0.0432	 0.0	 723	 723	 723	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 4427	 2.567244	 6.767111	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 4427	 0.309889	 1.214178	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 4427	 0.009191	 0.043289	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 1611	 0.691022	 5.239556	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	5210	 1445	 0.002669	 0.01718	 0.0	 1817	 1817	 1817	 0.0	 0.0	 1	 -30.0	 30.0;
	8179	 5509	 0.00074	 0.00694	 0.0	 1271.0	 4526	 4526	 0.0	 0.0	 1	 -30.0	 30.0;
	8179	 7762	 0.00068	 0.008	 0.0	 1567.0	 3935	 3935	 0.0	 0.0	 1	 -30.0	 30.0;
	7279	 4014	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 7279	 0.00524	 0.030631	 0.0	 1017	 1017	 1017	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 7279	 0.33932	 3.814667	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 7279	 0.22696	 2.614933	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 7279	 0.190671	 0.719378	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 7279	 1.050222	 2.105556	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 7279	 1.431644	 4.294578	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 7279	 0.022618	 0.161089	 0.0	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5509	 1579	 0.00088	 0.00895	 0.0	 1830.0	 3513	 3513	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 1531	 0.0	 0.000222	 0.0	 319.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 8335	 1.827778	 7.768	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 8335	 0.020849	 0.153382	 0.0	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 8335	 0.156231	 0.656267	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 8335	 0.176498	 0.891556	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	7762	 2268	 0.00067	 0.00777	 0.0	 1633.0	 4051	 4051	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 271	 0.004578	 0.061889	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 2908	 0.01348	 0.05932	 0.0	 520	 520	 520	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 5155	 0.066391	 2.802622	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 5155	 0.194258	 2.220444	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 1611	 0.008151	 0.072822	 0.0	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 2908	 0.016502	 0.055382	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 271	 0.0806	 4.633778	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 271	 0.831556	 3.729644	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 1611	 0.007951	 0.074151	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	1579	 5848	 0.0004	 0.00362	 0.0	 1633.0	 8673	 8673	 0.0	 0.0	 1	 -30.0	 30.0;
	7051	 8847	 0.00015	 0.00177	 0.0	 1600.0	 17783	 17783	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 8229	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	317	 6233	 2e-05	 0.00022	 0.0	 1698.0	 142990	 142990	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 2449	 0.02864	 0.172902	 0.0	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 4495	 0.017591	 0.1404	 0.0	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 4495	 0.00752	 0.031711	 0.0	 970	 970	 970	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 8420	 0.0	 0.000222	 0.0	 566.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9024	 6542	 0.000742	 0.067219	 0.0	 470	 470	 470	 0.994359	 0.0	 1	 -30.0	 30.0;
	9024	 6542	 0.000793	 0.06388	 0.0	 495	 495	 495	 0.998418	 0.0	 1	 -30.0	 30.0;
	6069	 9192	 0.000609	 0.046809	 0.0	 675	 675	 675	 0.933053	 0.0	 1	 -30.0	 30.0;
	6069	 1968	 0.00059	 0.04521	 0.0	 699	 699	 699	 0.91223	 0.0	 1	 -30.0	 30.0;
	7829	 1968	 0.519194	 5.108058	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	8574	 2299	 0.000559	 0.039982	 0.0	 790	 790	 790	 0.919523	 0.0	 1	 -30.0	 30.0;
	8574	 5587	 0.000537	 0.045312	 0.0	 698	 698	 698	 0.948262	 0.0	 1	 -30.0	 30.0;
	4929	 1815	 0.000889	 0.061549	 0.0	 514	 514	 514	 0.996867	 0.0	 1	 -30.0	 30.0;
	1815	 792	 1.467822	 7.764888	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	6704	 4586	 0.000586	 0.049031	 0.0	 645	 645	 645	 0.923407	 0.0	 1	 -30.0	 30.0;
	2441	 3506	 0.000417	 0.047801	 0.0	 661	 661	 661	 0.952413	 0.0	 1	 -30.0	 30.0;
	1367	 6826	 0.000755	 0.05143	 0.0	 615	 615	 615	 0.924009	 0.0	 1	 -30.0	 30.0;
	1676	 228	 0.000733	 0.052399	 0.0	 603	 603	 603	 0.934986	 0.0	 1	 -30.0	 30.0;
	7829	 6826	 0.00078	 0.064311	 0.0	 492	 492	 492	 1.0	 0.0	 1	 -30.0	 30.0;
	659	 3279	 0.00089	 0.048632	 0.0	 650	 650	 650	 0.987002	 0.0	 1	 -30.0	 30.0;
	5210	 792	 0.00855	 0.08972	 0.0	 351	 351	 351	 1.0	 0.0	 1	 -30.0	 30.0;
	1445	 792	 0.00223	 0.04836	 0.0	 653	 653	 653	 1.0	 0.0	 1	 -30.0	 30.0;
	7180	 2168	 0.000581	 0.043111	 0.0	 678.0	 733	 733	 0.924038	 0.0	 1	 -30.0	 30.0;
	6833	 8964	 0.000579	 0.043272	 0.0	 711.0	 730	 730	 0.901005	 0.0	 1	 -30.0	 30.0;
	3659	 3242	 0.000586	 0.049031	 0.0	 645	 645	 645	 0.923407	 0.0	 1	 -30.0	 30.0;
	8181	 4427	 0.000559	 0.049192	 0.0	 643	 643	 643	 0.924009	 0.0	 1	 -30.0	 30.0;
	9025	 7563	 0.000573	 0.051129	 0.0	 618	 618	 618	 0.934986	 0.0	 1	 -30.0	 30.0;
	2267	 5210	 0.000417	 0.039229	 0.0	 744.0	 806	 806	 0.967059	 0.0	 1	 -30.0	 30.0;
	5210	 7279	 0.230542	 1.197733	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	5210	 8335	 0.02284	 0.2644	 0.0	 120	 120	 120	 1.0	 0.0	 1	 -30.0	 30.0;
	5210	 2449	 0.08537	 0.736798	 0.0	 43	 43	 43	 1.0	 0.0	 1	 -30.0	 30.0;
	5210	 4665	 1.402768	 3.640289	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	5210	 4495	 1.050227	 4.450207	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	8179	 7279	 0.000716	 0.04371	 0.0	 723	 723	 723	 0.934986	 0.0	 1	 -30.0	 30.0;
	1445	 7279	 0.518622	 2.317689	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	5509	 8335	 0.00059	 0.045662	 0.0	 692	 692	 692	 0.955958	 0.0	 1	 -30.0	 30.0;
	5509	 1531	 0.000603	 0.050959	 0.0	 620	 620	 620	 0.968125	 0.0	 1	 -30.0	 30.0;
	1445	 8335	 0.047769	 0.554178	 0.0	 57	 57	 57	 1.0	 0.0	 1	 -30.0	 30.0;
	7762	 5155	 0.000591	 0.045153	 0.0	 700	 700	 700	 0.918868	 0.0	 1	 -30.0	 30.0;
	7762	 271	 0.0006	 0.047778	 0.0	 662	 662	 662	 0.948976	 0.0	 1	 -30.0	 30.0;
	7829	 5776	 0.02436	 0.270151	 0.0	 117	 117	 117	 1.0	 0.0	 1	 -30.0	 30.0;
	8329	 1445	 0.000802	 0.05727	 0.0	 552	 552	 552	 0.967021	 0.0	 1	 -30.0	 30.0;
	8329	 1445	 0.000823	 0.056059	 0.0	 564	 564	 564	 0.967021	 0.0	 1	 -30.0	 30.0;
	1445	 2449	 0.188099	 1.291901	 0.0	 25	 25	 25	 1.0	 0.0	 1	 -30.0	 30.0;
	1445	 4665	 2.466323	 7.26343	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	2268	 2908	 0.000523	 0.050352	 0.0	 628	 628	 628	 0.934622	 0.0	 1	 -30.0	 30.0;
	8847	 5776	 0.000682	 0.049638	 0.0	 637	 637	 637	 0.913034	 0.0	 1	 -30.0	 30.0;
	8847	 8103	 0.00099	 0.04736	 0.0	 667	 667	 667	 1.012146	 0.0	 1	 -30.0	 30.0;
	317	 2449	 0.000616	 0.048759	 0.0	 648	 648	 648	 0.933053	 0.0	 1	 -30.0	 30.0;
	7637	 8581	 9e-05	 0.015499	 0.0	 1698.0	 2038	 2038	 1.0	 -0.428189	 1	 -30.0	 30.0;
	5848	 7526	 9e-05	 0.00963	 0.0	 1698.0	 3280	 3280	 1.0	 0.178581	 1	 -30.0	 30.0;
	89	 4495	 0.000664	 0.045609	 0.0	 693	 693	 693	 0.924009	 0.0	 1	 -30.0	 30.0;
	2520	 4665	 0.000649	 0.044862	 0.0	 705	 705	 705	 0.933053	 0.0	 1	 -30.0	 30.0;
	5996	 8420	 0.00067	 0.04326	 0.0	 731	 731	 731	 0.923407	 0.0	 1	 -30.0	 30.0;
	2154	 5996	 9e-05	 0.009901	 0.0	 1698.0	 3191	 3191	 1.0	 -0.153178	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Line Capacity Model:         ub
% INFO    : Gen Active Cost Model:       stat
% INFO    : Setting Flat Start
% INFO    : Line Capacity PAB:           15.0 (deg.)
% INFO    : 
% INFO    : === Generator Classification Notes ===
% INFO    : NUC    2   -    36.29
% INFO    : COW    4   -    54.63
% INFO    : NG     6   -     9.08
% INFO    : 
% INFO    : === Generator Active Cost Stat Model Notes ===
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.58654064904 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.794850511 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.2938538618 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.5832364393 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.7624662557 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7070322939 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.39833286631 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.9923369108 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.7608365993 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5177897329 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2712932377 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.6553439803 0
% INFO    : 
% INFO    : === Generator Bounds Update Notes ===
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% WARNING : Branch 7829-1968 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1815-792 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7829-6826 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-792 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1445-792 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-7279 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-8335 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-2449 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-4665 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-4495 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1445-7279 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1445-8335 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7829-5776 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1445-2449 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1445-4665 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Transformer 7637-8581 has a phase shift of -0.428189, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 5848-7526 has a phase shift of 0.178581, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 2154-5996 has a phase shift of -0.153178, changing tap ratio 0.0 => 1.0
% INFO    : 
% INFO    : === Line Capacity UB Model Notes ===
% INFO    : Updated Thermal Rating: on line 3097-659 : Rate B, Rate C , 0.0, 0.0 -> 3480
% INFO    : Updated Thermal Rating: on line 9024-4929 : Rate B, Rate C , 0.0, 0.0 -> 1371
% INFO    : Updated Thermal Rating: on line 1815-6542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 6542-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 6069-6833 : Rate B, Rate C , 0.0, 0.0 -> 6748
% INFO    : Updated Thermal Rating: on line 6069-2268 : Rate B, Rate C , 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 6069-7180 : Rate B, Rate C , 0.0, 0.0 -> 5970
% INFO    : Updated Thermal Rating: on line 6069-6293 : Rate B, Rate C , 0.0, 0.0 -> 3355
% INFO    : Updated Thermal Rating: on line 1968-9192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8992
% INFO    : Updated Thermal Rating: on line 1968-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 1968-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 1968-228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 1968-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 1968-8964 : Rate B, Rate C , 0.0, 0.0 -> 2595
% INFO    : Updated Thermal Rating: on line 1968-5776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 9192-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on line 9192-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 9192-8964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 8574-1616 : Rate B, Rate C , 0.0, 0.0 -> 8142
% INFO    : Updated Thermal Rating: on line 8574-1163 : Rate B, Rate C , 0.0, 0.0 -> 2766
% INFO    : Updated Thermal Rating: on line 8574-9064 : Rate B, Rate C , 0.0, 0.0 -> 9657
% INFO    : Updated Thermal Rating: on line 8574-8921 : Rate B, Rate C , 0.0, 0.0 -> 9284
% INFO    : Updated Thermal Rating: on line 3493-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 2299-4423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6826-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 7563-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 4427-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 8335-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 5155-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 271-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 2449-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 4665-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 4495-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 3493-5587 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4586-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 228-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 6826-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on line 7563-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 4427-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 8335-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 5155-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 271-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 5776-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 2449-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 4665-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on line 4495-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 5587-4586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 4423-4586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1544
% INFO    : Updated Thermal Rating: on line 4929-2870 : Rate B, Rate C , 0.0, 0.0 -> 76679
% INFO    : Updated Thermal Rating: on line 4929-659 : Rate B, Rate C , 0.0, 0.0 -> 2897
% INFO    : Updated Thermal Rating: on line 4929-1037 : Rate B, Rate C , 0.0, 0.0 -> 68410
% INFO    : Updated Thermal Rating: on line 4929-659 : Rate B, Rate C , 0.0, 0.0 -> 3401
% INFO    : Updated Thermal Rating: on line 1815-5210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 1815-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 1616-7762 : Rate B, Rate C , 0.0, 0.0 -> 9780
% INFO    : Updated Thermal Rating: on line 1616-2520 : Rate B, Rate C , 0.0, 0.0 -> 6432
% INFO    : Updated Thermal Rating: on line 9064-7762 : Rate B, Rate C , 0.0, 0.0 -> 8942
% INFO    : Updated Thermal Rating: on line 9064-89 : Rate B, Rate C , 0.0, 0.0 -> 6915
% INFO    : Updated Thermal Rating: on line 1317-659 : Rate B, Rate C , 0.0, 0.0 -> 4217
% INFO    : Updated Thermal Rating: on line 1317-8605 : Rate B, Rate C , 0.0, 0.0 -> 3079
% INFO    : Updated Thermal Rating: on line 8605-1367 : Rate B, Rate C , 0.0, 0.0 -> 78577
% INFO    : Updated Thermal Rating: on line 8605-8921 : Rate B, Rate C , 0.0, 0.0 -> 4498
% INFO    : Updated Thermal Rating: on line 1163-1676 : Rate B, Rate C , 0.0, 0.0 -> 73144
% INFO    : Updated Thermal Rating: on line 1163-7051 : Rate B, Rate C , 0.0, 0.0 -> 10190
% INFO    : Updated Thermal Rating: on line 913-7762 : Rate B, Rate C , 0.0, 0.0 -> 5849
% INFO    : Updated Thermal Rating: on line 2107-7762 : Rate B, Rate C , 0.0, 0.0 -> 5744
% INFO    : Updated Thermal Rating: on line 2107-5996 : Rate B, Rate C , 0.0, 0.0 -> 18181
% INFO    : Updated Thermal Rating: on line 2107-6293 : Rate B, Rate C , 0.0, 0.0 -> 2134
% INFO    : Updated Thermal Rating: on line 913-7762 : Rate B, Rate C , 0.0, 0.0 -> 6140
% INFO    : Updated Thermal Rating: on line 6704-8921 : Rate B, Rate C , 0.0, 0.0 -> 12692
% INFO    : Updated Thermal Rating: on line 228-4586 : Rate B, Rate C , 0.0, 0.0 -> 1428
% INFO    : Updated Thermal Rating: on line 2441-6293 : Rate B, Rate C , 0.0, 0.0 -> 10893
% INFO    : Updated Thermal Rating: on line 955-3506 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 955-8964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 3506-2908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 228-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 228-5776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 8964-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 5776-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2682
% INFO    : Updated Thermal Rating: on line 659-8329 : Rate B, Rate C , 0.0, 0.0 -> 10293
% INFO    : Updated Thermal Rating: on line 659-7051 : Rate B, Rate C , 0.0, 0.0 -> 2505
% INFO    : Updated Thermal Rating: on line 659-9239 : Rate B, Rate C , 0.0, 0.0 -> 48391
% INFO    : Updated Thermal Rating: on line 659-7960 : Rate B, Rate C , 0.0, 0.0 -> 49913
% INFO    : Updated Thermal Rating: on line 659-6233 : Rate B, Rate C , 0.0, 0.0 -> 57093
% INFO    : Updated Thermal Rating: on line 659-5416 : Rate B, Rate C , 0.0, 0.0 -> 3253
% INFO    : Updated Thermal Rating: on line 659-6798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39828
% INFO    : Updated Thermal Rating: on line 792-3279 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7563-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 7279-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 8335-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 2449-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on line 4665-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 4495-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 5416-2267 : Rate B, Rate C , 0.0, 0.0 -> 14737
% INFO    : Updated Thermal Rating: on line 5416-7637 : Rate B, Rate C , 0.0, 0.0 -> 3554
% INFO    : Updated Thermal Rating: on line 8964-2168 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3659-5996 : Rate B, Rate C , 0.0, 0.0 -> 15425
% INFO    : Updated Thermal Rating: on line 5762-5996 : Rate B, Rate C , 0.0, 0.0 -> 15130
% INFO    : Updated Thermal Rating: on line 3242-5097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7563-3242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 4427-3242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 3242-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 271-3242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 3242-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on line 5097-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 8181-8179 : Rate B, Rate C , 0.0, 0.0 -> 9918
% INFO    : Updated Thermal Rating: on line 8181-7762 : Rate B, Rate C , 0.0, 0.0 -> 6320
% INFO    : Updated Thermal Rating: on line 9025-7762 : Rate B, Rate C , 0.0, 0.0 -> 6197
% INFO    : Updated Thermal Rating: on line 7563-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 7563-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 7563-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 7563-5155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 7563-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 2449-7563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 4665-7563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 4495-7563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 7563-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 4427-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 4427-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 4427-5155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 4427-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on line 2449-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 4665-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 4495-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 4427-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 5210-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1817
% INFO    : Updated Thermal Rating: on line 8179-5509 : Rate B, Rate C , 0.0, 0.0 -> 4526
% INFO    : Updated Thermal Rating: on line 8179-7762 : Rate B, Rate C , 0.0, 0.0 -> 3935
% INFO    : Updated Thermal Rating: on line 7279-4014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8335-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1017
% INFO    : Updated Thermal Rating: on line 5155-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 271-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 2449-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 4665-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 4495-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 1611-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5509-1579 : Rate B, Rate C , 0.0, 0.0 -> 3513
% INFO    : Updated Thermal Rating: on line 8335-1531 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5155-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 2449-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 4665-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 4495-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 7762-2268 : Rate B, Rate C , 0.0, 0.0 -> 4051
% INFO    : Updated Thermal Rating: on line 5155-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 5155-2908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 520
% INFO    : Updated Thermal Rating: on line 4665-5155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 4495-5155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 5155-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 271-2908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 4665-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 4495-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 271-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 1579-5848 : Rate B, Rate C , 0.0, 0.0 -> 8673
% INFO    : Updated Thermal Rating: on line 7051-8847 : Rate B, Rate C , 0.0, 0.0 -> 17783
% INFO    : Updated Thermal Rating: on line 5776-8229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 317-6233 : Rate B, Rate C , 0.0, 0.0 -> 142990
% INFO    : Updated Thermal Rating: on line 4665-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 2449-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 4665-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 970
% INFO    : Updated Thermal Rating: on line 1611-8420 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on transformer 9024-6542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on transformer 9024-6542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on transformer 6069-9192 : Rate A, Rate B, Rate C , 711.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on transformer 6069-1968 : Rate A, Rate B, Rate C , 711.0, 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on transformer 7829-1968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 8574-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 8574-5587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on transformer 4929-1815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on transformer 1815-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 6704-4586 : Rate A, Rate B, Rate C , 678.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on transformer 2441-3506 : Rate A, Rate B, Rate C , 678.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on transformer 1367-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on transformer 1676-228 : Rate A, Rate B, Rate C , 678.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on transformer 7829-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on transformer 659-3279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 650
% INFO    : Updated Thermal Rating: on transformer 5210-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on transformer 1445-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 653
% INFO    : Updated Thermal Rating: on transformer 7180-2168 : Rate B, Rate C , 0.0, 0.0 -> 733
% INFO    : Updated Thermal Rating: on transformer 6833-8964 : Rate B, Rate C , 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on transformer 3659-3242 : Rate A, Rate B, Rate C , 711.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on transformer 8181-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 643
% INFO    : Updated Thermal Rating: on transformer 9025-7563 : Rate A, Rate B, Rate C , 678.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on transformer 2267-5210 : Rate B, Rate C , 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 5210-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 5210-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on transformer 5210-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on transformer 5210-4665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 5210-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 8179-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on transformer 1445-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 5509-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on transformer 5509-1531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on transformer 1445-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on transformer 7762-5155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on transformer 7762-271 : Rate A, Rate B, Rate C , 711.0, 0.0, 0.0 -> 662
% INFO    : Updated Thermal Rating: on transformer 7829-5776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on transformer 8329-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on transformer 8329-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on transformer 1445-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 1445-4665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 2268-2908 : Rate A, Rate B, Rate C , 744.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on transformer 8847-5776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on transformer 8847-8103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on transformer 317-2449 : Rate A, Rate B, Rate C , 678.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on transformer 7637-8581 : Rate B, Rate C , 0.0, 0.0 -> 2038
% INFO    : Updated Thermal Rating: on transformer 5848-7526 : Rate B, Rate C , 0.0, 0.0 -> 3280
% INFO    : Updated Thermal Rating: on transformer 89-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on transformer 2520-4665 : Rate A, Rate B, Rate C , 711.0, 0.0, 0.0 -> 705
% INFO    : Updated Thermal Rating: on transformer 5996-8420 : Rate A, Rate B, Rate C , 744.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on transformer 2154-5996 : Rate B, Rate C , 0.0, 0.0 -> 3191
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 89	: V=0.998636, theta=-2.72828 -> V=1.0, theta=0.0
% INFO    : Bus 228	: V=1.052188, theta=-6.262599 -> V=1.0, theta=0.0
% INFO    : Bus 271	: V=1.039303, theta=-7.776587 -> V=1.0, theta=0.0
% INFO    : Bus 317	: V=1.052124, theta=7.796992 -> V=1.0, theta=0.0
% INFO    : Bus 659	: V=1.051131, theta=7.757217 -> V=1.0, theta=0.0
% INFO    : Bus 792	: V=1.034186, theta=-0.893204 -> V=1.0, theta=0.0
% INFO    : Bus 913	: V=1.030951, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 955	: V=1.002466, theta=-9.134162 -> V=1.0, theta=0.0
% INFO    : Bus 1037	: V=1.052997, theta=6.607316 -> V=1.0, theta=0.0
% INFO    : Bus 1163	: V=1.009762, theta=0.4517 -> V=1.0, theta=0.0
% INFO    : Bus 1317	: V=1.038584, theta=4.859365 -> V=1.0, theta=0.0
% INFO    : Bus 1367	: V=1.023381, theta=1.554555 -> V=1.0, theta=0.0
% INFO    : Bus 1445	: V=1.034571, theta=1.564741 -> V=1.0, theta=0.0
% INFO    : Bus 1531	: V=1.018598, theta=-9.561918 -> V=1.0, theta=0.0
% INFO    : Bus 1579	: V=1.006544, theta=-3.372817 -> V=1.0, theta=0.0
% INFO    : Bus 1611	: V=1.046304, theta=-7.257075 -> V=1.0, theta=0.0
% INFO    : Bus 1616	: V=1.00541, theta=-2.075628 -> V=1.0, theta=0.0
% INFO    : Bus 1676	: V=1.009368, theta=0.392255 -> V=1.0, theta=0.0
% INFO    : Bus 1815	: V=1.057772, theta=1.929189 -> V=1.0, theta=0.0
% INFO    : Bus 1968	: V=1.02308, theta=-9.077175 -> V=1.0, theta=0.0
% INFO    : Bus 2107	: V=1.03888, theta=1.910737 -> V=1.0, theta=0.0
% INFO    : Bus 2154	: V=1.038292, theta=13.048352 -> V=1.0, theta=0.0
% INFO    : Bus 2168	: V=1.016376, theta=-10.987335 -> V=1.0, theta=0.0
% INFO    : Bus 2267	: V=1.038741, theta=13.143978 -> V=1.0, theta=0.0
% INFO    : Bus 2268	: V=0.99293, theta=-3.22815 -> V=1.0, theta=0.0
% INFO    : Bus 2299	: V=1.041449, theta=-9.18839 -> V=1.0, theta=0.0
% INFO    : Bus 2441	: V=0.991005, theta=-2.851769 -> V=1.0, theta=0.0
% INFO    : Bus 2449	: V=1.086934, theta=-3.975972 -> V=1.0, theta=0.0
% INFO    : Bus 2520	: V=0.999733, theta=-2.864712 -> V=1.0, theta=0.0
% INFO    : Bus 2870	: V=1.052997, theta=6.607314 -> V=1.0, theta=0.0
% INFO    : Bus 2908	: V=1.022415, theta=-8.627044 -> V=1.0, theta=0.0
% INFO    : Bus 3097	: V=1.048722, theta=6.05208 -> V=1.0, theta=0.0
% INFO    : Bus 3242	: V=1.054504, theta=-7.413077 -> V=1.0, theta=0.0
% INFO    : Bus 3279	: V=1.034258, theta=-0.85281 -> V=1.0, theta=0.0
% INFO    : Bus 3493	: V=1.040629, theta=-8.48147 -> V=1.0, theta=0.0
% INFO    : Bus 3506	: V=1.002708, theta=-9.100433 -> V=1.0, theta=0.0
% INFO    : Bus 3659	: V=1.05217, theta=3.046806 -> V=1.0, theta=0.0
% INFO    : Bus 4014	: V=1.033972, theta=-11.212105 -> V=1.0, theta=0.0
% INFO    : Bus 4423	: V=1.041509, theta=-9.18519 -> V=1.0, theta=0.0
% INFO    : Bus 4427	: V=1.036884, theta=-8.989673 -> V=1.0, theta=0.0
% INFO    : Bus 4495	: V=1.038496, theta=-8.944438 -> V=1.0, theta=0.0
% INFO    : Bus 4586	: V=1.047701, theta=-8.937472 -> V=1.0, theta=0.0
% INFO    : Bus 4665	: V=1.038909, theta=-9.573486 -> V=1.0, theta=0.0
% INFO    : Bus 4929	: V=1.052995, theta=6.607328 -> V=1.0, theta=0.0
% INFO    : Bus 5097	: V=1.05444, theta=-7.409995 -> V=1.0, theta=0.0
% INFO    : Bus 5155	: V=1.030998, theta=-8.936324 -> V=1.0, theta=0.0
% INFO    : Bus 5210	: V=1.032893, theta=1.841903 -> V=1.0, theta=0.0
% INFO    : Bus 5416	: V=1.038395, theta=13.368566 -> V=1.0, theta=0.0
% INFO    : Bus 5509	: V=0.998445, theta=-4.250016 -> V=1.0, theta=0.0
% INFO    : Bus 5587	: V=1.040763, theta=-8.453527 -> V=1.0, theta=0.0
% INFO    : Bus 5762	: V=1.042316, theta=2.397232 -> V=1.0, theta=0.0
% INFO    : Bus 5776	: V=1.074342, theta=-5.370611 -> V=1.0, theta=0.0
% INFO    : Bus 5848	: V=1.009361, theta=-3.019939 -> V=1.0, theta=0.0
% INFO    : Bus 5996	: V=1.042267, theta=2.397462 -> V=1.0, theta=0.0
% INFO    : Bus 6069	: V=0.977261, theta=-4.165509 -> V=1.0, theta=0.0
% INFO    : Bus 6233	: V=1.052521, theta=7.854104 -> V=1.0, theta=0.0
% INFO    : Bus 6293	: V=0.994291, theta=-2.463618 -> V=1.0, theta=0.0
% INFO    : Bus 6542	: V=1.070142, theta=-0.548851 -> V=1.0, theta=0.0
% INFO    : Bus 6704	: V=1.003492, theta=-1.525293 -> V=1.0, theta=0.0
% INFO    : Bus 6798	: V=1.053791, theta=8.135392 -> V=1.0, theta=0.0
% INFO    : Bus 6826	: V=1.076556, theta=-5.786044 -> V=1.0, theta=0.0
% INFO    : Bus 6833	: V=0.968382, theta=-4.882064 -> V=1.0, theta=0.0
% INFO    : Bus 7051	: V=1.014089, theta=1.515243 -> V=1.0, theta=0.0
% INFO    : Bus 7180	: V=0.970985, theta=-4.970482 -> V=1.0, theta=0.0
% INFO    : Bus 7279	: V=1.033972, theta=-11.212105 -> V=1.0, theta=0.0
% INFO    : Bus 7526	: V=1.015361, theta=8.176427 -> V=1.0, theta=0.0
% INFO    : Bus 7563	: V=1.040779, theta=-11.087591 -> V=1.0, theta=0.0
% INFO    : Bus 7637	: V=1.035715, theta=19.538796 -> V=1.0, theta=0.0
% INFO    : Bus 7762	: V=1.010704, theta=-1.708563 -> V=1.0, theta=0.0
% INFO    : Bus 7829	: V=1.061047, theta=-2.764068 -> V=1.0, theta=0.0
% INFO    : Bus 7960	: V=1.052291, theta=7.889157 -> V=1.0, theta=0.0
% INFO    : Bus 8103	: V=1.004552, theta=0.141171 -> V=1.0, theta=0.0
% INFO    : Bus 8179	: V=1.00098, theta=-3.338785 -> V=1.0, theta=0.0
% INFO    : Bus 8181	: V=1.002201, theta=-2.957365 -> V=1.0, theta=0.0
% INFO    : Bus 8229	: V=1.074342, theta=-5.370611 -> V=1.0, theta=0.0
% INFO    : Bus 8329	: V=1.044426, theta=7.171947 -> V=1.0, theta=0.0
% INFO    : Bus 8335	: V=1.018566, theta=-9.585336 -> V=1.0, theta=0.0
% INFO    : Bus 8420	: V=1.046629, theta=-7.203894 -> V=1.0, theta=0.0
% INFO    : Bus 8574	: V=1.003438, theta=-1.910009 -> V=1.0, theta=0.0
% INFO    : Bus 8581	: V=1.039591, theta=5.776595 -> V=1.0, theta=0.0
% INFO    : Bus 8605	: V=1.023822, theta=1.617834 -> V=1.0, theta=0.0
% INFO    : Bus 8847	: V=1.012216, theta=1.209962 -> V=1.0, theta=0.0
% INFO    : Bus 8921	: V=1.00666, theta=-1.113996 -> V=1.0, theta=0.0
% INFO    : Bus 8964	: V=1.016233, theta=-11.01836 -> V=1.0, theta=0.0
% INFO    : Bus 9024	: V=1.057806, theta=3.596649 -> V=1.0, theta=0.0
% INFO    : Bus 9025	: V=1.004762, theta=-2.614968 -> V=1.0, theta=0.0
% INFO    : Bus 9064	: V=1.004902, theta=-2.063811 -> V=1.0, theta=0.0
% INFO    : Bus 9192	: V=1.024174, theta=-8.846156 -> V=1.0, theta=0.0
% INFO    : Bus 9239	: V=1.052319, theta=7.893501 -> V=1.0, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 913	: Pg=1249.4, Qg=684.16 -> Pg=1133.335, Qg=251.085
% INFO    : Gen at bus 913	: Vg=1.030951 -> Vg=1.0
% INFO    : Gen at bus 2107	: Pg=1269.4, Qg=558.16 -> Pg=1000.0, Qg=202.14
% INFO    : Gen at bus 2107	: Vg=1.03888 -> Vg=1.0
% INFO    : Gen at bus 2267	: Pg=362.0, Qg=200.02 -> Pg=333.335, Qg=74.665
% INFO    : Gen at bus 2267	: Vg=1.038741 -> Vg=1.0
% INFO    : Gen at bus 3659	: Pg=1097.4, Qg=689.53 -> Pg=1333.335, Qg=330.815
% INFO    : Gen at bus 3659	: Vg=1.05217 -> Vg=1.0
% INFO    : Gen at bus 4586	: Pg=-545.7, Qg=41.95 -> Pg=-313.8, Qg=31.575
% INFO    : Gen at bus 4586	: Vg=1.047701 -> Vg=1.0
% INFO    : Gen at bus 5097	: Pg=21.1, Qg=2.52 -> Pg=14.155, Qg=2.4
% INFO    : Gen at bus 5097	: Vg=1.05444 -> Vg=1.0
% INFO    : Gen at bus 6233	: Pg=879.6, Qg=368.28 -> Pg=800.0, Qg=177.855
% INFO    : Gen at bus 6233	: Vg=1.052521 -> Vg=1.0
% INFO    : Gen at bus 6798	: Pg=949.7, Qg=272.74 -> Pg=666.665, Qg=123.065
% INFO    : Gen at bus 6798	: Vg=1.053791 -> Vg=1.0
% INFO    : Gen at bus 7279	: Pg=-681.7, Qg=5.38 -> Pg=-404.465, Qg=4.07
% INFO    : Gen at bus 7279	: Vg=1.033972 -> Vg=1.0
% INFO    : Gen at bus 7960	: Pg=419.0, Qg=153.39 -> Pg=400.0, Qg=90.49
% INFO    : Gen at bus 7960	: Vg=1.052291 -> Vg=1.0
% INFO    : Gen at bus 8605	: Pg=427.0, Qg=170.21 -> Pg=400.0, Qg=90.145
% INFO    : Gen at bus 8605	: Vg=1.023822 -> Vg=1.0
% INFO    : Gen at bus 9239	: Pg=419.0, Qg=153.17 -> Pg=400.0, Qg=90.49
% INFO    : Gen at bus 9239	: Vg=1.052319 -> Vg=1.0
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
