%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v23.07     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                         23 - July - 2023                         %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   This network data stems from the Pan European Grid Advanced Simulation and
%   State Estimation (PEGASE) project, funded by the European Union
%   (http://www.fp7-pegase.com/). The data is derived from the original data
%   [1] provided to Florin Capitanescu in 2013 under request by the data owners
%   in PEGASE project. Revisions to the original raw include: (i) removing data
%   related to a specific transmission system operator, which were replaced by
%   equivalent loads at the end of the three interconnection lines; (ii) some
%   asymmetrical PI branch models were approximated as symmetrical, averaging
%   parameters values; (iii) modeling simplifications concerning the
%   transformer transversal sustenance; (iv) data anonymization; (v) data
%   conversion from Eurostag (.ech) format in to the MATPOWER (.m) format; and
%   (vi) definition of various AC-OPF problems (see [2] below). Note that
%   AC-OPF formulations of this dataset have traditionally modeled thermal
%   limits in terms of current but this version of the dataset uses MVA limits.
%
%   This power system model contains 8,387 buses, 1,865 generators, 4,669 loads,
%   12,474 lines, 2,087 transformers (out of which 589 OLTC and 84 phases
%   shifters) and 178 shunt capacitors/reactors. Also, 1,299 lines and 529
%   transformers (out of which 17 phase shifters) have more than one circuit in
%   parallel. The system models 8 voltage levels: 750, 400, 380, 330, 220, 150,
%   120, and 110 kV. This data is a reasonable representation of the size and
%   complexity of the European transmission system. However, the data is
%   fictitious and includes purposeful modifications of the real-world data.
%   Thus, this data can be used for test methods and algorithms, but should not
%   be used to make claims regarding the operation or planning of the European
%   power system.
%
%   This specific network data is publicly released for the purpose of testing
%   methods and algorithms on challenging optimization problems and more
%   comprehensive in terms of grid models and versatile AC OPF formulations
%   (see details in [2], where two solvers in MATPOWER version 4.1 failed to
%   converge on two instances and Florin Capitanescu's AC-OPF solver failed to
%   converge on another instance). For example, [2] presented results for 16
%   variants of AC-OPF problems with different objective functions, sets of
%   decision variables (e.g. among: generators active/reactive powers, ratio of
%   LTC transformers, reactance of shunt capacitors/reactors, and angle of
%   phase shifter transformers) and constraints. Researchers seeking to include
%   control variables like transformer tap ratio, phase shifter angle and shunt
%   reactance can contact Florin Capitanescu for the associated data.
%
%   Besides this test case, all AC OPF instances presented in [2] can be easily
%   obtained using one or some combinations of following features:
%
%   - Setting the angle of all 84 phase shifters to 0.0.
%
%   - Using identical unity costs (c=1.0) for all generators to minimize the
%     sum of generators active powers (an unconventional loss minimization via
%     also active power re-dispatch) as an OPF objective function.
%
%   - Using a quadratic OPF objective function that minimizes the sum of
%     squares of each generator's active power deviation with respect to the
%     initial value Pgi^0 (provided in the data set), i.e. (Pgi-Pgi^0)^2. Thus,
%     the coefficients of these fictitious cost function in p.u. (100MVA base)
%     are, (0.01*Pgi^0)^2 - 2*0.01*Pgi^0 + 0.0001*Pgi^0.
%
%   - The thermal limit of line between nodes 746 and 5968 and can be decreased
%     on purpose from 2061 MVA to 1000 MVA to create congestion (around 20%
%     current overload) and a tough OPF problem, see [2].
%
%   If one faces convergence issues with your an NLP solver, the following
%   simplifications are suggested:
%
%   - Generators with small active power range (<=20MW) are not taken as
%     control variable, their active power is fixed to the initial value.
%
%   - Generators with small reactive power range (<=10MVAr) are not taken as
%     control variable, their reactive power is fixed to the initial value.
%
%   - The reactance of 98 short lines could be raised to the minimum threshold
%     value of 0.0002 pu.
%
%   - The relative convergence tolerance of the NLP solver can be increased to
%     10^-5 on primal and dual feasibility.
%
%   When publishing results based on this data, please cite:
%
%   [1] F. Villella, S. Leclerc, I. Erlich, S. Rapoport, "PEGASE pan-European
%       test-beds for testing of algorithms on very large scale power systems".
%       IEEE PES Innovative Smart Grid Technologies Europe (ISGT Europe), 2012.
%
%   [2] F. Capitanescu, L. Wehenkel, "Experiments with the interior-point
%       method for solving large scale optimal power flow problems", Electric
%       Power Systems Research, 2013.
%
%   February, 2021
%
%   Copyright (c) 2021 by Florin Capitanescu <fcapitanescu@yahoo.com>
%   Licensed under the Creative Commons Attribution 4.0
%   International license, http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case8387_pegase
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	1	 1	 378.4	 98.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2	 1	 151.0	 48.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3	 1	 171.4081	 23.4	 0.0	 0.0	 1	    1.01394	    0.00000	 220.0	 1	    1.12789	    0.90000;
	4	 1	 45.95095	 14.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5	 2	 343.4	 53.1	 0.0	 20.0	 1	    1.01328	    0.00000	 380.0	 1	    1.12656	    0.90000;
	6	 1	 31.03441	 10.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7	 1	 134.0	 24.7	 0.0	 0.0	 1	    1.03048	    0.00000	 220.0	 1	    1.16095	    0.90000;
	8	 1	 0.0	 0.0	 0.0	 11.29798	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	9	 1	 -6.10677	 2.0	 0.0	 0.0	 1	    1.00252	    0.00000	 150.0	 1	    1.10505	    0.90000;
	10	 2	 8.509435	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	11	 1	 13.5	 14.8	 0.0	 0.0	 1	    1.03345	    0.00000	 380.0	 1	    1.16690	    0.90000;
	12	 1	 59.66615	 26.7	 0.0	 0.0	 1	    1.00668	    0.00000	 220.0	 1	    1.11337	    0.90000;
	13	 1	 67.67503	 12.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	14	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	15	 1	 25.32808	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	16	 1	 161.2	 39.3	 0.0	 0.0	 1	    1.02680	    0.00000	 220.0	 1	    1.15360	    0.90000;
	17	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02308	    0.00000	 220.0	 1	    1.14616	    0.90000;
	18	 1	 19.62176	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	19	 1	 17.21909	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	20	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	21	 1	 167.3	 54.8	 0.0	 0.0	 1	    1.02004	    0.00000	 380.0	 1	    1.14008	    0.90000;
	22	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02105	    0.00000	 380.0	 1	    1.14211	    0.90000;
	23	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	24	 1	 152.9	 49.4	 0.0	 0.0	 1	    1.01093	    0.00000	 380.0	 1	    1.12186	    0.90000;
	25	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	26	 1	 69.67725	 43.2	 0.0	 0.0	 1	    0.98986	    0.00000	 150.0	 1	    1.10000	    0.87973;
	27	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	28	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	29	 1	 13.51498	 4.9	 0.0	 0.0	 1	    1.00310	    0.00000	 110.0	 1	    1.10621	    0.90000;
	30	 1	 10.51165	 3.5	 0.0	 0.0	 1	    1.01172	    0.00000	 110.0	 1	    1.12345	    0.90000;
	31	 1	 0.0	 0.0	 0.122998	 0.0	 1	    1.00756	    0.00000	 220.0	 1	    1.11512	    0.90000;
	32	 1	 9.210212	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	33	 1	 42.74739	 12.8	 0.0	 0.0	 1	    1.02886	    0.00000	 220.0	 1	    1.15771	    0.90000;
	34	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	35	 2	 24.02664	 7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	36	 1	 20.82309	 7.9	 0.0	 0.0	 1	    1.01930	    0.00000	 380.0	 1	    1.13861	    0.90000;
	37	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03070	    0.00000	 220.0	 1	    1.16139	    0.90000;
	38	 1	 10.11121	 3.7	 0.0	 0.0	 1	    1.00689	    0.00000	 110.0	 1	    1.11378	    0.90000;
	39	 1	 10.0111	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	40	 1	 6.306993	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	41	 1	 2.903219	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	42	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00652	    0.00000	 220.0	 1	    1.11304	    0.90000;
	43	 2	 151.8	 48.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	44	 1	 127.6	 31.8	 0.0	 0.0	 1	    1.00986	    0.00000	 150.0	 1	    1.11972	    0.90000;
	45	 1	 48.65394	 16.1	 0.0	 0.0	 1	    1.02079	    0.00000	 220.0	 1	    1.14158	    0.90000;
	46	 1	 110.5	 -26.8	 0.0	 0.0	 1	    1.01425	    0.00000	 220.0	 1	    1.12849	    0.90000;
	47	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	48	 1	 140.0	 79.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	49	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01785	    0.00000	 380.0	 1	    1.13570	    0.90000;
	50	 1	 119.2	 20.7	 0.0	 0.0	 1	    1.01293	    0.00000	 220.0	 1	    1.12587	    0.90000;
	51	 2	 5.105661	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	52	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	53	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	54	 1	 187.9	 110.2	 0.0	 20.0	 1	    1.00663	    0.00000	 380.0	 1	    1.11326	    0.90000;
	55	 1	 14.91654	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	56	 1	 -18.5205	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	57	 1	 4.605106	 1.7	 0.0	 0.0	 1	    1.01755	    0.00000	 110.0	 1	    1.13511	    0.90000;
	58	 1	 0.0	 0.0	 0.090701	 0.0	 1	    1.02465	    0.00000	 380.0	 1	    1.14929	    0.90000;
	59	 1	 10.81199	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	60	 1	 62.86971	 20.5	 0.0	 0.0	 1	    1.01094	    0.00000	 150.0	 1	    1.12187	    0.90000;
	61	 1	 126.3	 42.4	 0.0	 0.0	 1	    1.02815	    0.00000	 150.0	 1	    1.15630	    0.90000;
	62	 1	 6.907659	 -4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	63	 1	 15.71743	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	64	 1	 0.0	 0.0	 0.0	 17.1282	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	65	 1	 38.74295	 6.1	 0.0	 0.0	 1	    1.00377	    0.00000	 220.0	 1	    1.10755	    0.90000;
	66	 1	 22.12453	 10.7	 0.0	 0.0	 1	    1.02891	    0.00000	 220.0	 1	    1.15781	    0.90000;
	67	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	68	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	69	 1	 138.8	 136.7	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	70	 2	 137.3	 66.4	 0.0	 0.0	 1	    1.00412	    0.00000	 220.0	 1	    1.10824	    0.90000;
	71	 2	 67.77514	 19.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	72	 1	 22.02442	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.20000	    0.80000;
	73	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	74	 1	 1.00111	 0.3	 0.0	 0.0	 1	    1.01642	    0.00000	 110.0	 1	    1.13284	    0.90000;
	75	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	76	 1	 21.52386	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	77	 1	 71.9798	 28.8	 0.0	 0.0	 1	    1.01750	    0.00000	 220.0	 1	    1.13500	    0.90000;
	78	 1	 0.0	 0.0	 0.173359	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	79	 2	 365.2	 116.5	 0.0	 0.0	 1	    1.00548	    0.00000	 220.0	 1	    1.11095	    0.90000;
	80	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02857	    0.00000	 150.0	 1	    1.15715	    0.90000;
	81	 1	 192.9	 73.3	 0.0	 0.0	 1	    1.01310	    0.00000	 380.0	 1	    1.12619	    0.90000;
	82	 1	 17.51942	 6.3	 0.0	 0.0	 1	    1.01760	    0.00000	 110.0	 1	    1.13520	    0.90000;
	83	 1	 33.13674	 12.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	84	 1	 40.44484	 25.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	85	 2	 212.9	 61.7	 0.0	 0.0	 1	    1.01207	    0.00000	 220.0	 1	    1.12414	    0.90000;
	86	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01340	    0.00000	 380.0	 1	    1.12681	    0.90000;
	87	 1	 90.70056	 25.5	 0.0	 0.0	 1	    1.00743	    0.00000	 220.0	 1	    1.11487	    0.90000;
	88	 1	 176.3	 -58.9	 0.0	 0.0	 1	    1.02562	    0.00000	 380.0	 1	    1.15124	    0.90000;
	89	 1	 35.93985	 22.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	90	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	91	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	92	 1	 65.07214	 40.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	93	 1	 51.35694	 -8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	94	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01449	    0.00000	 380.0	 1	    1.12898	    0.90000;
	95	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04155	    0.00000	 380.0	 1	    1.18311	    0.90000;
	96	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00954	    0.00000	 380.0	 1	    1.11908	    0.90000;
	97	 1	 3.804218	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	98	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	99	 1	 61.06771	 36.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	100	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01426	    0.00000	 220.0	 1	    1.12853	    0.90000;
	101	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02297	    0.00000	 380.0	 1	    1.14595	    0.90000;
	102	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04218	    0.00000	 220.0	 1	    1.18435	    0.90000;
	103	 1	 1.801998	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	104	 1	 40.0444	 16.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	105	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00980	    0.00000	 380.0	 1	    1.11960	    0.90000;
	106	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01150	    0.00000	 150.0	 1	    1.12300	    0.90000;
	107	 1	 45.15006	 14.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	108	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	109	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00665	    0.00000	 220.0	 1	    1.11331	    0.90000;
	110	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01601	    0.00000	 220.0	 1	    1.13202	    0.90000;
	111	 2	 8.209102	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01109	    0.00000	 220.0	 1	    1.12219	    0.90000;
	113	 1	 23.72631	 12.7	 0.0	 0.0	 1	    1.01454	    0.00000	 220.0	 1	    1.12909	    0.90000;
	114	 1	 121.9	 7.4	 0.0	 0.0	 1	    1.00959	    0.00000	 220.0	 1	    1.11918	    0.90000;
	115	 1	 0.0	 0.0	 0.156015	 0.0	 1	    1.02719	    0.00000	 380.0	 1	    1.15438	    0.90000;
	116	 1	 47.3525	 16.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	117	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02734	    0.00000	 380.0	 1	    1.15468	    0.90000;
	118	 1	 38.14229	 12.5	 0.0	 0.0	 1	    1.00880	    0.00000	 150.0	 1	    1.11760	    0.90000;
	119	 1	 130.6	 84.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	120	 1	 7.908769	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	121	 2	 47.15228	 78.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	122	 1	 -75.3836	 7.8	 0.0	 0.0	 1	    1.02934	    0.00000	 380.0	 1	    1.15868	    0.90000;
	123	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	124	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	125	 2	 100.9	 49.3	 0.0	 0.0	 1	    1.00263	    0.00000	 220.0	 1	    1.10525	    0.90000;
	126	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01655	    0.00000	 220.0	 1	    1.13311	    0.90000;
	127	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01901	    0.00000	 150.0	 1	    1.13802	    0.90000;
	128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	129	 1	 38.34251	 5.6	 0.0	 0.0	 1	    1.02298	    0.00000	 220.0	 1	    1.14596	    0.90000;
	130	 1	 269.6	 65.7	 0.0	 0.0	 1	    1.03024	    0.00000	 120.0	 1	    1.16048	    0.90000;
	131	 2	 160.0	 3.3	 0.0	 0.0	 1	    1.02245	    0.00000	 220.0	 1	    1.14491	    0.90000;
	132	 1	 32.33585	 12.0	 0.0	 0.0	 1	    1.01605	    0.00000	 220.0	 1	    1.13210	    0.90000;
	133	 1	 100.1	 45.1	 0.0	 0.0	 1	    1.00781	    0.00000	 380.0	 1	    1.11561	    0.90000;
	134	 2	 12.31365	 3.9	 0.0	 0.0	 1	    1.03188	    0.00000	 220.0	 1	    1.16377	    0.90000;
	135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01475	    0.00000	 150.0	 1	    1.12950	    0.90000;
	136	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	137	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	138	 1	 40.34473	 25.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	139	 1	 9.210212	 3.3	 0.0	 0.0	 1	    1.00362	    0.00000	 110.0	 1	    1.10724	    0.90000;
	140	 1	 166.0	 60.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	141	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	142	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00745	    0.00000	 150.0	 1	    1.11491	    0.90000;
	143	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03352	    0.00000	 380.0	 1	    1.16705	    0.90000;
	144	 2	 152.4	 35.1	 0.0	 0.0	 1	    1.01777	    0.00000	 220.0	 1	    1.13555	    0.90000;
	145	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01955	    0.00000	 150.0	 1	    1.13909	    0.90000;
	146	 1	 26.8	 -3.7	 0.0	 -25.3011	 1	    1.00905	    0.00000	 380.0	 1	    1.11809	    0.90000;
	147	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	148	 1	 257.5	 131.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	149	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	150	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	151	 1	 100.8	 13.2	 0.0	 0.0	 1	    1.04391	    0.00000	 220.0	 1	    1.18781	    0.90000;
	152	 2	 113.9	 11.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	153	 2	 104.4	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	154	 1	 370.5	 -17.0	 0.0	 0.0	 1	    1.02827	    0.00000	 220.0	 1	    1.15654	    0.90000;
	155	 1	 9.910988	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	156	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	157	 1	 94.9	 36.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	158	 1	 81.0899	 48.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	159	 2	 210.4	 159.2	 0.0	 0.0	 1	    1.01645	    0.00000	 380.0	 1	    1.13289	    0.90000;
	160	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	161	 1	 54.96094	 16.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	162	 1	 19.32142	 26.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01214	    0.00000	 220.0	 1	    1.12428	    0.90000;
	165	 1	 19.92209	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	166	 1	 57.16338	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	167	 1	 69.57714	 16.0	 0.0	 0.0	 1	    1.03299	    0.00000	 220.0	 1	    1.16597	    0.90000;
	168	 1	 36.84085	 13.9	 0.0	 0.0	 1	    1.03077	    0.00000	 220.0	 1	    1.16155	    0.90000;
	169	 2	 4.805328	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	170	 2	 9.210212	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	171	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00512	    0.00000	 220.0	 1	    1.11024	    0.90000;
	172	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	173	 1	 119.9	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	174	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00389	    0.00000	 150.0	 1	    1.10778	    0.90000;
	175	 2	 75.78402	 24.6	 0.0	 0.0	 1	    1.02662	    0.00000	 220.0	 1	    1.15324	    0.90000;
	176	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03341	    0.00000	 220.0	 1	    1.16682	    0.90000;
	177	 2	 0.0	 0.0	 0.288019	 0.0	 1	    1.00980	    0.00000	 380.0	 1	    1.11959	    0.90000;
	178	 1	 39.74406	 11.8	 0.0	 0.0	 1	    1.01333	    0.00000	 220.0	 1	    1.12666	    0.90000;
	179	 1	 86.79623	 28.4	 0.0	 0.0	 1	    1.01202	    0.00000	 150.0	 1	    1.12403	    0.90000;
	180	 1	 22.42486	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	181	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00385	    0.00000	 220.0	 1	    1.10770	    0.90000;
	182	 1	 110.9	 32.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	183	 1	 0.0	 0.0	 0.191685	 0.0	 1	    1.00682	    0.00000	 220.0	 1	    1.11363	    0.90000;
	184	 1	 46.15117	 18.2	 0.0	 0.0	 1	    1.01722	    0.00000	 150.0	 1	    1.13444	    0.90000;
	185	 1	 34.03774	 12.3	 0.0	 0.0	 1	    1.01882	    0.00000	 110.0	 1	    1.13765	    0.90000;
	186	 2	 322.4	 84.4	 0.0	 0.0	 1	    1.00468	    0.00000	 220.0	 1	    1.10936	    0.90000;
	187	 1	 33.43707	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	188	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	189	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	190	 1	 75.28346	 19.2	 0.0	 0.0	 1	    1.00758	    0.00000	 110.0	 1	    1.11516	    0.90000;
	191	 2	 219.6	 77.5	 0.0	 0.0	 1	    1.00634	    0.00000	 220.0	 1	    1.11269	    0.90000;
	192	 1	 37.3414	 10.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.20000	    0.80000;
	193	 2	 340.0	 93.8	 0.0	 0.0	 1	    1.01309	    0.00000	 380.0	 1	    1.12617	    0.90000;
	194	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	195	 1	 155.6	 54.7	 0.0	 0.0	 1	    1.01826	    0.00000	 220.0	 1	    1.13653	    0.90000;
	196	 1	 105.2	 0.1	 0.0	 0.0	 1	    1.01766	    0.00000	 220.0	 1	    1.13531	    0.90000;
	197	 2	 80.9898	 21.0	 0.0	 0.0	 1	    1.00321	    0.00000	 220.0	 1	    1.10643	    0.90000;
	198	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01008	    0.00000	 380.0	 1	    1.12015	    0.90000;
	199	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03238	    0.00000	 380.0	 1	    1.16475	    0.90000;
	200	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01916	    0.00000	 380.0	 1	    1.13832	    0.90000;
	201	 2	 176.2	 20.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	202	 1	 27.02997	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	203	 1	 2.602886	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	204	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04080	    0.00000	 220.0	 1	    1.18161	    0.90000;
	205	 1	 14.61621	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	206	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01103	    0.00000	 220.0	 1	    1.12206	    0.90000;
	207	 1	 -23.426	 57.4	 0.0	 0.0	 1	    1.02443	    0.00000	 150.0	 1	    1.14886	    0.90000;
	208	 1	 426.6	 93.7	 0.0	 0.0	 1	    1.02237	    0.00000	 380.0	 1	    1.14475	    0.90000;
	209	 2	 154.2	 23.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	210	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00601	    0.00000	 110.0	 1	    1.11201	    0.90000;
	211	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	212	 1	 2.502775	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	213	 1	 34.03774	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	214	 1	 45.85083	 7.0	 0.0	 0.0	 1	    1.00547	    0.00000	 220.0	 1	    1.11094	    0.90000;
	215	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01230	    0.00000	 380.0	 1	    1.12459	    0.90000;
	216	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01529	    0.00000	 220.0	 1	    1.13058	    0.90000;
	217	 2	 46.05106	 16.9	 0.0	 0.0	 1	    1.01593	    0.00000	 110.0	 1	    1.13186	    0.90000;
	218	 1	 0.0	 0.0	 0.0	 12.42588	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	219	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	220	 1	 167.9	 18.2	 0.0	 0.0	 1	    1.01733	    0.00000	 220.0	 1	    1.13466	    0.90000;
	221	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	222	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00487	    0.00000	 150.0	 1	    1.10975	    0.90000;
	223	 1	 16.61843	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	224	 2	 131.9	 31.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.20000	    0.80000;
	225	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	226	 2	 224.2	 73.9	 0.0	 0.0	 1	    1.00382	    0.00000	 380.0	 1	    1.10764	    0.90000;
	227	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	228	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00380	    0.00000	 380.0	 1	    1.10759	    0.90000;
	229	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00309	    0.00000	 220.0	 1	    1.10617	    0.90000;
	230	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00565	    0.00000	 220.0	 1	    1.11130	    0.90000;
	231	 1	 0.0	 0.0	 0.152776	 0.0	 1	    1.01758	    0.00000	 380.0	 1	    1.13516	    0.90000;
	232	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02376	    0.00000	 380.0	 1	    1.14752	    0.90000;
	233	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02867	    0.00000	 220.0	 1	    1.15733	    0.90000;
	234	 1	 113.9	 24.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	235	 2	 43.34806	 26.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	236	 1	 216.8	 40.5	 0.0	 0.0	 1	    1.01055	    0.00000	 220.0	 1	    1.12110	    0.90000;
	237	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02308	    0.00000	 380.0	 1	    1.14616	    0.90000;
	238	 2	 160.8	 10.6	 0.0	 0.0	 1	    1.01017	    0.00000	 220.0	 1	    1.12034	    0.90000;
	239	 1	 38.74295	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	240	 1	 350.4	 29.3	 0.0	 0.0	 1	    1.02510	    0.00000	 220.0	 1	    1.15020	    0.90000;
	241	 1	 0.0	 0.0	 0.0	 -261.753	 1	    1.02753	    0.00000	 380.0	 1	    1.15507	    0.90000;
	242	 1	 103.8	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	243	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03173	    0.00000	 220.0	 1	    1.16345	    0.90000;
	244	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	245	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	246	 1	 96.7	 26.8	 0.0	 0.0	 1	    1.02364	    0.00000	 150.0	 1	    1.14727	    0.90000;
	247	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02198	    0.00000	 150.0	 1	    1.14395	    0.90000;
	248	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	249	 1	 19.02109	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	250	 1	 102.1	 25.3	 0.0	 0.0	 1	    1.00568	    0.00000	 150.0	 1	    1.11136	    0.90000;
	251	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	252	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	253	 2	 113.3	 30.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	254	 1	 8.309213	 3.0	 0.0	 0.0	 1	    1.00629	    0.00000	 110.0	 1	    1.11258	    0.90000;
	255	 1	 119.6	 29.6	 0.0	 0.0	 1	    1.02818	    0.00000	 220.0	 1	    1.15635	    0.90000;
	256	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00854	    0.00000	 380.0	 1	    1.11709	    0.90000;
	257	 2	 49.9	 144.0	 0.0	 0.0	 1	    1.02506	    0.00000	 380.0	 1	    1.15011	    0.90000;
	258	 1	 27.3303	 11.9	 0.0	 0.0	 1	    1.00834	    0.00000	 220.0	 1	    1.11668	    0.90000;
	259	 1	 191.2	 -3.4	 0.0	 0.0	 1	    1.00692	    0.00000	 220.0	 1	    1.11384	    0.90000;
	260	 1	 0.0	 0.0	 0.03458	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	261	 1	 177.1	 66.9	 0.0	 0.0	 1	    1.02394	    0.00000	 380.0	 1	    1.14787	    0.90000;
	262	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01106	    0.00000	 150.0	 1	    1.12212	    0.90000;
	263	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02069	    0.00000	 220.0	 1	    1.14137	    0.90000;
	264	 1	 53.45927	 18.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	265	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	266	 1	 13.81532	 1.4	 0.0	 0.0	 1	    1.01764	    0.00000	 220.0	 1	    1.13528	    0.90000;
	267	 1	 85.1	 67.0	 0.0	 0.0	 1	    1.01018	    0.00000	 150.0	 1	    1.12035	    0.90000;
	268	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00899	    0.00000	 220.0	 1	    1.11797	    0.90000;
	269	 1	 189.3	 76.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	270	 1	 23.72631	 9.4	 0.0	 0.0	 1	    1.02215	    0.00000	 150.0	 1	    1.14430	    0.90000;
	271	 1	 10.0111	 -21.0	 0.0	 0.0	 1	    1.01709	    0.00000	 220.0	 1	    1.13418	    0.90000;
	272	 2	 228.1	 131.8	 0.0	 0.0	 1	    1.01005	    0.00000	 380.0	 1	    1.12010	    0.90000;
	273	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	274	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	275	 1	 431.7	 121.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	276	 1	 2.202442	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	277	 1	 103.0	 12.0	 0.0	 0.0	 1	    1.04213	    0.00000	 220.0	 1	    1.18425	    0.90000;
	278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03295	    0.00000	 220.0	 1	    1.16589	    0.90000;
	279	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 380.0	 1	    1.15556	    0.90000;
	280	 1	 0.0	 0.0	 0.0	 40.46213	 1	    0.96551	    0.00000	 150.0	 1	    1.10000	    0.83101;
	281	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	282	 2	 -463.61	 253.81	 0.0	 0.0	 1	    1.03765	    0.00000	 380.0	 1	    1.17531	    0.90000;
	283	 1	 42.04662	 17.2	 0.0	 0.0	 1	    1.01788	    0.00000	 150.0	 1	    1.13575	    0.90000;
	284	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02219	    0.00000	 110.0	 1	    1.14437	    0.90000;
	285	 1	 163.1	 46.3	 0.0	 0.0	 1	    1.01183	    0.00000	 220.0	 1	    1.12366	    0.90000;
	286	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00270	    0.00000	 220.0	 1	    1.10541	    0.90000;
	287	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01780	    0.00000	 220.0	 1	    1.13559	    0.90000;
	288	 1	 0.0	 0.0	 0.041702	 0.0	 1	    1.01745	    0.00000	 380.0	 1	    1.13490	    0.90000;
	289	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	290	 1	 67.17448	 -23.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	291	 1	 303.8	 85.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	292	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00709	    0.00000	 380.0	 1	    1.11417	    0.90000;
	293	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03177	    0.00000	 220.0	 1	    1.16355	    0.90000;
	294	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01207	    0.00000	 380.0	 1	    1.12414	    0.90000;
	295	 2	 291.5	 51.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	296	 1	 24.22686	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	297	 1	 108.6	 2.6	 0.0	 0.0	 1	    1.00417	    0.00000	 380.0	 1	    1.10834	    0.90000;
	298	 1	 4.00444	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	299	 1	 30.0333	 10.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	300	 1	 524.5	 43.0	 0.0	 0.0	 1	    1.01275	    0.00000	 220.0	 1	    1.12550	    0.90000;
	301	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	302	 1	 4.404884	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	303	 2	 7.408214	 2.7	 0.0	 0.0	 1	    1.01644	    0.00000	 110.0	 1	    1.13289	    0.90000;
	304	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01816	    0.00000	 220.0	 1	    1.13633	    0.90000;
	305	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02726	    0.00000	 220.0	 1	    1.15453	    0.90000;
	306	 1	 186.6	 56.6	 0.0	 0.0	 1	    1.02581	    0.00000	 380.0	 1	    1.15162	    0.90000;
	307	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	308	 2	 48.2535	 23.5	 0.0	 0.0	 1	    1.01782	    0.00000	 220.0	 1	    1.13565	    0.90000;
	309	 1	 3.203552	 1.2	 0.0	 0.0	 1	    1.01179	    0.00000	 110.0	 1	    1.12359	    0.90000;
	310	 1	 372.8	 147.5	 0.0	 0.0	 1	    1.02098	    0.00000	 150.0	 1	    1.14195	    0.90000;
	311	 1	 0.0	 0.0	 0.087531	 0.0	 1	    1.01269	    0.00000	 220.0	 1	    1.12538	    0.90000;
	312	 1	 197.5	 48.3	 0.0	 0.0	 1	    1.01785	    0.00000	 220.0	 1	    1.13570	    0.90000;
	313	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02752	    0.00000	 380.0	 1	    1.15504	    0.90000;
	314	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02472	    0.00000	 150.0	 1	    1.14945	    0.90000;
	315	 1	 110.4	 26.2	 0.0	 0.0	 1	    1.03073	    0.00000	 220.0	 1	    1.16146	    0.90000;
	316	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00337	    0.00000	 220.0	 1	    1.10675	    0.90000;
	317	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02694	    0.00000	 380.0	 1	    1.15389	    0.90000;
	318	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	319	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01108	    0.00000	 380.0	 1	    1.12215	    0.90000;
	320	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	321	 1	 141.1	 2.1	 0.0	 0.0	 1	    1.01180	    0.00000	 220.0	 1	    1.12359	    0.90000;
	322	 1	 52.95872	 32.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01524	    0.00000	 220.0	 1	    1.13047	    0.90000;
	324	 1	 35.5394	 11.5	 0.0	 0.0	 1	    1.01910	    0.00000	 110.0	 1	    1.13821	    0.90000;
	325	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03172	    0.00000	 380.0	 1	    1.16344	    0.90000;
	326	 2	 48.95428	 15.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	327	 1	 0.0	 0.0	 0.0	 -16.4774	 1	    1.04720	    0.00000	 150.0	 1	    1.19440	    0.90000;
	328	 1	 10.0111	 4.0	 0.0	 0.0	 1	    1.01858	    0.00000	 220.0	 1	    1.13716	    0.90000;
	329	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	330	 1	 65.17226	 -51.5	 0.0	 0.0	 1	    1.03018	    0.00000	 220.0	 1	    1.16037	    0.90000;
	331	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00494	    0.00000	 220.0	 1	    1.10988	    0.90000;
	332	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	333	 1	 56.76294	 23.2	 0.0	 0.0	 1	    1.01668	    0.00000	 150.0	 1	    1.13336	    0.90000;
	334	 2	 373.7	 125.6	 0.0	 0.0	 1	    1.01311	    0.00000	 380.0	 1	    1.12621	    0.90000;
	335	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	336	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	337	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01166	    0.00000	 380.0	 1	    1.12332	    0.90000;
	338	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	339	 2	 328.3	 96.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	340	 1	 23.82642	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	341	 1	 -95.7061	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	342	 1	 44.04884	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	343	 2	 16.51831	 3.0	 0.0	 0.0	 1	    1.02042	    0.00000	 220.0	 1	    1.14083	    0.90000;
	344	 1	 19.02109	 11.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	345	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	346	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01890	    0.00000	 380.0	 1	    1.13779	    0.90000;
	347	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01651	    0.00000	 380.0	 1	    1.13302	    0.90000;
	348	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02644	    0.00000	 150.0	 1	    1.15288	    0.90000;
	349	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	350	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	351	 1	 27.93097	 10.1	 0.0	 0.0	 1	    1.01106	    0.00000	 110.0	 1	    1.12212	    0.90000;
	352	 1	 34.93874	 21.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	353	 1	 134.1	 34.2	 0.0	 0.0	 1	    1.00946	    0.00000	 150.0	 1	    1.11891	    0.90000;
	354	 1	 17.71965	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	355	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	356	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00788	    0.00000	 380.0	 1	    1.11575	    0.90000;
	357	 1	 0.0	 0.0	 0.0	 33.63425	 1	    0.98819	    0.00000	 150.0	 1	    1.10000	    0.87639;
	358	 1	 77.78624	 -40.8	 0.0	 0.0	 1	    1.00730	    0.00000	 220.0	 1	    1.11459	    0.90000;
	359	 1	 11.91321	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	360	 1	 5.00555	 2.0	 0.0	 0.0	 1	    1.02089	    0.00000	 220.0	 1	    1.14179	    0.90000;
	361	 2	 11.01221	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	362	 2	 63.06993	 40.6	 0.0	 0.0	 1	    1.00676	    0.00000	 220.0	 1	    1.11352	    0.90000;
	363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	364	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.01388	    0.00000	 220.0	 1	    1.12776	    0.90000;
	365	 2	 13.6151	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	366	 1	 254.7	 79.4	 0.0	 0.0	 1	    1.01256	    0.00000	 380.0	 1	    1.12511	    0.90000;
	367	 2	 -0.6	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	368	 1	 129.1	 7.4	 0.0	 0.0	 1	    1.00839	    0.00000	 220.0	 1	    1.11677	    0.90000;
	369	 2	 174.2	 52.0	 0.0	 0.0	 1	    1.01616	    0.00000	 220.0	 1	    1.13232	    0.90000;
	370	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	371	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00808	    0.00000	 220.0	 1	    1.11617	    0.90000;
	372	 1	 20.52275	 10.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	373	 1	 4.705216	 0.7	 0.0	 0.0	 1	    1.01318	    0.00000	 220.0	 1	    1.12637	    0.90000;
	374	 1	 70.67836	 13.5	 0.0	 0.0	 1	    1.01255	    0.00000	 220.0	 1	    1.12509	    0.90000;
	375	 1	 187.1886	 1.8	 0.0	 0.0	 1	    1.01066	    0.00000	 220.0	 1	    1.12131	    0.90000;
	376	 1	 24.42708	 8.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	377	 1	 8.809768	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	378	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01392	    0.00000	 380.0	 1	    1.12785	    0.90000;
	379	 1	 33.73741	 20.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	380	 1	 35.83974	 12.5	 0.0	 0.0	 1	    1.00904	    0.00000	 110.0	 1	    1.11808	    0.90000;
	381	 2	 0.0	 0.0	 0.226002	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	382	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	383	 1	 123.1	 6.5	 0.0	 0.0	 1	    1.02551	    0.00000	 220.0	 1	    1.15102	    0.90000;
	384	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03228	    0.00000	 380.0	 1	    1.16457	    0.90000;
	385	 1	 0.100111	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	386	 1	 26.92986	 -22.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	387	 1	 29.03219	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	388	 2	 331.4	 164.8	 0.0	 0.0	 1	    1.02110	    0.00000	 220.0	 1	    1.14220	    0.90000;
	389	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02228	    0.00000	 380.0	 1	    1.14456	    0.90000;
	390	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00390	    0.00000	 380.0	 1	    1.10780	    0.90000;
	391	 1	 33.13674	 11.6	 0.0	 0.0	 1	    1.02159	    0.00000	 110.0	 1	    1.14318	    0.90000;
	392	 1	 -264.0	 63.3	 0.0	 0.0	 1	    1.02795	    0.00000	 380.0	 1	    1.15590	    0.90000;
	393	 1	 69.07658	 24.0	 0.0	 0.0	 1	    1.02199	    0.00000	 220.0	 1	    1.14398	    0.90000;
	394	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	395	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00310	    0.00000	 220.0	 1	    1.10621	    0.90000;
	396	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01739	    0.00000	 220.0	 1	    1.13478	    0.90000;
	397	 1	 0.0	 0.0	 0.209995	 0.0	 1	    1.01601	    0.00000	 380.0	 1	    1.13203	    0.90000;
	398	 2	 44.84972	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	399	 1	 -12.614	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	400	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00879	    0.00000	 220.0	 1	    1.11758	    0.90000;
	401	 1	 36.74074	 10.3	 0.0	 0.0	 1	    1.00388	    0.00000	 220.0	 1	    1.10776	    0.90000;
	402	 2	 105.9	 45.7	 0.0	 0.0	 1	    1.01483	    0.00000	 110.0	 1	    1.12967	    0.90000;
	403	 2	 2.202442	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	404	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	405	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01486	    0.00000	 380.0	 1	    1.12972	    0.90000;
	406	 1	 42.04662	 43.0	 0.0	 0.0	 1	    1.00651	    0.00000	 150.0	 1	    1.11303	    0.90000;
	407	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	408	 2	 104.4	 27.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	409	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01748	    0.00000	 380.0	 1	    1.13497	    0.90000;
	410	 2	 281.2	 9.1	 0.0	 0.0	 1	    1.02835	    0.00000	 220.0	 1	    1.15670	    0.90000;
	411	 2	 70.57825	 28.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	412	 1	 1.801998	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	413	 1	 0.0	 0.0	 0.169733	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	414	 1	 97.0	 40.3	 0.0	 0.0	 1	    1.00479	    0.00000	 220.0	 1	    1.10958	    0.90000;
	415	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	416	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	417	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	418	 1	 24.32697	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	419	 1	 44.74961	 0.9	 0.0	 0.0	 1	    1.01609	    0.00000	 220.0	 1	    1.13218	    0.90000;
	420	 1	 0.0	 0.0	 0.119	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	421	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	422	 1	 9.00999	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	423	 1	 81.0899	 48.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	424	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	425	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01208	    0.00000	 220.0	 1	    1.12415	    0.90000;
	426	 1	 336.2	 131.6	 0.0	 0.0	 1	    1.02501	    0.00000	 150.0	 1	    1.15002	    0.90000;
	427	 2	 -6.60733	 1.4	 0.0	 0.0	 1	    1.00506	    0.00000	 220.0	 1	    1.11013	    0.90000;
	428	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	429	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00974	    0.00000	 380.0	 1	    1.11947	    0.90000;
	430	 1	 67.3	 94.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	431	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02912	    0.00000	 380.0	 1	    1.15825	    0.90000;
	432	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	433	 1	 16.61843	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	434	 1	 5.806438	 1.1	 0.0	 0.0	 1	    1.01936	    0.00000	 110.0	 1	    1.13871	    0.90000;
	435	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00725	    0.00000	 220.0	 1	    1.11450	    0.90000;
	436	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	437	 1	 57.26349	 15.6	 0.0	 0.0	 1	    1.00267	    0.00000	 220.0	 1	    1.10534	    0.90000;
	438	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	439	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02526	    0.00000	 380.0	 1	    1.15051	    0.90000;
	440	 1	 7.00777	 2.0	 0.0	 0.0	 1	    1.00459	    0.00000	 150.0	 1	    1.10919	    0.90000;
	441	 2	 10.41154	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	442	 2	 115.9	 14.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	443	 1	 20.52275	 4.0	 0.0	 0.0	 1	    1.01914	    0.00000	 220.0	 1	    1.13828	    0.90000;
	444	 2	 0.0	 0.0	 0.265944	 490.5867	 1	    1.01153	    0.00000	 380.0	 1	    1.12307	    0.90000;
	445	 1	 68.17558	 22.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	446	 1	 23.22575	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	447	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	448	 1	 181.7	 51.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	450	 1	 31.23463	 11.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	451	 2	 423.2	 55.3	 0.0	 0.0	 1	    1.00871	    0.00000	 380.0	 1	    1.11742	    0.90000;
	452	 1	 144.4	 35.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	453	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	454	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01478	    0.00000	 220.0	 1	    1.12956	    0.90000;
	455	 1	 4.1	 -607.0	 0.248006	 0.0	 1	    1.01607	    0.00000	 380.0	 1	    1.13215	    0.90000;
	456	 1	 18.62065	 6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	457	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03391	    0.00000	 380.0	 1	    1.16782	    0.90000;
	458	 1	 23.42597	 8.5	 0.0	 0.0	 1	    1.00742	    0.00000	 110.0	 1	    1.11484	    0.90000;
	459	 2	 43.7485	 13.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	460	 1	 77.28568	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	461	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01262	    0.00000	 220.0	 1	    1.12523	    0.90000;
	462	 2	 0.0	 0.0	 0.26688	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	463	 1	 10.11121	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	464	 1	 57.46371	 17.1	 0.0	 0.0	 1	    1.01273	    0.00000	 220.0	 1	    1.12547	    0.90000;
	465	 1	 9.610656	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	466	 2	 -195.216	 -19.0	 0.0	 0.0	 1	    1.01348	    0.00000	 220.0	 1	    1.12695	    0.90000;
	467	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03884	    0.00000	 220.0	 1	    1.17768	    0.90000;
	468	 1	 7.708547	 16.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	469	 2	 602.9	 201.4	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	470	 1	 207.2	 9.4	 0.0	 0.0	 1	    1.00506	    0.00000	 220.0	 1	    1.11012	    0.90000;
	471	 1	 118.5	 20.4	 0.0	 0.0	 1	    1.01162	    0.00000	 220.0	 1	    1.12323	    0.90000;
	472	 1	 14.71632	 5.3	 0.0	 0.0	 1	    1.00546	    0.00000	 110.0	 1	    1.11092	    0.90000;
	473	 1	 11.61288	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	474	 1	 189.9	 74.7	 0.0	 0.0	 1	    1.02306	    0.00000	 150.0	 1	    1.14611	    0.90000;
	475	 1	 36.54051	 27.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	476	 1	 176.7	 25.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	477	 1	 277.7	 45.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00780	    0.00000	 380.0	 1	    1.11561	    0.90000;
	480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01055	    0.00000	 380.0	 1	    1.12110	    0.90000;
	481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	482	 1	 16.51831	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	483	 1	 11.51276	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	484	 1	 87.79734	 -1.4	 0.085004	 0.0	 1	    1.02607	    0.00000	 380.0	 1	    1.15213	    0.90000;
	485	 1	 27.53052	 17.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	486	 1	 21.02331	 13.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	487	 1	 57.96427	 18.9	 0.0	 0.0	 1	    1.00476	    0.00000	 150.0	 1	    1.10952	    0.90000;
	488	 1	 166.9	 86.1	 0.0	 210.9002	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	489	 1	 2.00222	 0.7	 0.0	 0.0	 1	    1.01373	    0.00000	 110.0	 1	    1.12746	    0.90000;
	490	 1	 79.68835	 39.6	 0.0	 0.0	 1	    1.01687	    0.00000	 380.0	 1	    1.13374	    0.90000;
	491	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01280	    0.00000	 220.0	 1	    1.12559	    0.90000;
	492	 1	 0.0	 0.0	 0.0	 -16.557	 1	    1.04196	    0.00000	 150.0	 1	    1.18393	    0.90000;
	493	 1	 30.0333	 14.0	 0.0	 0.0	 1	    1.02049	    0.00000	 220.0	 1	    1.14099	    0.90000;
	494	 1	 30.9343	 8.9	 0.0	 0.0	 1	    1.02305	    0.00000	 110.0	 1	    1.14609	    0.90000;
	495	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02651	    0.00000	 220.0	 1	    1.15303	    0.90000;
	496	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00730	    0.00000	 220.0	 1	    1.11460	    0.90000;
	497	 1	 17.71965	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	498	 1	 180.8	 90.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	499	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01841	    0.00000	 220.0	 1	    1.13682	    0.90000;
	500	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01207	    0.00000	 220.0	 1	    1.12415	    0.90000;
	501	 1	 16.51831	 9.0	 0.0	 0.0	 1	    1.01920	    0.00000	 220.0	 1	    1.13840	    0.90000;
	502	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00594	    0.00000	 220.0	 1	    1.11189	    0.90000;
	503	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	504	 1	 42.24684	 16.6	 0.0	 0.0	 1	    1.02472	    0.00000	 150.0	 1	    1.14945	    0.90000;
	505	 1	 3.804218	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	506	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 220.0	 1	    1.13333	    0.90000;
	507	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	508	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	509	 2	 58.56493	 -0.1	 0.0	 0.0	 1	    1.03585	    0.00000	 220.0	 1	    1.17170	    0.90000;
	510	 1	 198.4	 32.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	511	 1	 5.806438	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	512	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01866	    0.00000	 380.0	 1	    1.13732	    0.90000;
	513	 1	 20.22242	 7.3	 0.0	 0.0	 1	    1.01631	    0.00000	 110.0	 1	    1.13262	    0.90000;
	514	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03049	    0.00000	 380.0	 1	    1.16098	    0.90000;
	515	 1	 47.95317	 29.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	516	 1	 120.6337	 56.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	517	 1	 27.13008	 8.9	 0.0	 0.0	 1	    1.01511	    0.00000	 110.0	 1	    1.13023	    0.90000;
	518	 1	 10.71188	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	519	 1	 82.89191	 26.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	520	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00890	    0.00000	 220.0	 1	    1.11780	    0.90000;
	521	 1	 108.6	 38.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	522	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03064	    0.00000	 220.0	 1	    1.16128	    0.90000;
	523	 2	 166.0	 -8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	524	 1	 17.3192	 6.6	 0.0	 0.0	 1	    1.00703	    0.00000	 380.0	 1	    1.11406	    0.90000;
	525	 1	 322.7	 11.9	 0.0	 0.0	 1	    1.00567	    0.00000	 380.0	 1	    1.11135	    0.90000;
	526	 1	 51.15672	 18.2	 0.0	 0.0	 1	    1.00652	    0.00000	 220.0	 1	    1.11303	    0.90000;
	527	 2	 303.6	 79.8	 0.0	 0.0	 1	    1.00565	    0.00000	 220.0	 1	    1.11129	    0.90000;
	528	 1	 151.2	 72.4	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	529	 1	 21.12342	 8.3	 0.0	 0.0	 1	    1.02257	    0.00000	 150.0	 1	    1.14514	    0.90000;
	530	 1	 9.510545	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	531	 2	 3.00333	 0.2	 0.0	 0.0	 1	    1.01310	    0.00000	 220.0	 1	    1.12620	    0.90000;
	532	 1	 1.501665	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	533	 1	 27.02997	 9.8	 0.0	 0.0	 1	    1.00397	    0.00000	 110.0	 1	    1.10795	    0.90000;
	534	 2	 300.1	 126.3	 0.0	 0.0	 1	    1.00735	    0.00000	 380.0	 1	    1.11471	    0.90000;
	535	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	537	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01200	    0.00000	 380.0	 1	    1.12399	    0.90000;
	538	 1	 67.57492	 17.0	 0.0	 0.0	 1	    1.00635	    0.00000	 220.0	 1	    1.11270	    0.90000;
	539	 1	 47.55272	 5.3	 0.0	 0.0	 1	    1.00578	    0.00000	 220.0	 1	    1.11156	    0.90000;
	540	 1	 24.82753	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	541	 1	 33.33696	 15.7	 0.0	 0.0	 1	    1.02788	    0.00000	 380.0	 1	    1.15575	    0.90000;
	542	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	543	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	544	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00539	    0.00000	 380.0	 1	    1.11078	    0.90000;
	545	 1	 140.6	 42.6	 0.0	 0.0	 1	    1.01641	    0.00000	 220.0	 1	    1.13282	    0.90000;
	546	 1	 110.8	 -8.8	 0.0	 0.0	 1	    1.00944	    0.00000	 220.0	 1	    1.11887	    0.90000;
	547	 1	 48.9	 28.6	 0.0	 0.0	 1	    1.02329	    0.00000	 380.0	 1	    1.14658	    0.90000;
	548	 1	 33.23685	 4.4	 0.0	 0.0	 1	    1.00608	    0.00000	 380.0	 1	    1.11217	    0.90000;
	549	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	550	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02448	    0.00000	 330.0	 1	    1.14895	    0.90000;
	551	 1	 150.9	 10.4	 0.0	 0.0	 1	    1.01564	    0.00000	 220.0	 1	    1.13129	    0.90000;
	552	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	553	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	554	 1	 0.0	 0.0	 0.085901	 0.0	 1	    1.01664	    0.00000	 380.0	 1	    1.13328	    0.90000;
	555	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	556	 1	 18.5	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	557	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03582	    0.00000	 220.0	 1	    1.17165	    0.90000;
	558	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02080	    0.00000	 220.0	 1	    1.14159	    0.90000;
	559	 2	 8.809768	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	560	 2	 0.900999	 74.1	 0.0	 0.0	 1	    1.00945	    0.00000	 380.0	 1	    1.11890	    0.90000;
	561	 1	 72.88081	 14.4	 0.0	 0.0	 1	    1.01600	    0.00000	 220.0	 1	    1.13201	    0.90000;
	562	 1	 15.41709	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	563	 1	 21.42375	 8.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	564	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00847	    0.00000	 380.0	 1	    1.11694	    0.90000;
	565	 1	 111.4	 36.5	 0.0	 20.0	 1	    1.02281	    0.00000	 380.0	 1	    1.14562	    0.90000;
	566	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	567	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	568	 1	 116.8	 60.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	569	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	570	 1	 177.2	 32.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	571	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01273	    0.00000	 380.0	 1	    1.12546	    0.90000;
	572	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00597	    0.00000	 150.0	 1	    1.11194	    0.90000;
	574	 1	 2.502775	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	575	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	576	 2	 7.908769	 2.5	 0.0	 0.0	 1	    1.00903	    0.00000	 110.0	 1	    1.11807	    0.90000;
	577	 2	 202.0	 24.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	578	 2	 179.9	 -18.1	 0.0	 0.0	 1	    1.02234	    0.00000	 220.0	 1	    1.14468	    0.90000;
	579	 1	 102.0	 26.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	580	 2	 46.55161	 18.4	 0.0	 0.0	 1	    1.01769	    0.00000	 220.0	 1	    1.13538	    0.90000;
	581	 2	 -24.6273	 159.9	 0.0	 0.0	 1	    1.01330	    0.00000	 380.0	 1	    1.12659	    0.90000;
	582	 1	 15.5172	 6.3	 0.0	 0.0	 1	    1.01958	    0.00000	 150.0	 1	    1.13917	    0.90000;
	583	 1	 26.32919	 9.5	 0.0	 0.0	 1	    1.00466	    0.00000	 110.0	 1	    1.10931	    0.90000;
	584	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00323	    0.00000	 150.0	 1	    1.10646	    0.90000;
	585	 1	 48.05328	 15.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	586	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00420	    0.00000	 220.0	 1	    1.10840	    0.90000;
	587	 1	 40.9454	 19.2	 0.0	 0.0	 1	    1.00692	    0.00000	 220.0	 1	    1.11383	    0.90000;
	588	 1	 17.21909	 4.4	 0.0	 0.0	 1	    1.01359	    0.00000	 110.0	 1	    1.12719	    0.90000;
	589	 2	 79.98869	 10.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	590	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01383	    0.00000	 220.0	 1	    1.12766	    0.90000;
	591	 1	 10.31143	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	592	 1	 205.6	 74.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	593	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00336	    0.00000	 220.0	 1	    1.10673	    0.90000;
	594	 1	 65.27237	 30.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	595	 1	 258.4	 66.7	 0.0	 0.0	 1	    1.01999	    0.00000	 220.0	 1	    1.13997	    0.90000;
	596	 1	 0.0	 0.0	 0.174464	 20.0	 1	    1.01716	    0.00000	 380.0	 1	    1.13431	    0.90000;
	597	 1	 584.3	 166.3	 0.0	 0.0	 1	    1.02593	    0.00000	 380.0	 1	    1.15187	    0.90000;
	598	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01607	    0.00000	 380.0	 1	    1.13214	    0.90000;
	599	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00506	    0.00000	 380.0	 1	    1.11011	    0.90000;
	600	 1	 0.0	 0.0	 0.119999	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	601	 1	 38.04218	 11.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	602	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00391	    0.00000	 220.0	 1	    1.10781	    0.90000;
	603	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01212	    0.00000	 380.0	 1	    1.12423	    0.90000;
	604	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	605	 1	 0.0	 0.0	 0.0	 -15.6219	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	606	 1	 5.506105	 17.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	607	 1	 0.0	 0.0	 0.0	 10.91344	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	608	 2	 0.0	 -0.3	 0.0	 0.0	 1	    1.01471	    0.00000	 380.0	 1	    1.12941	    0.90000;
	609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	610	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03536	    0.00000	 380.0	 1	    1.17071	    0.90000;
	611	 1	 5.105661	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	612	 1	 109.3	 35.4	 0.0	 0.0	 1	    1.01972	    0.00000	 150.0	 1	    1.13944	    0.90000;
	613	 1	 30.83419	 10.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	614	 1	 232.1	 89.8	 0.0	 0.0	 1	    1.00603	    0.00000	 220.0	 1	    1.11206	    0.90000;
	615	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01867	    0.00000	 220.0	 1	    1.13735	    0.90000;
	616	 1	 79.58824	 50.5	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	617	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01869	    0.00000	 380.0	 1	    1.13737	    0.90000;
	618	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02744	    0.00000	 220.0	 1	    1.15488	    0.90000;
	619	 1	 169.8	 55.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	620	 1	 60.0666	 28.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	621	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03227	    0.00000	 380.0	 1	    1.16455	    0.90000;
	622	 2	 42.34695	 13.1	 0.0	 0.0	 1	    1.00449	    0.00000	 220.0	 1	    1.10898	    0.90000;
	623	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01832	    0.00000	 220.0	 1	    1.13665	    0.90000;
	624	 1	 -3.40377	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	625	 1	 124.8	 23.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	626	 1	 22.42486	 8.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	627	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03868	    0.00000	 120.0	 1	    1.17737	    0.90000;
	628	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02374	    0.00000	 380.0	 1	    1.14749	    0.90000;
	629	 1	 0.0	 0.0	 0.124999	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	630	 1	 96.40689	 26.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	631	 2	 13.01443	 8.1	 0.0	 0.0	 1	    1.01009	    0.00000	 150.0	 1	    1.12018	    0.90000;
	632	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03095	    0.00000	 380.0	 1	    1.16189	    0.90000;
	633	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	634	 1	 36.54051	 8.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	635	 1	 12.7141	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	636	 1	 20.32253	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	637	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	638	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02626	    0.00000	 380.0	 1	    1.15252	    0.90000;
	639	 1	 41.04551	 14.3	 0.0	 0.0	 1	    1.00920	    0.00000	 220.0	 1	    1.11840	    0.90000;
	640	 1	 114.8	 22.8	 0.0	 0.0	 1	    1.00285	    0.00000	 220.0	 1	    1.10570	    0.90000;
	641	 1	 83.99313	 21.2	 0.0	 0.0	 1	    1.02222	    0.00000	 220.0	 1	    1.14444	    0.90000;
	642	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	643	 2	 0.0	 0.0	 0.0	 -129.525	 1	    1.03208	    0.00000	 380.0	 1	    1.16416	    0.90000;
	644	 1	 76.38469	 5.1	 0.0	 0.0	 1	    1.01035	    0.00000	 220.0	 1	    1.12069	    0.90000;
	645	 2	 423.4	 215.2	 0.0	 0.0	 1	    1.01762	    0.00000	 380.0	 1	    1.13524	    0.90000;
	646	 1	 110.4	 41.9	 0.0	 0.0	 1	    1.01199	    0.00000	 150.0	 1	    1.12398	    0.90000;
	647	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	648	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01415	    0.00000	 380.0	 1	    1.12830	    0.90000;
	649	 1	 29.63285	 10.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	650	 1	 4.504995	 -5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	651	 2	 152.3	 46.2	 0.0	 0.0	 1	    1.01186	    0.00000	 220.0	 1	    1.12371	    0.90000;
	652	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00885	    0.00000	 220.0	 1	    1.11771	    0.90000;
	653	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	654	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01143	    0.00000	 220.0	 1	    1.12285	    0.90000;
	655	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02831	    0.00000	 150.0	 1	    1.15661	    0.90000;
	656	 1	 30.83419	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	657	 1	 0.0	 0.0	 0.0	 -25.7162	 1	    1.03110	    0.00000	 380.0	 1	    1.16219	    0.90000;
	658	 1	 400.3	 189.9	 0.0	 0.0	 1	    1.01397	    0.00000	 220.0	 1	    1.12794	    0.90000;
	659	 2	 34.93874	 -32.3	 0.0	 0.0	 1	    1.01610	    0.00000	 380.0	 1	    1.13220	    0.90000;
	660	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	661	 1	 20.62287	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	662	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02063	    0.00000	 380.0	 1	    1.14127	    0.90000;
	663	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01358	    0.00000	 380.0	 1	    1.12717	    0.90000;
	664	 1	 58.36471	 10.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	665	 2	 206.0	 110.9	 0.0	 0.0	 1	    1.00572	    0.00000	 220.0	 1	    1.11145	    0.90000;
	666	 2	 60.26682	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	667	 1	 8.108991	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	668	 2	 11.21221	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	669	 2	 1.301443	 59.6	 0.0	 0.0	 1	    1.02074	    0.00000	 380.0	 1	    1.14148	    0.90000;
	670	 1	 22.22464	 13.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	671	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	672	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01841	    0.00000	 220.0	 1	    1.13683	    0.90000;
	673	 1	 5.00555	 2.0	 0.0	 0.0	 1	    1.00519	    0.00000	 220.0	 1	    1.11037	    0.90000;
	674	 1	 6.507215	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	675	 1	 90.40023	 15.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	676	 1	 2.502775	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	677	 2	 69.97758	 21.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	678	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01887	    0.00000	 220.0	 1	    1.13773	    0.90000;
	679	 2	 16.51831	 7.8	 0.0	 0.0	 1	    1.00913	    0.00000	 220.0	 1	    1.11826	    0.90000;
	680	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01909	    0.00000	 220.0	 1	    1.13819	    0.90000;
	681	 2	 142.6	 50.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	682	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01119	    0.00000	 220.0	 1	    1.12237	    0.90000;
	683	 1	 1.902109	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	684	 1	 132.1	 32.4	 0.0	 0.0	 1	    1.01700	    0.00000	 380.0	 1	    1.13400	    0.90000;
	685	 1	 36.74074	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	686	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01622	    0.00000	 380.0	 1	    1.13245	    0.90000;
	687	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	688	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02605	    0.00000	 220.0	 1	    1.15210	    0.90000;
	689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00817	    0.00000	 110.0	 1	    1.11633	    0.90000;
	690	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00644	    0.00000	 110.0	 1	    1.11288	    0.90000;
	691	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	692	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01679	    0.00000	 220.0	 1	    1.13358	    0.90000;
	693	 2	 223.4	 107.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	694	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02208	    0.00000	 220.0	 1	    1.14416	    0.90000;
	695	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01949	    0.00000	 220.0	 1	    1.13898	    0.90000;
	696	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99568	    0.00000	 150.0	 1	    1.10000	    0.89136;
	697	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	698	 2	 153.0	 40.0	 0.0	 0.0	 1	    1.01800	    0.00000	 220.0	 1	    1.13600	    0.90000;
	699	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04242	    0.00000	 220.0	 1	    1.18485	    0.90000;
	700	 1	 46.15117	 20.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	701	 1	 343.9	 141.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	702	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	703	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02525	    0.00000	 150.0	 1	    1.15050	    0.90000;
	704	 2	 142.2	 29.6	 0.0	 0.0	 1	    1.01764	    0.00000	 220.0	 1	    1.13528	    0.90000;
	705	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01837	    0.00000	 220.0	 1	    1.13674	    0.90000;
	706	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01788	    0.00000	 380.0	 1	    1.13576	    0.90000;
	707	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	708	 1	 34.03774	 11.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	711	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02293	    0.00000	 150.0	 1	    1.14586	    0.90000;
	712	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00583	    0.00000	 220.0	 1	    1.11166	    0.90000;
	713	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	714	 1	 18.01998	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	715	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01399	    0.00000	 220.0	 1	    1.12798	    0.90000;
	716	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02306	    0.00000	 110.0	 1	    1.14612	    0.90000;
	717	 2	 52.05772	 0.0	 0.0	 0.0	 1	    1.02434	    0.00000	 380.0	 1	    1.14868	    0.90000;
	718	 1	 295.3	 41.9	 0.0	 0.0	 1	    1.01950	    0.00000	 150.0	 1	    1.13900	    0.90000;
	719	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	720	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01488	    0.00000	 220.0	 1	    1.12976	    0.90000;
	721	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	722	 1	 2.0	 114.6	 0.0	 0.0	 1	    1.01293	    0.00000	 220.0	 1	    1.12586	    0.90000;
	723	 1	 235.2	 41.1	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	724	 1	 26.72964	 10.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	725	 1	 50.55605	 18.0	 0.0	 0.0	 1	    1.00814	    0.00000	 220.0	 1	    1.11629	    0.90000;
	726	 1	 9.710767	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	727	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02618	    0.00000	 380.0	 1	    1.15237	    0.90000;
	728	 2	 200.4	 60.5	 0.0	 0.0	 1	    1.01097	    0.00000	 220.0	 1	    1.12194	    0.90000;
	729	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03292	    0.00000	 220.0	 1	    1.16583	    0.90000;
	730	 1	 124.5	 29.6	 0.0	 0.0	 1	    1.00797	    0.00000	 220.0	 1	    1.11594	    0.90000;
	731	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	732	 2	 222.5	 262.8	 0.0	 0.0	 1	    1.01402	    0.00000	 380.0	 1	    1.12804	    0.90000;
	733	 1	 24.52719	 8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	734	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01930	    0.00000	 380.0	 1	    1.13859	    0.90000;
	735	 1	 0.0	 0.0	 0.0	 10.61976	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	736	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	737	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	738	 1	 287.7	 16.3	 0.0	 0.0	 1	    1.00563	    0.00000	 380.0	 1	    1.11127	    0.90000;
	739	 2	 22.12453	 7.5	 0.0	 0.0	 1	    1.02332	    0.00000	 110.0	 1	    1.14664	    0.90000;
	740	 1	 234.7	 -12.0	 0.0	 0.0	 1	    1.01736	    0.00000	 380.0	 1	    1.13472	    0.90000;
	741	 1	 333.1	 17.5	 0.0	 0.0	 1	    1.00316	    0.00000	 380.0	 1	    1.10632	    0.90000;
	742	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	743	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02739	    0.00000	 220.0	 1	    1.15478	    0.90000;
	744	 1	 0.0	 0.0	 0.0	 -14.7192	 1	    1.04367	    0.00000	 150.0	 1	    1.18734	    0.90000;
	745	 1	 121.9	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	746	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02424	    0.00000	 380.0	 1	    1.14848	    0.90000;
	747	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	748	 1	 31.93541	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	749	 1	 167.8	 77.0	 0.0	 0.0	 1	    1.01429	    0.00000	 380.0	 1	    1.12859	    0.90000;
	750	 1	 113.6	 122.7	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	751	 1	 303.1	 75.5	 0.0	 0.0	 1	    1.00802	    0.00000	 380.0	 1	    1.11605	    0.90000;
	752	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	753	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	754	 1	 15.01665	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	755	 1	 52.7585	 17.2	 0.0	 0.0	 1	    1.01813	    0.00000	 220.0	 1	    1.13626	    0.90000;
	756	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01021	    0.00000	 380.0	 1	    1.12043	    0.90000;
	757	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02205	    0.00000	 220.0	 1	    1.14411	    0.90000;
	758	 1	 615.8	 286.7	 0.0	 0.0	 1	    1.02008	    0.00000	 150.0	 1	    1.14015	    0.90000;
	759	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01770	    0.00000	 380.0	 1	    1.13540	    0.90000;
	760	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	761	 1	 0.0	 0.0	 0.148479	 0.0	 1	    1.02556	    0.00000	 380.0	 1	    1.15112	    0.90000;
	762	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	763	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	764	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01414	    0.00000	 380.0	 1	    1.12827	    0.90000;
	765	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	766	 1	 159.2	 59.9	 0.0	 0.0	 1	    1.01987	    0.00000	 380.0	 1	    1.13975	    0.90000;
	767	 2	 62.7696	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	768	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01405	    0.00000	 380.0	 1	    1.12810	    0.90000;
	769	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	770	 2	 34.43818	 4.4	 0.0	 0.0	 1	    1.01218	    0.00000	 220.0	 1	    1.12436	    0.90000;
	771	 1	 190.0	 43.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	772	 1	 49.95539	 7.5	 0.0	 0.0	 1	    1.00692	    0.00000	 220.0	 1	    1.11383	    0.90000;
	773	 1	 10.0111	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	774	 1	 -28.9321	 9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	775	 1	 21.72409	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	776	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02137	    0.00000	 380.0	 1	    1.14275	    0.90000;
	777	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00854	    0.00000	 150.0	 1	    1.11708	    0.90000;
	778	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00809	    0.00000	 110.0	 1	    1.11617	    0.90000;
	779	 1	 36.4404	 12.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	780	 1	 1.301443	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	781	 1	 43.44817	 26.9	 0.0	 0.0	 1	    1.00388	    0.00000	 150.0	 1	    1.10775	    0.90000;
	782	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	783	 1	 25.12786	 14.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	784	 1	 13.81532	 5.0	 0.0	 0.0	 1	    1.01437	    0.00000	 110.0	 1	    1.12874	    0.90000;
	785	 1	 94.20444	 5.5	 0.0	 0.0	 1	    1.01105	    0.00000	 220.0	 1	    1.12210	    0.90000;
	786	 1	 110.0	 3.4	 0.0	 0.0	 1	    1.01895	    0.00000	 220.0	 1	    1.13791	    0.90000;
	787	 2	 120.7	 -16.9	 0.0	 0.0	 1	    1.01823	    0.00000	 220.0	 1	    1.13645	    0.90000;
	788	 1	 143.9	 123.2	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	789	 1	 0.0	 0.0	 0.0	 11.12461	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	790	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02997	    0.00000	 380.0	 1	    1.15995	    0.90000;
	791	 1	 42.24684	 13.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	792	 1	 2.00222	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	793	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01682	    0.00000	 150.0	 1	    1.13364	    0.90000;
	794	 1	 7.708547	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	795	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03997	    0.00000	 220.0	 1	    1.17993	    0.90000;
	796	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	797	 1	 394.9	 77.0	 0.0	 0.0	 1	    1.01142	    0.00000	 380.0	 1	    1.12285	    0.90000;
	798	 1	 192.5	 78.3	 0.0	 0.0	 1	    1.01524	    0.00000	 220.0	 1	    1.13047	    0.90000;
	799	 1	 13.81532	 5.0	 0.0	 0.0	 1	    1.01748	    0.00000	 110.0	 1	    1.13496	    0.90000;
	800	 1	 23.02553	 14.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	801	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	802	 1	 0.0	 0.0	 0.34231	 0.0	 1	    1.02191	    0.00000	 380.0	 1	    1.14383	    0.90000;
	803	 2	 17.41931	 11.9	 0.122998	 0.0	 1	    1.00937	    0.00000	 220.0	 1	    1.11875	    0.90000;
	804	 1	 3.904329	 1.4	 0.0	 0.0	 1	    1.00392	    0.00000	 110.0	 1	    1.10783	    0.90000;
	805	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01911	    0.00000	 220.0	 1	    1.13822	    0.90000;
	806	 2	 0.0	 0.0	 0.0	 20.0	 1	    1.03180	    0.00000	 380.0	 1	    1.16360	    0.90000;
	807	 2	 452.5	 113.2	 0.0	 0.0	 1	    1.01049	    0.00000	 220.0	 1	    1.12097	    0.90000;
	808	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02832	    0.00000	 220.0	 1	    1.15664	    0.90000;
	809	 2	 24.92764	 13.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	810	 1	 0.0	 0.0	 0.259062	 0.0	 1	    1.02125	    0.00000	 380.0	 1	    1.14250	    0.90000;
	811	 1	 25.62842	 7.9	 0.0	 0.0	 1	    1.00882	    0.00000	 110.0	 1	    1.11764	    0.90000;
	812	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03061	    0.00000	 380.0	 1	    1.16122	    0.90000;
	813	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01525	    0.00000	 220.0	 1	    1.13050	    0.90000;
	814	 1	 0.0	 0.0	 0.0	 11.74494	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	815	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	816	 1	 82.69168	 20.1	 0.0	 0.0	 1	    1.03254	    0.00000	 220.0	 1	    1.16508	    0.90000;
	817	 1	 146.9	 60.6	 0.0	 0.0	 1	    1.01769	    0.00000	 220.0	 1	    1.13539	    0.90000;
	818	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00779	    0.00000	 380.0	 1	    1.11558	    0.90000;
	819	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	820	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02102	    0.00000	 220.0	 1	    1.14204	    0.90000;
	821	 1	 125.9	 -0.5	 0.0	 0.0	 1	    1.02162	    0.00000	 220.0	 1	    1.14324	    0.90000;
	822	 1	 12.61399	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	823	 1	 13.21465	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	824	 1	 22.02442	 13.2	 0.0	 0.0	 1	    1.00757	    0.00000	 150.0	 1	    1.11513	    0.90000;
	825	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00600	    0.00000	 380.0	 1	    1.11200	    0.90000;
	826	 1	 0.0	 0.0	 0.0	 -50.7692	 1	    1.00955	    0.00000	 380.0	 1	    1.11910	    0.90000;
	827	 1	 24.52719	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	828	 2	 0.800888	 18.6	 0.0	 0.0	 1	    1.01406	    0.00000	 220.0	 1	    1.12811	    0.90000;
	829	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	830	 1	 110.1	 29.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	831	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	832	 1	 34.43818	 8.5	 0.0	 0.0	 1	    1.01995	    0.00000	 220.0	 1	    1.13990	    0.90000;
	833	 1	 0.0	 0.0	 0.117	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	834	 1	 15.21687	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	835	 1	 62.06882	 14.7	 0.0	 0.0	 1	    1.01878	    0.00000	 220.0	 1	    1.13756	    0.90000;
	836	 1	 10.0111	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	837	 1	 8.00888	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	838	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01195	    0.00000	 220.0	 1	    1.12390	    0.90000;
	839	 1	 112.9	 19.3	 0.0	 0.0	 1	    1.00911	    0.00000	 150.0	 1	    1.11822	    0.90000;
	840	 1	 43.7485	 12.4	 0.0	 0.0	 1	    1.01090	    0.00000	 220.0	 1	    1.12181	    0.90000;
	841	 2	 1.101221	 61.2	 0.0	 0.0	 1	    1.02290	    0.00000	 380.0	 1	    1.14580	    0.90000;
	842	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	843	 1	 77.58602	 12.3	 0.0	 0.0	 1	    1.00651	    0.00000	 220.0	 1	    1.11303	    0.90000;
	844	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	845	 1	 2.502775	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	846	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01683	    0.00000	 220.0	 1	    1.13367	    0.90000;
	847	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	848	 1	 -12.5139	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	849	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	850	 1	 30.33363	 10.5	 0.0	 0.0	 1	    1.02029	    0.00000	 220.0	 1	    1.14058	    0.90000;
	851	 1	 50.0555	 16.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	852	 1	 26.02886	 9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	853	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01645	    0.00000	 380.0	 1	    1.13290	    0.90000;
	854	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	855	 1	 30.33363	 11.0	 0.0	 0.0	 1	    1.00358	    0.00000	 110.0	 1	    1.10717	    0.90000;
	856	 1	 0.200222	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	857	 1	 189.1	 -11.9	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	858	 1	 90.70056	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	859	 1	 15.81754	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	860	 1	 4.805328	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	861	 1	 69.07658	 22.6	 0.0	 0.0	 1	    1.01559	    0.00000	 150.0	 1	    1.13119	    0.90000;
	862	 1	 0.5	 -271.9	 0.0	 0.0	 1	    1.01279	    0.00000	 380.0	 1	    1.12558	    0.90000;
	863	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01370	    0.00000	 150.0	 1	    1.12741	    0.90000;
	864	 2	 118.8	 -8.2	 0.0	 0.0	 1	    1.03153	    0.00000	 380.0	 1	    1.16305	    0.90000;
	865	 1	 66.27348	 13.6	 0.0	 0.0	 1	    1.01003	    0.00000	 220.0	 1	    1.12006	    0.90000;
	866	 1	 244.2	 152.7	 0.0	 0.0	 1	    1.01818	    0.00000	 150.0	 1	    1.13637	    0.90000;
	867	 1	 19.42153	 11.6	 0.0	 0.0	 1	    1.00928	    0.00000	 110.0	 1	    1.11856	    0.90000;
	868	 1	 65.77292	 16.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	869	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01861	    0.00000	 380.0	 1	    1.13722	    0.90000;
	870	 1	 166.6	 8.1	 0.0	 0.0	 1	    1.01030	    0.00000	 380.0	 1	    1.12061	    0.90000;
	871	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03391	    0.00000	 380.0	 1	    1.16781	    0.90000;
	872	 1	 32.93652	 20.4	 0.0	 0.0	 1	    0.97349	    0.00000	 150.0	 1	    1.10000	    0.84698;
	873	 1	 42.54717	 17.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	874	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	875	 1	 88.49812	 16.5	 0.0	 0.0	 1	    1.01663	    0.00000	 380.0	 1	    1.13325	    0.90000;
	876	 1	 45.04995	 9.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	877	 2	 215.2	 64.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	878	 1	 1.301443	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	879	 1	 0.400444	 1.1	 0.0	 0.0	 1	    1.00962	    0.00000	 380.0	 1	    1.11924	    0.90000;
	880	 1	 62.26904	 -2.1	 0.0	 0.0	 1	    1.00302	    0.00000	 220.0	 1	    1.10604	    0.90000;
	881	 1	 0.0	 0.0	 0.090703	 0.0	 1	    1.02750	    0.00000	 380.0	 1	    1.15501	    0.90000;
	882	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02072	    0.00000	 380.0	 1	    1.14144	    0.90000;
	883	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	884	 2	 6.707437	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	885	 1	 33.23685	 11.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	886	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01051	    0.00000	 380.0	 1	    1.12102	    0.90000;
	887	 2	 165.7	 7.9	 0.0	 0.0	 1	    1.02029	    0.00000	 220.0	 1	    1.14058	    0.90000;
	888	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	889	 1	 21.12342	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	890	 1	 14.71632	 4.6	 0.0	 0.0	 1	    1.01617	    0.00000	 220.0	 1	    1.13234	    0.90000;
	891	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	892	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00589	    0.00000	 380.0	 1	    1.11178	    0.90000;
	893	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03122	    0.00000	 380.0	 1	    1.16245	    0.90000;
	894	 1	 17.51942	 4.6	 0.0	 0.0	 1	    1.01741	    0.00000	 220.0	 1	    1.13482	    0.90000;
	895	 2	 36.84085	 5.0	 0.0	 0.0	 1	    1.01227	    0.00000	 220.0	 1	    1.12453	    0.90000;
	896	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	897	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00565	    0.00000	 220.0	 1	    1.11130	    0.90000;
	898	 1	 32.33585	 10.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	899	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	900	 2	 18.12009	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	901	 2	 38.34251	 51.8	 0.0	 0.0	 1	    1.00825	    0.00000	 220.0	 1	    1.11650	    0.90000;
	902	 2	 171.0	 69.2	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	903	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02646	    0.00000	 150.0	 1	    1.15292	    0.90000;
	904	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01333	    0.00000	 220.0	 1	    1.12666	    0.90000;
	905	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	906	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	907	 1	 22.32475	 13.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	908	 1	 20.0222	 6.8	 0.0	 0.0	 1	    1.01096	    0.00000	 110.0	 1	    1.12193	    0.90000;
	909	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	910	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03857	    0.00000	 220.0	 1	    1.17714	    0.90000;
	911	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02191	    0.00000	 220.0	 1	    1.14381	    0.90000;
	912	 1	 24.02664	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	913	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	914	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02701	    0.00000	 220.0	 1	    1.15402	    0.90000;
	915	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01537	    0.00000	 380.0	 1	    1.13075	    0.90000;
	916	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	917	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	918	 1	 0.200222	 0.4	 0.0	 0.0	 1	    1.01411	    0.00000	 220.0	 1	    1.12821	    0.90000;
	919	 1	 21.32364	 7.3	 0.0	 0.0	 1	    1.01069	    0.00000	 110.0	 1	    1.12139	    0.90000;
	920	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02115	    0.00000	 150.0	 1	    1.14231	    0.90000;
	921	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	922	 2	 137.1	 41.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	923	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	924	 1	 44.54939	 0.0	 0.0	 0.0	 1	    1.01629	    0.00000	 220.0	 1	    1.13258	    0.90000;
	925	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01632	    0.00000	 380.0	 1	    1.13264	    0.90000;
	926	 1	 26.92986	 9.5	 0.0	 0.0	 1	    1.01200	    0.00000	 220.0	 1	    1.12400	    0.90000;
	927	 1	 21.02331	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	928	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	929	 1	 8.209102	 3.3	 0.0	 0.0	 1	    1.02640	    0.00000	 150.0	 1	    1.15280	    0.90000;
	930	 2	 227.9	 36.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	931	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	932	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	933	 1	 241.4	 -2.5	 0.219001	 0.0	 1	    1.01082	    0.00000	 380.0	 1	    1.12164	    0.90000;
	934	 1	 201.4	 53.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	935	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00755	    0.00000	 380.0	 1	    1.11509	    0.90000;
	936	 1	 13.81532	 5.0	 0.0	 0.0	 1	    1.00528	    0.00000	 110.0	 1	    1.11057	    0.90000;
	937	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	938	 2	 -34.5383	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	939	 1	 84.59379	 -18.5	 0.0	 0.0	 1	    1.02980	    0.00000	 380.0	 1	    1.15960	    0.90000;
	940	 1	 27.02997	 13.0	 0.0	 0.0	 1	    1.01105	    0.00000	 220.0	 1	    1.12210	    0.90000;
	941	 1	 26.32919	 5.3	 0.0	 0.0	 1	    1.01902	    0.00000	 220.0	 1	    1.13804	    0.90000;
	942	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00899	    0.00000	 220.0	 1	    1.11797	    0.90000;
	943	 2	 392.6	 63.3	 0.0	 0.0	 1	    1.04241	    0.00000	 220.0	 1	    1.18482	    0.90000;
	944	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00720	    0.00000	 220.0	 1	    1.11440	    0.90000;
	945	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01847	    0.00000	 380.0	 1	    1.13694	    0.90000;
	946	 1	 3.704107	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	947	 1	 34.6384	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	948	 1	 31.93541	 8.8	 0.0	 0.0	 1	    1.02268	    0.00000	 220.0	 1	    1.14537	    0.90000;
	949	 1	 12.11343	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	950	 1	 153.3	 27.6	 0.0	 0.0	 1	    1.00449	    0.00000	 380.0	 1	    1.10898	    0.90000;
	951	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02083	    0.00000	 380.0	 1	    1.14166	    0.90000;
	952	 1	 8.909878	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	953	 1	 47.05217	 19.3	 0.0	 0.0	 1	    1.01793	    0.00000	 150.0	 1	    1.13586	    0.90000;
	954	 1	 1.902109	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	955	 2	 28.2313	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	956	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02854	    0.00000	 380.0	 1	    1.15708	    0.90000;
	957	 2	 146.9083	 24.3	 0.0	 0.0	 1	    1.02958	    0.00000	 220.0	 1	    1.15915	    0.90000;
	958	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01453	    0.00000	 220.0	 1	    1.12905	    0.90000;
	959	 1	 67.47482	 32.6	 0.0	 0.0	 1	    1.01869	    0.00000	 220.0	 1	    1.13738	    0.90000;
	960	 1	 39.1434	 13.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	961	 1	 0.0	 0.0	 0.0	 23.18786	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	963	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03161	    0.00000	 220.0	 1	    1.16322	    0.90000;
	964	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01357	    0.00000	 380.0	 1	    1.12714	    0.90000;
	965	 1	 0.0	 0.0	 0.0	 -42.2993	 1	    1.00933	    0.00000	 380.0	 1	    1.11866	    0.90000;
	966	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02146	    0.00000	 380.0	 1	    1.14291	    0.90000;
	967	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	968	 1	 84.89413	 32.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	969	 1	 50.0555	 17.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	970	 1	 215.2	 -7.6	 0.0	 0.0	 1	    1.00830	    0.00000	 220.0	 1	    1.11660	    0.90000;
	971	 1	 89.59934	 20.0	 0.0	 0.0	 1	    1.00499	    0.00000	 220.0	 1	    1.10998	    0.90000;
	972	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00770	    0.00000	 380.0	 1	    1.11540	    0.90000;
	973	 1	 279.4	 22.9	 0.0	 0.0	 1	    1.01464	    0.00000	 220.0	 1	    1.12928	    0.90000;
	974	 1	 35.23907	 11.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	975	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00411	    0.00000	 220.0	 1	    1.10823	    0.90000;
	976	 1	 1.601776	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	977	 1	 83.3	 47.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	978	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02050	    0.00000	 380.0	 1	    1.14100	    0.90000;
	979	 1	 21.92431	 7.2	 0.0	 0.0	 1	    1.02502	    0.00000	 110.0	 1	    1.15005	    0.90000;
	980	 1	 403.9	 -0.1	 0.0	 0.0	 1	    1.01455	    0.00000	 380.0	 1	    1.12910	    0.90000;
	981	 2	 27.63063	 5.6	 0.0	 0.0	 1	    1.03657	    0.00000	 110.0	 1	    1.17314	    0.90000;
	982	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	983	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00834	    0.00000	 220.0	 1	    1.11668	    0.90000;
	984	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02079	    0.00000	 220.0	 1	    1.14157	    0.90000;
	985	 1	 0.200222	 1.3	 0.286541	 0.0	 1	    1.00547	    0.00000	 380.0	 1	    1.11093	    0.90000;
	986	 2	 284.0	 60.9	 0.0	 0.0	 1	    1.02599	    0.00000	 380.0	 1	    1.15198	    0.90000;
	987	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02673	    0.00000	 380.0	 1	    1.15346	    0.90000;
	988	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00838	    0.00000	 220.0	 1	    1.11677	    0.90000;
	989	 1	 42.14673	 14.2	 0.0	 0.0	 1	    1.02239	    0.00000	 110.0	 1	    1.14478	    0.90000;
	990	 1	 162.1	 43.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	991	 1	 12.01332	 5.6	 0.0	 0.0	 1	    1.01195	    0.00000	 380.0	 1	    1.12390	    0.90000;
	992	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	993	 1	 -7.60844	 2.5	 0.0	 0.0	 1	    1.00494	    0.00000	 150.0	 1	    1.10989	    0.90000;
	994	 1	 56.06216	 18.7	 0.0	 0.0	 1	    1.02470	    0.00000	 220.0	 1	    1.14939	    0.90000;
	995	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	996	 1	 30.9343	 -46.6	 0.0	 0.0	 1	    1.01249	    0.00000	 220.0	 1	    1.12498	    0.90000;
	997	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02157	    0.00000	 380.0	 1	    1.14313	    0.90000;
	998	 1	 28.53163	 11.3	 0.0	 0.0	 1	    1.02485	    0.00000	 150.0	 1	    1.14970	    0.90000;
	999	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1000	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02603	    0.00000	 220.0	 1	    1.15206	    0.90000;
	1001	 2	 46.25128	 21.0	 0.0	 0.0	 1	    1.03049	    0.00000	 110.0	 1	    1.16098	    0.90000;
	1002	 1	 0.0	 0.0	 0.0	 11.97037	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1003	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02215	    0.00000	 220.0	 1	    1.14431	    0.90000;
	1004	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1005	 2	 180.3753	 76.9	 0.0	 0.0	 1	    1.00795	    0.00000	 220.0	 1	    1.11589	    0.90000;
	1006	 2	 13.31475	 8.1	 0.0	 0.0	 1	    1.04703	    0.00000	 380.0	 1	    1.19406	    0.90000;
	1007	 1	 5.105661	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1008	 1	 29.83308	 7.3	 0.0	 0.0	 1	    1.03329	    0.00000	 220.0	 1	    1.16658	    0.90000;
	1009	 1	 192.4	 63.9	 0.0	 0.0	 1	    1.02411	    0.00000	 150.0	 1	    1.14822	    0.90000;
	1010	 1	 1.801998	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1011	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1012	 1	 -54.0599	 13.1	 0.0	 0.0	 1	    1.00309	    0.00000	 220.0	 1	    1.10617	    0.90000;
	1013	 2	 302.6	 263.5	 0.0	 0.0	 1	    1.00292	    0.00000	 380.0	 1	    1.10584	    0.90000;
	1014	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00642	    0.00000	 220.0	 1	    1.11285	    0.90000;
	1015	 1	 10.9121	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1016	 1	 59.26571	 5.1	 0.0	 0.0	 1	    1.02012	    0.00000	 380.0	 1	    1.14023	    0.90000;
	1017	 1	 -40.545	 9.3	 0.0	 0.0	 1	    1.01390	    0.00000	 220.0	 1	    1.12779	    0.90000;
	1018	 1	 70.27792	 58.9	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1019	 1	 254.0	 74.3	 0.0	 0.0	 1	    1.02546	    0.00000	 380.0	 1	    1.15092	    0.90000;
	1020	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01661	    0.00000	 220.0	 1	    1.13323	    0.90000;
	1021	 1	 244.8	 119.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1022	 2	 11.41265	 36.1	 0.0	 0.0	 1	    1.00809	    0.00000	 220.0	 1	    1.11618	    0.90000;
	1023	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01399	    0.00000	 220.0	 1	    1.12797	    0.90000;
	1024	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1025	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1026	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00273	    0.00000	 220.0	 1	    1.10546	    0.90000;
	1027	 1	 0.0	 0.0	 0.100424	 0.0	 1	    1.02367	    0.00000	 220.0	 1	    1.14734	    0.90000;
	1028	 1	 -878.1	 -312.7	 0.0	 20.0	 1	    1.02372	    0.00000	 380.0	 1	    1.14744	    0.90000;
	1029	 2	 228.3	 71.3	 0.0	 0.0	 1	    1.02177	    0.00000	 220.0	 1	    1.14353	    0.90000;
	1030	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03966	    0.00000	 380.0	 1	    1.17932	    0.90000;
	1031	 1	 7.8	 50.9	 0.0	 0.0	 1	    1.00613	    0.00000	 380.0	 1	    1.11225	    0.90000;
	1032	 1	 115.2	 319.2	 0.0	 0.0	 1	    1.02958	    0.00000	 380.0	 1	    1.15916	    0.90000;
	1033	 1	 1.401554	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1034	 1	 16.21798	 2.0	 0.0	 0.0	 1	    1.02296	    0.00000	 220.0	 1	    1.14591	    0.90000;
	1035	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01666	    0.00000	 220.0	 1	    1.13332	    0.90000;
	1036	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00387	    0.00000	 380.0	 1	    1.10774	    0.90000;
	1037	 2	 18.92098	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1038	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1039	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01908	    0.00000	 380.0	 1	    1.13815	    0.90000;
	1040	 1	 45.9	 36.8	 0.0	 0.0	 1	    1.00932	    0.00000	 380.0	 1	    1.11863	    0.90000;
	1041	 1	 0.0	 0.0	 0.198999	 0.0	 1	    1.00429	    0.00000	 220.0	 1	    1.10858	    0.90000;
	1042	 1	 39.04329	 -5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1043	 2	 -61.7688	 -36.7	 0.0	 0.0	 1	    1.00914	    0.00000	 220.0	 1	    1.11828	    0.90000;
	1044	 1	 32.83641	 0.0	 0.0	 0.0	 1	    1.01206	    0.00000	 220.0	 1	    1.12413	    0.90000;
	1045	 1	 20.0222	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1046	 1	 141.4	 123.0	 0.0	 0.0	 1	    1.00450	    0.00000	 380.0	 1	    1.10900	    0.90000;
	1047	 1	 0.0	 0.0	 0.0	 -35.2657	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1048	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01569	    0.00000	 380.0	 1	    1.13139	    0.90000;
	1049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02116	    0.00000	 220.0	 1	    1.14232	    0.90000;
	1050	 1	 12.41376	 3.9	 0.0	 0.0	 1	    1.02005	    0.00000	 220.0	 1	    1.14010	    0.90000;
	1051	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01820	    0.00000	 380.0	 1	    1.13639	    0.90000;
	1052	 1	 65.67281	 24.0	 0.0	 0.0	 1	    1.02086	    0.00000	 220.0	 1	    1.14172	    0.90000;
	1053	 1	 24.12675	 12.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1054	 1	 112.4	 13.0	 0.0	 0.0	 1	    1.02630	    0.00000	 220.0	 1	    1.15260	    0.90000;
	1055	 1	 0.100111	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1056	 1	 170.2	 60.8	 0.0	 0.0	 1	    1.00812	    0.00000	 380.0	 1	    1.11625	    0.90000;
	1057	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1058	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1059	 1	 26.4293	 16.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1060	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01787	    0.00000	 380.0	 1	    1.13575	    0.90000;
	1061	 1	 -39.8081	 -10.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1062	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1063	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01572	    0.00000	 380.0	 1	    1.13144	    0.90000;
	1064	 2	 0.0	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1065	 1	 79.88858	 29.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1066	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03279	    0.00000	 220.0	 1	    1.16558	    0.90000;
	1067	 2	 129.1	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1068	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1069	 2	 -128.743	 38.0	 0.0	 0.0	 1	    1.01513	    0.00000	 220.0	 1	    1.13027	    0.90000;
	1070	 2	 92.70278	 -11.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1071	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1072	 1	 35.83974	 11.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1073	 1	 86.59601	 23.4	 0.0	 0.0	 1	    1.01680	    0.00000	 220.0	 1	    1.13360	    0.90000;
	1074	 1	 43.7485	 16.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1075	 1	 0.100111	 -19.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1076	 1	 10.81199	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1077	 1	 199.4	 -19.9	 0.0	 0.0	 1	    1.02651	    0.00000	 220.0	 1	    1.15301	    0.90000;
	1078	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01528	    0.00000	 380.0	 1	    1.13056	    0.90000;
	1079	 1	 150.4	 15.3	 0.0	 0.0	 1	    1.00295	    0.00000	 220.0	 1	    1.10590	    0.90000;
	1080	 1	 67.57492	 21.2	 0.0	 0.0	 1	    1.01469	    0.00000	 220.0	 1	    1.12938	    0.90000;
	1081	 1	 30.9343	 6.6	 0.0	 0.0	 1	    1.02877	    0.00000	 220.0	 1	    1.15754	    0.90000;
	1082	 1	 96.40689	 18.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1083	 1	 14.61621	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1084	 1	 13.21465	 9.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1085	 1	 181.5	 21.2	 0.0	 0.0	 1	    1.03297	    0.00000	 380.0	 1	    1.16593	    0.90000;
	1086	 1	 129.6	 13.3	 0.0	 0.0	 1	    1.02523	    0.00000	 380.0	 1	    1.15046	    0.90000;
	1087	 1	 3.804218	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1088	 1	 0.0	 0.0	 0.191685	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1089	 1	 25.22797	 10.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1090	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00965	    0.00000	 380.0	 1	    1.11930	    0.90000;
	1091	 1	 0.0	 0.0	 0.053002	 0.0	 1	    1.00568	    0.00000	 380.0	 1	    1.11136	    0.90000;
	1092	 1	 124.8	 7.9	 0.0	 0.0	 1	    1.01747	    0.00000	 380.0	 1	    1.13493	    0.90000;
	1093	 1	 114.1	 23.5	 0.0	 0.0	 1	    1.01755	    0.00000	 220.0	 1	    1.13510	    0.90000;
	1094	 1	 0.0	 0.0	 0.0	 -25.7113	 1	    1.03185	    0.00000	 380.0	 1	    1.16370	    0.90000;
	1095	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1096	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01851	    0.00000	 150.0	 1	    1.13702	    0.90000;
	1097	 1	 27.13008	 16.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1098	 1	 70.1778	 28.7	 0.0	 0.0	 1	    1.02425	    0.00000	 150.0	 1	    1.14850	    0.90000;
	1099	 1	 183.0286	 15.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1100	 1	 -15.8175	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1101	 2	 0.0	 0.0	 0.045352	 -88.2763	 1	    1.02613	    0.00000	 380.0	 1	    1.15227	    0.90000;
	1102	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04130	    0.00000	 380.0	 1	    1.18261	    0.90000;
	1103	 1	 105.0	 412.0	 0.0	 20.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1104	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00259	    0.00000	 150.0	 1	    1.10518	    0.90000;
	1105	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02709	    0.00000	 220.0	 1	    1.15417	    0.90000;
	1106	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1107	 1	 30.83419	 13.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1108	 1	 1.401554	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1109	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1110	 1	 230.5	 91.0	 0.0	 0.0	 1	    1.02211	    0.00000	 150.0	 1	    1.14421	    0.90000;
	1111	 1	 23.02553	 14.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1112	 1	 168.3	 -57.1	 0.0	 0.0	 1	    1.02597	    0.00000	 380.0	 1	    1.15193	    0.90000;
	1113	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01436	    0.00000	 220.0	 1	    1.12871	    0.90000;
	1114	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00698	    0.00000	 150.0	 1	    1.11396	    0.90000;
	1115	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1116	 1	 53.15894	 17.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1117	 1	 5.506105	 2.0	 0.0	 0.0	 1	    1.01682	    0.00000	 110.0	 1	    1.13364	    0.90000;
	1118	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02475	    0.00000	 380.0	 1	    1.14949	    0.90000;
	1120	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02068	    0.00000	 220.0	 1	    1.14136	    0.90000;
	1121	 1	 71.77958	 17.9	 0.0	 0.0	 1	    1.02120	    0.00000	 220.0	 1	    1.14240	    0.90000;
	1122	 1	 105.5	 24.7	 0.0	 0.0	 1	    1.00406	    0.00000	 220.0	 1	    1.10812	    0.90000;
	1123	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04349	    0.00000	 380.0	 1	    1.18699	    0.90000;
	1124	 1	 60.36693	 35.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1125	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1126	 1	 23.52608	 4.0	 0.0	 0.0	 1	    1.00760	    0.00000	 220.0	 1	    1.11521	    0.90000;
	1127	 2	 -30.1334	 -22.3	 0.0	 0.0	 1	    1.01642	    0.00000	 220.0	 1	    1.13283	    0.90000;
	1128	 1	 226.3	 51.7	 0.0	 0.0	 1	    1.00350	    0.00000	 220.0	 1	    1.10700	    0.90000;
	1129	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1130	 2	 5.205771	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1131	 1	 2.00222	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1132	 1	 23.02553	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1133	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01786	    0.00000	 220.0	 1	    1.13572	    0.90000;
	1134	 1	 141.2566	 30.6	 0.0	 0.0	 1	    1.01669	    0.00000	 380.0	 1	    1.13338	    0.90000;
	1135	 1	 39.44373	 24.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1136	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02173	    0.00000	 380.0	 1	    1.14346	    0.90000;
	1137	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1138	 1	 186.6	 155.8	 0.0	 0.0	 1	    1.00357	    0.00000	 380.0	 1	    1.10715	    0.90000;
	1139	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1140	 1	 20.62287	 8.2	 0.0	 0.0	 1	    1.01901	    0.00000	 150.0	 1	    1.13802	    0.90000;
	1141	 1	 1.902109	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1142	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01191	    0.00000	 220.0	 1	    1.12382	    0.90000;
	1143	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1144	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03134	    0.00000	 380.0	 1	    1.16268	    0.90000;
	1145	 1	 50.85638	 36.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1146	 1	 279.5	 25.8	 0.0	 0.0	 1	    1.01331	    0.00000	 220.0	 1	    1.12661	    0.90000;
	1147	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01944	    0.00000	 220.0	 1	    1.13888	    0.90000;
	1148	 1	 0.0	 0.0	 0.219	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1149	 1	 224.9	 -32.5	 0.0	 0.0	 1	    1.02732	    0.00000	 380.0	 1	    1.15465	    0.90000;
	1150	 1	 173.0	 -21.3	 0.0	 0.0	 1	    1.03144	    0.00000	 220.0	 1	    1.16287	    0.90000;
	1151	 1	 15.41709	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1152	 2	 3.103441	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1153	 1	 151.2	 96.4	 0.233362	 292.6621	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1154	 1	 112.8	 27.6	 0.0	 0.0	 1	    1.00362	    0.00000	 220.0	 1	    1.10724	    0.90000;
	1155	 1	 1.801998	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1156	 2	 119.6	 26.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1157	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1158	 1	 7.00777	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1159	 1	 149.9	 53.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1160	 1	 52.45816	 2.9	 0.0	 0.0	 1	    1.01759	    0.00000	 220.0	 1	    1.13519	    0.90000;
	1161	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1162	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02122	    0.00000	 150.0	 1	    1.14243	    0.90000;
	1163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00984	    0.00000	 380.0	 1	    1.11967	    0.90000;
	1164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1165	 1	 0.0	 0.0	 0.0	 -262.422	 1	    1.03288	    0.00000	 380.0	 1	    1.16575	    0.90000;
	1166	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1167	 1	 202.0	 34.1	 0.0	 0.0	 1	    1.00987	    0.00000	 220.0	 1	    1.11973	    0.90000;
	1168	 1	 42.74739	 15.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1169	 1	 19.02109	 9.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1170	 1	 0.0	 -0.2	 0.0	 0.0	 1	    1.01272	    0.00000	 110.0	 1	    1.12545	    0.90000;
	1171	 1	 7.608436	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1172	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01762	    0.00000	 380.0	 1	    1.13524	    0.90000;
	1173	 1	 9.610656	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1174	 1	 18.82087	 6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1175	 1	 22.32475	 7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1176	 1	 50.25572	 19.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1177	 1	 6.106771	 0.0	 0.0	 0.0	 1	    1.00367	    0.00000	 220.0	 1	    1.10735	    0.90000;
	1178	 2	 181.1	 78.7	 0.0	 0.0	 1	    1.00830	    0.00000	 220.0	 1	    1.11660	    0.90000;
	1179	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1180	 1	 19.02109	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1181	 1	 0.0	 0.0	 0.0	 19.31922	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1182	 1	 30.53385	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1183	 1	 42.94762	 26.6	 0.0	 0.0	 1	    0.99531	    0.00000	 150.0	 1	    1.10000	    0.89063;
	1184	 1	 479.0	 99.2	 0.0	 0.0	 1	    1.01914	    0.00000	 220.0	 1	    1.13827	    0.90000;
	1185	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1186	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03320	    0.00000	 220.0	 1	    1.16641	    0.90000;
	1187	 1	 5.405994	 1.8	 0.0	 0.0	 1	    1.00610	    0.00000	 110.0	 1	    1.11221	    0.90000;
	1188	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01823	    0.00000	 220.0	 1	    1.13645	    0.90000;
	1189	 1	 8.509435	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1190	 2	 479.3	 127.6	 0.0	 0.0	 1	    1.01104	    0.00000	 380.0	 1	    1.12208	    0.90000;
	1191	 1	 71.37914	 10.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1192	 1	 17.71965	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1193	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1194	 1	 37.94207	 15.2	 0.0	 0.0	 1	    1.02109	    0.00000	 380.0	 1	    1.14218	    0.90000;
	1195	 2	 18.72076	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1196	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00674	    0.00000	 220.0	 1	    1.11347	    0.90000;
	1197	 2	 278.1	 95.2	 0.0	 0.0	 1	    1.03053	    0.00000	 380.0	 1	    1.16105	    0.90000;
	1198	 1	 13.81532	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1199	 1	 149.3	 -2.0	 0.0	 0.0	 1	    1.01405	    0.00000	 380.0	 1	    1.12811	    0.90000;
	1200	 1	 0.200222	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1201	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1202	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1203	 1	 11.41265	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1204	 1	 0.0	 0.0	 0.0	 15.2568	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1205	 1	 118.9	 129.2	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1206	 1	 37.14118	 11.6	 0.0	 0.0	 1	    1.00397	    0.00000	 110.0	 1	    1.10793	    0.90000;
	1207	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00515	    0.00000	 110.0	 1	    1.11031	    0.90000;
	1208	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03647	    0.00000	 220.0	 1	    1.17294	    0.90000;
	1209	 1	 135.7	 31.6	 0.0	 0.0	 1	    1.00453	    0.00000	 220.0	 1	    1.10905	    0.90000;
	1210	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03065	    0.00000	 380.0	 1	    1.16131	    0.90000;
	1211	 1	 100.6	 15.3	 0.0	 0.0	 1	    1.00394	    0.00000	 150.0	 1	    1.10787	    0.90000;
	1212	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01393	    0.00000	 380.0	 1	    1.12787	    0.90000;
	1213	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1214	 1	 -9.61066	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1215	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02230	    0.00000	 220.0	 1	    1.14461	    0.90000;
	1216	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02233	    0.00000	 150.0	 1	    1.14466	    0.90000;
	1217	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02266	    0.00000	 380.0	 1	    1.14531	    0.90000;
	1218	 1	 29.03219	 9.4	 0.0	 0.0	 1	    1.01864	    0.00000	 110.0	 1	    1.13727	    0.90000;
	1219	 1	 108.4	 -2.4	 0.0	 0.0	 1	    1.02236	    0.00000	 380.0	 1	    1.14472	    0.90000;
	1220	 1	 13.21465	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1221	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1222	 2	 31.13452	 8.5	 0.0	 0.0	 1	    1.01607	    0.00000	 220.0	 1	    1.13214	    0.90000;
	1223	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01296	    0.00000	 380.0	 1	    1.12593	    0.90000;
	1224	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01107	    0.00000	 220.0	 1	    1.12214	    0.90000;
	1225	 2	 2.00222	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1226	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1227	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00515	    0.00000	 220.0	 1	    1.11030	    0.90000;
	1228	 1	 30.53385	 13.8	 0.0	 0.0	 1	    1.02179	    0.00000	 150.0	 1	    1.14359	    0.90000;
	1229	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1230	 1	 28.93208	 11.9	 0.0	 0.0	 1	    1.02375	    0.00000	 150.0	 1	    1.14749	    0.90000;
	1231	 1	 6.407104	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1232	 2	 291.9	 91.9	 0.0	 0.0	 1	    1.01246	    0.00000	 220.0	 1	    1.12491	    0.90000;
	1233	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02343	    0.00000	 380.0	 1	    1.14685	    0.90000;
	1234	 1	 538.3	 90.8	 0.0	 0.0	 1	    1.02547	    0.00000	 380.0	 1	    1.15094	    0.90000;
	1235	 1	 100.3	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1236	 1	 60.16671	 30.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1237	 1	 0.0	 0.0	 0.296958	 0.0	 1	    1.02693	    0.00000	 380.0	 1	    1.15387	    0.90000;
	1238	 2	 211.8	 87.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1239	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03057	    0.00000	 220.0	 1	    1.16114	    0.90000;
	1240	 1	 0.0	 0.0	 0.260248	 0.0	 1	    1.00791	    0.00000	 380.0	 1	    1.11583	    0.90000;
	1241	 1	 40.84529	 14.5	 0.0	 0.0	 1	    1.01636	    0.00000	 220.0	 1	    1.13273	    0.90000;
	1242	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01602	    0.00000	 380.0	 1	    1.13203	    0.90000;
	1243	 1	 22.02442	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1244	 1	 0.0	 0.0	 0.154869	 0.0	 1	    1.00937	    0.00000	 380.0	 1	    1.11875	    0.90000;
	1245	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1246	 1	 0.0	 0.0	 0.264593	 0.0	 1	    1.01451	    0.00000	 380.0	 1	    1.12902	    0.90000;
	1247	 1	 46.55161	 28.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1248	 1	 50.9565	 16.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1249	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1250	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1251	 1	 10.11121	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1252	 1	 0.0	 0.0	 0.0	 22.60474	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1253	 1	 18.01998	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1254	 2	 3.603996	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1255	 1	 145.2	 21.4	 0.0	 0.0	 1	    1.01049	    0.00000	 220.0	 1	    1.12097	    0.90000;
	1256	 1	 10.81199	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1258	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02497	    0.00000	 380.0	 1	    1.14995	    0.90000;
	1259	 2	 19.82198	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1260	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1261	 2	 562.3	 159.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1262	 1	 20.32253	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1263	 1	 0.0	 0.0	 0.0	 16.62709	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1264	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01149	    0.00000	 220.0	 1	    1.12298	    0.90000;
	1265	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01458	    0.00000	 220.0	 1	    1.12916	    0.90000;
	1266	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00312	    0.00000	 220.0	 1	    1.10624	    0.90000;
	1267	 1	 2.402664	 0.7	 0.0	 0.0	 1	    1.00311	    0.00000	 220.0	 1	    1.10623	    0.90000;
	1268	 1	 30.9343	 7.6	 0.0	 0.0	 1	    1.03332	    0.00000	 220.0	 1	    1.16664	    0.90000;
	1269	 1	 52.95872	 15.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1270	 1	 0.0	 -6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01924	    0.00000	 220.0	 1	    1.13848	    0.90000;
	1272	 1	 196.7	 44.2	 0.0	 0.0	 1	    1.00865	    0.00000	 220.0	 1	    1.11730	    0.90000;
	1273	 2	 185.5	 62.3	 0.0	 0.0	 1	    1.02458	    0.00000	 380.0	 1	    1.14916	    0.90000;
	1274	 1	 39.24351	 71.7	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1275	 1	 11.91321	 2.9	 0.0	 0.0	 1	    1.01940	    0.00000	 220.0	 1	    1.13879	    0.90000;
	1276	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1277	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1279	 1	 157.9	 26.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1280	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1281	 1	 15.5172	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1282	 2	 138.2	 153.5	 0.0	 0.0	 1	    1.00678	    0.00000	 220.0	 1	    1.11356	    0.90000;
	1283	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1284	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1285	 1	 5.105661	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1286	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1287	 1	 144.7	 20.3	 0.0	 0.0	 1	    1.02059	    0.00000	 220.0	 1	    1.14118	    0.90000;
	1288	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02601	    0.00000	 220.0	 1	    1.15202	    0.90000;
	1289	 1	 7.808658	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1290	 2	 4.805328	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1291	 1	 40.54495	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1292	 1	 16.51831	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1293	 1	 42.94762	 19.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1294	 2	 132.2	 32.8	 0.0	 0.0	 1	    1.01208	    0.00000	 220.0	 1	    1.12416	    0.90000;
	1295	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02311	    0.00000	 220.0	 1	    1.14622	    0.90000;
	1296	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1297	 1	 0.300333	 0.2	 0.0	 0.0	 1	    1.02102	    0.00000	 380.0	 1	    1.14205	    0.90000;
	1298	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1300	 1	 22.82531	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1301	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01846	    0.00000	 380.0	 1	    1.13692	    0.90000;
	1302	 1	 20.82309	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1303	 1	 -8.30921	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1304	 1	 193.2	 121.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1305	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00847	    0.00000	 220.0	 1	    1.11693	    0.90000;
	1306	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03242	    0.00000	 220.0	 1	    1.16485	    0.90000;
	1307	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02211	    0.00000	 220.0	 1	    1.14423	    0.90000;
	1308	 1	 204.6	 53.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1309	 1	 0.0	 0.0	 0.310992	 0.0	 1	    1.00616	    0.00000	 220.0	 1	    1.11233	    0.90000;
	1310	 1	 110.1	 2.0	 0.0	 0.0	 1	    1.00700	    0.00000	 220.0	 1	    1.11399	    0.90000;
	1311	 1	 60.0666	 20.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1312	 2	 298.7	 85.3	 0.0	 0.0	 1	    1.01780	    0.00000	 380.0	 1	    1.13559	    0.90000;
	1313	 1	 238.4	 210.9	 0.0	 0.0	 1	    1.01417	    0.00000	 220.0	 1	    1.12833	    0.90000;
	1314	 1	 10.9121	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1315	 1	 4.605106	 1.7	 0.0	 0.0	 1	    1.00383	    0.00000	 110.0	 1	    1.10766	    0.90000;
	1316	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04728	    0.00000	 220.0	 1	    1.19456	    0.90000;
	1317	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1318	 1	 39.54384	 14.3	 0.0	 0.0	 1	    1.01413	    0.00000	 110.0	 1	    1.12827	    0.90000;
	1319	 1	 20.52275	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1320	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01328	    0.00000	 380.0	 1	    1.12656	    0.90000;
	1321	 1	 80.0888	 26.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1322	 1	 20.62287	 10.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1323	 1	 18.01998	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1324	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1325	 1	 20.82309	 36.0	 0.0	 0.0	 1	    1.02039	    0.00000	 220.0	 1	    1.14079	    0.90000;
	1326	 2	 4.0	 172.7	 0.0	 0.0	 1	    1.02724	    0.00000	 380.0	 1	    1.15447	    0.90000;
	1327	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00948	    0.00000	 220.0	 1	    1.11896	    0.90000;
	1328	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01018	    0.00000	 220.0	 1	    1.12037	    0.90000;
	1329	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01209	    0.00000	 220.0	 1	    1.12418	    0.90000;
	1330	 1	 109.6	 36.4	 0.0	 0.0	 1	    1.02142	    0.00000	 150.0	 1	    1.14283	    0.90000;
	1331	 1	 22.7252	 6.4	 0.0	 0.0	 1	    1.00502	    0.00000	 150.0	 1	    1.11004	    0.90000;
	1332	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00796	    0.00000	 380.0	 1	    1.11593	    0.90000;
	1333	 1	 42.94762	 26.6	 0.0	 0.0	 1	    1.00426	    0.00000	 150.0	 1	    1.10851	    0.90000;
	1334	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1335	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1336	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02167	    0.00000	 220.0	 1	    1.14334	    0.90000;
	1337	 1	 18.12009	 -11.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1338	 1	 95.606	 8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1339	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1340	 1	 0.0	 0.0	 0.143001	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1341	 2	 1.501665	 87.9	 0.0	 0.0	 1	    1.01545	    0.00000	 380.0	 1	    1.13090	    0.90000;
	1342	 1	 30.63396	 19.0	 0.0	 0.0	 1	    0.96551	    0.00000	 150.0	 1	    1.10000	    0.83101;
	1343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01960	    0.00000	 150.0	 1	    1.13919	    0.90000;
	1344	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00675	    0.00000	 220.0	 1	    1.11349	    0.90000;
	1345	 1	 82.19112	 23.4	 0.0	 0.0	 1	    1.02036	    0.00000	 380.0	 1	    1.14072	    0.90000;
	1346	 1	 100.1	 45.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1347	 2	 627.8	 293.4	 0.0	 0.0	 1	    1.01067	    0.00000	 220.0	 1	    1.12134	    0.90000;
	1348	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1349	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03635	    0.00000	 220.0	 1	    1.17270	    0.90000;
	1350	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00441	    0.00000	 220.0	 1	    1.10882	    0.90000;
	1351	 1	 144.9	 87.7	 0.210144	 0.0	 1	    1.01415	    0.00000	 380.0	 1	    1.12831	    0.90000;
	1352	 1	 79.58824	 18.8	 0.0	 0.0	 1	    1.01915	    0.00000	 220.0	 1	    1.13829	    0.90000;
	1353	 2	 -29.0322	 -4.0	 0.0	 0.0	 1	    1.02207	    0.00000	 220.0	 1	    1.14413	    0.90000;
	1354	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03015	    0.00000	 380.0	 1	    1.16029	    0.90000;
	1355	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00268	    0.00000	 220.0	 1	    1.10536	    0.90000;
	1356	 1	 23.02553	 14.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1357	 1	 117.5	 -3.0	 0.0	 0.0	 1	    1.00567	    0.00000	 220.0	 1	    1.11134	    0.90000;
	1358	 2	 193.8	 27.3	 0.0	 0.0	 1	    1.01446	    0.00000	 220.0	 1	    1.12892	    0.90000;
	1359	 1	 1.101221	 2.5	 0.207794	 20.0	 1	    1.01322	    0.00000	 380.0	 1	    1.12644	    0.90000;
	1360	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00650	    0.00000	 380.0	 1	    1.11301	    0.90000;
	1361	 1	 18.01998	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1362	 1	 0.700777	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1364	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03466	    0.00000	 380.0	 1	    1.16933	    0.90000;
	1365	 1	 6.407104	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1366	 1	 13.81532	 5.0	 0.0	 0.0	 1	    1.00585	    0.00000	 110.0	 1	    1.11170	    0.90000;
	1367	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00761	    0.00000	 220.0	 1	    1.11521	    0.90000;
	1368	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01925	    0.00000	 380.0	 1	    1.13851	    0.90000;
	1369	 1	 142.8	 -6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1370	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00677	    0.00000	 220.0	 1	    1.11354	    0.90000;
	1371	 1	 6.707437	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1372	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01536	    0.00000	 380.0	 1	    1.13072	    0.90000;
	1373	 2	 125.4	 7.6	 0.0	 0.0	 1	    1.03122	    0.00000	 220.0	 1	    1.16244	    0.90000;
	1374	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1375	 1	 16.4182	 5.9	 0.0	 0.0	 1	    1.00401	    0.00000	 110.0	 1	    1.10801	    0.90000;
	1376	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1377	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1378	 1	 339.1	 89.0	 0.0	 0.0	 1	    1.01239	    0.00000	 380.0	 1	    1.12478	    0.90000;
	1379	 1	 -35.7396	 38.6	 0.0	 0.0	 1	    1.00394	    0.00000	 220.0	 1	    1.10788	    0.90000;
	1380	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1381	 1	 22.02442	 9.0	 0.0	 0.0	 1	    1.02667	    0.00000	 150.0	 1	    1.15334	    0.90000;
	1382	 1	 7.408214	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1383	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1384	 1	 -10.5117	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1385	 1	 173.6	 72.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1386	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1387	 1	 72.1	 71.8	 0.0	 0.0	 1	    1.00878	    0.00000	 380.0	 1	    1.11757	    0.90000;
	1388	 1	 57.86415	 23.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1389	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00259	    0.00000	 380.0	 1	    1.10519	    0.90000;
	1390	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01929	    0.00000	 380.0	 1	    1.13858	    0.90000;
	1391	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01213	    0.00000	 220.0	 1	    1.12426	    0.90000;
	1392	 1	 39.64395	 11.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1393	 1	 5.806438	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1394	 1	 0.0	 8.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1395	 1	 0.0	 0.0	 0.0	 65.8105	 1	    1.00673	    0.00000	 150.0	 1	    1.11346	    0.90000;
	1396	 1	 2.502775	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1397	 1	 43.8	 20.7	 0.0	 -42.3306	 1	    1.00927	    0.00000	 380.0	 1	    1.11855	    0.90000;
	1398	 1	 0.0	 0.0	 0.28785	 0.0	 1	    1.02048	    0.00000	 380.0	 1	    1.14096	    0.90000;
	1399	 1	 20.32253	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1400	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1401	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1402	 1	 36.34029	 15.2	 0.0	 0.0	 1	    1.00905	    0.00000	 220.0	 1	    1.11811	    0.90000;
	1403	 2	 106.7	 12.4	 0.0	 0.0	 1	    1.03274	    0.00000	 220.0	 1	    1.16548	    0.90000;
	1404	 1	 0.0	 0.0	 0.296958	 -84.3852	 1	    1.02758	    0.00000	 380.0	 1	    1.15517	    0.90000;
	1405	 1	 125.4	 45.8	 0.0	 0.0	 1	    1.02553	    0.00000	 220.0	 1	    1.15107	    0.90000;
	1406	 1	 170.4	 81.9	 0.0	 0.0	 1	    1.01747	    0.00000	 380.0	 1	    1.13495	    0.90000;
	1407	 1	 116.7	 64.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1408	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03594	    0.00000	 380.0	 1	    1.17188	    0.90000;
	1409	 1	 42.54717	 8.2	 0.0	 0.0	 1	    1.03162	    0.00000	 220.0	 1	    1.16324	    0.90000;
	1410	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01734	    0.00000	 380.0	 1	    1.13469	    0.90000;
	1411	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1412	 1	 7.608436	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1413	 1	 300.2	 -3.1	 0.0	 0.0	 1	    1.00774	    0.00000	 380.0	 1	    1.11549	    0.90000;
	1414	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02944	    0.00000	 380.0	 1	    1.15888	    0.90000;
	1415	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02951	    0.00000	 220.0	 1	    1.15902	    0.90000;
	1416	 1	 20.42264	 8.1	 0.0	 0.0	 1	    1.02647	    0.00000	 380.0	 1	    1.15293	    0.90000;
	1417	 1	 -21.624	 -3.9	 0.0	 0.0	 1	    1.01557	    0.00000	 220.0	 1	    1.13113	    0.90000;
	1418	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01465	    0.00000	 220.0	 1	    1.12931	    0.90000;
	1419	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01415	    0.00000	 380.0	 1	    1.12830	    0.90000;
	1420	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03503	    0.00000	 220.0	 1	    1.17006	    0.90000;
	1421	 2	 0.0	 0.0	 0.178992	 0.0	 1	    1.00643	    0.00000	 380.0	 1	    1.11287	    0.90000;
	1422	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00682	    0.00000	 220.0	 1	    1.11364	    0.90000;
	1423	 1	 175.2	 82.4	 0.0	 0.0	 1	    1.02155	    0.00000	 220.0	 1	    1.14310	    0.90000;
	1424	 1	 77.3858	 24.1	 0.0	 0.0	 1	    1.01398	    0.00000	 220.0	 1	    1.12796	    0.90000;
	1425	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.00729	    0.00000	 220.0	 1	    1.11457	    0.90000;
	1426	 1	 140.4	 49.4	 0.0	 0.0	 1	    1.01211	    0.00000	 150.0	 1	    1.12422	    0.90000;
	1427	 1	 156.9	 -4.0	 0.0	 0.0	 1	    1.02666	    0.00000	 220.0	 1	    1.15332	    0.90000;
	1428	 1	 60.0666	 27.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1429	 1	 69.07658	 21.5	 0.0	 0.0	 1	    1.01603	    0.00000	 220.0	 1	    1.13206	    0.90000;
	1430	 1	 0.0	 0.0	 0.0	 11.06628	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1431	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03267	    0.00000	 380.0	 1	    1.16534	    0.90000;
	1432	 1	 329.4	 12.9	 0.0	 0.0	 1	    1.02165	    0.00000	 380.0	 1	    1.14330	    0.90000;
	1433	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1434	 1	 34.03774	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1435	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1436	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00349	    0.00000	 380.0	 1	    1.10698	    0.90000;
	1437	 1	 32.03552	 19.8	 0.0	 0.0	 1	    1.00288	    0.00000	 150.0	 1	    1.10577	    0.90000;
	1438	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00703	    0.00000	 220.0	 1	    1.11405	    0.90000;
	1439	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1440	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1441	 1	 146.6	 3.3	 0.0	 0.0	 1	    1.00758	    0.00000	 220.0	 1	    1.11516	    0.90000;
	1442	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1443	 2	 5.706326	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00808	    0.00000	 220.0	 1	    1.11615	    0.90000;
	1445	 1	 30.53385	 10.4	 0.0	 0.0	 1	    1.01717	    0.00000	 110.0	 1	    1.13435	    0.90000;
	1446	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01016	    0.00000	 380.0	 1	    1.12031	    0.90000;
	1447	 1	 78.5	 137.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1448	 1	 104.5	 -56.4	 0.0	 0.0	 1	    1.01991	    0.00000	 380.0	 1	    1.13981	    0.90000;
	1449	 1	 25.72853	 9.3	 0.0	 0.0	 1	    1.01365	    0.00000	 110.0	 1	    1.12729	    0.90000;
	1450	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00502	    0.00000	 380.0	 1	    1.11004	    0.90000;
	1451	 1	 28.33141	 44.8	 0.0	 0.0	 1	    1.02229	    0.00000	 220.0	 1	    1.14459	    0.90000;
	1452	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00860	    0.00000	 380.0	 1	    1.11719	    0.90000;
	1453	 2	 95.10545	 21.7	 0.0	 0.0	 1	    1.01773	    0.00000	 220.0	 1	    1.13546	    0.90000;
	1454	 1	 76.28458	 45.7	 0.0	 0.0	 1	    1.00797	    0.00000	 380.0	 1	    1.11593	    0.90000;
	1455	 1	 51.95761	 13.4	 0.0	 0.0	 1	    1.01928	    0.00000	 110.0	 1	    1.13856	    0.90000;
	1456	 1	 58.86526	 36.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1457	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1458	 1	 38.74295	 14.1	 0.0	 0.0	 1	    1.00536	    0.00000	 220.0	 1	    1.11071	    0.90000;
	1459	 1	 63.5	 -381.2	 0.550858	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1460	 1	 45.75072	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1461	 1	 137.2	 16.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1462	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01490	    0.00000	 220.0	 1	    1.12981	    0.90000;
	1463	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03584	    0.00000	 220.0	 1	    1.17167	    0.90000;
	1464	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01478	    0.00000	 380.0	 1	    1.12955	    0.90000;
	1465	 1	 73.7818	 0.0	 0.0	 0.0	 1	    1.01208	    0.00000	 380.0	 1	    1.12416	    0.90000;
	1466	 1	 25.12786	 15.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1467	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01272	    0.00000	 220.0	 1	    1.12544	    0.90000;
	1468	 1	 164.8	 42.5	 0.0	 0.0	 1	    1.00457	    0.00000	 380.0	 1	    1.10914	    0.90000;
	1469	 1	 274.1	 166.5	 0.0	 0.0	 1	    1.02383	    0.00000	 150.0	 1	    1.14767	    0.90000;
	1470	 1	 149.8	 63.1	 0.0	 0.0	 1	    1.02118	    0.00000	 220.0	 1	    1.14236	    0.90000;
	1471	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1472	 1	 50.0555	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1474	 1	 14.71632	 5.3	 0.0	 0.0	 1	    1.01910	    0.00000	 110.0	 1	    1.13820	    0.90000;
	1475	 2	 152.1	 194.4	 0.0	 0.0	 1	    1.01751	    0.00000	 380.0	 1	    1.13502	    0.90000;
	1476	 1	 20.32253	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01167	    0.00000	 380.0	 1	    1.12333	    0.90000;
	1478	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00482	    0.00000	 220.0	 1	    1.10963	    0.90000;
	1479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1480	 1	 164.2	 -10.7	 0.0	 0.0	 1	    1.00648	    0.00000	 220.0	 1	    1.11296	    0.90000;
	1481	 1	 73.18114	 22.3	 0.0	 0.0	 1	    1.01942	    0.00000	 220.0	 1	    1.13885	    0.90000;
	1482	 1	 123.5	 -49.4	 0.0	 0.0	 1	    1.01788	    0.00000	 220.0	 1	    1.13577	    0.90000;
	1483	 1	 3.303663	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1484	 1	 41.94651	 8.5	 0.0	 0.0	 1	    1.01003	    0.00000	 220.0	 1	    1.12007	    0.90000;
	1485	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00654	    0.00000	 380.0	 1	    1.11309	    0.90000;
	1486	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1487	 1	 20.82309	 7.9	 0.0	 0.0	 1	    1.00391	    0.00000	 220.0	 1	    1.10781	    0.90000;
	1488	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1489	 1	 5.305883	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1490	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1491	 1	 0.0	 0.0	 0.122611	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1492	 1	 -8.40932	 2.7	 0.0	 0.0	 1	    1.00495	    0.00000	 150.0	 1	    1.10991	    0.90000;
	1493	 1	 70.0777	 11.1	 0.0	 0.0	 1	    1.00614	    0.00000	 220.0	 1	    1.11229	    0.90000;
	1494	 1	 51.65727	 8.0	 0.0	 0.0	 1	    1.00762	    0.00000	 220.0	 1	    1.11524	    0.90000;
	1495	 1	 33.23685	 11.5	 0.0	 0.0	 1	    1.00908	    0.00000	 110.0	 1	    1.11816	    0.90000;
	1496	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01997	    0.00000	 380.0	 1	    1.13995	    0.90000;
	1497	 1	 95.70611	 25.9	 0.0	 0.0	 1	    1.01391	    0.00000	 220.0	 1	    1.12781	    0.90000;
	1498	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01544	    0.00000	 380.0	 1	    1.13087	    0.90000;
	1499	 1	 60.26682	 9.4	 0.0	 0.0	 1	    1.00606	    0.00000	 220.0	 1	    1.11211	    0.90000;
	1500	 2	 15.5172	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1501	 1	 13.31476	 4.8	 0.0	 0.0	 1	    1.01910	    0.00000	 110.0	 1	    1.13821	    0.90000;
	1502	 1	 103.7	 14.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1503	 1	 33.03663	 15.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1504	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01337	    0.00000	 380.0	 1	    1.12675	    0.90000;
	1505	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02268	    0.00000	 220.0	 1	    1.14536	    0.90000;
	1506	 1	 22.02442	 11.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1507	 1	 0.0	 0.0	 0.184	 0.0	 1	    1.00293	    0.00000	 380.0	 1	    1.10586	    0.90000;
	1508	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03297	    0.00000	 380.0	 1	    1.16594	    0.90000;
	1509	 1	 15.21687	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1510	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00679	    0.00000	 380.0	 1	    1.11359	    0.90000;
	1511	 1	 257.2	 -26.8	 0.0	 0.0	 1	    1.00726	    0.00000	 220.0	 1	    1.11453	    0.90000;
	1512	 1	 25.82864	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1513	 1	 -13.9154	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1514	 1	 22.02442	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1515	 2	 19.02109	 4.7	 0.0	 0.0	 1	    1.02042	    0.00000	 220.0	 1	    1.14084	    0.90000;
	1516	 1	 -592.205	 -227.4	 0.466992	 0.0	 1	    1.01928	    0.00000	 380.0	 1	    1.13857	    0.90000;
	1517	 1	 20.0222	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1518	 1	 34.03774	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1519	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00839	    0.00000	 380.0	 1	    1.11678	    0.90000;
	1520	 1	 0.0	 0.0	 0.251998	 0.0	 1	    1.01134	    0.00000	 380.0	 1	    1.12268	    0.90000;
	1521	 1	 0.0	 0.0	 0.191685	 0.0	 1	    1.02900	    0.00000	 220.0	 1	    1.15801	    0.90000;
	1522	 1	 46.4515	 19.1	 0.0	 0.0	 1	    1.02701	    0.00000	 150.0	 1	    1.15402	    0.90000;
	1523	 1	 3.303663	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1524	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03502	    0.00000	 220.0	 1	    1.17004	    0.90000;
	1525	 2	 4.705216	 89.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1526	 1	 16.91876	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1527	 1	 55.26127	 -11.1	 0.0	 0.0	 1	    1.01374	    0.00000	 220.0	 1	    1.12748	    0.90000;
	1528	 1	 0.0	 0.0	 0.154873	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1529	 1	 9.210212	 3.3	 0.0	 0.0	 1	    1.00627	    0.00000	 110.0	 1	    1.11254	    0.90000;
	1530	 1	 0.0	 0.0	 0.0	 -14.7231	 1	    1.04197	    0.00000	 150.0	 1	    1.18394	    0.90000;
	1531	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01002	    0.00000	 380.0	 1	    1.12003	    0.90000;
	1532	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02419	    0.00000	 380.0	 1	    1.14839	    0.90000;
	1533	 1	 7.408214	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1534	 2	 20.22242	 7.3	 0.0	 0.0	 1	    1.01545	    0.00000	 110.0	 1	    1.13090	    0.90000;
	1535	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1536	 2	 415.5	 52.5	 0.0	 0.0	 1	    1.01171	    0.00000	 380.0	 1	    1.12342	    0.90000;
	1537	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1538	 1	 0.0	 0.0	 0.401381	 0.0	 1	    1.01627	    0.00000	 380.0	 1	    1.13254	    0.90000;
	1539	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1540	 1	 72.18002	 31.9	 0.0	 0.0	 1	    1.02192	    0.00000	 220.0	 1	    1.14384	    0.90000;
	1541	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00566	    0.00000	 380.0	 1	    1.11132	    0.90000;
	1542	 1	 118.2	 -33.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1543	 1	 83.19224	 25.8	 0.0	 0.0	 1	    1.00951	    0.00000	 220.0	 1	    1.11902	    0.90000;
	1544	 2	 29.23241	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1545	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.00436	    0.00000	 220.0	 1	    1.10872	    0.90000;
	1546	 1	 12.41376	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1547	 2	 207.9	 9.2	 0.0	 0.0	 1	    1.01485	    0.00000	 380.0	 1	    1.12969	    0.90000;
	1548	 1	 14.71632	 5.3	 0.0	 0.0	 1	    1.02413	    0.00000	 110.0	 1	    1.14826	    0.90000;
	1549	 1	 4.304773	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1550	 1	 5.00555	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1551	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99534	    0.00000	 150.0	 1	    1.10000	    0.89069;
	1552	 1	 47.45261	 18.7	 0.0	 0.0	 1	    1.02443	    0.00000	 150.0	 1	    1.14886	    0.90000;
	1553	 1	 68.2757	 39.0	 0.226015	 0.0	 1	    1.02358	    0.00000	 380.0	 1	    1.14715	    0.90000;
	1554	 2	 62.56937	 8.0	 0.0	 0.0	 1	    1.00920	    0.00000	 220.0	 1	    1.11840	    0.90000;
	1555	 1	 15.21687	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1556	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1557	 1	 92.60267	 36.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1558	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02536	    0.00000	 380.0	 1	    1.15072	    0.90000;
	1559	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01293	    0.00000	 380.0	 1	    1.12585	    0.90000;
	1560	 1	 138.2	 40.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1561	 1	 25.12786	 -61.6	 0.0	 0.0	 1	    1.02341	    0.00000	 220.0	 1	    1.14682	    0.90000;
	1562	 1	 2.502775	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1563	 1	 4.905439	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1564	 1	 53.55938	 17.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1565	 2	 48.2535	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1566	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01785	    0.00000	 380.0	 1	    1.13570	    0.90000;
	1567	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1568	 1	 -14.3159	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1569	 2	 157.6333	 115.5	 0.0	 0.0	 1	    1.00742	    0.00000	 220.0	 1	    1.11484	    0.90000;
	1570	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00614	    0.00000	 380.0	 1	    1.11227	    0.90000;
	1571	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03163	    0.00000	 220.0	 1	    1.16325	    0.90000;
	1572	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00768	    0.00000	 150.0	 1	    1.11536	    0.90000;
	1573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02631	    0.00000	 380.0	 1	    1.15262	    0.90000;
	1574	 1	 8.00888	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1575	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1576	 2	 38.04218	 29.0	 0.0	 0.0	 1	    1.00946	    0.00000	 220.0	 1	    1.11891	    0.90000;
	1577	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1578	 1	 34.43818	 14.4	 0.0	 0.0	 1	    1.01726	    0.00000	 380.0	 1	    1.13453	    0.90000;
	1579	 1	 68.37582	 42.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1580	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01619	    0.00000	 380.0	 1	    1.13239	    0.90000;
	1581	 1	 19.92209	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1582	 1	 0.0	 0.0	 0.148479	 0.0	 1	    1.02381	    0.00000	 380.0	 1	    1.14761	    0.90000;
	1583	 1	 16.01776	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1584	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1585	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00888	    0.00000	 150.0	 1	    1.11776	    0.90000;
	1586	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1587	 1	 9.710767	 3.5	 0.0	 0.0	 1	    1.01796	    0.00000	 110.0	 1	    1.13593	    0.90000;
	1588	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01450	    0.00000	 220.0	 1	    1.12901	    0.90000;
	1589	 1	 10.11121	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1590	 1	 162.5	 48.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1591	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01728	    0.00000	 220.0	 1	    1.13456	    0.90000;
	1592	 2	 0.0	 -0.1	 0.0	 0.0	 1	    1.03508	    0.00000	 220.0	 1	    1.17016	    0.90000;
	1593	 1	 2.00222	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1594	 1	 0.0	 0.0	 0.0	 11.0253	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1595	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01689	    0.00000	 220.0	 1	    1.13377	    0.90000;
	1596	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01260	    0.00000	 380.0	 1	    1.12520	    0.90000;
	1597	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01539	    0.00000	 380.0	 1	    1.13078	    0.90000;
	1598	 1	 39.24351	 24.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1599	 1	 58.46482	 6.6	 0.0	 0.0	 1	    1.01966	    0.00000	 220.0	 1	    1.13932	    0.90000;
	1600	 1	 11.51276	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1601	 1	 85.79512	 13.4	 0.0	 0.0	 1	    1.00538	    0.00000	 220.0	 1	    1.11075	    0.90000;
	1602	 1	 0.0	 0.0	 0.119999	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1603	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02191	    0.00000	 380.0	 1	    1.14382	    0.90000;
	1604	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1605	 2	 0.0	 0.0	 0.133294	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1606	 1	 80.0888	 20.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1607	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02023	    0.00000	 380.0	 1	    1.14046	    0.90000;
	1608	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02212	    0.00000	 220.0	 1	    1.14423	    0.90000;
	1609	 1	 328.9	 30.4	 0.0	 0.0	 1	    1.01670	    0.00000	 380.0	 1	    1.13339	    0.90000;
	1610	 1	 11.11232	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1611	 1	 45.75072	 20.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1612	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01711	    0.00000	 380.0	 1	    1.13423	    0.90000;
	1613	 1	 25.42819	 14.7	 0.0	 0.0	 1	    1.00872	    0.00000	 220.0	 1	    1.11744	    0.90000;
	1614	 1	 122.2	 68.9	 0.0	 0.0	 1	    1.02861	    0.00000	 380.0	 1	    1.15722	    0.90000;
	1615	 1	 26.02886	 8.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1616	 1	 333.5	 -1.4	 0.0	 0.0	 1	    1.02604	    0.00000	 220.0	 1	    1.15208	    0.90000;
	1617	 1	 73.98203	 22.5	 0.0	 0.0	 1	    1.01588	    0.00000	 220.0	 1	    1.13176	    0.90000;
	1618	 1	 35.13896	 1.8	 0.0	 0.0	 1	    1.00996	    0.00000	 220.0	 1	    1.11992	    0.90000;
	1619	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1620	 1	 22.42486	 29.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1621	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1622	 1	 -32.0355	 10.3	 0.0	 0.0	 1	    1.02307	    0.00000	 380.0	 1	    1.14614	    0.90000;
	1623	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00669	    0.00000	 220.0	 1	    1.11338	    0.90000;
	1624	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1625	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02320	    0.00000	 110.0	 1	    1.14639	    0.90000;
	1626	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1627	 1	 5.506105	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1628	 1	 -1.8	 -4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1629	 1	 16.51831	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1630	 1	 28.63174	 10.0	 0.0	 0.0	 1	    1.01364	    0.00000	 110.0	 1	    1.12728	    0.90000;
	1631	 1	 0.0	 -0.8	 0.0	 0.0	 1	    1.01977	    0.00000	 110.0	 1	    1.13954	    0.90000;
	1632	 1	 0.0	 0.0	 0.0	 12.57819	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1633	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1634	 2	 18.4	 10.1	 0.0	 -52.5877	 1	    1.01705	    0.00000	 380.0	 1	    1.13409	    0.90000;
	1635	 1	 32.93652	 10.1	 0.0	 0.0	 1	    1.00333	    0.00000	 110.0	 1	    1.10666	    0.90000;
	1636	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00529	    0.00000	 380.0	 1	    1.11058	    0.90000;
	1637	 1	 45.75072	 27.5	 0.0	 0.0	 1	    1.00938	    0.00000	 220.0	 1	    1.11876	    0.90000;
	1638	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00424	    0.00000	 220.0	 1	    1.10849	    0.90000;
	1639	 1	 -19.3214	 6.4	 0.0	 0.0	 1	    1.00456	    0.00000	 150.0	 1	    1.10911	    0.90000;
	1640	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1641	 2	 166.1	 64.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1642	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02648	    0.00000	 380.0	 1	    1.15296	    0.90000;
	1643	 1	 71.17892	 23.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1644	 1	 13.31476	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1645	 2	 12.31365	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1646	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1647	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1648	 1	 8.509435	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1649	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01959	    0.00000	 220.0	 1	    1.13918	    0.90000;
	1650	 1	 23.02553	 10.5	 0.0	 0.0	 1	    1.02111	    0.00000	 220.0	 1	    1.14221	    0.90000;
	1651	 1	 25.42819	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1652	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01386	    0.00000	 380.0	 1	    1.12773	    0.90000;
	1653	 2	 166.2	 55.1	 0.0	 0.0	 1	    1.02211	    0.00000	 220.0	 1	    1.14422	    0.90000;
	1654	 1	 0.0	 0.0	 0.0	 -573.554	 1	    1.00000	    0.00000	 750.0	 1	    1.10000	    0.90000;
	1655	 1	 52.45816	 11.3	 0.0	 0.0	 1	    1.02377	    0.00000	 110.0	 1	    1.14754	    0.90000;
	1656	 1	 99.51033	 1.5	 0.0	 0.0	 1	    1.01468	    0.00000	 380.0	 1	    1.12936	    0.90000;
	1657	 2	 116.8	 30.4	 0.0	 0.0	 1	    1.01271	    0.00000	 220.0	 1	    1.12543	    0.90000;
	1658	 2	 34.13785	 -2.8	 0.0	 0.0	 1	    1.03344	    0.00000	 380.0	 1	    1.16687	    0.90000;
	1659	 1	 63.66304	 9.7	 0.0	 0.0	 1	    1.01927	    0.00000	 220.0	 1	    1.13854	    0.90000;
	1660	 1	 335.3	 -101.3	 0.0	 0.0	 1	    1.01882	    0.00000	 380.0	 1	    1.13763	    0.90000;
	1661	 2	 109.5	 33.7	 0.0	 0.0	 1	    1.03302	    0.00000	 380.0	 1	    1.16605	    0.90000;
	1662	 1	 -29.733	 9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1663	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03200	    0.00000	 380.0	 1	    1.16399	    0.90000;
	1664	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01155	    0.00000	 220.0	 1	    1.12310	    0.90000;
	1665	 1	 14.61621	 2.0	 0.0	 0.0	 1	    1.02839	    0.00000	 220.0	 1	    1.15678	    0.90000;
	1666	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01893	    0.00000	 380.0	 1	    1.13786	    0.90000;
	1667	 2	 0.0	 0.0	 0.328599	 20.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1668	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01029	    0.00000	 150.0	 1	    1.12059	    0.90000;
	1669	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00625	    0.00000	 380.0	 1	    1.11249	    0.90000;
	1670	 1	 56.4626	 22.0	 0.0	 0.0	 1	    1.02789	    0.00000	 220.0	 1	    1.15578	    0.90000;
	1671	 1	 2.502775	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1672	 1	 5.00555	 13.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1673	 1	 17.81976	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1674	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1675	 1	 34.13785	 21.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1676	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02772	    0.00000	 220.0	 1	    1.15543	    0.90000;
	1677	 1	 8.209102	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1678	 2	 102.2	 45.4	 0.0	 0.0	 1	    1.01074	    0.00000	 220.0	 1	    1.12148	    0.90000;
	1679	 1	 62.36915	 25.5	 0.0	 0.0	 1	    1.02225	    0.00000	 150.0	 1	    1.14449	    0.90000;
	1680	 2	 202.4	 66.4	 0.0	 0.0	 1	    1.00727	    0.00000	 220.0	 1	    1.11455	    0.90000;
	1681	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02800	    0.00000	 220.0	 1	    1.15600	    0.90000;
	1682	 1	 0.4	 -170.2	 0.0	 0.0	 1	    1.01307	    0.00000	 380.0	 1	    1.12614	    0.90000;
	1683	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1684	 1	 56.26238	 8.5	 0.0	 0.0	 1	    1.00713	    0.00000	 220.0	 1	    1.11426	    0.90000;
	1685	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02309	    0.00000	 220.0	 1	    1.14618	    0.90000;
	1686	 2	 30.53385	 15.1	 0.0	 0.0	 1	    1.01613	    0.00000	 110.0	 1	    1.13227	    0.90000;
	1687	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03503	    0.00000	 220.0	 1	    1.17006	    0.90000;
	1688	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1689	 1	 22.02442	 21.8	 0.0	 0.0	 1	    1.00554	    0.00000	 220.0	 1	    1.11107	    0.90000;
	1690	 1	 5.105661	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1691	 2	 7.808658	 5.8	 0.0	 0.0	 1	    1.01395	    0.00000	 220.0	 1	    1.12790	    0.90000;
	1692	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02209	    0.00000	 220.0	 1	    1.14418	    0.90000;
	1693	 2	 295.8	 90.9	 0.0	 0.0	 1	    1.01354	    0.00000	 220.0	 1	    1.12708	    0.90000;
	1694	 1	 25.72853	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1695	 1	 0.200222	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1696	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1697	 1	 5.506105	 2.0	 0.0	 0.0	 1	    1.02719	    0.00000	 110.0	 1	    1.15438	    0.90000;
	1698	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01047	    0.00000	 220.0	 1	    1.12094	    0.90000;
	1699	 1	 10.51165	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1700	 1	 369.5	 16.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1701	 1	 88.79845	 -3.2	 0.0	 0.0	 1	    1.01421	    0.00000	 220.0	 1	    1.12843	    0.90000;
	1702	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01315	    0.00000	 380.0	 1	    1.12630	    0.90000;
	1703	 1	 177.4	 41.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1704	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02421	    0.00000	 220.0	 1	    1.14843	    0.90000;
	1705	 1	 -19.6218	 28.6	 0.0	 0.0	 1	    1.01037	    0.00000	 150.0	 1	    1.12075	    0.90000;
	1706	 1	 55.26127	 23.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1707	 1	 209.2	 23.5	 0.0	 0.0	 1	    1.02171	    0.00000	 220.0	 1	    1.14342	    0.90000;
	1708	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02829	    0.00000	 220.0	 1	    1.15658	    0.90000;
	1709	 1	 11.71299	 3.8	 0.0	 0.0	 1	    1.01413	    0.00000	 220.0	 1	    1.12826	    0.90000;
	1710	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00910	    0.00000	 220.0	 1	    1.11821	    0.90000;
	1711	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01487	    0.00000	 150.0	 1	    1.12974	    0.90000;
	1712	 2	 95.1	 35.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1713	 1	 94.30456	 13.8	 0.0	 0.0	 1	    1.00658	    0.00000	 220.0	 1	    1.11316	    0.90000;
	1714	 1	 83.29234	 30.1	 0.0	 0.0	 1	    1.02903	    0.00000	 110.0	 1	    1.15807	    0.90000;
	1715	 1	 223.9	 72.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.20000	    0.80000;
	1716	 1	 0.0	 0.0	 0.0	 12.60168	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1717	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02301	    0.00000	 380.0	 1	    1.14602	    0.90000;
	1718	 2	 1.201332	 0.8	 0.0	 0.0	 1	    1.00933	    0.00000	 150.0	 1	    1.11867	    0.90000;
	1719	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1720	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1721	 1	 50.25572	 16.4	 0.0	 0.0	 1	    1.01196	    0.00000	 150.0	 1	    1.12391	    0.90000;
	1722	 1	 64.27126	 20.1	 0.0	 0.0	 1	    1.01712	    0.00000	 220.0	 1	    1.13424	    0.90000;
	1723	 1	 27.3303	 5.0	 0.0	 0.0	 1	    1.02131	    0.00000	 220.0	 1	    1.14262	    0.90000;
	1724	 2	 289.4	 96.2	 0.0	 0.0	 1	    1.01308	    0.00000	 380.0	 1	    1.12617	    0.90000;
	1725	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02217	    0.00000	 380.0	 1	    1.14433	    0.90000;
	1726	 1	 2.202442	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1727	 2	 195.1	 41.4	 0.0	 0.0	 1	    1.02214	    0.00000	 220.0	 1	    1.14429	    0.90000;
	1728	 1	 57.16338	 0.0	 0.0	 0.0	 1	    1.00961	    0.00000	 110.0	 1	    1.11921	    0.90000;
	1729	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00747	    0.00000	 380.0	 1	    1.11494	    0.90000;
	1730	 1	 28.63174	 17.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1731	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01355	    0.00000	 380.0	 1	    1.12711	    0.90000;
	1732	 1	 22.22464	 5.9	 0.0	 0.0	 1	    1.00738	    0.00000	 220.0	 1	    1.11477	    0.90000;
	1733	 1	 20.82309	 0.0	 0.0	 0.0	 1	    1.00905	    0.00000	 220.0	 1	    1.11810	    0.90000;
	1734	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01740	    0.00000	 380.0	 1	    1.13480	    0.90000;
	1735	 1	 53.95983	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1736	 2	 0.500555	 21.5	 0.0	 0.0	 1	    1.03196	    0.00000	 380.0	 1	    1.16391	    0.90000;
	1737	 1	 0.0	 0.0	 0.227005	 0.0	 1	    1.03126	    0.00000	 380.0	 1	    1.16251	    0.90000;
	1738	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1739	 1	 0.200222	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1740	 1	 26.4293	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1741	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1742	 1	 16.01776	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1743	 2	 17.5	 502.7	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1744	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1745	 2	 2.903219	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1746	 2	 68.37582	 6.2	 0.0	 0.0	 1	    1.00836	    0.00000	 220.0	 1	    1.11672	    0.90000;
	1747	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01828	    0.00000	 220.0	 1	    1.13657	    0.90000;
	1748	 1	 39.54384	 14.3	 0.0	 0.0	 1	    1.00263	    0.00000	 110.0	 1	    1.10525	    0.90000;
	1749	 1	 52.05772	 14.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1750	 1	 91.1	 54.8	 0.0	 0.0	 1	    1.02151	    0.00000	 150.0	 1	    1.14302	    0.90000;
	1751	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01955	    0.00000	 220.0	 1	    1.13909	    0.90000;
	1752	 1	 33.63729	 3.9	 0.0	 0.0	 1	    1.01384	    0.00000	 220.0	 1	    1.12769	    0.90000;
	1753	 1	 10.51165	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1754	 1	 197.5	 -31.0	 0.0	 0.0	 1	    1.01755	    0.00000	 220.0	 1	    1.13510	    0.90000;
	1755	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01976	    0.00000	 380.0	 1	    1.13951	    0.90000;
	1756	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04381	    0.00000	 380.0	 1	    1.18762	    0.90000;
	1757	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01137	    0.00000	 380.0	 1	    1.12275	    0.90000;
	1758	 1	 49.25461	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1759	 1	 0.0	 0.0	 0.117	 0.0	 1	    1.03213	    0.00000	 220.0	 1	    1.16426	    0.90000;
	1760	 2	 195.0	 47.3	 0.0	 0.0	 1	    1.01038	    0.00000	 380.0	 1	    1.12075	    0.90000;
	1761	 1	 108.3	 62.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1762	 1	 14.91654	 4.9	 0.0	 0.0	 1	    1.00978	    0.00000	 110.0	 1	    1.11957	    0.90000;
	1763	 2	 64.37138	 38.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1764	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1765	 1	 14.8	 6.6	 0.0	 0.0	 1	    1.02815	    0.00000	 380.0	 1	    1.15629	    0.90000;
	1766	 1	 24.32697	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1767	 1	 51.85749	 13.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.20000	    0.80000;
	1768	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01985	    0.00000	 380.0	 1	    1.13970	    0.90000;
	1769	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1770	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02201	    0.00000	 150.0	 1	    1.14402	    0.90000;
	1771	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1772	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01209	    0.00000	 220.0	 1	    1.12418	    0.90000;
	1773	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03292	    0.00000	 220.0	 1	    1.16584	    0.90000;
	1774	 1	 44.74961	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1775	 1	 4.404884	 99.7	 0.0	 0.0	 1	    1.00320	    0.00000	 380.0	 1	    1.10640	    0.90000;
	1776	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1777	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1778	 1	 19.42153	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1779	 2	 21.8242	 10.3	 0.0	 0.0	 1	    1.01905	    0.00000	 380.0	 1	    1.13810	    0.90000;
	1780	 1	 159.8	 45.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1781	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01430	    0.00000	 380.0	 1	    1.12859	    0.90000;
	1782	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1783	 1	 115.1	 10.4	 0.0	 0.0	 1	    1.01836	    0.00000	 220.0	 1	    1.13672	    0.90000;
	1784	 1	 0.0	 0.0	 0.062995	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1785	 1	 21.62398	 13.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1786	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1787	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01391	    0.00000	 380.0	 1	    1.12783	    0.90000;
	1788	 1	 76.28458	 2.9	 0.0	 0.0	 1	    1.00511	    0.00000	 220.0	 1	    1.11022	    0.90000;
	1789	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03612	    0.00000	 220.0	 1	    1.17224	    0.90000;
	1790	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1791	 1	 3.203552	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1792	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1793	 1	 29.43263	 10.7	 0.0	 0.0	 1	    1.00388	    0.00000	 110.0	 1	    1.10775	    0.90000;
	1794	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1795	 1	 248.7	 8.1	 0.0	 0.0	 1	    1.03128	    0.00000	 220.0	 1	    1.16256	    0.90000;
	1796	 1	 -20.6	 -9.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1797	 1	 46.05106	 16.7	 0.0	 0.0	 1	    1.01352	    0.00000	 110.0	 1	    1.12704	    0.90000;
	1798	 1	 118.4	 137.0	 0.0	 0.0	 1	    1.02277	    0.00000	 150.0	 1	    1.14553	    0.90000;
	1799	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00636	    0.00000	 220.0	 1	    1.11273	    0.90000;
	1800	 2	 9.210212	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1801	 1	 88.99868	 -1.8	 0.0	 0.0	 1	    1.00348	    0.00000	 220.0	 1	    1.10695	    0.90000;
	1802	 1	 1.8	 4.9	 0.0	 0.0	 1	    1.02784	    0.00000	 380.0	 1	    1.15568	    0.90000;
	1803	 1	 210.1	 66.2	 0.0	 0.0	 1	    1.03335	    0.00000	 220.0	 1	    1.16671	    0.90000;
	1804	 1	 241.9	 38.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1805	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1806	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04317	    0.00000	 380.0	 1	    1.18634	    0.90000;
	1807	 1	 0.0	 0.0	 0.152776	 0.0	 1	    1.02242	    0.00000	 380.0	 1	    1.14484	    0.90000;
	1808	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03857	    0.00000	 220.0	 1	    1.17714	    0.90000;
	1809	 1	 177.3	 36.4	 0.0	 0.0	 1	    1.01797	    0.00000	 220.0	 1	    1.13594	    0.90000;
	1810	 1	 12.41376	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1811	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02184	    0.00000	 150.0	 1	    1.14367	    0.90000;
	1812	 1	 147.4	 -55.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1813	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1814	 1	 70.1778	 44.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1815	 1	 50.25572	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1816	 1	 69.77736	 20.3	 0.0	 0.0	 1	    1.02239	    0.00000	 110.0	 1	    1.14479	    0.90000;
	1817	 1	 61.8686	 -12.4	 0.0	 0.0	 1	    1.00335	    0.00000	 220.0	 1	    1.10670	    0.90000;
	1818	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02205	    0.00000	 220.0	 1	    1.14411	    0.90000;
	1819	 1	 0.200222	 0.2	 0.0	 0.0	 1	    1.00755	    0.00000	 220.0	 1	    1.11511	    0.90000;
	1820	 1	 89.5	 33.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1821	 1	 0.0	 0.0	 0.432997	 0.0	 1	    1.02330	    0.00000	 380.0	 1	    1.14660	    0.90000;
	1822	 1	 15.21687	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1823	 1	 0.900999	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1824	 1	 25.72853	 7.3	 0.0	 0.0	 1	    1.01847	    0.00000	 220.0	 1	    1.13694	    0.90000;
	1825	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03336	    0.00000	 380.0	 1	    1.16671	    0.90000;
	1826	 1	 54.0	 29.1	 0.0	 0.0	 1	    1.00905	    0.00000	 380.0	 1	    1.11810	    0.90000;
	1827	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01502	    0.00000	 380.0	 1	    1.13004	    0.90000;
	1828	 1	 139.1	 60.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1829	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01612	    0.00000	 110.0	 1	    1.13224	    0.90000;
	1830	 1	 54.6606	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1831	 1	 -40.4448	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1832	 1	 11.41265	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1833	 1	 154.8	 -47.1	 0.0	 0.0	 1	    1.00542	    0.00000	 220.0	 1	    1.11085	    0.90000;
	1834	 1	 0.0	 0.0	 0.0	 12.53399	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1835	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1836	 1	 41.44595	 4.9	 0.0	 0.0	 1	    1.02037	    0.00000	 220.0	 1	    1.14074	    0.90000;
	1837	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02464	    0.00000	 220.0	 1	    1.14928	    0.90000;
	1838	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02932	    0.00000	 380.0	 1	    1.15863	    0.90000;
	1839	 1	 25.92875	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1840	 1	 119.0	 -315.3	 0.0	 0.0	 1	    1.01363	    0.00000	 380.0	 1	    1.12726	    0.90000;
	1841	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01379	    0.00000	 220.0	 1	    1.12758	    0.90000;
	1842	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1843	 1	 72.07992	 21.3	 0.0	 0.0	 1	    1.01971	    0.00000	 220.0	 1	    1.13942	    0.90000;
	1844	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01781	    0.00000	 220.0	 1	    1.13562	    0.90000;
	1845	 1	 3.904329	 1.0	 0.0	 0.0	 1	    1.01734	    0.00000	 220.0	 1	    1.13467	    0.90000;
	1846	 1	 8.108991	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1847	 1	 36.4404	 12.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1848	 1	 8.909878	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1849	 1	 89.09879	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1850	 1	 16.01776	 4.0	 0.0	 0.0	 1	    1.01376	    0.00000	 220.0	 1	    1.12752	    0.90000;
	1851	 1	 0.0	 0.0	 0.191685	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1852	 1	 90.0999	 12.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1853	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02253	    0.00000	 150.0	 1	    1.14507	    0.90000;
	1854	 1	 0.0	 0.0	 0.147005	 0.0	 1	    1.03337	    0.00000	 380.0	 1	    1.16673	    0.90000;
	1855	 1	 56.86304	 35.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1856	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1857	 1	 153.6423	 29.2	 0.0	 0.0	 1	    1.00876	    0.00000	 220.0	 1	    1.11753	    0.90000;
	1858	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02084	    0.00000	 380.0	 1	    1.14168	    0.90000;
	1859	 1	 6.306993	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1860	 1	 28.83197	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1861	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01798	    0.00000	 380.0	 1	    1.13597	    0.90000;
	1862	 1	 297.7	 258.6	 0.0	 0.0	 1	    1.03323	    0.00000	 380.0	 1	    1.16647	    0.90000;
	1863	 1	 178.4	 69.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1864	 1	 0.0	 0.0	 0.26688	 0.0	 1	    1.01312	    0.00000	 380.0	 1	    1.12624	    0.90000;
	1865	 1	 14.01554	 6.5	 0.0	 0.0	 1	    1.01651	    0.00000	 220.0	 1	    1.13303	    0.90000;
	1866	 1	 3.203552	 1.7	 0.0	 0.0	 1	    1.01207	    0.00000	 220.0	 1	    1.12415	    0.90000;
	1867	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02368	    0.00000	 220.0	 1	    1.14735	    0.90000;
	1868	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1869	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1870	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1871	 1	 19.22131	 6.9	 0.0	 0.0	 1	    1.00297	    0.00000	 110.0	 1	    1.10593	    0.90000;
	1872	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02080	    0.00000	 380.0	 1	    1.14161	    0.90000;
	1873	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02634	    0.00000	 380.0	 1	    1.15267	    0.90000;
	1874	 1	 0.0	 0.0	 0.0	 22.29212	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1875	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01149	    0.00000	 220.0	 1	    1.12299	    0.90000;
	1876	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01675	    0.00000	 220.0	 1	    1.13350	    0.90000;
	1877	 1	 52.65838	 21.5	 0.0	 0.0	 1	    1.01858	    0.00000	 150.0	 1	    1.13717	    0.90000;
	1878	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00765	    0.00000	 380.0	 1	    1.11530	    0.90000;
	1879	 1	 120.2	 20.5	 0.0	 0.0	 1	    1.02169	    0.00000	 220.0	 1	    1.14338	    0.90000;
	1880	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02308	    0.00000	 380.0	 1	    1.14616	    0.90000;
	1881	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02278	    0.00000	 380.0	 1	    1.14556	    0.90000;
	1882	 1	 115.1	 23.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1883	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1884	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1885	 2	 108.7	 10.3	 0.0	 0.0	 1	    1.01027	    0.00000	 220.0	 1	    1.12053	    0.90000;
	1886	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01450	    0.00000	 220.0	 1	    1.12900	    0.90000;
	1887	 1	 0.0	 0.0	 0.0	 35.51478	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1888	 1	 50.15561	 18.0	 0.0	 0.0	 1	    1.01178	    0.00000	 110.0	 1	    1.12356	    0.90000;
	1889	 1	 1.401554	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1890	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1891	 1	 101.2	 2.1	 0.0	 0.0	 1	    1.02793	    0.00000	 380.0	 1	    1.15587	    0.90000;
	1892	 1	 86.89635	 30.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1893	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01379	    0.00000	 380.0	 1	    1.12759	    0.90000;
	1894	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01466	    0.00000	 380.0	 1	    1.12933	    0.90000;
	1895	 1	 72.18002	 44.9	 0.0	 0.0	 1	    1.01550	    0.00000	 150.0	 1	    1.13099	    0.90000;
	1896	 1	 77.18558	 18.6	 0.0	 0.0	 1	    1.01901	    0.00000	 220.0	 1	    1.13801	    0.90000;
	1897	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00351	    0.00000	 220.0	 1	    1.10701	    0.90000;
	1898	 1	 163.7	 94.1	 0.0	 0.0	 1	    1.01035	    0.00000	 380.0	 1	    1.12071	    0.90000;
	1899	 1	 30.9343	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1900	 1	 121.4	 20.2	 0.0	 0.0	 1	    1.02305	    0.00000	 220.0	 1	    1.14610	    0.90000;
	1901	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1902	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01621	    0.00000	 380.0	 1	    1.13241	    0.90000;
	1903	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00859	    0.00000	 220.0	 1	    1.11717	    0.90000;
	1904	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00614	    0.00000	 220.0	 1	    1.11228	    0.90000;
	1905	 2	 208.5	 60.9	 0.0	 0.0	 1	    1.01428	    0.00000	 220.0	 1	    1.12856	    0.90000;
	1906	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01695	    0.00000	 220.0	 1	    1.13390	    0.90000;
	1907	 2	 110.6	 53.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1908	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00632	    0.00000	 380.0	 1	    1.11265	    0.90000;
	1909	 1	 65.87304	 31.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1910	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1911	 2	 3.3	 313.7	 0.0	 0.0	 1	    1.01559	    0.00000	 380.0	 1	    1.13119	    0.90000;
	1912	 1	 54.26016	 19.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1913	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00358	    0.00000	 380.0	 1	    1.10716	    0.90000;
	1914	 1	 -3.70411	 -8.0	 0.0	 0.0	 1	    1.01084	    0.00000	 380.0	 1	    1.12169	    0.90000;
	1915	 2	 0.2	 0.2	 0.0	 0.0	 1	    1.02639	    0.00000	 380.0	 1	    1.15278	    0.90000;
	1916	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01846	    0.00000	 380.0	 1	    1.13691	    0.90000;
	1917	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1918	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00862	    0.00000	 220.0	 1	    1.11724	    0.90000;
	1919	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1920	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1921	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00992	    0.00000	 380.0	 1	    1.11984	    0.90000;
	1922	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.01234	    0.00000	 220.0	 1	    1.12467	    0.90000;
	1923	 1	 529.9	 23.3	 0.0	 0.0	 1	    1.01337	    0.00000	 380.0	 1	    1.12675	    0.90000;
	1924	 1	 0.0	 0.0	 0.127001	 0.0	 1	    1.01184	    0.00000	 220.0	 1	    1.12367	    0.90000;
	1925	 1	 12.81421	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1926	 1	 152.5	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1927	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03527	    0.00000	 380.0	 1	    1.17053	    0.90000;
	1928	 1	 5.706326	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1929	 2	 15.81754	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1930	 1	 53.35916	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1931	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02122	    0.00000	 150.0	 1	    1.14244	    0.90000;
	1932	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1933	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02154	    0.00000	 150.0	 1	    1.14308	    0.90000;
	1934	 1	 133.2	 24.8	 0.0	 0.0	 1	    1.03183	    0.00000	 380.0	 1	    1.16366	    0.90000;
	1935	 1	 19.82198	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1936	 2	 8.108991	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1937	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1938	 1	 92.30234	 14.6	 0.0	 0.0	 1	    1.00288	    0.00000	 220.0	 1	    1.10577	    0.90000;
	1939	 1	 30.33363	 11.0	 0.0	 0.0	 1	    1.01391	    0.00000	 110.0	 1	    1.12783	    0.90000;
	1940	 1	 79.08768	 18.7	 0.0	 0.0	 1	    1.01892	    0.00000	 220.0	 1	    1.13785	    0.90000;
	1941	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01602	    0.00000	 380.0	 1	    1.13204	    0.90000;
	1942	 1	 34.33807	 12.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1943	 1	 16.21798	 4.0	 0.0	 0.0	 1	    1.00677	    0.00000	 150.0	 1	    1.11354	    0.90000;
	1944	 1	 107.3	 14.2	 0.0	 0.0	 1	    1.02003	    0.00000	 220.0	 1	    1.14005	    0.90000;
	1945	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00698	    0.00000	 380.0	 1	    1.11395	    0.90000;
	1946	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02335	    0.00000	 220.0	 1	    1.14669	    0.90000;
	1947	 1	 78.68724	 56.7	 0.0	 0.0	 1	    1.00865	    0.00000	 220.0	 1	    1.11730	    0.90000;
	1948	 1	 137.8	 64.5	 0.0	 0.0	 1	    1.00911	    0.00000	 380.0	 1	    1.11822	    0.90000;
	1949	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1950	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1951	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03001	    0.00000	 220.0	 1	    1.16003	    0.90000;
	1952	 1	 129.5	 38.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1953	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00517	    0.00000	 220.0	 1	    1.11034	    0.90000;
	1954	 1	 130.9	 37.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1955	 1	 10.81199	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1956	 1	 6.106771	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1957	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1958	 1	 17.61954	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1959	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01852	    0.00000	 380.0	 1	    1.13704	    0.90000;
	1960	 1	 0.0	 0.0	 0.191685	 0.0	 1	    1.00383	    0.00000	 220.0	 1	    1.10766	    0.90000;
	1961	 2	 708.5	 228.6	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1962	 1	 0.0	 0.0	 0.294	 0.0	 1	    1.00907	    0.00000	 380.0	 1	    1.11814	    0.90000;
	1963	 1	 63.67059	 20.2	 0.0	 0.0	 1	    1.01656	    0.00000	 220.0	 1	    1.13313	    0.90000;
	1964	 1	 6.00666	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1965	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00590	    0.00000	 380.0	 1	    1.11180	    0.90000;
	1966	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1967	 1	 51.95761	 32.2	 0.0	 0.0	 1	    0.94750	    0.00000	 150.0	 1	    1.10000	    0.79500;
	1968	 1	 304.2	 114.1	 0.0	 0.0	 1	    1.01109	    0.00000	 380.0	 1	    1.12218	    0.90000;
	1969	 2	 52.15783	 2.1	 0.0	 0.0	 1	    1.01507	    0.00000	 220.0	 1	    1.13013	    0.90000;
	1970	 1	 12.21354	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1971	 2	 6.607326	 2.4	 0.0	 0.0	 1	    1.00542	    0.00000	 110.0	 1	    1.11084	    0.90000;
	1972	 1	 15.81754	 9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1973	 1	 20.9232	 7.7	 0.0	 0.0	 1	    1.00940	    0.00000	 220.0	 1	    1.11880	    0.90000;
	1974	 2	 29.93319	 9.9	 0.0	 0.0	 1	    1.00424	    0.00000	 110.0	 1	    1.10847	    0.90000;
	1975	 2	 20.62287	 6.2	 0.0	 0.0	 1	    1.02299	    0.00000	 150.0	 1	    1.14597	    0.90000;
	1976	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01067	    0.00000	 220.0	 1	    1.12134	    0.90000;
	1977	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1978	 1	 114.2	 34.4	 0.0	 0.0	 1	    1.00776	    0.00000	 220.0	 1	    1.11551	    0.90000;
	1979	 1	 396.7	 62.8	 0.0	 0.0	 1	    1.02142	    0.00000	 120.0	 1	    1.14285	    0.90000;
	1980	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01482	    0.00000	 380.0	 1	    1.12964	    0.90000;
	1981	 1	 0.0	 0.0	 0.167999	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1982	 2	 -1397.75	 -894.7	 0.28548	 20.0	 1	    1.01242	    0.00000	 380.0	 1	    1.12484	    0.90000;
	1983	 2	 171.1	 49.1	 0.0	 0.0	 1	    1.00804	    0.00000	 220.0	 1	    1.11607	    0.90000;
	1984	 1	 40.64506	 13.2	 0.0	 0.0	 1	    1.00994	    0.00000	 110.0	 1	    1.11988	    0.90000;
	1985	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1986	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01951	    0.00000	 150.0	 1	    1.13902	    0.90000;
	1987	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00526	    0.00000	 380.0	 1	    1.11051	    0.90000;
	1988	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1989	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01640	    0.00000	 220.0	 1	    1.13280	    0.90000;
	1990	 2	 156.5	 31.2	 0.0	 0.0	 1	    1.02598	    0.00000	 380.0	 1	    1.15196	    0.90000;
	1991	 1	 25.22797	 11.9	 0.0	 0.0	 1	    1.02491	    0.00000	 380.0	 1	    1.14982	    0.90000;
	1992	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01782	    0.00000	 220.0	 1	    1.13565	    0.90000;
	1993	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01654	    0.00000	 380.0	 1	    1.13308	    0.90000;
	1994	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01117	    0.00000	 220.0	 1	    1.12234	    0.90000;
	1995	 2	 0.0	 0.0	 0.164823	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1996	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1997	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1998	 1	 55.46149	 18.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1999	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2000	 2	 79.2879	 40.1	 0.0	 0.0	 1	    1.02209	    0.00000	 380.0	 1	    1.14417	    0.90000;
	2001	 1	 34.13785	 11.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2002	 1	 297.2	 93.2	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2003	 1	 137.3	 -2.8	 0.0	 0.0	 1	    1.00665	    0.00000	 220.0	 1	    1.11330	    0.90000;
	2004	 1	 29.03219	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2005	 1	 213.0	 39.6	 0.0	 0.0	 1	    1.01450	    0.00000	 380.0	 1	    1.12900	    0.90000;
	2006	 1	 0.0	 0.0	 0.260248	 0.0	 1	    1.00747	    0.00000	 380.0	 1	    1.11495	    0.90000;
	2007	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01309	    0.00000	 380.0	 1	    1.12617	    0.90000;
	2008	 1	 11.01221	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2009	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2010	 2	 17.51942	 10.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2011	 1	 74.98314	 26.9	 0.0	 0.0	 1	    1.01592	    0.00000	 220.0	 1	    1.13184	    0.90000;
	2012	 1	 6.00666	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2013	 1	 0.0	 -7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2014	 1	 44.54939	 16.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2015	 1	 60.0666	 45.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2016	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2017	 2	 54.36027	 9.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2018	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02887	    0.00000	 380.0	 1	    1.15774	    0.90000;
	2019	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2020	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2021	 1	 20.32253	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2022	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00711	    0.00000	 150.0	 1	    1.11421	    0.90000;
	2023	 2	 24.12675	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2024	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02839	    0.00000	 380.0	 1	    1.15678	    0.90000;
	2025	 1	 142.8	 19.5	 0.0	 0.0	 1	    1.00638	    0.00000	 220.0	 1	    1.11276	    0.90000;
	2026	 1	 78.78735	 27.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2027	 2	 88.69834	 25.5	 0.0	 0.0	 1	    1.01142	    0.00000	 220.0	 1	    1.12284	    0.90000;
	2028	 1	 145.7	 83.6	 0.148479	 0.0	 1	    1.01878	    0.00000	 380.0	 1	    1.13756	    0.90000;
	2029	 1	 0.0	 0.0	 0.0	 31.03723	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2030	 1	 143.1	 18.9	 0.0	 0.0	 1	    1.00294	    0.00000	 110.0	 1	    1.10587	    0.90000;
	2031	 1	 -18.8	 -5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2032	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02779	    0.00000	 220.0	 1	    1.15559	    0.90000;
	2033	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02639	    0.00000	 220.0	 1	    1.15277	    0.90000;
	2034	 1	 19.52164	 11.0	 0.0	 0.0	 1	    1.01329	    0.00000	 220.0	 1	    1.12657	    0.90000;
	2035	 1	 269.9	 12.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2036	 1	 63.67059	 39.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2037	 1	 193.1	 69.9	 0.0	 0.0	 1	    1.01179	    0.00000	 380.0	 1	    1.12358	    0.90000;
	2038	 2	 43.7485	 16.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2039	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00655	    0.00000	 220.0	 1	    1.11309	    0.90000;
	2040	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2041	 2	 1.301443	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2042	 1	 66.87415	 21.8	 0.0	 0.0	 1	    1.00457	    0.00000	 150.0	 1	    1.10913	    0.90000;
	2043	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03347	    0.00000	 220.0	 1	    1.16695	    0.90000;
	2044	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00489	    0.00000	 150.0	 1	    1.10979	    0.90000;
	2045	 1	 7.608436	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2046	 2	 61.76849	 15.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2047	 1	 110.3	 28.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2048	 1	 1.801998	 0.7	 0.0	 0.0	 1	    1.03110	    0.00000	 110.0	 1	    1.16220	    0.90000;
	2049	 2	 162.9	 93.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2050	 1	 25.32808	 12.7	 0.191685	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2051	 1	 100.7	 -4.2	 0.0	 0.0	 1	    1.03506	    0.00000	 220.0	 1	    1.17012	    0.90000;
	2052	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03373	    0.00000	 380.0	 1	    1.16745	    0.90000;
	2053	 1	 0.0	 -8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2054	 1	 23.02553	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2055	 1	 97.0	 18.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2056	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2057	 1	 5.706326	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2058	 1	 305.6	 207.3	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2059	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01731	    0.00000	 380.0	 1	    1.13462	    0.90000;
	2060	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2061	 1	 1.902109	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2062	 2	 0.0	 0.0	 0.092763	 0.0	 1	    1.01222	    0.00000	 380.0	 1	    1.12443	    0.90000;
	2063	 1	 0.0	 0.0	 0.155924	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2064	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2065	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01051	    0.00000	 150.0	 1	    1.12102	    0.90000;
	2066	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2067	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01597	    0.00000	 380.0	 1	    1.13193	    0.90000;
	2068	 1	 141.3	 32.4	 0.0	 0.0	 1	    1.03318	    0.00000	 220.0	 1	    1.16636	    0.90000;
	2069	 2	 342.1	 61.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2070	 1	 91.90189	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2071	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01939	    0.00000	 220.0	 1	    1.13877	    0.90000;
	2072	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00960	    0.00000	 380.0	 1	    1.11921	    0.90000;
	2073	 1	 73.18114	 22.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2074	 1	 11.61288	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2075	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2076	 1	 1.401554	 0.5	 0.0	 0.0	 1	    1.00560	    0.00000	 110.0	 1	    1.11119	    0.90000;
	2077	 2	 100.7	 12.8	 0.0	 0.0	 1	    1.01418	    0.00000	 220.0	 1	    1.12837	    0.90000;
	2078	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2079	 2	 209.3	 60.8	 0.0	 0.0	 1	    1.01568	    0.00000	 220.0	 1	    1.13136	    0.90000;
	2080	 1	 170.9	 39.0	 0.0	 0.0	 1	    1.02196	    0.00000	 220.0	 1	    1.14392	    0.90000;
	2081	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01574	    0.00000	 220.0	 1	    1.13149	    0.90000;
	2082	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02725	    0.00000	 220.0	 1	    1.15449	    0.90000;
	2083	 1	 13.04129	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2084	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2085	 1	 71.8797	 51.3	 0.0	 0.0	 1	    1.01741	    0.00000	 380.0	 1	    1.13482	    0.90000;
	2086	 1	 15.01665	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2087	 1	 30.83419	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2088	 1	 93.20334	 13.6	 0.0	 0.0	 1	    1.00642	    0.00000	 220.0	 1	    1.11283	    0.90000;
	2089	 1	 402.1	 110.2	 0.0	 0.0	 1	    1.01708	    0.00000	 150.0	 1	    1.13416	    0.90000;
	2090	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00506	    0.00000	 220.0	 1	    1.11012	    0.90000;
	2091	 1	 82.39135	 12.3	 0.0	 0.0	 1	    1.00572	    0.00000	 220.0	 1	    1.11145	    0.90000;
	2092	 1	 628.5	 91.8	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2093	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01910	    0.00000	 220.0	 1	    1.13819	    0.90000;
	2094	 1	 88.69834	 -0.1	 0.0	 0.0	 1	    1.03185	    0.00000	 220.0	 1	    1.16370	    0.90000;
	2095	 1	 21.22353	 8.3	 0.0	 0.0	 1	    1.02197	    0.00000	 150.0	 1	    1.14395	    0.90000;
	2096	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00801	    0.00000	 380.0	 1	    1.11601	    0.90000;
	2097	 1	 45.75072	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2098	 1	 32.03552	 6.6	 0.0	 0.0	 1	    1.02769	    0.00000	 220.0	 1	    1.15538	    0.90000;
	2099	 2	 0.0	 0.0	 0.248006	 302.3515	 1	    1.01503	    0.00000	 380.0	 1	    1.13005	    0.90000;
	2100	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2101	 1	 8.409324	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2102	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01112	    0.00000	 220.0	 1	    1.12224	    0.90000;
	2104	 1	 110.6	 20.4	 0.0	 0.0	 1	    1.00338	    0.00000	 220.0	 1	    1.10676	    0.90000;
	2105	 1	 264.0	 40.1	 0.0	 0.0	 1	    1.00959	    0.00000	 380.0	 1	    1.11919	    0.90000;
	2106	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00533	    0.00000	 220.0	 1	    1.11065	    0.90000;
	2107	 1	 12.51387	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2108	 1	 39.64395	 20.9	 0.0	 0.0	 1	    1.01877	    0.00000	 220.0	 1	    1.13755	    0.90000;
	2109	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00558	    0.00000	 220.0	 1	    1.11115	    0.90000;
	2110	 1	 8.409324	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2111	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2113	 1	 24.22686	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2114	 1	 114.5	 25.2	 0.0	 0.0	 1	    1.01618	    0.00000	 220.0	 1	    1.13235	    0.90000;
	2115	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01516	    0.00000	 220.0	 1	    1.13032	    0.90000;
	2116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00578	    0.00000	 380.0	 1	    1.11156	    0.90000;
	2117	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01200	    0.00000	 150.0	 1	    1.12400	    0.90000;
	2118	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01121	    0.00000	 110.0	 1	    1.12243	    0.90000;
	2119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01195	    0.00000	 380.0	 1	    1.12390	    0.90000;
	2120	 1	 27.93097	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01171	    0.00000	 150.0	 1	    1.12343	    0.90000;
	2122	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02679	    0.00000	 150.0	 1	    1.15359	    0.90000;
	2123	 1	 103.4	 27.0	 0.0	 0.0	 1	    1.01617	    0.00000	 220.0	 1	    1.13235	    0.90000;
	2124	 1	 12.7141	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2125	 1	 24.32697	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2126	 1	 96.90745	 13.9	 0.0	 0.0	 1	    1.00656	    0.00000	 220.0	 1	    1.11313	    0.90000;
	2127	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04112	    0.00000	 220.0	 1	    1.18223	    0.90000;
	2128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00763	    0.00000	 380.0	 1	    1.11527	    0.90000;
	2129	 1	 33.03663	 5.6	 0.0	 0.0	 1	    1.00312	    0.00000	 220.0	 1	    1.10624	    0.90000;
	2130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03802	    0.00000	 380.0	 1	    1.17603	    0.90000;
	2131	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2132	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2133	 1	 33.23685	 11.1	 0.0	 0.0	 1	    0.99745	    0.00000	 110.0	 1	    1.10000	    0.89491;
	2134	 1	 0.0	 0.0	 0.119999	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2136	 2	 84.89413	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2137	 1	 4.905439	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2138	 1	 75.78402	 46.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2139	 1	 54.46038	 11.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2140	 1	 0.0	 0.0	 0.0	 11.03517	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2141	 2	 225.9	 50.0	 0.0	 0.0	 1	    1.01309	    0.00000	 380.0	 1	    1.12617	    0.90000;
	2142	 1	 52.95872	 8.2	 0.0	 0.0	 1	    1.00625	    0.00000	 220.0	 1	    1.11250	    0.90000;
	2143	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01978	    0.00000	 380.0	 1	    1.13957	    0.90000;
	2144	 1	 215.5	 31.3	 0.0	 0.0	 1	    1.01549	    0.00000	 220.0	 1	    1.13098	    0.90000;
	2145	 2	 23.32586	 6.9	 0.0	 0.0	 1	    1.02589	    0.00000	 220.0	 1	    1.15178	    0.90000;
	2146	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02695	    0.00000	 380.0	 1	    1.15390	    0.90000;
	2147	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2148	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2149	 1	 37.94207	 15.4	 0.0	 0.0	 1	    1.02157	    0.00000	 380.0	 1	    1.14315	    0.90000;
	2150	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2151	 1	 -15.9176	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2152	 1	 178.5	 65.8	 0.0	 0.0	 1	    1.02364	    0.00000	 380.0	 1	    1.14729	    0.90000;
	2153	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01734	    0.00000	 220.0	 1	    1.13468	    0.90000;
	2154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00666	    0.00000	 380.0	 1	    1.11331	    0.90000;
	2155	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00859	    0.00000	 380.0	 1	    1.11717	    0.90000;
	2156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2157	 1	 17.11898	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2158	 1	 101.7	 17.6	 0.0	 0.0	 1	    1.01047	    0.00000	 220.0	 1	    1.12094	    0.90000;
	2159	 1	 -41.2457	 13.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2160	 1	 1.401554	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2161	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01638	    0.00000	 220.0	 1	    1.13277	    0.90000;
	2162	 1	 32.93652	 13.0	 0.0	 0.0	 1	    1.02457	    0.00000	 150.0	 1	    1.14915	    0.90000;
	2163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2164	 1	 52.25794	 44.2	 0.191685	 0.0	 1	    1.01490	    0.00000	 220.0	 1	    1.12981	    0.90000;
	2165	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01576	    0.00000	 220.0	 1	    1.13152	    0.90000;
	2166	 1	 122.1	 16.7	 0.0	 0.0	 1	    1.01535	    0.00000	 380.0	 1	    1.13069	    0.90000;
	2167	 1	 24.12675	 8.7	 0.079606	 0.0	 1	    1.00646	    0.00000	 220.0	 1	    1.11293	    0.90000;
	2168	 1	 0.100111	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2169	 1	 57.56382	 24.0	 0.0	 0.0	 1	    1.01776	    0.00000	 220.0	 1	    1.13552	    0.90000;
	2170	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00445	    0.00000	 220.0	 1	    1.10891	    0.90000;
	2171	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2172	 1	 20.12231	 12.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2173	 1	 173.7	 23.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2174	 1	 20.82309	 0.0	 0.0	 0.0	 1	    1.00906	    0.00000	 220.0	 1	    1.11812	    0.90000;
	2175	 2	 200.5	 85.0	 0.0	 0.0	 1	    1.00747	    0.00000	 380.0	 1	    1.11494	    0.90000;
	2176	 1	 190.7	 13.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2177	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2178	 2	 75.18336	 50.1	 0.26925	 0.0	 1	    1.03299	    0.00000	 380.0	 1	    1.16599	    0.90000;
	2179	 1	 69.37692	 43.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2180	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2181	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01107	    0.00000	 220.0	 1	    1.12214	    0.90000;
	2182	 1	 37.24129	 5.3	 0.0	 0.0	 1	    1.00794	    0.00000	 220.0	 1	    1.11588	    0.90000;
	2183	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2184	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01666	    0.00000	 220.0	 1	    1.13332	    0.90000;
	2185	 1	 117.1299	 52.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2186	 1	 64.8	 99.1	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2187	 1	 3.904329	 -35.8	 0.0	 0.0	 1	    1.00254	    0.00000	 220.0	 1	    1.10508	    0.90000;
	2188	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2189	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2190	 2	 93.9	 51.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2191	 1	 5.506105	 2.0	 0.0	 0.0	 1	    1.01014	    0.00000	 110.0	 1	    1.12027	    0.90000;
	2192	 1	 14.31587	 5.6	 0.0	 0.0	 1	    1.02212	    0.00000	 380.0	 1	    1.14423	    0.90000;
	2193	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2194	 1	 15.9	 116.3	 0.0	 0.0	 1	    1.00415	    0.00000	 220.0	 1	    1.10831	    0.90000;
	2195	 1	 0.0	 0.0	 0.253999	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2196	 1	 3.403774	 123.8	 0.0	 0.0	 1	    1.01278	    0.00000	 380.0	 1	    1.12557	    0.90000;
	2197	 2	 373.8	 55.6	 0.0	 0.0	 1	    1.03114	    0.00000	 220.0	 1	    1.16229	    0.90000;
	2198	 1	 39.34362	 24.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2199	 1	 523.3	 137.2	 0.0	 0.0	 1	    1.01285	    0.00000	 380.0	 1	    1.12571	    0.90000;
	2200	 1	 44.54939	 16.8	 0.0	 0.0	 1	    1.01782	    0.00000	 220.0	 1	    1.13564	    0.90000;
	2201	 2	 197.4	 52.4	 0.0	 0.0	 1	    1.02227	    0.00000	 220.0	 1	    1.14453	    0.90000;
	2202	 2	 119.4	 23.6	 0.0	 0.0	 1	    1.01884	    0.00000	 220.0	 1	    1.13769	    0.90000;
	2203	 1	 0.0	 0.0	 0.296959	 0.0	 1	    1.02603	    0.00000	 380.0	 1	    1.15206	    0.90000;
	2204	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01777	    0.00000	 150.0	 1	    1.13554	    0.90000;
	2205	 2	 99.4	 35.8	 0.265353	 0.0	 1	    1.00433	    0.00000	 380.0	 1	    1.10867	    0.90000;
	2206	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01706	    0.00000	 220.0	 1	    1.13412	    0.90000;
	2207	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2208	 1	 291.2	 35.4	 0.0	 0.0	 1	    1.01717	    0.00000	 220.0	 1	    1.13434	    0.90000;
	2209	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2210	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2211	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03216	    0.00000	 380.0	 1	    1.16432	    0.90000;
	2212	 1	 0.0	 -8.6	 0.0	 0.0	 1	    1.02441	    0.00000	 380.0	 1	    1.14882	    0.90000;
	2213	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01110	    0.00000	 220.0	 1	    1.12221	    0.90000;
	2214	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2215	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2216	 1	 0.0	 0.0	 0.222985	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2217	 1	 45.6	 142.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2218	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01346	    0.00000	 380.0	 1	    1.12693	    0.90000;
	2219	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2220	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02358	    0.00000	 380.0	 1	    1.14715	    0.90000;
	2221	 1	 34.23796	 16.5	 0.0	 0.0	 1	    1.03184	    0.00000	 220.0	 1	    1.16368	    0.90000;
	2222	 1	 301.9	 -103.2	 0.0	 0.0	 1	    1.02176	    0.00000	 150.0	 1	    1.14352	    0.90000;
	2223	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00547	    0.00000	 150.0	 1	    1.11095	    0.90000;
	2224	 2	 189.1	 38.8	 0.0	 0.0	 1	    1.01067	    0.00000	 220.0	 1	    1.12134	    0.90000;
	2225	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2226	 1	 262.5	 18.9	 0.0	 0.0	 1	    1.04103	    0.00000	 380.0	 1	    1.18207	    0.90000;
	2227	 1	 30.73408	 9.6	 0.0	 0.0	 1	    1.01829	    0.00000	 220.0	 1	    1.13658	    0.90000;
	2228	 1	 132.0	 26.0	 0.0	 0.0	 1	    1.01131	    0.00000	 380.0	 1	    1.12261	    0.90000;
	2229	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02684	    0.00000	 380.0	 1	    1.15367	    0.90000;
	2230	 2	 6.807548	 23.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2231	 1	 3.303663	 1.9	 0.0	 0.0	 1	    1.01827	    0.00000	 110.0	 1	    1.13654	    0.90000;
	2232	 2	 4.605106	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2233	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2234	 1	 1.501665	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2235	 2	 324.4	 93.0	 0.0	 0.0	 1	    1.00318	    0.00000	 380.0	 1	    1.10637	    0.90000;
	2236	 1	 0.0	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2237	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01778	    0.00000	 220.0	 1	    1.13556	    0.90000;
	2238	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01804	    0.00000	 220.0	 1	    1.13607	    0.90000;
	2239	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2240	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2241	 1	 103.5	 21.7	 0.0	 0.0	 1	    1.00263	    0.00000	 220.0	 1	    1.10525	    0.90000;
	2242	 1	 76.58492	 14.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2243	 1	 40.44484	 12.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2244	 1	 35.03885	 16.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2245	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02179	    0.00000	 220.0	 1	    1.14358	    0.90000;
	2246	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2247	 1	 50.9565	 6.8	 0.0	 0.0	 1	    1.02377	    0.00000	 110.0	 1	    1.14754	    0.90000;
	2248	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01797	    0.00000	 380.0	 1	    1.13594	    0.90000;
	2249	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2250	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00490	    0.00000	 220.0	 1	    1.10980	    0.90000;
	2251	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00604	    0.00000	 150.0	 1	    1.11208	    0.90000;
	2252	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00662	    0.00000	 220.0	 1	    1.11323	    0.90000;
	2253	 1	 79.08768	 -36.9	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2254	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00812	    0.00000	 220.0	 1	    1.11624	    0.90000;
	2255	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2256	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02637	    0.00000	 220.0	 1	    1.15275	    0.90000;
	2257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2258	 1	 74.18224	 22.6	 0.0	 0.0	 1	    1.02206	    0.00000	 220.0	 1	    1.14413	    0.90000;
	2259	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00986	    0.00000	 150.0	 1	    1.11972	    0.90000;
	2260	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2261	 1	 50.55605	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2262	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2263	 1	 87.69723	 22.2	 0.0	 0.0	 1	    1.01035	    0.00000	 220.0	 1	    1.12069	    0.90000;
	2264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03607	    0.00000	 380.0	 1	    1.17214	    0.90000;
	2265	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01436	    0.00000	 220.0	 1	    1.12871	    0.90000;
	2266	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02051	    0.00000	 380.0	 1	    1.14103	    0.90000;
	2267	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02599	    0.00000	 220.0	 1	    1.15199	    0.90000;
	2268	 1	 119.2	 32.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2269	 1	 48.75406	 16.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2270	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02518	    0.00000	 380.0	 1	    1.15036	    0.90000;
	2272	 2	 133.7	 10.4	 0.0	 0.0	 1	    1.00963	    0.00000	 220.0	 1	    1.11927	    0.90000;
	2273	 2	 142.7	 34.8	 0.0	 0.0	 1	    1.02449	    0.00000	 220.0	 1	    1.14899	    0.90000;
	2274	 1	 174.1	 -519.7	 0.0	 0.0	 1	    1.02057	    0.00000	 380.0	 1	    1.14114	    0.90000;
	2275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03178	    0.00000	 380.0	 1	    1.16356	    0.90000;
	2276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01485	    0.00000	 380.0	 1	    1.12969	    0.90000;
	2277	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01220	    0.00000	 220.0	 1	    1.12440	    0.90000;
	2279	 2	 42.24684	 12.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2280	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01165	    0.00000	 380.0	 1	    1.12330	    0.90000;
	2281	 2	 89.79956	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2282	 1	 0.0	 0.0	 0.047488	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2283	 1	 59.7	 26.3	 0.0	 0.0	 1	    1.00819	    0.00000	 380.0	 1	    1.11638	    0.90000;
	2284	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03057	    0.00000	 220.0	 1	    1.16115	    0.90000;
	2285	 1	 18.32031	 14.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2286	 2	 275.1	 63.0	 0.0	 0.0	 1	    1.02505	    0.00000	 380.0	 1	    1.15010	    0.90000;
	2287	 1	 59.76627	 16.7	 0.0	 0.0	 1	    1.01414	    0.00000	 220.0	 1	    1.12829	    0.90000;
	2288	 1	 -10.4086	 -3.3	 0.0	 0.0	 1	    1.00480	    0.00000	 150.0	 1	    1.10960	    0.90000;
	2289	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2290	 1	 77.3858	 20.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2291	 1	 1.301443	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2292	 1	 0.0	 0.0	 0.077386	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2293	 2	 0.0	 0.0	 0.196238	 0.0	 1	    1.01354	    0.00000	 220.0	 1	    1.12708	    0.90000;
	2294	 1	 51.55716	 2.1	 0.0	 0.0	 1	    1.02130	    0.00000	 220.0	 1	    1.14259	    0.90000;
	2295	 1	 15.11676	 9.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2296	 1	 70.27792	 16.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2297	 1	 118.8	 39.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2298	 2	 177.4	 85.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2299	 1	 278.3481	 90.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2300	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2301	 1	 72.68058	 45.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2302	 1	 38.44262	 13.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2303	 1	 27.3303	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2304	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01344	    0.00000	 380.0	 1	    1.12688	    0.90000;
	2305	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2306	 1	 -4.87602	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2307	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01997	    0.00000	 220.0	 1	    1.13994	    0.90000;
	2308	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01839	    0.00000	 220.0	 1	    1.13677	    0.90000;
	2309	 1	 205.3	 27.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2310	 1	 28.53163	 11.3	 0.0	 0.0	 1	    1.02318	    0.00000	 150.0	 1	    1.14637	    0.90000;
	2311	 2	 92.50256	 -23.8	 0.0	 0.0	 1	    1.03578	    0.00000	 220.0	 1	    1.17156	    0.90000;
	2312	 1	 32.53607	 10.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2313	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02306	    0.00000	 110.0	 1	    1.14612	    0.90000;
	2314	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01404	    0.00000	 220.0	 1	    1.12808	    0.90000;
	2315	 1	 0.0	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2316	 2	 160.6	 39.6	 0.0	 0.0	 1	    1.01669	    0.00000	 220.0	 1	    1.13338	    0.90000;
	2317	 1	 17.01887	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2318	 1	 6.507215	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2319	 1	 1.801998	 0.7	 0.0	 0.0	 1	    1.01147	    0.00000	 110.0	 1	    1.12294	    0.90000;
	2320	 1	 -88.5982	 -24.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2321	 1	 52.8586	 13.0	 0.0	 0.0	 1	    1.01761	    0.00000	 220.0	 1	    1.13523	    0.90000;
	2322	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00725	    0.00000	 220.0	 1	    1.11450	    0.90000;
	2323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2324	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02121	    0.00000	 380.0	 1	    1.14242	    0.90000;
	2325	 1	 25.42819	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2326	 2	 78.58714	 21.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2327	 2	 42.24684	 10.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2328	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01444	    0.00000	 220.0	 1	    1.12889	    0.90000;
	2329	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2330	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01869	    0.00000	 150.0	 1	    1.13738	    0.90000;
	2331	 2	 255.7	 67.4	 0.0	 0.0	 1	    1.00307	    0.00000	 220.0	 1	    1.10613	    0.90000;
	2332	 1	 100.1	 44.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2333	 1	 62.96982	 17.4	 0.0	 0.0	 1	    1.01712	    0.00000	 220.0	 1	    1.13424	    0.90000;
	2334	 1	 27.05028	 22.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2335	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01450	    0.00000	 380.0	 1	    1.12900	    0.90000;
	2336	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2337	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01981	    0.00000	 110.0	 1	    1.13961	    0.90000;
	2338	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99635	    0.00000	 150.0	 1	    1.10000	    0.89269;
	2339	 1	 -15.7174	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2340	 1	 2.302553	 0.8	 0.0	 0.0	 1	    1.01648	    0.00000	 110.0	 1	    1.13296	    0.90000;
	2341	 1	 174.6	 48.9	 0.0	 0.0	 1	    1.00878	    0.00000	 380.0	 1	    1.11757	    0.90000;
	2342	 1	 0.0	 0.0	 0.119668	 0.0	 1	    1.02574	    0.00000	 380.0	 1	    1.15148	    0.90000;
	2343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00960	    0.00000	 150.0	 1	    1.11920	    0.90000;
	2344	 1	 39.04329	 24.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2345	 2	 235.1	 54.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2346	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01198	    0.00000	 380.0	 1	    1.12396	    0.90000;
	2347	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2348	 2	 254.2	 84.6	 0.0	 0.0	 1	    1.01825	    0.00000	 220.0	 1	    1.13649	    0.90000;
	2349	 1	 28.13119	 14.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2350	 1	 -9.51054	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2351	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02786	    0.00000	 220.0	 1	    1.15571	    0.90000;
	2352	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00662	    0.00000	 380.0	 1	    1.11324	    0.90000;
	2353	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2354	 1	 14.71632	 5.4	 0.0	 0.0	 1	    1.02219	    0.00000	 220.0	 1	    1.14437	    0.90000;
	2355	 1	 25.62842	 12.7	 0.0	 0.0	 1	    1.01811	    0.00000	 220.0	 1	    1.13621	    0.90000;
	2356	 2	 16.31809	 3.0	 0.0	 0.0	 1	    1.01941	    0.00000	 220.0	 1	    1.13882	    0.90000;
	2357	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2358	 1	 -23.1256	 -8.4	 0.0	 0.0	 1	    1.00615	    0.00000	 110.0	 1	    1.11230	    0.90000;
	2359	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2360	 2	 234.3	 105.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2361	 1	 115.3	 -8.8	 0.0	 0.0	 1	    1.01703	    0.00000	 220.0	 1	    1.13406	    0.90000;
	2362	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02238	    0.00000	 380.0	 1	    1.14477	    0.90000;
	2364	 1	 226.8002	 53.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2365	 1	 14.91654	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2366	 1	 499.8002	 110.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2367	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00893	    0.00000	 380.0	 1	    1.11786	    0.90000;
	2368	 1	 0.0	 0.0	 0.0	 -16.763	 1	    1.02986	    0.00000	 150.0	 1	    1.15971	    0.90000;
	2369	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2370	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2371	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00415	    0.00000	 380.0	 1	    1.10831	    0.90000;
	2372	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02474	    0.00000	 150.0	 1	    1.14948	    0.90000;
	2373	 1	 14.73807	 14.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2374	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00459	    0.00000	 150.0	 1	    1.10918	    0.90000;
	2375	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2376	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02143	    0.00000	 380.0	 1	    1.14285	    0.90000;
	2377	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01135	    0.00000	 220.0	 1	    1.12270	    0.90000;
	2378	 1	 10.61177	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2379	 1	 5.506105	 2.0	 0.0	 0.0	 1	    1.01097	    0.00000	 110.0	 1	    1.12194	    0.90000;
	2380	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02350	    0.00000	 380.0	 1	    1.14701	    0.90000;
	2381	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2382	 1	 203.1	 65.2	 0.0	 0.0	 1	    1.01508	    0.00000	 220.0	 1	    1.13017	    0.90000;
	2383	 1	 166.7	 87.6	 0.0	 0.0	 1	    1.01301	    0.00000	 380.0	 1	    1.12601	    0.90000;
	2384	 1	 29.93319	 -4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2385	 1	 655.8	 72.8	 0.0	 0.0	 1	    1.01667	    0.00000	 380.0	 1	    1.13335	    0.90000;
	2386	 1	 3.704107	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2387	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00882	    0.00000	 380.0	 1	    1.11764	    0.90000;
	2388	 1	 42.94762	 26.6	 0.0	 0.0	 1	    0.96083	    0.00000	 150.0	 1	    1.10000	    0.82166;
	2389	 1	 98.3	 25.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2390	 1	 33.03663	 12.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2391	 1	 21.72409	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2392	 1	 45.04995	 -4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2393	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00928	    0.00000	 220.0	 1	    1.11856	    0.90000;
	2394	 2	 87.8	 492.1	 0.0	 0.0	 1	    1.01562	    0.00000	 380.0	 1	    1.13124	    0.90000;
	2395	 1	 2.00222	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2396	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03195	    0.00000	 220.0	 1	    1.16390	    0.90000;
	2397	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2398	 1	 123.1	 3.9	 0.0	 0.0	 1	    1.02172	    0.00000	 380.0	 1	    1.14343	    0.90000;
	2399	 1	 70.1778	 30.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2400	 1	 46.65172	 15.1	 0.0	 0.0	 1	    1.01970	    0.00000	 110.0	 1	    1.13941	    0.90000;
	2401	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02291	    0.00000	 380.0	 1	    1.14582	    0.90000;
	2402	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02878	    0.00000	 220.0	 1	    1.15755	    0.90000;
	2403	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2404	 1	 93.1	 43.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2405	 2	 71.47926	 24.0	 0.0	 0.0	 1	    1.01917	    0.00000	 220.0	 1	    1.13834	    0.90000;
	2406	 1	 207.1	 50.4	 0.0	 0.0	 1	    1.00966	    0.00000	 220.0	 1	    1.11932	    0.90000;
	2407	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2408	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01101	    0.00000	 380.0	 1	    1.12203	    0.90000;
	2409	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2410	 2	 -10.812	 35.4	 0.0	 0.0	 1	    1.00422	    0.00000	 220.0	 1	    1.10845	    0.90000;
	2411	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2412	 1	 45.45039	 28.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2413	 2	 62.66948	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2414	 1	 150.0	 104.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2415	 2	 7.207992	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2416	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2417	 1	 70.67836	 10.7	 0.0	 0.0	 1	    1.00747	    0.00000	 220.0	 1	    1.11495	    0.90000;
	2418	 1	 252.9	 95.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2419	 1	 223.5	 48.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2420	 1	 20.9232	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2421	 1	 16.81865	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2422	 2	 7.908769	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2423	 1	 13.21465	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2424	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2425	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01572	    0.00000	 220.0	 1	    1.13144	    0.90000;
	2426	 2	 139.2	 29.0	 0.0	 0.0	 1	    1.02334	    0.00000	 220.0	 1	    1.14668	    0.90000;
	2427	 1	 0.0	 0.0	 0.238001	 0.0	 1	    1.00415	    0.00000	 220.0	 1	    1.10831	    0.90000;
	2428	 1	 10.61177	 3.8	 0.0	 0.0	 1	    1.01058	    0.00000	 110.0	 1	    1.12117	    0.90000;
	2429	 1	 27.93097	 10.1	 0.0	 0.0	 1	    1.01271	    0.00000	 110.0	 1	    1.12541	    0.90000;
	2430	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02735	    0.00000	 380.0	 1	    1.15470	    0.90000;
	2431	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2432	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2433	 1	 394.9	 45.9	 0.0	 0.0	 1	    1.00674	    0.00000	 380.0	 1	    1.11349	    0.90000;
	2434	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2435	 2	 107.4	 37.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2436	 1	 2.00222	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2437	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99531	    0.00000	 150.0	 1	    1.10000	    0.89063;
	2438	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01972	    0.00000	 220.0	 1	    1.13943	    0.90000;
	2439	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2440	 2	 13.91543	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2441	 1	 285.2	 65.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2442	 1	 681.5	 57.7	 0.0	 0.0	 1	    1.01373	    0.00000	 380.0	 1	    1.12746	    0.90000;
	2443	 1	 16.21798	 8.9	 0.0	 0.0	 1	    1.02073	    0.00000	 220.0	 1	    1.14146	    0.90000;
	2444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2445	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2446	 1	 0.0	 -1.2	 0.0	 0.0	 1	    1.00557	    0.00000	 110.0	 1	    1.11113	    0.90000;
	2447	 1	 23.12564	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2448	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01086	    0.00000	 380.0	 1	    1.12173	    0.90000;
	2449	 1	 0.0	 0.0	 0.0	 18.60544	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2450	 1	 151.7	 27.6	 0.0	 0.0	 1	    1.01416	    0.00000	 220.0	 1	    1.12832	    0.90000;
	2451	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01912	    0.00000	 150.0	 1	    1.13824	    0.90000;
	2452	 1	 56.26238	 18.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2453	 1	 117.4	 12.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2454	 1	 118.0	 37.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2455	 1	 0.0	 0.0	 0.090703	 0.0	 1	    1.02101	    0.00000	 380.0	 1	    1.14202	    0.90000;
	2456	 1	 47.75294	 18.8	 0.0	 0.0	 1	    1.01935	    0.00000	 150.0	 1	    1.13871	    0.90000;
	2457	 1	 189.7	 52.0	 0.0	 0.0	 1	    1.01251	    0.00000	 380.0	 1	    1.12503	    0.90000;
	2458	 2	 349.6	 96.7	 0.0	 20.0	 1	    1.01252	    0.00000	 380.0	 1	    1.12503	    0.90000;
	2459	 1	 104.8	 22.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2460	 1	 11.01221	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2461	 1	 0.0	 8.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2462	 1	 90.50034	 27.8	 0.0	 0.0	 1	    1.00965	    0.00000	 220.0	 1	    1.11930	    0.90000;
	2463	 1	 0.0	 0.0	 0.319997	 0.0	 1	    1.00738	    0.00000	 380.0	 1	    1.11477	    0.90000;
	2464	 1	 32.03552	 11.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2465	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01484	    0.00000	 220.0	 1	    1.12967	    0.90000;
	2466	 1	 13.01443	 14.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2467	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2468	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2469	 1	 3.804218	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2470	 1	 151.2	 81.3	 0.0	 0.0	 1	    1.01164	    0.00000	 380.0	 1	    1.12327	    0.90000;
	2471	 2	 43.34806	 26.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2472	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2473	 1	 32.53607	 11.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2474	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03178	    0.00000	 220.0	 1	    1.16356	    0.90000;
	2475	 2	 26.62953	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.20000	    0.80000;
	2476	 1	 0.1	 152.7	 0.0	 0.0	 1	    1.02446	    0.00000	 380.0	 1	    1.14892	    0.90000;
	2477	 1	 44.04884	 14.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2478	 2	 86.59601	 21.5	 0.0	 0.0	 1	    1.01424	    0.00000	 380.0	 1	    1.12848	    0.90000;
	2479	 2	 34.13785	 12.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2480	 1	 -61.6684	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2481	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2482	 1	 0.0	 0.0	 0.13851	 0.0	 1	    1.02946	    0.00000	 380.0	 1	    1.15892	    0.90000;
	2483	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2484	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2485	 1	 36.24018	 5.7	 0.0	 0.0	 1	    1.00644	    0.00000	 220.0	 1	    1.11289	    0.90000;
	2486	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00346	    0.00000	 150.0	 1	    1.10693	    0.90000;
	2487	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2488	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2489	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02264	    0.00000	 150.0	 1	    1.14528	    0.90000;
	2490	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2491	 1	 65.4726	 26.7	 0.0	 0.0	 1	    1.02112	    0.00000	 150.0	 1	    1.14224	    0.90000;
	2492	 1	 55.5616	 26.5	 0.0	 0.0	 1	    1.02168	    0.00000	 220.0	 1	    1.14335	    0.90000;
	2493	 1	 34.53829	 8.6	 0.0	 0.0	 1	    1.00911	    0.00000	 220.0	 1	    1.11823	    0.90000;
	2494	 1	 12.21354	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2495	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2496	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00666	    0.00000	 220.0	 1	    1.11333	    0.90000;
	2497	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00261	    0.00000	 380.0	 1	    1.10522	    0.90000;
	2498	 1	 159.3	 13.5	 0.0	 0.0	 1	    1.01265	    0.00000	 380.0	 1	    1.12529	    0.90000;
	2499	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2500	 2	 263.3	 21.9	 0.0	 0.0	 1	    1.02705	    0.00000	 380.0	 1	    1.15410	    0.90000;
	2501	 1	 90.40023	 13.8	 0.0	 0.0	 1	    1.02231	    0.00000	 220.0	 1	    1.14462	    0.90000;
	2502	 1	 64.87193	 25.6	 0.0	 0.0	 1	    1.02036	    0.00000	 150.0	 1	    1.14071	    0.90000;
	2503	 1	 8.509435	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2504	 1	 16.51831	 6.0	 0.0	 0.0	 1	    1.00774	    0.00000	 110.0	 1	    1.11549	    0.90000;
	2505	 2	 0.900999	 49.1	 0.0	 0.0	 1	    1.02213	    0.00000	 380.0	 1	    1.14426	    0.90000;
	2506	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01290	    0.00000	 380.0	 1	    1.12580	    0.90000;
	2507	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2508	 1	 98.6	 28.3	 0.0	 0.0	 1	    1.02864	    0.00000	 220.0	 1	    1.15727	    0.90000;
	2509	 1	 85.39468	 14.3	 0.0	 0.0	 1	    1.01086	    0.00000	 220.0	 1	    1.12172	    0.90000;
	2510	 2	 150.8	 29.5	 0.0	 0.0	 1	    1.01354	    0.00000	 220.0	 1	    1.12707	    0.90000;
	2511	 1	 103.1	 3.1	 0.0	 0.0	 1	    1.01842	    0.00000	 380.0	 1	    1.13683	    0.90000;
	2512	 1	 4.705216	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2513	 1	 1.501665	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2514	 2	 10.11121	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2515	 1	 26.62953	 7.6	 0.0	 0.0	 1	    1.01581	    0.00000	 110.0	 1	    1.13163	    0.90000;
	2516	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2517	 1	 35.33918	 21.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2518	 1	 2.903219	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2519	 1	 -9.41043	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2520	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03503	    0.00000	 220.0	 1	    1.17006	    0.90000;
	2521	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2522	 1	 0.300333	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2523	 1	 189.4	 25.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2524	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02032	    0.00000	 380.0	 1	    1.14064	    0.90000;
	2525	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2526	 1	 129.5	 26.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2527	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2528	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01741	    0.00000	 110.0	 1	    1.13483	    0.90000;
	2529	 1	 3.00333	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2530	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02305	    0.00000	 220.0	 1	    1.14610	    0.90000;
	2531	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02722	    0.00000	 220.0	 1	    1.15444	    0.90000;
	2532	 1	 100.7	 17.5	 0.0	 0.0	 1	    1.01882	    0.00000	 150.0	 1	    1.13765	    0.90000;
	2533	 2	 274.1	 69.3	 0.0	 0.0	 1	    1.02186	    0.00000	 220.0	 1	    1.14373	    0.90000;
	2534	 1	 8.909878	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2535	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02703	    0.00000	 220.0	 1	    1.15406	    0.90000;
	2536	 2	 1.0	 128.0	 0.0	 0.0	 1	    1.01018	    0.00000	 380.0	 1	    1.12036	    0.90000;
	2537	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01906	    0.00000	 220.0	 1	    1.13812	    0.90000;
	2538	 1	 24.62731	 8.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2539	 1	 69.07658	 68.0	 0.0	 0.0	 1	    1.00280	    0.00000	 220.0	 1	    1.10559	    0.90000;
	2540	 1	 31.33474	 9.6	 0.0	 0.0	 1	    1.00519	    0.00000	 110.0	 1	    1.11038	    0.90000;
	2541	 1	 390.8	 79.5	 0.0	 0.0	 1	    1.01554	    0.00000	 380.0	 1	    1.13109	    0.90000;
	2542	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02556	    0.00000	 220.0	 1	    1.15112	    0.90000;
	2543	 1	 327.4	 125.3	 0.0	 0.0	 1	    1.01967	    0.00000	 380.0	 1	    1.13933	    0.90000;
	2544	 1	 27.53052	 11.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2545	 1	 6.907659	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2546	 1	 97.0	 18.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2547	 1	 32.93652	 11.8	 0.0	 0.0	 1	    1.00259	    0.00000	 110.0	 1	    1.10518	    0.90000;
	2548	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01570	    0.00000	 380.0	 1	    1.13139	    0.90000;
	2549	 1	 25.32808	 14.2	 0.0	 0.0	 1	    1.01920	    0.00000	 220.0	 1	    1.13839	    0.90000;
	2550	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02641	    0.00000	 380.0	 1	    1.15282	    0.90000;
	2551	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2552	 1	 22.02442	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2553	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2554	 1	 81.19002	 31.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2555	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00306	    0.00000	 220.0	 1	    1.10612	    0.90000;
	2556	 1	 19.32142	 6.4	 0.0	 0.0	 1	    1.01159	    0.00000	 110.0	 1	    1.12318	    0.90000;
	2557	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2558	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2559	 1	 8.909878	 4.9	 0.0	 0.0	 1	    1.00664	    0.00000	 220.0	 1	    1.11329	    0.90000;
	2560	 1	 166.7	 87.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2561	 1	 69.27681	 23.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2562	 1	 46.55161	 9.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2563	 1	 7.408214	 2.7	 0.0	 0.0	 1	    1.02497	    0.00000	 110.0	 1	    1.14993	    0.90000;
	2564	 1	 48.15339	 14.8	 0.0	 0.0	 1	    1.00274	    0.00000	 110.0	 1	    1.10547	    0.90000;
	2565	 1	 3.804218	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2566	 2	 75.08324	 4.0	 0.0	 0.0	 1	    1.02250	    0.00000	 380.0	 1	    1.14500	    0.90000;
	2567	 2	 36.94096	 8.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2568	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2569	 1	 -9.31032	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2570	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2571	 1	 330.9	 51.9	 0.0	 0.0	 1	    1.02419	    0.00000	 120.0	 1	    1.14838	    0.90000;
	2572	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01359	    0.00000	 220.0	 1	    1.12717	    0.90000;
	2573	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01484	    0.00000	 220.0	 1	    1.12969	    0.90000;
	2574	 1	 25.12786	 15.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2575	 1	 179.0	 50.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2576	 1	 21.22353	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2577	 1	 42.24684	 4.4	 0.002004	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2578	 1	 40.14451	 8.8	 0.0	 0.0	 1	    1.01906	    0.00000	 220.0	 1	    1.13813	    0.90000;
	2579	 2	 454.1	 140.0	 0.0	 0.0	 1	    1.00567	    0.00000	 380.0	 1	    1.11133	    0.90000;
	2580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01956	    0.00000	 380.0	 1	    1.13912	    0.90000;
	2581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01778	    0.00000	 220.0	 1	    1.13557	    0.90000;
	2582	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2583	 2	 0.200222	 77.4	 0.0	 0.0	 1	    1.00412	    0.00000	 220.0	 1	    1.10824	    0.90000;
	2584	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2585	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02692	    0.00000	 380.0	 1	    1.15383	    0.90000;
	2586	 1	 0.0	 0.0	 0.25906	 0.0	 1	    1.02570	    0.00000	 380.0	 1	    1.15140	    0.90000;
	2587	 1	 7.107881	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2588	 1	 4.204662	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2589	 1	 192.3	 84.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2590	 1	 -57.0	 -24.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2591	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2592	 1	 17.71965	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2593	 2	 157.2	 14.5	 0.0	 0.0	 1	    1.01003	    0.00000	 220.0	 1	    1.12006	    0.90000;
	2594	 2	 39.24351	 14.5	 0.0	 0.0	 1	    1.01038	    0.00000	 220.0	 1	    1.12075	    0.90000;
	2595	 1	 30.0333	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2596	 1	 46.35139	 16.8	 0.0	 0.0	 1	    1.00726	    0.00000	 220.0	 1	    1.11451	    0.90000;
	2597	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01392	    0.00000	 220.0	 1	    1.12784	    0.90000;
	2598	 2	 235.3	 75.0	 0.0	 0.0	 1	    1.01474	    0.00000	 220.0	 1	    1.12947	    0.90000;
	2599	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2600	 1	 18.8	 8.5	 0.0	 0.0	 1	    1.03034	    0.00000	 380.0	 1	    1.16068	    0.90000;
	2601	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01847	    0.00000	 380.0	 1	    1.13695	    0.90000;
	2602	 2	 87.59712	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2603	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02079	    0.00000	 220.0	 1	    1.14158	    0.90000;
	2604	 2	 33.93763	 21.0	 0.0	 0.0	 1	    1.04688	    0.00000	 150.0	 1	    1.19376	    0.90000;
	2605	 1	 69.27681	 23.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2606	 1	 24.12675	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2607	 1	 29.93319	 0.0	 0.0	 0.0	 1	    1.01745	    0.00000	 220.0	 1	    1.13489	    0.90000;
	2608	 2	 43.54828	 12.0	 0.0	 0.0	 1	    1.01836	    0.00000	 220.0	 1	    1.13673	    0.90000;
	2609	 1	 13.81532	 5.0	 0.0	 0.0	 1	    1.01729	    0.00000	 110.0	 1	    1.13458	    0.90000;
	2610	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2611	 2	 10.41154	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2612	 1	 205.9	 38.3	 0.0	 0.0	 1	    1.01224	    0.00000	 220.0	 1	    1.12448	    0.90000;
	2613	 1	 282.5	 17.4	 0.0	 0.0	 1	    1.00734	    0.00000	 380.0	 1	    1.11468	    0.90000;
	2614	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02364	    0.00000	 380.0	 1	    1.14729	    0.90000;
	2615	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01021	    0.00000	 220.0	 1	    1.12041	    0.90000;
	2616	 1	 57.66393	 61.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2617	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02623	    0.00000	 220.0	 1	    1.15247	    0.90000;
	2618	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02603	    0.00000	 220.0	 1	    1.15206	    0.90000;
	2619	 1	 102.8	 30.8	 0.0	 0.0	 1	    1.02285	    0.00000	 380.0	 1	    1.14570	    0.90000;
	2620	 1	 254.9	 71.4	 0.0	 0.0	 1	    1.00903	    0.00000	 380.0	 1	    1.11806	    0.90000;
	2621	 1	 10.11121	 3.7	 0.0	 0.0	 1	    1.02860	    0.00000	 110.0	 1	    1.15720	    0.90000;
	2622	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2623	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2624	 1	 151.0	 45.7	 0.0	 0.0	 1	    1.00660	    0.00000	 220.0	 1	    1.11320	    0.90000;
	2625	 2	 227.0	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2626	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01799	    0.00000	 110.0	 1	    1.13598	    0.90000;
	2627	 1	 56.76294	 13.4	 0.0	 0.0	 1	    1.01860	    0.00000	 220.0	 1	    1.13720	    0.90000;
	2628	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02186	    0.00000	 380.0	 1	    1.14371	    0.90000;
	2629	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02443	    0.00000	 150.0	 1	    1.14886	    0.90000;
	2630	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01499	    0.00000	 220.0	 1	    1.12997	    0.90000;
	2631	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02155	    0.00000	 220.0	 1	    1.14310	    0.90000;
	2632	 1	 133.7	 59.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2633	 1	 0.0	 0.0	 0.429913	 0.0	 1	    1.02805	    0.00000	 380.0	 1	    1.15611	    0.90000;
	2634	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02092	    0.00000	 220.0	 1	    1.14184	    0.90000;
	2635	 1	 255.8	 144.8	 0.0	 0.0	 1	    1.01094	    0.00000	 380.0	 1	    1.12189	    0.90000;
	2636	 1	 241.0	 32.3	 0.0	 0.0	 1	    1.00714	    0.00000	 220.0	 1	    1.11429	    0.90000;
	2637	 1	 203.8	 61.0	 0.0	 0.0	 1	    1.02272	    0.00000	 150.0	 1	    1.14543	    0.90000;
	2638	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00475	    0.00000	 220.0	 1	    1.10951	    0.90000;
	2639	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02369	    0.00000	 220.0	 1	    1.14738	    0.90000;
	2640	 1	 10.9121	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2641	 1	 46.25128	 32.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2642	 1	 51.95761	 9.4	 0.0	 0.0	 1	    1.01438	    0.00000	 380.0	 1	    1.12876	    0.90000;
	2643	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01060	    0.00000	 110.0	 1	    1.12120	    0.90000;
	2644	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2645	 1	 63.47037	 30.2	 0.0	 0.0	 1	    1.02002	    0.00000	 380.0	 1	    1.14005	    0.90000;
	2646	 1	 31.63507	 7.5	 0.0	 0.0	 1	    1.00861	    0.00000	 220.0	 1	    1.11722	    0.90000;
	2647	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01326	    0.00000	 380.0	 1	    1.12653	    0.90000;
	2648	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00693	    0.00000	 380.0	 1	    1.11385	    0.90000;
	2649	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01411	    0.00000	 380.0	 1	    1.12821	    0.90000;
	2650	 1	 37.24129	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2651	 1	 34.03774	 12.3	 0.0	 0.0	 1	    1.01633	    0.00000	 110.0	 1	    1.13265	    0.90000;
	2652	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01473	    0.00000	 380.0	 1	    1.12945	    0.90000;
	2653	 1	 19.92209	 7.4	 0.0	 0.0	 1	    1.02832	    0.00000	 220.0	 1	    1.15664	    0.90000;
	2654	 1	 19.03607	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2655	 1	 61.96871	 14.3	 0.0	 0.0	 1	    1.00796	    0.00000	 220.0	 1	    1.11593	    0.90000;
	2656	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01385	    0.00000	 380.0	 1	    1.12770	    0.90000;
	2657	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03328	    0.00000	 220.0	 1	    1.16655	    0.90000;
	2658	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2659	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02212	    0.00000	 220.0	 1	    1.14424	    0.90000;
	2660	 1	 230.7	 19.3	 0.0	 0.0	 1	    1.03126	    0.00000	 220.0	 1	    1.16252	    0.90000;
	2661	 1	 17.7	 -333.3	 0.144009	 0.0	 1	    1.01615	    0.00000	 380.0	 1	    1.13229	    0.90000;
	2662	 1	 70.0777	 10.0	 0.0	 0.0	 1	    1.01749	    0.00000	 380.0	 1	    1.13498	    0.90000;
	2663	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01932	    0.00000	 220.0	 1	    1.13864	    0.90000;
	2664	 1	 187.2	 -44.2	 0.0	 0.0	 1	    1.01364	    0.00000	 380.0	 1	    1.12729	    0.90000;
	2665	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00557	    0.00000	 220.0	 1	    1.11113	    0.90000;
	2666	 1	 16.71854	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2667	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00892	    0.00000	 380.0	 1	    1.11783	    0.90000;
	2668	 1	 0.0	 0.0	 0.261	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2669	 1	 103.0	 28.7	 0.0	 0.0	 1	    1.01313	    0.00000	 220.0	 1	    1.12626	    0.90000;
	2670	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01902	    0.00000	 380.0	 1	    1.13804	    0.90000;
	2671	 2	 17.5	 502.7	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2672	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2673	 1	 6.607326	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2674	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2675	 1	 41.94651	 26.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2676	 2	 226.4	 -13.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2677	 2	 2.402664	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2678	 2	 352.7	 119.5	 0.0	 0.0	 1	    1.01326	    0.00000	 380.0	 1	    1.12651	    0.90000;
	2679	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02218	    0.00000	 220.0	 1	    1.14435	    0.90000;
	2680	 1	 16.21798	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2681	 1	 104.6	 40.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2682	 1	 0.0	 0.0	 0.0	 22.7313	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2683	 1	 4.805328	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2684	 1	 188.2	 23.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2685	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04059	    0.00000	 380.0	 1	    1.18119	    0.90000;
	2686	 1	 81.19002	 24.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2687	 1	 16.71854	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2688	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2690	 1	 159.9	 53.2	 0.0	 0.0	 1	    1.01911	    0.00000	 220.0	 1	    1.13821	    0.90000;
	2691	 1	 93.5	 42.5	 0.0	 0.0	 1	    1.02627	    0.00000	 380.0	 1	    1.15253	    0.90000;
	2692	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02017	    0.00000	 380.0	 1	    1.14033	    0.90000;
	2693	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2694	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2695	 1	 4.404884	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2696	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00665	    0.00000	 220.0	 1	    1.11330	    0.90000;
	2697	 2	 134.3	 24.2	 0.0	 0.0	 1	    1.02563	    0.00000	 220.0	 1	    1.15125	    0.90000;
	2698	 1	 9.310323	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2699	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2700	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2701	 2	 108.3	 26.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2702	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00387	    0.00000	 380.0	 1	    1.10774	    0.90000;
	2703	 1	 65.4726	 26.7	 0.0	 0.0	 1	    1.02208	    0.00000	 150.0	 1	    1.14417	    0.90000;
	2704	 2	 53.85971	 15.4	 0.0	 0.0	 1	    1.01209	    0.00000	 110.0	 1	    1.12417	    0.90000;
	2705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2706	 1	 5.806438	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2707	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00683	    0.00000	 220.0	 1	    1.11366	    0.90000;
	2708	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03391	    0.00000	 380.0	 1	    1.16782	    0.90000;
	2709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04747	    0.00000	 220.0	 1	    1.19495	    0.90000;
	2710	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2711	 1	 26.82975	 13.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2712	 2	 17.81976	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2713	 2	 137.0	 22.8	 0.0	 0.0	 1	    1.02597	    0.00000	 220.0	 1	    1.15193	    0.90000;
	2714	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02120	    0.00000	 380.0	 1	    1.14240	    0.90000;
	2715	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02306	    0.00000	 220.0	 1	    1.14612	    0.90000;
	2716	 1	 27.02997	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2717	 2	 629.0	 184.3	 0.0	 0.0	 1	    1.00675	    0.00000	 380.0	 1	    1.11350	    0.90000;
	2718	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01100	    0.00000	 380.0	 1	    1.12201	    0.90000;
	2719	 1	 0.0	 0.0	 0.0	 47.40056	 1	    0.96083	    0.00000	 150.0	 1	    1.10000	    0.82166;
	2720	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02978	    0.00000	 380.0	 1	    1.15955	    0.90000;
	2721	 1	 17.71965	 7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2722	 1	 5.806438	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2723	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01822	    0.00000	 220.0	 1	    1.13644	    0.90000;
	2724	 1	 31.8353	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2725	 2	 193.9	 221.1	 0.0	 0.0	 1	    1.03173	    0.00000	 380.0	 1	    1.16346	    0.90000;
	2726	 1	 17.01887	 6.2	 0.0	 0.0	 1	    1.00345	    0.00000	 110.0	 1	    1.10690	    0.90000;
	2727	 1	 139.6	 68.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2728	 2	 149.1	 45.0	 0.0	 0.0	 1	    1.01482	    0.00000	 220.0	 1	    1.12964	    0.90000;
	2729	 2	 339.7	 106.8	 0.0	 0.0	 1	    1.01456	    0.00000	 220.0	 1	    1.12911	    0.90000;
	2730	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00443	    0.00000	 150.0	 1	    1.10886	    0.90000;
	2731	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01536	    0.00000	 380.0	 1	    1.13072	    0.90000;
	2732	 1	 87.59712	 27.4	 0.0	 0.0	 1	    1.00929	    0.00000	 110.0	 1	    1.11857	    0.90000;
	2733	 1	 108.8	 33.2	 0.374986	 0.0	 1	    1.01256	    0.00000	 380.0	 1	    1.12512	    0.90000;
	2734	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01305	    0.00000	 380.0	 1	    1.12610	    0.90000;
	2735	 2	 146.9	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2736	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2737	 1	 33.33696	 11.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2738	 1	 -1398.9	 -380.6	 0.0	 0.0	 1	    1.02667	    0.00000	 380.0	 1	    1.15334	    0.90000;
	2739	 1	 2.202442	 1.1	 0.0	 0.0	 1	    1.02058	    0.00000	 220.0	 1	    1.14117	    0.90000;
	2740	 1	 12.81421	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2741	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2742	 1	 30.23352	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2743	 1	 0.0	 0.0	 0.296959	 0.0	 1	    1.02144	    0.00000	 380.0	 1	    1.14288	    0.90000;
	2744	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01493	    0.00000	 220.0	 1	    1.12986	    0.90000;
	2745	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01914	    0.00000	 220.0	 1	    1.13829	    0.90000;
	2746	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02807	    0.00000	 220.0	 1	    1.15614	    0.90000;
	2747	 1	 74.38247	 8.8	 0.0	 0.0	 1	    1.00826	    0.00000	 220.0	 1	    1.11651	    0.90000;
	2748	 1	 149.0	 19.8	 0.0	 0.0	 1	    1.02430	    0.00000	 380.0	 1	    1.14860	    0.90000;
	2749	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2750	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01784	    0.00000	 220.0	 1	    1.13568	    0.90000;
	2751	 1	 0.0	 0.0	 0.169272	 0.0	 1	    1.02493	    0.00000	 380.0	 1	    1.14987	    0.90000;
	2752	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2753	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00726	    0.00000	 220.0	 1	    1.11451	    0.90000;
	2754	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02074	    0.00000	 380.0	 1	    1.14148	    0.90000;
	2755	 2	 28.73186	 9.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2756	 1	 78.58714	 25.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2757	 1	 6.607326	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2758	 1	 41.14562	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2759	 1	 4.605106	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2760	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00592	    0.00000	 380.0	 1	    1.11185	    0.90000;
	2761	 1	 116.9296	 33.6	 0.0	 0.0	 1	    1.01600	    0.00000	 220.0	 1	    1.13200	    0.90000;
	2762	 1	 221.0	 146.8	 0.0	 0.0	 1	    1.00835	    0.00000	 220.0	 1	    1.11671	    0.90000;
	2763	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2764	 2	 96.40689	 4.7	 0.0	 0.0	 1	    1.01073	    0.00000	 220.0	 1	    1.12145	    0.90000;
	2765	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2766	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01442	    0.00000	 220.0	 1	    1.12885	    0.90000;
	2767	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01072	    0.00000	 380.0	 1	    1.12145	    0.90000;
	2768	 1	 26.92986	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2769	 1	 29.33252	 5.6	 0.0	 0.0	 1	    1.01566	    0.00000	 220.0	 1	    1.13131	    0.90000;
	2770	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2771	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00889	    0.00000	 150.0	 1	    1.11779	    0.90000;
	2772	 1	 95.90633	 -15.4	 0.0	 0.0	 1	    1.01118	    0.00000	 220.0	 1	    1.12236	    0.90000;
	2773	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2774	 2	 0.0	 0.0	 0.191685	 0.0	 1	    1.02219	    0.00000	 220.0	 1	    1.14437	    0.90000;
	2775	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01186	    0.00000	 220.0	 1	    1.12371	    0.90000;
	2776	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01601	    0.00000	 110.0	 1	    1.13201	    0.90000;
	2777	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01596	    0.00000	 380.0	 1	    1.13192	    0.90000;
	2778	 1	 10.31143	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2779	 2	 181.9	 -68.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2780	 1	 22.5	 9.5	 0.0	 0.0	 1	    1.03098	    0.00000	 380.0	 1	    1.16196	    0.90000;
	2781	 2	 0.0	 0.0	 0.143721	 0.0	 1	    1.00987	    0.00000	 380.0	 1	    1.11973	    0.90000;
	2782	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2783	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2784	 1	 493.4	 53.5	 0.0	 0.0	 1	    1.00844	    0.00000	 380.0	 1	    1.11688	    0.90000;
	2785	 1	 8.709657	 1.6	 0.0	 0.0	 1	    1.01418	    0.00000	 110.0	 1	    1.12837	    0.90000;
	2786	 1	 71.27902	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2787	 1	 55.86193	 8.8	 0.0	 0.0	 1	    1.00636	    0.00000	 220.0	 1	    1.11272	    0.90000;
	2788	 1	 119.7	 3.7	 0.0	 0.0	 1	    1.00603	    0.00000	 220.0	 1	    1.11206	    0.90000;
	2789	 1	 272.3	 58.5	 0.0	 0.0	 1	    1.01731	    0.00000	 380.0	 1	    1.13462	    0.90000;
	2790	 1	 566.1	 54.2	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2791	 1	 89.59934	 22.7	 0.0	 0.0	 1	    1.00915	    0.00000	 220.0	 1	    1.11830	    0.90000;
	2792	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02623	    0.00000	 220.0	 1	    1.15246	    0.90000;
	2793	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01542	    0.00000	 220.0	 1	    1.13084	    0.90000;
	2794	 1	 92.90301	 27.7	 0.0	 0.0	 1	    1.02203	    0.00000	 220.0	 1	    1.14406	    0.90000;
	2795	 1	 100.7	 -23.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2796	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2797	 1	 164.0	 42.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2798	 1	 11.91321	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2799	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01099	    0.00000	 220.0	 1	    1.12197	    0.90000;
	2800	 1	 10.11121	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2801	 1	 0.0	 0.0	 0.301008	 0.0	 1	    1.02842	    0.00000	 380.0	 1	    1.15685	    0.90000;
	2802	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01375	    0.00000	 150.0	 1	    1.12751	    0.90000;
	2803	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00819	    0.00000	 380.0	 1	    1.11638	    0.90000;
	2804	 2	 575.6	 132.7	 0.0	 0.0	 1	    1.04180	    0.00000	 220.0	 1	    1.18360	    0.90000;
	2805	 2	 426.4	 122.7	 0.0	 0.0	 1	    1.01261	    0.00000	 220.0	 1	    1.12522	    0.90000;
	2806	 1	 64.6717	 24.5	 0.0	 0.0	 1	    1.04129	    0.00000	 220.0	 1	    1.18258	    0.90000;
	2807	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2808	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2809	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01328	    0.00000	 220.0	 1	    1.12657	    0.90000;
	2810	 1	 15.21687	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.20000	    0.80000;
	2811	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00484	    0.00000	 220.0	 1	    1.10968	    0.90000;
	2812	 1	 28.63174	 12.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2813	 1	 11.21243	 3.7	 0.0	 0.0	 1	    1.01884	    0.00000	 110.0	 1	    1.13769	    0.90000;
	2814	 1	 4.104551	 1.5	 0.0	 0.0	 1	    1.01280	    0.00000	 110.0	 1	    1.12560	    0.90000;
	2815	 1	 69.77736	 15.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2816	 1	 128.1061	 64.9	 0.0	 0.0	 1	    1.01586	    0.00000	 380.0	 1	    1.13171	    0.90000;
	2817	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2818	 1	 380.9	 85.1	 0.0	 0.0	 1	    1.01974	    0.00000	 380.0	 1	    1.13948	    0.90000;
	2819	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2820	 1	 0.0	 8.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2821	 1	 125.2	 105.4	 0.0	 0.0	 1	    1.01325	    0.00000	 380.0	 1	    1.12649	    0.90000;
	2822	 1	 0.0	 0.0	 0.059999	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2823	 1	 0.0	 0.0	 0.114	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2824	 1	 2.302553	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2825	 1	 30.63396	 11.6	 0.0	 0.0	 1	    1.01781	    0.00000	 380.0	 1	    1.13562	    0.90000;
	2826	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01923	    0.00000	 220.0	 1	    1.13847	    0.90000;
	2827	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2828	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2829	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01762	    0.00000	 380.0	 1	    1.13525	    0.90000;
	2830	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01230	    0.00000	 220.0	 1	    1.12460	    0.90000;
	2831	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02746	    0.00000	 220.0	 1	    1.15492	    0.90000;
	2832	 2	 36.4	 356.1	 0.0	 0.0	 1	    1.02774	    0.00000	 380.0	 1	    1.15547	    0.90000;
	2833	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02538	    0.00000	 220.0	 1	    1.15076	    0.90000;
	2834	 1	 0.0	 0.0	 0.0	 -84.0008	 1	    1.02992	    0.00000	 380.0	 1	    1.15984	    0.90000;
	2835	 1	 57.86415	 70.5	 0.54138	 0.0	 1	    1.00258	    0.00000	 380.0	 1	    1.10516	    0.90000;
	2836	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2837	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2838	 1	 99.9	 20.1	 0.0	 0.0	 1	    1.00761	    0.00000	 150.0	 1	    1.11522	    0.90000;
	2839	 1	 0.0	 0.0	 0.191685	 0.0	 1	    1.01043	    0.00000	 220.0	 1	    1.12086	    0.90000;
	2840	 2	 247.6	 75.8	 0.0	 0.0	 1	    1.01388	    0.00000	 220.0	 1	    1.12776	    0.90000;
	2841	 1	 13.21465	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2842	 1	 115.5	 71.5	 0.0	 0.0	 1	    1.02820	    0.00000	 380.0	 1	    1.15640	    0.90000;
	2843	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01082	    0.00000	 220.0	 1	    1.12165	    0.90000;
	2844	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00436	    0.00000	 220.0	 1	    1.10871	    0.90000;
	2845	 2	 107.1	 22.2	 0.0	 0.0	 1	    1.00748	    0.00000	 220.0	 1	    1.11497	    0.90000;
	2846	 2	 0.7	 270.7	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2847	 1	 2.502775	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2848	 1	 109.5	 22.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2849	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01067	    0.00000	 380.0	 1	    1.12133	    0.90000;
	2850	 1	 3.503885	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2851	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2852	 2	 56.06216	 17.1	 0.0	 0.0	 1	    1.02778	    0.00000	 220.0	 1	    1.15555	    0.90000;
	2853	 2	 278.3	 174.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2854	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01961	    0.00000	 380.0	 1	    1.13922	    0.90000;
	2855	 1	 7.608436	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2856	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04112	    0.00000	 220.0	 1	    1.18224	    0.90000;
	2857	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2858	 1	 20.72298	 6.3	 0.0	 0.0	 1	    1.00410	    0.00000	 110.0	 1	    1.10819	    0.90000;
	2859	 1	 100.5	 37.0	 0.0	 0.0	 1	    1.02272	    0.00000	 380.0	 1	    1.14544	    0.90000;
	2860	 1	 19.82198	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2861	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00858	    0.00000	 380.0	 1	    1.11716	    0.90000;
	2862	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02871	    0.00000	 380.0	 1	    1.15742	    0.90000;
	2863	 2	 149.2	 -74.6	 0.0	 0.0	 1	    1.03858	    0.00000	 380.0	 1	    1.17715	    0.90000;
	2864	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02257	    0.00000	 150.0	 1	    1.14514	    0.90000;
	2865	 1	 80.0888	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2866	 2	 40.34473	 7.8	 0.0	 0.0	 1	    1.00469	    0.00000	 220.0	 1	    1.10939	    0.90000;
	2867	 1	 8.309213	 3.0	 0.0	 0.0	 1	    1.00574	    0.00000	 110.0	 1	    1.11148	    0.90000;
	2868	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00842	    0.00000	 220.0	 1	    1.11685	    0.90000;
	2869	 1	 68.67614	 19.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2870	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2871	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2872	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01460	    0.00000	 220.0	 1	    1.12919	    0.90000;
	2873	 2	 205.0	 24.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2874	 1	 136.7	 19.3	 0.0	 0.0	 1	    1.02903	    0.00000	 380.0	 1	    1.15805	    0.90000;
	2875	 1	 10.61177	 51.2	 0.211044	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2876	 2	 60.46704	 16.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2877	 1	 8.309213	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2878	 2	 0.0	 -8.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2879	 1	 -16.5	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2880	 2	 196.8	 36.4	 0.0	 0.0	 1	    1.02392	    0.00000	 220.0	 1	    1.14785	    0.90000;
	2881	 1	 11.11232	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2882	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02218	    0.00000	 150.0	 1	    1.14436	    0.90000;
	2883	 1	 39.64395	 9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2884	 2	 11.01221	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2885	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2886	 1	 0.0	 0.0	 0.224995	 0.0	 1	    1.00479	    0.00000	 220.0	 1	    1.10957	    0.90000;
	2887	 1	 292.8	 114.2	 0.0	 0.0	 1	    1.01100	    0.00000	 380.0	 1	    1.12200	    0.90000;
	2888	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2889	 1	 132.9	 40.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2890	 1	 39.34362	 11.2	 0.0	 0.0	 1	    1.00405	    0.00000	 150.0	 1	    1.10810	    0.90000;
	2891	 1	 180.2	 46.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2892	 1	 23.6262	 7.8	 0.0	 0.0	 1	    1.01043	    0.00000	 110.0	 1	    1.12085	    0.90000;
	2893	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01284	    0.00000	 380.0	 1	    1.12567	    0.90000;
	2894	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2895	 1	 31.93541	 12.6	 0.0	 0.0	 1	    1.02184	    0.00000	 150.0	 1	    1.14367	    0.90000;
	2896	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02793	    0.00000	 220.0	 1	    1.15587	    0.90000;
	2897	 1	 14.11565	 7.7	 0.0	 0.0	 1	    1.01768	    0.00000	 220.0	 1	    1.13536	    0.90000;
	2898	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2899	 1	 -20.9232	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2900	 1	 107.0	 34.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2901	 1	 75.5838	 30.3	 0.0	 0.0	 1	    1.02755	    0.00000	 220.0	 1	    1.15510	    0.90000;
	2902	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2903	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00766	    0.00000	 380.0	 1	    1.11533	    0.90000;
	2904	 1	 127.8	 15.2	 0.0	 0.0	 1	    1.00712	    0.00000	 220.0	 1	    1.11423	    0.90000;
	2905	 1	 0.0	 0.0	 0.38766	 0.0	 1	    1.03124	    0.00000	 380.0	 1	    1.16248	    0.90000;
	2906	 1	 0.0	 0.0	 0.0	 -132.645	 1	    1.03163	    0.00000	 380.0	 1	    1.16327	    0.90000;
	2907	 1	 104.5	 31.8	 0.0	 0.0	 1	    1.01745	    0.00000	 220.0	 1	    1.13490	    0.90000;
	2908	 1	 398.0	 11.5	 0.0	 0.0	 1	    1.01423	    0.00000	 380.0	 1	    1.12846	    0.90000;
	2909	 1	 15.91765	 12.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2910	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2911	 1	 86.19556	 19.9	 0.0	 0.0	 1	    1.01902	    0.00000	 220.0	 1	    1.13803	    0.90000;
	2912	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2913	 1	 0.200222	 0.9	 0.0	 0.0	 1	    1.01285	    0.00000	 220.0	 1	    1.12569	    0.90000;
	2914	 1	 27.02997	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2915	 1	 8.509435	 3.2	 0.0	 0.0	 1	    1.01530	    0.00000	 220.0	 1	    1.13060	    0.90000;
	2916	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01393	    0.00000	 380.0	 1	    1.12786	    0.90000;
	2917	 1	 146.7	 20.7	 0.0	 0.0	 1	    1.02513	    0.00000	 150.0	 1	    1.15025	    0.90000;
	2918	 1	 98.00867	 16.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2919	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01987	    0.00000	 380.0	 1	    1.13975	    0.90000;
	2920	 1	 2.302553	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2921	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2922	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2923	 1	 0.0	 0.0	 0.191685	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2924	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2925	 1	 63.06993	 25.8	 0.0	 0.0	 1	    1.02100	    0.00000	 150.0	 1	    1.14200	    0.90000;
	2926	 1	 73.58158	 30.1	 0.0	 0.0	 1	    1.02054	    0.00000	 150.0	 1	    1.14108	    0.90000;
	2927	 2	 165.2	 64.5	 0.0	 0.0	 1	    1.01008	    0.00000	 220.0	 1	    1.12016	    0.90000;
	2928	 2	 341.2	 46.6	 0.0	 0.0	 1	    1.01064	    0.00000	 220.0	 1	    1.12128	    0.90000;
	2929	 1	 76.38469	 24.8	 0.0	 0.0	 1	    1.00377	    0.00000	 220.0	 1	    1.10753	    0.90000;
	2930	 1	 9.00999	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2931	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2932	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00812	    0.00000	 110.0	 1	    1.11623	    0.90000;
	2933	 1	 81.2	 89.3	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2934	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02207	    0.00000	 380.0	 1	    1.14414	    0.90000;
	2935	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03281	    0.00000	 220.0	 1	    1.16562	    0.90000;
	2936	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04397	    0.00000	 380.0	 1	    1.18795	    0.90000;
	2937	 1	 251.3	 42.6	 0.0	 0.0	 1	    1.00669	    0.00000	 220.0	 1	    1.11337	    0.90000;
	2938	 1	 133.9	 32.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2939	 2	 374.1	 61.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2940	 2	 -38.8431	 -17.0	 0.0	 0.0	 1	    1.01052	    0.00000	 220.0	 1	    1.12104	    0.90000;
	2941	 2	 3.203552	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2942	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2943	 1	 16.4182	 5.9	 0.0	 0.0	 1	    1.00441	    0.00000	 110.0	 1	    1.10883	    0.90000;
	2944	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02879	    0.00000	 220.0	 1	    1.15759	    0.90000;
	2945	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03097	    0.00000	 380.0	 1	    1.16194	    0.90000;
	2946	 2	 110.7	 26.9	 0.0	 0.0	 1	    1.02618	    0.00000	 220.0	 1	    1.15237	    0.90000;
	2947	 1	 132.0	 27.0	 0.0	 0.0	 1	    1.00991	    0.00000	 220.0	 1	    1.11982	    0.90000;
	2948	 1	 296.1	 82.3	 0.0	 0.0	 1	    1.02590	    0.00000	 150.0	 1	    1.15181	    0.90000;
	2949	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00755	    0.00000	 380.0	 1	    1.11510	    0.90000;
	2950	 1	 0.0	 0.0	 0.0	 18.54267	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2951	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2952	 1	 20.9	 -171.5	 0.0	 0.0	 1	    1.01564	    0.00000	 220.0	 1	    1.13128	    0.90000;
	2953	 1	 113.0	 56.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2954	 1	 84.19334	 17.3	 0.0	 0.0	 1	    1.03422	    0.00000	 220.0	 1	    1.16844	    0.90000;
	2955	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2956	 1	 26.32919	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2957	 2	 142.4	 87.8	 0.0	 0.0	 1	    1.00764	    0.00000	 220.0	 1	    1.11528	    0.90000;
	2958	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2959	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00597	    0.00000	 380.0	 1	    1.11194	    0.90000;
	2960	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01959	    0.00000	 220.0	 1	    1.13918	    0.90000;
	2961	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01820	    0.00000	 380.0	 1	    1.13639	    0.90000;
	2962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2963	 1	 -11.713	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2964	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03197	    0.00000	 380.0	 1	    1.16393	    0.90000;
	2965	 1	 86.99646	 29.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2966	 1	 0.0	 0.0	 0.234904	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	2967	 2	 9.210212	 3.5	 0.0	 0.0	 1	    1.02581	    0.00000	 110.0	 1	    1.15161	    0.90000;
	2968	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01799	    0.00000	 380.0	 1	    1.13599	    0.90000;
	2969	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01424	    0.00000	 380.0	 1	    1.12848	    0.90000;
	2970	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2971	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01502	    0.00000	 380.0	 1	    1.13005	    0.90000;
	2972	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02194	    0.00000	 380.0	 1	    1.14389	    0.90000;
	2973	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00819	    0.00000	 380.0	 1	    1.11637	    0.90000;
	2974	 1	 -30.0333	 9.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2975	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2976	 1	 12.11343	 5.5	 0.0	 0.0	 1	    1.00287	    0.00000	 110.0	 1	    1.10574	    0.90000;
	2977	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02068	    0.00000	 380.0	 1	    1.14135	    0.90000;
	2978	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02987	    0.00000	 220.0	 1	    1.15975	    0.90000;
	2979	 1	 0.0	 0.0	 0.268997	 0.0	 1	    1.01013	    0.00000	 380.0	 1	    1.12026	    0.90000;
	2980	 2	 66.67392	 33.3	 0.0	 0.0	 1	    1.00582	    0.00000	 220.0	 1	    1.11164	    0.90000;
	2981	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02036	    0.00000	 150.0	 1	    1.14072	    0.90000;
	2982	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02239	    0.00000	 150.0	 1	    1.14478	    0.90000;
	2983	 1	 10.61177	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2984	 1	 0.0	 0.0	 0.0	 92.67897	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2985	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01232	    0.00000	 380.0	 1	    1.12464	    0.90000;
	2986	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02181	    0.00000	 380.0	 1	    1.14362	    0.90000;
	2987	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2988	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2989	 1	 11.01221	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2990	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01465	    0.00000	 380.0	 1	    1.12930	    0.90000;
	2991	 2	 0.600666	 28.7	 0.0	 0.0	 1	    1.00408	    0.00000	 220.0	 1	    1.10816	    0.90000;
	2992	 1	 33.13674	 11.6	 0.0	 0.0	 1	    1.00899	    0.00000	 220.0	 1	    1.11798	    0.90000;
	2993	 1	 5.506105	 2.0	 0.0	 0.0	 1	    1.01683	    0.00000	 110.0	 1	    1.13366	    0.90000;
	2994	 1	 0.0	 0.0	 0.0	 -22.9504	 1	    1.04363	    0.00000	 150.0	 1	    1.18725	    0.90000;
	2995	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2996	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2997	 2	 22.12453	 13.7	 0.0	 0.0	 1	    1.00806	    0.00000	 150.0	 1	    1.11612	    0.90000;
	2998	 1	 332.9	 99.6	 0.0	 0.0	 1	    1.00347	    0.00000	 150.0	 1	    1.10695	    0.90000;
	2999	 1	 12.01332	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3000	 1	 72.07992	 29.5	 0.0	 0.0	 1	    1.02215	    0.00000	 150.0	 1	    1.14431	    0.90000;
	3001	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01784	    0.00000	 220.0	 1	    1.13568	    0.90000;
	3002	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00955	    0.00000	 220.0	 1	    1.11910	    0.90000;
	3003	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3004	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02535	    0.00000	 380.0	 1	    1.15070	    0.90000;
	3005	 1	 32.63618	 11.8	 0.0	 0.0	 1	    1.01030	    0.00000	 110.0	 1	    1.12060	    0.90000;
	3006	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3007	 1	 19.82198	 7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3008	 1	 -10.1112	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3009	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02634	    0.00000	 380.0	 1	    1.15268	    0.90000;
	3010	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02009	    0.00000	 150.0	 1	    1.14018	    0.90000;
	3011	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00636	    0.00000	 150.0	 1	    1.11273	    0.90000;
	3012	 1	 50.55605	 16.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3013	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3014	 1	 120.4	 39.5	 0.0	 0.0	 1	    1.00918	    0.00000	 380.0	 1	    1.11836	    0.90000;
	3015	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3016	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3017	 2	 78.18668	 27.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3018	 2	 70.47814	 16.4	 0.0	 0.0	 1	    1.01410	    0.00000	 220.0	 1	    1.12821	    0.90000;
	3019	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01877	    0.00000	 220.0	 1	    1.13754	    0.90000;
	3020	 2	 219.2189	 70.1	 0.0	 0.0	 1	    1.02943	    0.00000	 220.0	 1	    1.15885	    0.90000;
	3021	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3022	 1	 14.71632	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3023	 1	 2.302553	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3024	 2	 70.47814	 33.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3025	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01550	    0.00000	 220.0	 1	    1.13101	    0.90000;
	3026	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3027	 2	 48.35361	 62.8	 0.0	 0.0	 1	    1.03126	    0.00000	 220.0	 1	    1.16252	    0.90000;
	3028	 2	 120.5	 37.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3029	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 380.0	 1	    1.13175	    0.90000;
	3030	 1	 236.2	 116.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3031	 1	 14.71632	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3032	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3033	 2	 379.5	 113.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3034	 1	 46.85194	 16.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3035	 1	 76.18446	 13.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3036	 1	 379.9	 73.0	 0.0	 0.0	 1	    1.00438	    0.00000	 380.0	 1	    1.10877	    0.90000;
	3037	 1	 83.29234	 24.1	 0.0	 0.0	 1	    1.00285	    0.00000	 220.0	 1	    1.10569	    0.90000;
	3038	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01715	    0.00000	 380.0	 1	    1.13429	    0.90000;
	3039	 1	 38.04218	 20.0	 0.0	 0.0	 1	    1.01238	    0.00000	 220.0	 1	    1.12476	    0.90000;
	3040	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01167	    0.00000	 380.0	 1	    1.12333	    0.90000;
	3041	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3042	 1	 1.301443	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3043	 1	 129.5	 51.8	 0.0	 0.0	 1	    1.03368	    0.00000	 380.0	 1	    1.16737	    0.90000;
	3044	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00576	    0.00000	 380.0	 1	    1.11152	    0.90000;
	3045	 2	 25.12786	 9.4	 0.0	 0.0	 1	    1.02325	    0.00000	 220.0	 1	    1.14650	    0.90000;
	3046	 1	 0.0	 0.0	 0.0	 14.75693	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3047	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3048	 1	 0.0	 0.0	 0.193831	 0.0	 1	    1.02336	    0.00000	 380.0	 1	    1.14672	    0.90000;
	3049	 1	 36.54051	 27.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3050	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3051	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3052	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02249	    0.00000	 380.0	 1	    1.14498	    0.90000;
	3053	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01372	    0.00000	 380.0	 1	    1.12743	    0.90000;
	3054	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00936	    0.00000	 220.0	 1	    1.11872	    0.90000;
	3055	 1	 155.8	 38.4	 0.0	 0.0	 1	    1.01483	    0.00000	 150.0	 1	    1.12965	    0.90000;
	3056	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02700	    0.00000	 220.0	 1	    1.15400	    0.90000;
	3057	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.00997	    0.00000	 220.0	 1	    1.11993	    0.90000;
	3058	 1	 3.804218	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3059	 1	 57.46371	 15.3	 0.0	 0.0	 1	    1.01166	    0.00000	 220.0	 1	    1.12332	    0.90000;
	3060	 2	 201.6	 127.8	 0.0	 0.0	 1	    1.02371	    0.00000	 380.0	 1	    1.14742	    0.90000;
	3061	 1	 3.403774	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3062	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01381	    0.00000	 380.0	 1	    1.12761	    0.90000;
	3063	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3064	 1	 0.0	 0.0	 0.130002	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3065	 1	 0.500555	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3066	 1	 156.2	 24.5	 0.0	 0.0	 1	    1.00308	    0.00000	 150.0	 1	    1.10615	    0.90000;
	3067	 2	 322.1	 131.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3068	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3069	 1	 77.48591	 21.4	 0.0	 0.0	 1	    1.01693	    0.00000	 220.0	 1	    1.13386	    0.90000;
	3070	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3071	 1	 50.0555	 19.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3072	 1	 8.309213	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3073	 1	 115.0	 -4.5	 0.0	 0.0	 1	    1.00941	    0.00000	 220.0	 1	    1.11882	    0.90000;
	3074	 1	 47.15228	 15.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3075	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3076	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99743	    0.00000	 150.0	 1	    1.10000	    0.89487;
	3077	 1	 4.605106	 1.7	 0.0	 0.0	 1	    1.00893	    0.00000	 110.0	 1	    1.11787	    0.90000;
	3078	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02009	    0.00000	 150.0	 1	    1.14018	    0.90000;
	3079	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3080	 2	 91.80178	 18.6	 0.0	 0.0	 1	    1.00848	    0.00000	 220.0	 1	    1.11695	    0.90000;
	3081	 1	 302.5	 65.1	 0.0	 0.0	 1	    1.03885	    0.00000	 220.0	 1	    1.17770	    0.90000;
	3082	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3083	 2	 40.44484	 13.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3084	 1	 27.13008	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3085	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3086	 2	 0.2	 108.3	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3087	 1	 24.12675	 9.8	 0.0	 0.0	 1	    1.02377	    0.00000	 150.0	 1	    1.14755	    0.90000;
	3088	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3089	 1	 50.0555	 16.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3090	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01635	    0.00000	 220.0	 1	    1.13270	    0.90000;
	3091	 1	 23.22575	 6.3	 0.0	 0.0	 1	    1.01744	    0.00000	 220.0	 1	    1.13488	    0.90000;
	3092	 2	 207.0643	 45.5	 0.0	 0.0	 1	    1.01784	    0.00000	 220.0	 1	    1.13568	    0.90000;
	3093	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3094	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3095	 1	 108.7	 26.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3096	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3097	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01818	    0.00000	 380.0	 1	    1.13637	    0.90000;
	3098	 1	 52.05772	 17.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3099	 2	 179.5	 85.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3100	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02746	    0.00000	 220.0	 1	    1.15492	    0.90000;
	3101	 1	 19.42153	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3102	 1	 78.08658	 27.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3103	 1	 14.71632	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3104	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3105	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3106	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3107	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3108	 1	 6.707437	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3109	 1	 11.51276	 4.2	 0.0	 0.0	 1	    1.01380	    0.00000	 110.0	 1	    1.12761	    0.90000;
	3110	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03577	    0.00000	 220.0	 1	    1.17155	    0.90000;
	3111	 1	 173.1	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3112	 1	 83.59268	 21.6	 0.0	 0.0	 1	    1.00586	    0.00000	 220.0	 1	    1.11172	    0.90000;
	3113	 1	 146.9	 26.6	 0.0	 0.0	 1	    1.00565	    0.00000	 220.0	 1	    1.11130	    0.90000;
	3114	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01402	    0.00000	 380.0	 1	    1.12804	    0.90000;
	3115	 1	 175.4	 28.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3116	 1	 125.1	 44.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3117	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3118	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01038	    0.00000	 220.0	 1	    1.12077	    0.90000;
	3119	 1	 0.0	 0.0	 0.120982	 0.0	 1	    1.00845	    0.00000	 380.0	 1	    1.11691	    0.90000;
	3120	 1	 4.204662	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01433	    0.00000	 220.0	 1	    1.12867	    0.90000;
	3122	 2	 314.5	 83.9	 0.0	 0.0	 1	    1.01912	    0.00000	 220.0	 1	    1.13824	    0.90000;
	3123	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00551	    0.00000	 110.0	 1	    1.11102	    0.90000;
	3124	 2	 140.1	 10.0	 0.0	 0.0	 1	    1.01464	    0.00000	 220.0	 1	    1.12928	    0.90000;
	3125	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02043	    0.00000	 380.0	 1	    1.14085	    0.90000;
	3126	 2	 0.0	 0.0	 0.191685	 0.0	 1	    1.01707	    0.00000	 220.0	 1	    1.13414	    0.90000;
	3127	 1	 54.96094	 12.2	 0.0	 0.0	 1	    1.00607	    0.00000	 220.0	 1	    1.11213	    0.90000;
	3128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00489	    0.00000	 150.0	 1	    1.10979	    0.90000;
	3129	 1	 5.105661	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3130	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00485	    0.00000	 380.0	 1	    1.10970	    0.90000;
	3131	 2	 285.4	 81.4	 0.0	 0.0	 1	    1.00909	    0.00000	 380.0	 1	    1.11819	    0.90000;
	3132	 1	 120.1	 30.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3133	 1	 -15.8	 -2.8	 0.0	 0.0	 1	    1.00765	    0.00000	 150.0	 1	    1.11530	    0.90000;
	3134	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00760	    0.00000	 380.0	 1	    1.11520	    0.90000;
	3135	 1	 78.98758	 16.2	 0.0	 0.0	 1	    1.01040	    0.00000	 220.0	 1	    1.12080	    0.90000;
	3136	 1	 20.82309	 9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3137	 2	 16.11787	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3138	 1	 3.904329	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3139	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01131	    0.00000	 380.0	 1	    1.12262	    0.90000;
	3140	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01694	    0.00000	 220.0	 1	    1.13389	    0.90000;
	3141	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02244	    0.00000	 150.0	 1	    1.14487	    0.90000;
	3142	 1	 23.12564	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3143	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3144	 1	 119.1	 60.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3145	 1	 209.5	 95.0	 0.0	 0.0	 1	    1.01479	    0.00000	 150.0	 1	    1.12958	    0.90000;
	3146	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3147	 1	 119.1	 22.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3148	 1	 7.708547	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3149	 1	 1.501665	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3150	 1	 50.35583	 -36.2	 0.0	 0.0	 1	    1.00874	    0.00000	 220.0	 1	    1.11749	    0.90000;
	3151	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3152	 1	 123.1	 51.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3153	 1	 18.72076	 5.5	 0.0	 0.0	 1	    1.01248	    0.00000	 110.0	 1	    1.12495	    0.90000;
	3154	 1	 18.01998	 -15.7	 0.0	 0.0	 1	    1.00770	    0.00000	 110.0	 1	    1.11540	    0.90000;
	3155	 1	 0.0	 0.0	 0.0	 11.93467	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3156	 1	 23.92653	 8.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3157	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01084	    0.00000	 380.0	 1	    1.12167	    0.90000;
	3158	 1	 22.12453	 7.9	 0.0	 0.0	 1	    1.00605	    0.00000	 110.0	 1	    1.11210	    0.90000;
	3159	 1	 -3.40377	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3160	 1	 124.9	 104.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3161	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02110	    0.00000	 220.0	 1	    1.14219	    0.90000;
	3162	 1	 142.5	 23.6	 0.0	 0.0	 1	    1.01815	    0.00000	 220.0	 1	    1.13630	    0.90000;
	3163	 1	 22.02442	 13.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01481	    0.00000	 380.0	 1	    1.12963	    0.90000;
	3165	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00765	    0.00000	 380.0	 1	    1.11530	    0.90000;
	3166	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00303	    0.00000	 380.0	 1	    1.10605	    0.90000;
	3167	 1	 101.5	 -18.3	 0.0	 0.0	 1	    1.01960	    0.00000	 220.0	 1	    1.13919	    0.90000;
	3168	 1	 16.31809	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3169	 1	 55.66171	 4.5	 0.0	 0.0	 1	    1.00631	    0.00000	 220.0	 1	    1.11262	    0.90000;
	3170	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00516	    0.00000	 220.0	 1	    1.11032	    0.90000;
	3171	 1	 12.51387	 4.1	 0.0	 0.0	 1	    1.00535	    0.00000	 110.0	 1	    1.11070	    0.90000;
	3172	 1	 15.91765	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3173	 2	 473.4	 113.1	 0.0	 0.0	 1	    1.00800	    0.00000	 220.0	 1	    1.11601	    0.90000;
	3174	 1	 226.3	 61.1	 0.0	 0.0	 1	    1.01860	    0.00000	 150.0	 1	    1.13720	    0.90000;
	3175	 1	 0.0	 0.0	 0.241452	 0.0	 1	    1.01091	    0.00000	 380.0	 1	    1.12181	    0.90000;
	3176	 1	 36.34029	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3177	 1	 99.3	 23.3	 0.0	 0.0	 1	    1.02634	    0.00000	 220.0	 1	    1.15267	    0.90000;
	3178	 1	 100.5	 32.0	 0.0	 0.0	 1	    1.02180	    0.00000	 150.0	 1	    1.14360	    0.90000;
	3179	 1	 138.5	 19.3	 0.0	 0.0	 1	    1.01505	    0.00000	 220.0	 1	    1.13010	    0.90000;
	3180	 1	 180.4	 71.6	 0.0	 0.0	 1	    1.02126	    0.00000	 380.0	 1	    1.14252	    0.90000;
	3181	 1	 94.20444	 21.6	 0.0	 0.0	 1	    1.00604	    0.00000	 220.0	 1	    1.11207	    0.90000;
	3182	 1	 98.2	 19.1	 0.0	 0.0	 1	    1.01814	    0.00000	 220.0	 1	    1.13628	    0.90000;
	3183	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02600	    0.00000	 220.0	 1	    1.15201	    0.90000;
	3184	 1	 8.909878	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3185	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3186	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01930	    0.00000	 150.0	 1	    1.13860	    0.90000;
	3187	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01876	    0.00000	 220.0	 1	    1.13751	    0.90000;
	3188	 2	 0.0	 0.0	 0.445544	 0.0	 1	    1.00307	    0.00000	 380.0	 1	    1.10614	    0.90000;
	3189	 1	 23.6262	 16.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3190	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02688	    0.00000	 380.0	 1	    1.15376	    0.90000;
	3191	 2	 0.0	 0.0	 0.095843	 0.0	 1	    1.04464	    0.00000	 220.0	 1	    1.18927	    0.90000;
	3192	 2	 68.87637	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3193	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01980	    0.00000	 380.0	 1	    1.13959	    0.90000;
	3194	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00849	    0.00000	 380.0	 1	    1.11699	    0.90000;
	3195	 2	 123.8	 41.4	 0.0	 0.0	 1	    1.01235	    0.00000	 220.0	 1	    1.12470	    0.90000;
	3196	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3197	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02100	    0.00000	 380.0	 1	    1.14199	    0.90000;
	3198	 2	 36.34029	 45.0	 0.0	 0.0	 1	    1.00780	    0.00000	 330.0	 1	    1.11561	    0.90000;
	3199	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01089	    0.00000	 380.0	 1	    1.12179	    0.90000;
	3200	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01672	    0.00000	 220.0	 1	    1.13343	    0.90000;
	3201	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01241	    0.00000	 380.0	 1	    1.12482	    0.90000;
	3202	 1	 29.33252	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3203	 1	 29.93319	 10.8	 0.0	 0.0	 1	    1.00302	    0.00000	 110.0	 1	    1.10603	    0.90000;
	3204	 1	 0.0	 0.0	 0.038315	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3205	 1	 33.33696	 13.2	 0.0	 0.0	 1	    1.01807	    0.00000	 220.0	 1	    1.13614	    0.90000;
	3206	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3207	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3208	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00657	    0.00000	 220.0	 1	    1.11313	    0.90000;
	3209	 1	 118.5	 21.0	 0.0	 0.0	 1	    1.01227	    0.00000	 150.0	 1	    1.12454	    0.90000;
	3210	 1	 7.808658	 2.8	 0.0	 0.0	 1	    1.01274	    0.00000	 110.0	 1	    1.12548	    0.90000;
	3211	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99563	    0.00000	 150.0	 1	    1.10000	    0.89125;
	3212	 1	 159.1	 -28.7	 0.0	 0.0	 1	    1.01606	    0.00000	 220.0	 1	    1.13212	    0.90000;
	3213	 1	 8.609546	 3.1	 0.0	 0.0	 1	    1.00803	    0.00000	 110.0	 1	    1.11605	    0.90000;
	3214	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02648	    0.00000	 220.0	 1	    1.15296	    0.90000;
	3215	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3216	 1	 96.5	 -43.0	 0.0	 0.0	 1	    1.02300	    0.00000	 220.0	 1	    1.14600	    0.90000;
	3217	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00312	    0.00000	 220.0	 1	    1.10625	    0.90000;
	3218	 1	 97.0	 -52.1	 0.0	 0.0	 1	    1.01277	    0.00000	 220.0	 1	    1.12553	    0.90000;
	3219	 1	 6.00666	 3.0	 0.0	 0.0	 1	    1.02088	    0.00000	 220.0	 1	    1.14177	    0.90000;
	3220	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02795	    0.00000	 220.0	 1	    1.15590	    0.90000;
	3221	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3222	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00775	    0.00000	 380.0	 1	    1.11549	    0.90000;
	3223	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00791	    0.00000	 380.0	 1	    1.11582	    0.90000;
	3224	 1	 20.12231	 7.6	 0.0	 0.0	 1	    1.02949	    0.00000	 220.0	 1	    1.15897	    0.90000;
	3225	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02002	    0.00000	 380.0	 1	    1.14003	    0.90000;
	3226	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02760	    0.00000	 110.0	 1	    1.15519	    0.90000;
	3227	 1	 10.0111	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3228	 1	 0.0	 0.0	 0.0	 102.8747	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3229	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00308	    0.00000	 220.0	 1	    1.10615	    0.90000;
	3230	 2	 387.1	 138.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3231	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00440	    0.00000	 380.0	 1	    1.10880	    0.90000;
	3232	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3233	 1	 362.2	 -10.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3234	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3235	 1	 31.23463	 12.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3236	 1	 87.19668	 31.8	 0.0	 0.0	 1	    1.02226	    0.00000	 220.0	 1	    1.14451	    0.90000;
	3237	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03160	    0.00000	 220.0	 1	    1.16319	    0.90000;
	3238	 1	 4.104551	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3239	 1	 47.95317	 17.2	 0.0	 0.0	 1	    1.01557	    0.00000	 220.0	 1	    1.13114	    0.90000;
	3240	 1	 60.66726	 37.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3241	 1	 6.306993	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3242	 1	 392.8	 70.6	 0.0	 0.0	 1	    1.01050	    0.00000	 380.0	 1	    1.12099	    0.90000;
	3243	 2	 19.72187	 9.4	 0.0	 0.0	 1	    1.01295	    0.00000	 220.0	 1	    1.12590	    0.90000;
	3244	 1	 5.205771	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3245	 1	 0.0	 0.0	 0.0	 42.58596	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3246	 1	 215.3	 37.7	 0.0	 0.0	 1	    1.00583	    0.00000	 220.0	 1	    1.11165	    0.90000;
	3247	 2	 0.0	 0.0	 0.095844	 0.0	 1	    1.00797	    0.00000	 220.0	 1	    1.11594	    0.90000;
	3248	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3249	 1	 8.309213	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3250	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3251	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3252	 1	 24.42708	 8.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3253	 1	 1.401554	 0.5	 0.0	 0.0	 1	    1.01820	    0.00000	 110.0	 1	    1.13641	    0.90000;
	3254	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01886	    0.00000	 380.0	 1	    1.13772	    0.90000;
	3255	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3256	 2	 279.6	 9.2	 0.0	 0.0	 1	    1.04255	    0.00000	 220.0	 1	    1.18509	    0.90000;
	3257	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03894	    0.00000	 220.0	 1	    1.17788	    0.90000;
	3258	 1	 -10.6118	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3259	 2	 353.0	 20.7	 0.0	 0.0	 1	    1.01759	    0.00000	 380.0	 1	    1.13518	    0.90000;
	3260	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01685	    0.00000	 380.0	 1	    1.13369	    0.90000;
	3261	 2	 115.0	 34.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3262	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3263	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02730	    0.00000	 380.0	 1	    1.15461	    0.90000;
	3265	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3266	 1	 37.54162	 18.3	 0.0	 0.0	 1	    1.01449	    0.00000	 220.0	 1	    1.12898	    0.90000;
	3267	 1	 102.7	 77.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3268	 1	 84.09324	 52.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3269	 1	 31.43485	 6.6	 0.0	 0.0	 1	    1.01831	    0.00000	 220.0	 1	    1.13662	    0.90000;
	3270	 1	 14.01554	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3271	 1	 86.69612	 34.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3272	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3273	 1	 4.404884	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3274	 2	 129.2	 13.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3275	 1	 -11.0122	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01775	    0.00000	 220.0	 1	    1.13549	    0.90000;
	3277	 1	 86.59601	 14.9	 0.0	 0.0	 1	    1.02174	    0.00000	 220.0	 1	    1.14348	    0.90000;
	3278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00361	    0.00000	 150.0	 1	    1.10722	    0.90000;
	3279	 1	 124.3	 39.4	 0.0	 0.0	 1	    1.00789	    0.00000	 380.0	 1	    1.11577	    0.90000;
	3280	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01697	    0.00000	 220.0	 1	    1.13393	    0.90000;
	3281	 1	 194.3	 27.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3282	 2	 112.0	 -12.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3283	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01973	    0.00000	 380.0	 1	    1.13945	    0.90000;
	3284	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03503	    0.00000	 220.0	 1	    1.17005	    0.90000;
	3285	 1	 185.8	 31.8	 0.0	 0.0	 1	    1.02768	    0.00000	 220.0	 1	    1.15536	    0.90000;
	3286	 2	 217.8	 60.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3287	 1	 152.5	 14.4	 0.0	 0.0	 1	    1.01802	    0.00000	 380.0	 1	    1.13604	    0.90000;
	3288	 1	 9.210212	 3.3	 0.0	 0.0	 1	    1.00507	    0.00000	 110.0	 1	    1.11013	    0.90000;
	3289	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01808	    0.00000	 380.0	 1	    1.13615	    0.90000;
	3290	 2	 222.4	 81.7	 0.0	 0.0	 1	    1.00609	    0.00000	 220.0	 1	    1.11218	    0.90000;
	3291	 1	 81.79068	 51.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3292	 2	 11.31254	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3293	 1	 0.0	 0.0	 0.0	 18.08379	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3294	 1	 35.13896	 16.1	 0.0	 0.0	 1	    1.02385	    0.00000	 150.0	 1	    1.14770	    0.90000;
	3295	 2	 58.96538	 27.1	 0.0	 0.0	 1	    1.00350	    0.00000	 220.0	 1	    1.10700	    0.90000;
	3296	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02766	    0.00000	 380.0	 1	    1.15532	    0.90000;
	3297	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00581	    0.00000	 220.0	 1	    1.11162	    0.90000;
	3298	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3299	 1	 13.6151	 8.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3300	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3301	 2	 24.62731	 16.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3302	 1	 21.52386	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3303	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00829	    0.00000	 380.0	 1	    1.11658	    0.90000;
	3304	 1	 -12.3	 -10.6	 0.0	 0.0	 1	    1.00941	    0.00000	 150.0	 1	    1.11882	    0.90000;
	3305	 1	 0.0	 0.0	 0.0	 91.8129	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3306	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02813	    0.00000	 220.0	 1	    1.15626	    0.90000;
	3307	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3308	 1	 23.92653	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3309	 1	 1.701887	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3310	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00782	    0.00000	 220.0	 1	    1.11564	    0.90000;
	3311	 1	 30.33363	 11.0	 0.0	 0.0	 1	    1.01620	    0.00000	 110.0	 1	    1.13241	    0.90000;
	3312	 1	 1.902109	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3313	 1	 24.22686	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3314	 2	 0.0	 -5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3315	 1	 42.54717	 17.6	 0.0	 0.0	 1	    1.02819	    0.00000	 220.0	 1	    1.15638	    0.90000;
	3316	 1	 32.23574	 11.7	 0.0	 0.0	 1	    1.00450	    0.00000	 110.0	 1	    1.10901	    0.90000;
	3317	 1	 -668.3	 -230.2	 0.0	 0.0	 1	    1.01924	    0.00000	 380.0	 1	    1.13847	    0.90000;
	3318	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01097	    0.00000	 380.0	 1	    1.12194	    0.90000;
	3319	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02811	    0.00000	 220.0	 1	    1.15623	    0.90000;
	3320	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00754	    0.00000	 220.0	 1	    1.11507	    0.90000;
	3321	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02438	    0.00000	 380.0	 1	    1.14875	    0.90000;
	3322	 2	 12.11343	 7.5	 0.0	 0.0	 1	    1.00730	    0.00000	 150.0	 1	    1.11460	    0.90000;
	3323	 1	 20.72298	 5.0	 0.0	 0.0	 1	    1.03309	    0.00000	 220.0	 1	    1.16619	    0.90000;
	3324	 1	 114.8	 121.5	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3325	 2	 138.4	 39.5	 0.0	 0.0	 1	    1.02498	    0.00000	 220.0	 1	    1.14995	    0.90000;
	3326	 1	 131.0	 1.3	 0.0	 0.0	 1	    1.03365	    0.00000	 220.0	 1	    1.16729	    0.90000;
	3327	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3328	 2	 0.0	 0.0	 0.141558	 0.0	 1	    1.01443	    0.00000	 380.0	 1	    1.12886	    0.90000;
	3329	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02606	    0.00000	 380.0	 1	    1.15213	    0.90000;
	3330	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01533	    0.00000	 380.0	 1	    1.13065	    0.90000;
	3331	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00615	    0.00000	 150.0	 1	    1.11229	    0.90000;
	3332	 1	 295.4	 42.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3333	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3334	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3335	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3336	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03302	    0.00000	 110.0	 1	    1.16604	    0.90000;
	3337	 1	 28.03108	 6.5	 0.0	 0.0	 1	    1.02678	    0.00000	 220.0	 1	    1.15355	    0.90000;
	3338	 1	 22.82531	 9.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3339	 1	 82.99202	 25.9	 0.0	 0.0	 1	    1.00676	    0.00000	 220.0	 1	    1.11353	    0.90000;
	3340	 2	 132.3	 135.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3341	 2	 161.2	 41.8	 0.0	 0.0	 1	    1.01761	    0.00000	 220.0	 1	    1.13521	    0.90000;
	3342	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3343	 2	 169.2	 35.7	 0.0	 0.0	 1	    1.02568	    0.00000	 380.0	 1	    1.15136	    0.90000;
	3344	 1	 5.506105	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3345	 2	 5.305883	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3346	 2	 64.87193	 28.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3347	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01480	    0.00000	 220.0	 1	    1.12960	    0.90000;
	3348	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99588	    0.00000	 150.0	 1	    1.10000	    0.89177;
	3349	 1	 2.502775	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3350	 1	 28.93208	 10.5	 0.0	 0.0	 1	    1.00332	    0.00000	 110.0	 1	    1.10664	    0.90000;
	3351	 1	 182.3	 65.9	 0.0	 0.0	 1	    1.02859	    0.00000	 380.0	 1	    1.15718	    0.90000;
	3352	 2	 62.66948	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3353	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3354	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02343	    0.00000	 380.0	 1	    1.14687	    0.90000;
	3355	 1	 0.0	 0.0	 0.108	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3356	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01231	    0.00000	 220.0	 1	    1.12462	    0.90000;
	3357	 1	 -17.6195	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3358	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00395	    0.00000	 150.0	 1	    1.10789	    0.90000;
	3359	 2	 223.4	 143.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3360	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3361	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03594	    0.00000	 380.0	 1	    1.17189	    0.90000;
	3362	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02663	    0.00000	 380.0	 1	    1.15326	    0.90000;
	3363	 2	 74.5827	 12.3	 0.0	 0.0	 1	    1.01934	    0.00000	 220.0	 1	    1.13869	    0.90000;
	3364	 1	 16.61843	 -10.3	 0.0	 0.0	 1	    1.01193	    0.00000	 220.0	 1	    1.12386	    0.90000;
	3365	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01655	    0.00000	 220.0	 1	    1.13309	    0.90000;
	3367	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00903	    0.00000	 220.0	 1	    1.11806	    0.90000;
	3368	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3369	 1	 72.68058	 45.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3370	 1	 120.7	 24.3	 0.0	 0.0	 1	    1.00470	    0.00000	 220.0	 1	    1.10940	    0.90000;
	3371	 1	 2.502775	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3372	 1	 77.48591	 17.3	 0.0	 0.0	 1	    1.01549	    0.00000	 220.0	 1	    1.13099	    0.90000;
	3373	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3374	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02042	    0.00000	 220.0	 1	    1.14085	    0.90000;
	3375	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3376	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01943	    0.00000	 150.0	 1	    1.13887	    0.90000;
	3377	 1	 24.02664	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3378	 1	 -2835.7	 -818.9	 0.0	 20.0	 1	    1.02962	    0.00000	 380.0	 1	    1.15925	    0.90000;
	3379	 1	 68.77625	 13.0	 0.0	 0.0	 1	    1.00665	    0.00000	 220.0	 1	    1.11330	    0.90000;
	3380	 1	 85.1	 -122.4	 0.0	 0.0	 1	    1.01128	    0.00000	 380.0	 1	    1.12256	    0.90000;
	3381	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3382	 1	 179.4	 58.3	 0.0	 0.0	 1	    1.01549	    0.00000	 220.0	 1	    1.13099	    0.90000;
	3383	 1	 4.404884	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3384	 2	 104.0	 51.2	 0.0	 0.0	 1	    1.00270	    0.00000	 220.0	 1	    1.10540	    0.90000;
	3385	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3386	 1	 65.1	 26.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3387	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01051	    0.00000	 380.0	 1	    1.12102	    0.90000;
	3388	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3389	 1	 50.9565	 17.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3390	 1	 16.51831	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3391	 1	 165.3	 89.2	 0.0	 0.0	 1	    1.01081	    0.00000	 380.0	 1	    1.12161	    0.90000;
	3392	 1	 67.77514	 10.4	 0.0	 0.0	 1	    1.00836	    0.00000	 220.0	 1	    1.11671	    0.90000;
	3393	 1	 0.0	 0.0	 0.296958	 0.0	 1	    1.02719	    0.00000	 380.0	 1	    1.15437	    0.90000;
	3394	 1	 2.302553	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3395	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.00871	    0.00000	 220.0	 1	    1.11742	    0.90000;
	3396	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3397	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3398	 1	 51.35694	 -0.7	 0.0	 0.0	 1	    1.00844	    0.00000	 220.0	 1	    1.11688	    0.90000;
	3399	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3400	 1	 45.15006	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3401	 2	 48.15339	 13.2	 0.0	 0.0	 1	    1.02101	    0.00000	 220.0	 1	    1.14201	    0.90000;
	3402	 1	 18.42042	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3403	 2	 0.300333	 1.3	 0.0	 0.0	 1	    1.00663	    0.00000	 220.0	 1	    1.11326	    0.90000;
	3404	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02067	    0.00000	 220.0	 1	    1.14134	    0.90000;
	3405	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02093	    0.00000	 380.0	 1	    1.14186	    0.90000;
	3406	 1	 122.3	 45.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3407	 2	 71.37914	 10.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3408	 2	 120.4	 18.2	 0.0	 0.0	 1	    1.01080	    0.00000	 220.0	 1	    1.12159	    0.90000;
	3409	 1	 5.506105	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3410	 2	 34.13785	 11.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3411	 1	 39.44373	 5.9	 0.0	 0.0	 1	    1.00552	    0.00000	 220.0	 1	    1.11104	    0.90000;
	3412	 1	 194.6	 48.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3413	 1	 115.1	 16.4	 0.0	 0.0	 1	    1.02460	    0.00000	 220.0	 1	    1.14920	    0.90000;
	3414	 2	 69.27681	 44.1	 0.24	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3415	 1	 2.502775	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3416	 1	 7.608436	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3417	 2	 0.0	 0.0	 0.0	 20.0	 1	    1.00392	    0.00000	 380.0	 1	    1.10783	    0.90000;
	3418	 1	 -24.9276	 11.8	 0.0	 0.0	 1	    1.01012	    0.00000	 220.0	 1	    1.12024	    0.90000;
	3419	 1	 35.5394	 11.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3420	 1	 4.00444	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3421	 1	 83.49257	 17.4	 0.0	 0.0	 1	    1.03293	    0.00000	 220.0	 1	    1.16586	    0.90000;
	3422	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3423	 1	 163.5	 44.9	 0.0	 0.0	 1	    1.03821	    0.00000	 220.0	 1	    1.17642	    0.90000;
	3424	 1	 71.0788	 16.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3425	 2	 484.3	 168.0	 0.0	 0.0	 1	    1.00981	    0.00000	 380.0	 1	    1.11962	    0.90000;
	3426	 1	 119.1	 61.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3427	 1	 37.84196	 23.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3428	 1	 18.01998	 6.5	 0.0	 0.0	 1	    1.00584	    0.00000	 110.0	 1	    1.11168	    0.90000;
	3429	 1	 33.03663	 21.6	 0.0	 0.0	 1	    1.01624	    0.00000	 220.0	 1	    1.13248	    0.90000;
	3430	 1	 19.82198	 10.9	 0.0	 0.0	 1	    1.00905	    0.00000	 220.0	 1	    1.11811	    0.90000;
	3431	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00423	    0.00000	 220.0	 1	    1.10846	    0.90000;
	3432	 1	 27.13008	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3433	 1	 34.13785	 13.5	 0.0	 0.0	 1	    1.01925	    0.00000	 150.0	 1	    1.13850	    0.90000;
	3434	 1	 2.202442	 -48.8	 0.0	 0.0	 1	    1.00663	    0.00000	 380.0	 1	    1.11326	    0.90000;
	3435	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02039	    0.00000	 380.0	 1	    1.14078	    0.90000;
	3436	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3437	 2	 63.57048	 22.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3438	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3439	 1	 77.18558	 25.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3440	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00380	    0.00000	 220.0	 1	    1.10761	    0.90000;
	3441	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00755	    0.00000	 150.0	 1	    1.11511	    0.90000;
	3442	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3443	 1	 52.45816	 19.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3444	 2	 162.4	 14.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3445	 1	 46.35139	 86.9	 0.0	 0.0	 1	    1.00530	    0.00000	 380.0	 1	    1.11060	    0.90000;
	3446	 1	 0.0	 0.0	 0.0	 64.52167	 1	    1.02161	    0.00000	 220.0	 1	    1.14322	    0.90000;
	3447	 2	 86.59601	 24.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3448	 1	 23.92653	 8.7	 0.0	 0.0	 1	    1.00773	    0.00000	 110.0	 1	    1.11546	    0.90000;
	3449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3450	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3451	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3452	 2	 105.4	 92.5	 0.0	 0.0	 1	    1.01676	    0.00000	 220.0	 1	    1.13352	    0.90000;
	3453	 2	 210.9	 73.8	 0.0	 0.0	 1	    1.01866	    0.00000	 220.0	 1	    1.13731	    0.90000;
	3454	 1	 165.3	 7.4	 0.0	 0.0	 1	    1.01817	    0.00000	 380.0	 1	    1.13634	    0.90000;
	3455	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3456	 1	 2.803108	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3457	 2	 272.5	 127.2	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3458	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01470	    0.00000	 380.0	 1	    1.12941	    0.90000;
	3459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3460	 1	 0.0	 0.0	 0.191685	 0.0	 1	    1.01533	    0.00000	 220.0	 1	    1.13067	    0.90000;
	3461	 1	 10.11121	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3462	 1	 8.909878	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3463	 1	 5.00555	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3464	 1	 258.3	 166.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3465	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01568	    0.00000	 380.0	 1	    1.13135	    0.90000;
	3466	 2	 306.5	 57.7	 0.0	 0.0	 1	    1.03811	    0.00000	 220.0	 1	    1.17623	    0.90000;
	3467	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3468	 1	 159.9	 10.6	 0.0	 0.0	 1	    1.02797	    0.00000	 380.0	 1	    1.15595	    0.90000;
	3469	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3470	 2	 227.6	 56.8	 0.0	 0.0	 1	    1.00493	    0.00000	 220.0	 1	    1.10987	    0.90000;
	3471	 1	 130.5	 24.7	 0.0	 0.0	 1	    1.00856	    0.00000	 220.0	 1	    1.11711	    0.90000;
	3472	 1	 16.31809	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3474	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04031	    0.00000	 220.0	 1	    1.18063	    0.90000;
	3475	 1	 44.44928	 10.9	 0.0	 0.0	 1	    1.01418	    0.00000	 220.0	 1	    1.12835	    0.90000;
	3476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01893	    0.00000	 150.0	 1	    1.13786	    0.90000;
	3477	 1	 5.305883	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3478	 2	 105.6	 70.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3479	 1	 227.6	 37.8	 0.0	 0.0	 1	    1.00518	    0.00000	 380.0	 1	    1.11037	    0.90000;
	3480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3481	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02163	    0.00000	 380.0	 1	    1.14326	    0.90000;
	3482	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01570	    0.00000	 220.0	 1	    1.13140	    0.90000;
	3483	 1	 18.82087	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3484	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3485	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00784	    0.00000	 380.0	 1	    1.11567	    0.90000;
	3486	 1	 74.98314	 46.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3487	 1	 130.1	 19.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3488	 1	 14.21576	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3489	 1	 160.0	 69.2	 0.0	 0.0	 1	    1.01837	    0.00000	 220.0	 1	    1.13674	    0.90000;
	3490	 1	 180.4	 119.2	 0.0	 20.0	 1	    1.00927	    0.00000	 380.0	 1	    1.11855	    0.90000;
	3491	 1	 44.14895	 10.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3492	 1	 36.74074	 22.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3493	 1	 89.09879	 27.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3494	 1	 28.83197	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3495	 2	 44.34917	 12.8	 0.0	 0.0	 1	    1.01281	    0.00000	 220.0	 1	    1.12561	    0.90000;
	3496	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02116	    0.00000	 220.0	 1	    1.14231	    0.90000;
	3497	 1	 6.407104	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3498	 1	 123.9	 32.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3499	 1	 12.91432	 4.7	 0.0	 0.0	 1	    1.02188	    0.00000	 110.0	 1	    1.14376	    0.90000;
	3500	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3501	 1	 6.807548	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3502	 2	 141.0	 17.1	 0.0	 0.0	 1	    1.02155	    0.00000	 220.0	 1	    1.14310	    0.90000;
	3503	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3504	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02109	    0.00000	 220.0	 1	    1.14219	    0.90000;
	3505	 2	 73.08102	 15.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3506	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02011	    0.00000	 380.0	 1	    1.14022	    0.90000;
	3507	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02408	    0.00000	 220.0	 1	    1.14817	    0.90000;
	3508	 1	 85.5	 118.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3509	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03367	    0.00000	 220.0	 1	    1.16733	    0.90000;
	3510	 1	 28.03108	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3511	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04481	    0.00000	 220.0	 1	    1.18962	    0.90000;
	3512	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3513	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01922	    0.00000	 220.0	 1	    1.13845	    0.90000;
	3514	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3515	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3516	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00543	    0.00000	 380.0	 1	    1.11086	    0.90000;
	3517	 1	 -18.3203	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3518	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3519	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02018	    0.00000	 220.0	 1	    1.14035	    0.90000;
	3520	 2	 210.3	 23.0	 0.0	 0.0	 1	    1.00965	    0.00000	 220.0	 1	    1.11931	    0.90000;
	3521	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3522	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01362	    0.00000	 150.0	 1	    1.12725	    0.90000;
	3523	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02146	    0.00000	 380.0	 1	    1.14292	    0.90000;
	3524	 1	 50.0555	 23.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3525	 1	 58.96538	 18.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3526	 1	 51.25683	 -17.2	 0.0	 0.0	 1	    1.03022	    0.00000	 380.0	 1	    1.16044	    0.90000;
	3527	 1	 11.61288	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3528	 2	 102.1	 27.8	 0.0	 0.0	 1	    1.00977	    0.00000	 220.0	 1	    1.11954	    0.90000;
	3529	 1	 31.73519	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3530	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01844	    0.00000	 220.0	 1	    1.13689	    0.90000;
	3531	 2	 -1.09167	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3532	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03502	    0.00000	 220.0	 1	    1.17004	    0.90000;
	3533	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3534	 1	 56.26238	 20.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3535	 1	 3.203552	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3536	 1	 293.0	 -45.9	 0.0	 0.0	 1	    1.02098	    0.00000	 380.0	 1	    1.14196	    0.90000;
	3537	 1	 0.0	 0.0	 0.237627	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3538	 1	 94.30456	 -27.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3539	 1	 -49.0544	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3540	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.20000	    0.80000;
	3541	 1	 -10.4115	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3542	 1	 4.605106	 1.7	 0.0	 0.0	 1	    1.00502	    0.00000	 110.0	 1	    1.11004	    0.90000;
	3543	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3544	 1	 19.62176	 -3.1	 0.0	 0.0	 1	    1.03025	    0.00000	 220.0	 1	    1.16050	    0.90000;
	3545	 1	 8.909878	 5.1	 0.0	 0.0	 1	    1.01572	    0.00000	 110.0	 1	    1.13144	    0.90000;
	3546	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01896	    0.00000	 220.0	 1	    1.13792	    0.90000;
	3547	 1	 -272.202	 6.6	 0.0	 0.0	 1	    1.03183	    0.00000	 380.0	 1	    1.16366	    0.90000;
	3548	 1	 33.03663	 12.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3549	 1	 23.42597	 8.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3550	 1	 121.5	 29.6	 0.0	 0.0	 1	    1.00549	    0.00000	 150.0	 1	    1.11097	    0.90000;
	3551	 1	 5.105661	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3552	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00308	    0.00000	 220.0	 1	    1.10615	    0.90000;
	3553	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3554	 1	 20.12231	 8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3555	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01802	    0.00000	 220.0	 1	    1.13604	    0.90000;
	3556	 1	 7.608436	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3557	 1	 195.3	 87.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3558	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02446	    0.00000	 380.0	 1	    1.14892	    0.90000;
	3559	 2	 5.305883	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3560	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01478	    0.00000	 220.0	 1	    1.12955	    0.90000;
	3561	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3562	 1	 -3.3	 -0.7	 0.0	 0.0	 1	    1.01514	    0.00000	 150.0	 1	    1.13027	    0.90000;
	3563	 1	 0.0	 0.0	 0.0	 40.80943	 1	    1.02072	    0.00000	 220.0	 1	    1.14143	    0.90000;
	3564	 1	 143.9	 85.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3565	 1	 16.31809	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3566	 1	 0.0	 0.0	 0.100424	 0.0	 1	    1.02362	    0.00000	 220.0	 1	    1.14725	    0.90000;
	3567	 2	 66.67392	 16.9	 0.0	 0.0	 1	    1.02351	    0.00000	 220.0	 1	    1.14702	    0.90000;
	3568	 1	 20.32253	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3569	 2	 0.0	 0.0	 0.0	 56.71428	 1	    1.01772	    0.00000	 380.0	 1	    1.13545	    0.90000;
	3570	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01772	    0.00000	 380.0	 1	    1.13544	    0.90000;
	3571	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00410	    0.00000	 380.0	 1	    1.10820	    0.90000;
	3572	 1	 39.34362	 10.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3573	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00989	    0.00000	 380.0	 1	    1.11978	    0.90000;
	3574	 1	 11.11232	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3575	 1	 227.4	 40.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3576	 1	 89.299	 25.1	 0.0	 0.0	 1	    1.02113	    0.00000	 220.0	 1	    1.14227	    0.90000;
	3577	 1	 29.73297	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3578	 1	 35.63951	 22.0	 0.0	 0.0	 1	    0.99605	    0.00000	 150.0	 1	    1.10000	    0.89211;
	3579	 1	 105.2	 24.2	 0.0	 0.0	 1	    1.01742	    0.00000	 220.0	 1	    1.13483	    0.90000;
	3580	 1	 48.95428	 11.6	 0.0	 0.0	 1	    1.01819	    0.00000	 220.0	 1	    1.13637	    0.90000;
	3581	 2	 123.9	 46.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3582	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3583	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00403	    0.00000	 220.0	 1	    1.10805	    0.90000;
	3584	 1	 37.94207	 23.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3585	 1	 236.2	 45.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3586	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01799	    0.00000	 220.0	 1	    1.13598	    0.90000;
	3587	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01471	    0.00000	 110.0	 1	    1.12942	    0.90000;
	3588	 1	 83.19224	 11.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3589	 2	 101.2	 45.2	 0.0	 0.0	 1	    1.01114	    0.00000	 220.0	 1	    1.12227	    0.90000;
	3590	 2	 62.4	 123.4	 0.0	 0.0	 1	    1.00988	    0.00000	 220.0	 1	    1.11976	    0.90000;
	3591	 1	 4.805328	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3592	 1	 1.101221	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3593	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3594	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00409	    0.00000	 220.0	 1	    1.10819	    0.90000;
	3595	 1	 71.8797	 44.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3596	 1	 20.0222	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3597	 2	 74.28236	 -11.3	 0.0	 0.0	 1	    1.01601	    0.00000	 220.0	 1	    1.13202	    0.90000;
	3598	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01962	    0.00000	 220.0	 1	    1.13924	    0.90000;
	3599	 1	 0.400444	 0.9	 0.0	 0.0	 1	    1.01487	    0.00000	 380.0	 1	    1.12973	    0.90000;
	3600	 2	 90.4	 53.4	 0.0	 0.0	 1	    1.01583	    0.00000	 220.0	 1	    1.13166	    0.90000;
	3601	 1	 5.105661	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3602	 2	 174.4	 45.5	 0.0	 0.0	 1	    1.02158	    0.00000	 220.0	 1	    1.14317	    0.90000;
	3603	 1	 310.8	 162.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3604	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3605	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01688	    0.00000	 220.0	 1	    1.13375	    0.90000;
	3606	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3607	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02754	    0.00000	 220.0	 1	    1.15507	    0.90000;
	3608	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01960	    0.00000	 150.0	 1	    1.13919	    0.90000;
	3609	 1	 42.34695	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3610	 2	 22.62509	 13.5	 0.0	 0.0	 1	    1.02981	    0.00000	 220.0	 1	    1.15962	    0.90000;
	3611	 2	 127.8	 37.6	 0.0	 0.0	 1	    1.01278	    0.00000	 380.0	 1	    1.12556	    0.90000;
	3612	 1	 1.301443	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3613	 1	 4.204662	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3614	 1	 220.7	 -14.8	 0.0	 0.0	 1	    1.01402	    0.00000	 380.0	 1	    1.12804	    0.90000;
	3615	 1	 3.904329	 1.4	 0.0	 0.0	 1	    1.01090	    0.00000	 110.0	 1	    1.12179	    0.90000;
	3616	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01399	    0.00000	 380.0	 1	    1.12798	    0.90000;
	3617	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01726	    0.00000	 220.0	 1	    1.13452	    0.90000;
	3618	 1	 5.105661	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3619	 2	 218.5	 93.7	 0.0	 0.0	 1	    1.01942	    0.00000	 220.0	 1	    1.13883	    0.90000;
	3620	 1	 419.5	 114.1	 0.0	 0.0	 1	    1.03680	    0.00000	 380.0	 1	    1.17360	    0.90000;
	3621	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01589	    0.00000	 220.0	 1	    1.13178	    0.90000;
	3622	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01914	    0.00000	 150.0	 1	    1.13827	    0.90000;
	3623	 1	 148.0	 26.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3624	 1	 159.5	 42.0	 0.0	 0.0	 1	    1.01569	    0.00000	 220.0	 1	    1.13137	    0.90000;
	3625	 1	 29.83308	 14.4	 0.0	 0.0	 1	    1.02246	    0.00000	 220.0	 1	    1.14492	    0.90000;
	3626	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02525	    0.00000	 380.0	 1	    1.15049	    0.90000;
	3627	 1	 0.0	 0.0	 0.357007	 0.0	 1	    1.01051	    0.00000	 380.0	 1	    1.12102	    0.90000;
	3628	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3629	 1	 33.33696	 20.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3630	 1	 77.18558	 26.5	 0.0	 0.0	 1	    1.02431	    0.00000	 220.0	 1	    1.14862	    0.90000;
	3631	 2	 14.61621	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3632	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3633	 1	 22.7252	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3634	 1	 7.00777	 1.8	 0.0	 0.0	 1	    1.02469	    0.00000	 380.0	 1	    1.14939	    0.90000;
	3635	 2	 280.1	 1.7	 0.0	 0.0	 1	    1.02174	    0.00000	 220.0	 1	    1.14348	    0.90000;
	3636	 1	 34.6384	 21.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3637	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3638	 1	 36.34029	 10.4	 0.0	 0.0	 1	    1.02455	    0.00000	 220.0	 1	    1.14911	    0.90000;
	3639	 1	 -7.90877	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3640	 2	 148.9	 23.5	 0.0	 0.0	 1	    1.02044	    0.00000	 220.0	 1	    1.14088	    0.90000;
	3641	 1	 26.12897	 9.7	 0.0	 0.0	 1	    1.01205	    0.00000	 220.0	 1	    1.12410	    0.90000;
	3642	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3643	 1	 110.8	 36.9	 0.0	 0.0	 1	    1.03208	    0.00000	 220.0	 1	    1.16415	    0.90000;
	3644	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00848	    0.00000	 380.0	 1	    1.11697	    0.90000;
	3645	 2	 98.9	 21.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3646	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01066	    0.00000	 380.0	 1	    1.12132	    0.90000;
	3647	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3648	 2	 182.1	 32.9	 0.0	 0.0	 1	    1.01155	    0.00000	 220.0	 1	    1.12311	    0.90000;
	3649	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3650	 1	 0.0	 0.0	 0.715884	 0.0	 1	    1.05248	    0.00000	 220.0	 1	    1.20495	    0.90000;
	3651	 2	 22.92542	 8.6	 0.0	 0.0	 1	    1.01843	    0.00000	 110.0	 1	    1.13686	    0.90000;
	3652	 1	 19.32142	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3653	 1	 144.8	 39.7	 0.0	 0.0	 1	    1.00550	    0.00000	 220.0	 1	    1.11100	    0.90000;
	3654	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3655	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3656	 1	 0.0	 0.0	 0.0	 63.87749	 1	    1.01498	    0.00000	 150.0	 1	    1.12995	    0.90000;
	3657	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3658	 2	 0.300333	 10.5	 0.0	 0.0	 1	    1.00757	    0.00000	 220.0	 1	    1.11514	    0.90000;
	3659	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3660	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3661	 1	 394.9	 -17.3	 0.0	 0.0	 1	    1.02222	    0.00000	 380.0	 1	    1.14445	    0.90000;
	3662	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02311	    0.00000	 380.0	 1	    1.14623	    0.90000;
	3663	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3664	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02622	    0.00000	 380.0	 1	    1.15244	    0.90000;
	3665	 1	 -1270.6	 -476.3	 0.0	 0.0	 1	    1.01750	    0.00000	 380.0	 1	    1.13500	    0.90000;
	3666	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01619	    0.00000	 380.0	 1	    1.13239	    0.90000;
	3667	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02462	    0.00000	 220.0	 1	    1.14923	    0.90000;
	3668	 2	 1.701887	 -5.9	 0.0	 0.0	 1	    1.01844	    0.00000	 380.0	 1	    1.13687	    0.90000;
	3669	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02449	    0.00000	 380.0	 1	    1.14898	    0.90000;
	3670	 2	 93.70389	 28.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3671	 1	 20.9232	 10.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3672	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00388	    0.00000	 150.0	 1	    1.10775	    0.90000;
	3673	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02075	    0.00000	 220.0	 1	    1.14151	    0.90000;
	3674	 1	 265.7	 113.5	 0.0	 0.0	 1	    1.00840	    0.00000	 220.0	 1	    1.11681	    0.90000;
	3675	 1	 54.96094	 31.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3676	 1	 24.02664	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3677	 1	 58.56493	 15.9	 0.0	 0.0	 1	    1.01441	    0.00000	 220.0	 1	    1.12882	    0.90000;
	3678	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03495	    0.00000	 380.0	 1	    1.16990	    0.90000;
	3679	 1	 352.6	 193.5	 0.0	 0.0	 1	    1.03590	    0.00000	 380.0	 1	    1.17180	    0.90000;
	3680	 1	 15.5172	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3681	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02069	    0.00000	 220.0	 1	    1.14139	    0.90000;
	3682	 1	 37.24129	 40.5	 0.0	 0.0	 1	    1.02755	    0.00000	 380.0	 1	    1.15510	    0.90000;
	3683	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01378	    0.00000	 380.0	 1	    1.12757	    0.90000;
	3684	 1	 1.902109	 0.7	 0.0	 0.0	 1	    1.01482	    0.00000	 110.0	 1	    1.12965	    0.90000;
	3685	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3686	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01193	    0.00000	 380.0	 1	    1.12386	    0.90000;
	3687	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00895	    0.00000	 220.0	 1	    1.11791	    0.90000;
	3688	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02742	    0.00000	 220.0	 1	    1.15484	    0.90000;
	3689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01525	    0.00000	 220.0	 1	    1.13049	    0.90000;
	3690	 2	 93.60378	 -21.0	 0.0	 0.0	 1	    1.03573	    0.00000	 220.0	 1	    1.17146	    0.90000;
	3691	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00738	    0.00000	 380.0	 1	    1.11476	    0.90000;
	3692	 1	 66.07326	 12.5	 0.0	 0.0	 1	    1.00985	    0.00000	 220.0	 1	    1.11970	    0.90000;
	3693	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02306	    0.00000	 220.0	 1	    1.14612	    0.90000;
	3694	 1	 347.7	 96.6	 0.0	 0.0	 1	    1.02513	    0.00000	 380.0	 1	    1.15027	    0.90000;
	3695	 2	 123.1	 23.5	 0.0	 0.0	 1	    1.02079	    0.00000	 220.0	 1	    1.14158	    0.90000;
	3696	 1	 74.78291	 -31.4	 0.0	 0.0	 1	    1.01071	    0.00000	 110.0	 1	    1.12143	    0.90000;
	3697	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3698	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01532	    0.00000	 380.0	 1	    1.13064	    0.90000;
	3699	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02417	    0.00000	 220.0	 1	    1.14834	    0.90000;
	3700	 1	 6.306993	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3701	 2	 74.08214	 17.1	 0.0	 0.0	 1	    1.03447	    0.00000	 110.0	 1	    1.16894	    0.90000;
	3702	 1	 131.3456	 63.6	 0.0	 0.0	 1	    1.01882	    0.00000	 220.0	 1	    1.13763	    0.90000;
	3703	 1	 14.71632	 5.3	 0.0	 0.0	 1	    1.02303	    0.00000	 110.0	 1	    1.14607	    0.90000;
	3704	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3705	 1	 18.2202	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3706	 2	 3.704107	 1.1	 0.0	 0.0	 1	    1.01328	    0.00000	 110.0	 1	    1.12657	    0.90000;
	3707	 1	 35.43929	 22.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3708	 1	 4.204662	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00636	    0.00000	 150.0	 1	    1.11273	    0.90000;
	3710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3711	 2	 0.0	 -0.1	 0.0	 0.0	 1	    1.03505	    0.00000	 220.0	 1	    1.17010	    0.90000;
	3712	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3713	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01246	    0.00000	 380.0	 1	    1.12493	    0.90000;
	3714	 1	 0.0	 0.0	 0.16999	 0.0	 1	    1.01564	    0.00000	 380.0	 1	    1.13128	    0.90000;
	3715	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00277	    0.00000	 150.0	 1	    1.10554	    0.90000;
	3716	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00925	    0.00000	 220.0	 1	    1.11851	    0.90000;
	3717	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01784	    0.00000	 150.0	 1	    1.13569	    0.90000;
	3718	 1	 113.0	 57.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3719	 2	 135.9	 4.0	 0.0	 0.0	 1	    1.01978	    0.00000	 220.0	 1	    1.13957	    0.90000;
	3720	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3721	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01348	    0.00000	 380.0	 1	    1.12696	    0.90000;
	3722	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00447	    0.00000	 220.0	 1	    1.10894	    0.90000;
	3723	 1	 195.2	 92.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3724	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02759	    0.00000	 380.0	 1	    1.15519	    0.90000;
	3725	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3726	 1	 40.24462	 24.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3727	 2	 225.8	 123.0	 0.0	 0.0	 1	    1.01015	    0.00000	 220.0	 1	    1.12031	    0.90000;
	3728	 1	 65.27237	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3729	 1	 47.65283	 7.1	 0.0	 0.0	 1	    1.00255	    0.00000	 220.0	 1	    1.10509	    0.90000;
	3730	 1	 61.66837	 28.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3731	 1	 173.0	 11.3	 0.0	 0.0	 1	    1.01147	    0.00000	 220.0	 1	    1.12295	    0.90000;
	3732	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03575	    0.00000	 220.0	 1	    1.17149	    0.90000;
	3733	 1	 128.0	 72.9	 0.0	 0.0	 1	    1.01627	    0.00000	 380.0	 1	    1.13255	    0.90000;
	3734	 1	 5.305883	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3735	 1	 81.0899	 12.5	 0.0	 0.0	 1	    1.02712	    0.00000	 220.0	 1	    1.15423	    0.90000;
	3736	 1	 40.34473	 10.4	 0.0	 0.0	 1	    1.01105	    0.00000	 110.0	 1	    1.12209	    0.90000;
	3737	 1	 0.500555	 12.4	 0.0	 0.0	 1	    1.01948	    0.00000	 220.0	 1	    1.13895	    0.90000;
	3738	 1	 0.0	 0.0	 0.0	 39.30328	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3739	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3740	 1	 13.01443	 3.8	 0.0	 0.0	 1	    1.02557	    0.00000	 220.0	 1	    1.15114	    0.90000;
	3741	 1	 0.0	 0.0	 0.00501	 0.0	 1	    1.01897	    0.00000	 380.0	 1	    1.13794	    0.90000;
	3742	 1	 64.77181	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3743	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01181	    0.00000	 380.0	 1	    1.12363	    0.90000;
	3744	 1	 9.910988	 5.4	 0.0	 0.0	 1	    1.01655	    0.00000	 220.0	 1	    1.13310	    0.90000;
	3745	 1	 0.0	 0.0	 0.08753	 0.0	 1	    1.00597	    0.00000	 220.0	 1	    1.11195	    0.90000;
	3746	 1	 2.202442	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3747	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00717	    0.00000	 380.0	 1	    1.11434	    0.90000;
	3748	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02021	    0.00000	 220.0	 1	    1.14041	    0.90000;
	3749	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00798	    0.00000	 380.0	 1	    1.11596	    0.90000;
	3750	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00480	    0.00000	 150.0	 1	    1.10961	    0.90000;
	3751	 1	 0.0	 0.0	 0.277056	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3752	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3753	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3754	 2	 232.1	 -6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3755	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00994	    0.00000	 380.0	 1	    1.11988	    0.90000;
	3756	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03328	    0.00000	 220.0	 1	    1.16656	    0.90000;
	3757	 1	 39.1434	 7.7	 0.0	 0.0	 1	    1.01844	    0.00000	 220.0	 1	    1.13687	    0.90000;
	3758	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00981	    0.00000	 220.0	 1	    1.11962	    0.90000;
	3759	 2	 0.0	 0.0	 0.0	 74.47162	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3760	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3761	 2	 39.84418	 17.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3762	 1	 25.42819	 7.9	 0.0	 0.0	 1	    1.00271	    0.00000	 110.0	 1	    1.10542	    0.90000;
	3763	 1	 145.8	 42.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3764	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03857	    0.00000	 220.0	 1	    1.17714	    0.90000;
	3765	 1	 13.31476	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3766	 1	 13.6414	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3767	 1	 137.8	 22.9	 0.0	 0.0	 1	    1.00881	    0.00000	 220.0	 1	    1.11762	    0.90000;
	3768	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3769	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3770	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01984	    0.00000	 380.0	 1	    1.13968	    0.90000;
	3771	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02544	    0.00000	 380.0	 1	    1.15087	    0.90000;
	3772	 1	 11.11232	 4.1	 0.0	 0.0	 1	    1.02609	    0.00000	 220.0	 1	    1.15218	    0.90000;
	3773	 1	 310.2	 4.5	 0.0	 0.0	 1	    1.01963	    0.00000	 220.0	 1	    1.13925	    0.90000;
	3774	 2	 128.3	 37.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3775	 1	 246.9	 20.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3776	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01196	    0.00000	 380.0	 1	    1.12391	    0.90000;
	3777	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3778	 1	 6.707437	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3779	 1	 1.902109	 9.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3780	 1	 91.4	 -88.2	 0.0	 0.0	 1	    1.00934	    0.00000	 220.0	 1	    1.11868	    0.90000;
	3781	 1	 71.67947	 14.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3782	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3783	 1	 110.7	 94.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3784	 1	 15.01665	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3785	 1	 0.2	 109.4	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3786	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03329	    0.00000	 220.0	 1	    1.16657	    0.90000;
	3787	 1	 121.4	 40.0	 0.0	 0.0	 1	    1.00904	    0.00000	 380.0	 1	    1.11808	    0.90000;
	3788	 1	 175.2	 70.7	 0.0	 0.0	 1	    1.03133	    0.00000	 380.0	 1	    1.16265	    0.90000;
	3789	 1	 0.0	 0.0	 0.0	 11.43648	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3790	 1	 29.03219	 10.1	 0.0	 0.0	 1	    1.01252	    0.00000	 110.0	 1	    1.12503	    0.90000;
	3791	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02761	    0.00000	 380.0	 1	    1.15522	    0.90000;
	3792	 2	 27.02997	 69.9	 0.0	 0.0	 1	    1.01332	    0.00000	 220.0	 1	    1.12664	    0.90000;
	3793	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00443	    0.00000	 380.0	 1	    1.10886	    0.90000;
	3794	 1	 325.2	 38.1	 0.0	 0.0	 1	    1.01460	    0.00000	 380.0	 1	    1.12920	    0.90000;
	3795	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3796	 1	 50.85638	 -23.0	 0.0	 0.0	 1	    1.00496	    0.00000	 220.0	 1	    1.10992	    0.90000;
	3797	 1	 200.2	 90.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3798	 1	 62.06882	 20.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3799	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3800	 1	 7.908769	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3801	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3802	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3803	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00591	    0.00000	 380.0	 1	    1.11181	    0.90000;
	3804	 1	 144.5	 40.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3805	 1	 20.22242	 5.7	 0.0	 0.0	 1	    1.00437	    0.00000	 220.0	 1	    1.10874	    0.90000;
	3806	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03091	    0.00000	 380.0	 1	    1.16183	    0.90000;
	3807	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3808	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01043	    0.00000	 220.0	 1	    1.12087	    0.90000;
	3809	 1	 195.6	 -1.0	 0.0	 0.0	 1	    1.00390	    0.00000	 220.0	 1	    1.10780	    0.90000;
	3810	 2	 29.3	 90.5	 0.0	 0.0	 1	    1.01197	    0.00000	 380.0	 1	    1.12394	    0.90000;
	3811	 2	 43.14784	 22.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3812	 1	 26.72964	 9.6	 0.0	 0.0	 1	    1.01497	    0.00000	 110.0	 1	    1.12994	    0.90000;
	3813	 1	 87.49701	 21.3	 0.0	 0.0	 1	    1.01419	    0.00000	 220.0	 1	    1.12838	    0.90000;
	3814	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01967	    0.00000	 220.0	 1	    1.13934	    0.90000;
	3815	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.01456	    0.00000	 220.0	 1	    1.12911	    0.90000;
	3816	 1	 59.1656	 19.3	 0.0	 0.0	 1	    1.00939	    0.00000	 150.0	 1	    1.11879	    0.90000;
	3817	 2	 205.3	 32.6	 0.0	 0.0	 1	    1.01448	    0.00000	 220.0	 1	    1.12896	    0.90000;
	3818	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02604	    0.00000	 380.0	 1	    1.15208	    0.90000;
	3819	 1	 12.7141	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3820	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01530	    0.00000	 380.0	 1	    1.13059	    0.90000;
	3821	 1	 0.0	 0.0	 0.0	 25.22114	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3822	 2	 1110.6	 290.8	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3823	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02302	    0.00000	 380.0	 1	    1.14604	    0.90000;
	3824	 1	 9.00999	 4.9	 0.0	 0.0	 1	    1.03153	    0.00000	 220.0	 1	    1.16306	    0.90000;
	3825	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3826	 1	 318.3	 76.8	 0.147737	 0.0	 1	    1.00817	    0.00000	 380.0	 1	    1.11633	    0.90000;
	3827	 1	 53.85971	 18.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3828	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3829	 2	 52.45816	 5.2	 0.0	 0.0	 1	    1.01246	    0.00000	 220.0	 1	    1.12492	    0.90000;
	3830	 1	 5.806438	 1.7	 0.0	 0.0	 1	    1.01685	    0.00000	 220.0	 1	    1.13370	    0.90000;
	3831	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02058	    0.00000	 380.0	 1	    1.14115	    0.90000;
	3832	 2	 67.07436	 34.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3833	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03124	    0.00000	 380.0	 1	    1.16248	    0.90000;
	3834	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01403	    0.00000	 380.0	 1	    1.12807	    0.90000;
	3835	 2	 -2.29168	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3836	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01332	    0.00000	 220.0	 1	    1.12664	    0.90000;
	3837	 1	 32.33585	 14.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3838	 1	 -806.3	 -50.1	 0.0	 0.0	 1	    1.00914	    0.00000	 380.0	 1	    1.11828	    0.90000;
	3839	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03450	    0.00000	 220.0	 1	    1.16901	    0.90000;
	3840	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00468	    0.00000	 110.0	 1	    1.10937	    0.90000;
	3841	 1	 0.0	 0.0	 0.120317	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3842	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00834	    0.00000	 220.0	 1	    1.11669	    0.90000;
	3843	 1	 8.409324	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3844	 1	 27.63063	 9.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3845	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3846	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3847	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01231	    0.00000	 220.0	 1	    1.12461	    0.90000;
	3848	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01141	    0.00000	 380.0	 1	    1.12282	    0.90000;
	3849	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3850	 2	 119.3	 106.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3851	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97190	    0.00000	 150.0	 1	    1.10000	    0.84379;
	3852	 1	 57.76405	 16.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3853	 3	 0.0	 0.0	 0.0	 0.0	 1	    1.02411	    0.00000	 380.0	 1	    1.14823	    0.90000;
	3854	 1	 11.01221	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3855	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3856	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03405	    0.00000	 220.0	 1	    1.16810	    0.90000;
	3857	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01917	    0.00000	 220.0	 1	    1.13835	    0.90000;
	3858	 1	 19.52164	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3859	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3860	 1	 190.7	 52.0	 0.0	 0.0	 1	    1.01660	    0.00000	 220.0	 1	    1.13320	    0.90000;
	3861	 1	 44.34917	 14.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3862	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01630	    0.00000	 380.0	 1	    1.13261	    0.90000;
	3863	 2	 271.9	 100.3	 0.0	 0.0	 1	    1.01533	    0.00000	 110.0	 1	    1.13066	    0.90000;
	3864	 1	 188.4777	 128.3	 0.0	 0.0	 1	    1.00825	    0.00000	 220.0	 1	    1.11651	    0.90000;
	3865	 2	 286.3	 94.1	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3866	 1	 24.92764	 9.6	 0.0	 0.0	 1	    1.02220	    0.00000	 220.0	 1	    1.14439	    0.90000;
	3867	 1	 24.22686	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3868	 1	 33.53718	 20.8	 0.0	 0.0	 1	    0.96110	    0.00000	 150.0	 1	    1.10000	    0.82220;
	3869	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02749	    0.00000	 220.0	 1	    1.15497	    0.90000;
	3870	 1	 57.06327	 15.6	 0.0	 0.0	 1	    1.00588	    0.00000	 220.0	 1	    1.11176	    0.90000;
	3871	 1	 -10.7119	 3.5	 0.0	 0.0	 1	    1.00412	    0.00000	 150.0	 1	    1.10824	    0.90000;
	3872	 1	 47.15228	 15.7	 0.0	 0.0	 1	    1.01351	    0.00000	 220.0	 1	    1.12702	    0.90000;
	3873	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3874	 1	 105.0	 18.0	 0.0	 0.0	 1	    1.00663	    0.00000	 220.0	 1	    1.11325	    0.90000;
	3875	 1	 44.54939	 27.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3876	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3877	 2	 204.2	 87.7	 0.0	 0.0	 1	    1.01870	    0.00000	 380.0	 1	    1.13741	    0.90000;
	3878	 1	 9.510545	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3879	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3880	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3881	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00292	    0.00000	 380.0	 1	    1.10584	    0.90000;
	3882	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3883	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3884	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3885	 1	 70.77847	 19.6	 0.0	 0.0	 1	    1.02276	    0.00000	 220.0	 1	    1.14552	    0.90000;
	3886	 1	 303.7	 247.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3887	 1	 24.92764	 8.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3888	 1	 128.7	 25.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.20000	    0.80000;
	3889	 1	 66.97426	 45.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3890	 1	 184.7	 71.5	 0.0	 0.0	 1	    1.01844	    0.00000	 150.0	 1	    1.13689	    0.90000;
	3891	 1	 31.93541	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3892	 2	 65.37248	 17.5	 0.0	 0.0	 1	    1.00624	    0.00000	 220.0	 1	    1.11248	    0.90000;
	3893	 1	 5.706326	 2.1	 0.0	 0.0	 1	    1.02269	    0.00000	 110.0	 1	    1.14538	    0.90000;
	3894	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02157	    0.00000	 380.0	 1	    1.14314	    0.90000;
	3895	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3896	 2	 9.610656	 62.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3897	 1	 11.91321	 4.3	 0.0	 0.0	 1	    1.01722	    0.00000	 110.0	 1	    1.13443	    0.90000;
	3898	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02782	    0.00000	 220.0	 1	    1.15563	    0.90000;
	3899	 1	 22.22464	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3900	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01808	    0.00000	 220.0	 1	    1.13617	    0.90000;
	3901	 1	 214.4	 52.9	 0.0	 0.0	 1	    1.01058	    0.00000	 220.0	 1	    1.12116	    0.90000;
	3902	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00352	    0.00000	 380.0	 1	    1.10704	    0.90000;
	3903	 2	 47.85305	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3904	 1	 0.500555	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3905	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01803	    0.00000	 220.0	 1	    1.13606	    0.90000;
	3906	 1	 0.0	 0.0	 0.0	 11.1585	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3907	 1	 -1.90211	 -28.1	 0.0	 0.0	 1	    1.03126	    0.00000	 380.0	 1	    1.16251	    0.90000;
	3908	 2	 0.300333	 16.8	 0.0	 0.0	 1	    1.01494	    0.00000	 220.0	 1	    1.12989	    0.90000;
	3909	 1	 80.58935	 7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3910	 1	 63.87082	 55.1	 0.0	 0.0	 1	    1.01173	    0.00000	 380.0	 1	    1.12347	    0.90000;
	3911	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02319	    0.00000	 150.0	 1	    1.14638	    0.90000;
	3912	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3913	 1	 26.62953	 9.7	 0.0	 0.0	 1	    1.01910	    0.00000	 110.0	 1	    1.13820	    0.90000;
	3914	 1	 0.0	 0.0	 0.0	 20.0	 1	    1.01461	    0.00000	 380.0	 1	    1.12922	    0.90000;
	3915	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3916	 1	 81.49035	 25.1	 0.0	 0.0	 1	    1.01105	    0.00000	 220.0	 1	    1.12211	    0.90000;
	3917	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02074	    0.00000	 220.0	 1	    1.14148	    0.90000;
	3918	 1	 30.53385	 9.0	 0.0	 0.0	 1	    1.01301	    0.00000	 110.0	 1	    1.12602	    0.90000;
	3919	 1	 2.402664	 0.9	 0.0	 0.0	 1	    1.01382	    0.00000	 110.0	 1	    1.12764	    0.90000;
	3920	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01711	    0.00000	 380.0	 1	    1.13423	    0.90000;
	3921	 1	 8.209102	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3922	 1	 60.0666	 -4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3923	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3924	 1	 8.909878	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3925	 1	 11.41265	 -3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3926	 1	 133.4	 29.4	 0.0	 0.0	 1	    1.01927	    0.00000	 220.0	 1	    1.13854	    0.90000;
	3927	 1	 26.12897	 2.7	 0.0	 0.0	 1	    1.02597	    0.00000	 220.0	 1	    1.15194	    0.90000;
	3928	 1	 -113.326	 45.2	 0.0	 0.0	 1	    1.02051	    0.00000	 380.0	 1	    1.14102	    0.90000;
	3929	 1	 -9.00999	 21.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3930	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3931	 1	 51.05661	 16.5	 0.0	 0.0	 1	    1.01873	    0.00000	 110.0	 1	    1.13747	    0.90000;
	3932	 1	 50.35583	 24.3	 0.0	 0.0	 1	    1.02743	    0.00000	 220.0	 1	    1.15487	    0.90000;
	3933	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3934	 2	 50.0555	 -30.4	 0.0	 0.0	 1	    1.00585	    0.00000	 110.0	 1	    1.11170	    0.90000;
	3935	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01187	    0.00000	 380.0	 1	    1.12374	    0.90000;
	3936	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3937	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02888	    0.00000	 380.0	 1	    1.15775	    0.90000;
	3938	 1	 10.81199	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3939	 1	 0.0	 0.0	 0.059489	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3940	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3941	 1	 96.2	 37.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3942	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02373	    0.00000	 380.0	 1	    1.14746	    0.90000;
	3943	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01067	    0.00000	 220.0	 1	    1.12134	    0.90000;
	3944	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01488	    0.00000	 380.0	 1	    1.12975	    0.90000;
	3945	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3946	 2	 0.0	 0.0	 0.51412	 485.2212	 1	    1.00762	    0.00000	 380.0	 1	    1.11524	    0.90000;
	3947	 1	 0.0	 0.0	 0.14848	 0.0	 1	    1.02563	    0.00000	 380.0	 1	    1.15126	    0.90000;
	3948	 1	 55.46149	 8.4	 0.0	 0.0	 1	    1.00624	    0.00000	 220.0	 1	    1.11249	    0.90000;
	3949	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3950	 2	 92.40245	 22.0	 0.0	 0.0	 1	    1.00748	    0.00000	 220.0	 1	    1.11495	    0.90000;
	3951	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00698	    0.00000	 380.0	 1	    1.11397	    0.90000;
	3952	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03196	    0.00000	 220.0	 1	    1.16393	    0.90000;
	3953	 1	 18.62065	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3954	 1	 14.31587	 7.2	 0.0	 0.0	 1	    1.01325	    0.00000	 220.0	 1	    1.12650	    0.90000;
	3955	 1	 43.54828	 14.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3956	 1	 68.47592	 -10.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3957	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01358	    0.00000	 380.0	 1	    1.12715	    0.90000;
	3958	 1	 57.0	 39.9	 0.0	 0.0	 1	    1.02087	    0.00000	 380.0	 1	    1.14175	    0.90000;
	3959	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02627	    0.00000	 220.0	 1	    1.15254	    0.90000;
	3960	 1	 24.12675	 29.4	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3961	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00465	    0.00000	 220.0	 1	    1.10929	    0.90000;
	3962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3963	 1	 163.6343	 23.0	 0.0	 0.0	 1	    1.01659	    0.00000	 220.0	 1	    1.13319	    0.90000;
	3964	 1	 165.8	 44.0	 0.0	 0.0	 1	    1.03198	    0.00000	 220.0	 1	    1.16396	    0.90000;
	3965	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3966	 1	 65.07214	 15.0	 0.0	 0.0	 1	    1.03254	    0.00000	 220.0	 1	    1.16509	    0.90000;
	3967	 1	 22.12453	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3968	 1	 235.0	 58.9	 0.0	 0.0	 1	    1.01373	    0.00000	 220.0	 1	    1.12746	    0.90000;
	3969	 1	 5.105661	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3970	 1	 20.82309	 8.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3971	 1	 0.0	 0.0	 0.053001	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3972	 1	 43.7485	 17.3	 0.0	 0.0	 1	    1.01698	    0.00000	 150.0	 1	    1.13396	    0.90000;
	3973	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01901	    0.00000	 380.0	 1	    1.13802	    0.90000;
	3974	 1	 1.301443	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3975	 1	 -13.7152	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3976	 1	 156.9	 122.5	 0.0	 0.0	 1	    1.01773	    0.00000	 380.0	 1	    1.13546	    0.90000;
	3977	 1	 23.22575	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3978	 1	 90.60045	 15.8	 0.0	 0.0	 1	    1.02990	    0.00000	 220.0	 1	    1.15981	    0.90000;
	3979	 1	 136.1	 18.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3980	 1	 72.28014	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3981	 1	 2.803108	 1.0	 0.0	 0.0	 1	    1.01911	    0.00000	 110.0	 1	    1.13823	    0.90000;
	3982	 1	 28.63174	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3983	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3984	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3985	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3986	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3987	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01307	    0.00000	 380.0	 1	    1.12613	    0.90000;
	3988	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01554	    0.00000	 150.0	 1	    1.13107	    0.90000;
	3989	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00462	    0.00000	 380.0	 1	    1.10925	    0.90000;
	3990	 1	 35.23907	 12.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3991	 1	 17.81976	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3992	 1	 33.73741	 11.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3993	 1	 60.9676	 19.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3994	 1	 10.9121	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3995	 1	 0.0	 0.0	 0.255999	 0.0	 1	    1.03727	    0.00000	 220.0	 1	    1.17453	    0.90000;
	3996	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01446	    0.00000	 380.0	 1	    1.12892	    0.90000;
	3997	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02326	    0.00000	 380.0	 1	    1.14653	    0.90000;
	3998	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3999	 1	 62.06882	 20.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4000	 2	 37.04107	 15.2	 0.0	 0.0	 1	    1.02737	    0.00000	 380.0	 1	    1.15474	    0.90000;
	4001	 1	 0.0	 0.0	 0.148479	 0.0	 1	    1.02789	    0.00000	 380.0	 1	    1.15579	    0.90000;
	4002	 2	 169.9	 41.9	 0.0	 0.0	 1	    1.02029	    0.00000	 220.0	 1	    1.14059	    0.90000;
	4003	 2	 0.0	 0.0	 0.045351	 0.0	 1	    1.02155	    0.00000	 380.0	 1	    1.14309	    0.90000;
	4004	 1	 193.0	 17.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4005	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02474	    0.00000	 380.0	 1	    1.14948	    0.90000;
	4006	 2	 41.04551	 12.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4007	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01476	    0.00000	 380.0	 1	    1.12952	    0.90000;
	4008	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4009	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04033	    0.00000	 220.0	 1	    1.18065	    0.90000;
	4010	 1	 35.23907	 12.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4011	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4012	 1	 -15.0166	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4013	 1	 29.1323	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4014	 1	 0.0	 0.0	 0.0	 -131.662	 1	    1.02578	    0.00000	 380.0	 1	    1.15157	    0.90000;
	4015	 1	 11.01221	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4016	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00292	    0.00000	 150.0	 1	    1.10584	    0.90000;
	4017	 1	 45.04995	 13.2	 0.0	 0.0	 1	    1.02443	    0.00000	 220.0	 1	    1.14885	    0.90000;
	4018	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00503	    0.00000	 220.0	 1	    1.11006	    0.90000;
	4019	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01554	    0.00000	 150.0	 1	    1.13107	    0.90000;
	4020	 1	 303.6	 47.5	 0.0	 0.0	 1	    1.02641	    0.00000	 380.0	 1	    1.15282	    0.90000;
	4021	 1	 30.0333	 9.7	 0.0	 0.0	 1	    1.00596	    0.00000	 110.0	 1	    1.11191	    0.90000;
	4022	 1	 117.4	 12.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4023	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4024	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03584	    0.00000	 220.0	 1	    1.17167	    0.90000;
	4025	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02602	    0.00000	 380.0	 1	    1.15204	    0.90000;
	4026	 1	 32.83641	 9.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4027	 1	 77.18558	 47.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4028	 1	 0.0	 0.0	 0.0	 64.3288	 1	    1.01727	    0.00000	 150.0	 1	    1.13454	    0.90000;
	4029	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01436	    0.00000	 220.0	 1	    1.12871	    0.90000;
	4030	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4031	 2	 496.5	 62.4	 0.0	 0.0	 1	    1.03190	    0.00000	 220.0	 1	    1.16380	    0.90000;
	4032	 1	 296.8	 77.7	 0.0	 0.0	 1	    1.01743	    0.00000	 150.0	 1	    1.13485	    0.90000;
	4033	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4034	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4035	 1	 19.52164	 5.6	 0.0	 0.0	 1	    1.00517	    0.00000	 150.0	 1	    1.11034	    0.90000;
	4036	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03328	    0.00000	 220.0	 1	    1.16657	    0.90000;
	4037	 1	 142.5	 523.5	 0.0	 0.0	 1	    1.03322	    0.00000	 380.0	 1	    1.16644	    0.90000;
	4038	 1	 60.0666	 45.0	 0.0	 0.0	 1	    1.01266	    0.00000	 220.0	 1	    1.12533	    0.90000;
	4039	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4040	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03682	    0.00000	 380.0	 1	    1.17364	    0.90000;
	4041	 1	 0.0	 0.0	 0.163	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4042	 1	 5.506105	 2.0	 0.0	 0.0	 1	    1.00936	    0.00000	 110.0	 1	    1.11873	    0.90000;
	4043	 1	 13.81532	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4044	 2	 141.2	 33.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4045	 1	 1.301443	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4046	 2	 31.53496	 12.5	 0.0	 0.0	 1	    1.01299	    0.00000	 380.0	 1	    1.12598	    0.90000;
	4047	 1	 5.205771	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4048	 1	 16.51831	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4049	 2	 0.4	 0.2	 0.0	 0.0	 1	    1.00906	    0.00000	 380.0	 1	    1.11811	    0.90000;
	4050	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01228	    0.00000	 380.0	 1	    1.12456	    0.90000;
	4051	 2	 27.43041	 13.7	 0.0	 0.0	 1	    1.02976	    0.00000	 380.0	 1	    1.15952	    0.90000;
	4052	 1	 182.182	 36.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4053	 1	 140.2	 11.2	 0.0	 0.0	 1	    1.00704	    0.00000	 220.0	 1	    1.11409	    0.90000;
	4054	 1	 8.909878	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4055	 1	 52.6	 110.6	 0.0	 0.0	 1	    1.01388	    0.00000	 220.0	 1	    1.12777	    0.90000;
	4056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00666	    0.00000	 220.0	 1	    1.11332	    0.90000;
	4057	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4058	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02261	    0.00000	 380.0	 1	    1.14522	    0.90000;
	4059	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4060	 1	 22.42486	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4061	 1	 0.0	 0.0	 0.087538	 0.0	 1	    1.00395	    0.00000	 220.0	 1	    1.10790	    0.90000;
	4062	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4063	 1	 15.11676	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4064	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4065	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4066	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4067	 1	 37.44151	 -28.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4068	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00797	    0.00000	 380.0	 1	    1.11594	    0.90000;
	4069	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00658	    0.00000	 150.0	 1	    1.11317	    0.90000;
	4070	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4071	 1	 49.45483	 30.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4072	 1	 24.92764	 15.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4073	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02009	    0.00000	 150.0	 1	    1.14018	    0.90000;
	4074	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00937	    0.00000	 380.0	 1	    1.11873	    0.90000;
	4075	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4076	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00954	    0.00000	 220.0	 1	    1.11909	    0.90000;
	4077	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4078	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01968	    0.00000	 220.0	 1	    1.13935	    0.90000;
	4079	 1	 0.0	 0.0	 0.0	 17.25139	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4080	 1	 69.77736	 25.0	 0.0	 0.0	 1	    1.01626	    0.00000	 220.0	 1	    1.13252	    0.90000;
	4081	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01126	    0.00000	 380.0	 1	    1.12251	    0.90000;
	4082	 2	 1.101221	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4083	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02618	    0.00000	 380.0	 1	    1.15237	    0.90000;
	4084	 1	 71.8797	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4085	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00923	    0.00000	 220.0	 1	    1.11845	    0.90000;
	4086	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4087	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01931	    0.00000	 220.0	 1	    1.13862	    0.90000;
	4088	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01035	    0.00000	 380.0	 1	    1.12071	    0.90000;
	4089	 1	 15.31698	 18.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4090	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01399	    0.00000	 380.0	 1	    1.12797	    0.90000;
	4091	 1	 336.3	 104.4	 0.0	 0.0	 1	    1.01547	    0.00000	 150.0	 1	    1.13094	    0.90000;
	4092	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4093	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4094	 2	 0.0	 0.0	 0.536314	 0.0	 1	    1.01015	    0.00000	 380.0	 1	    1.12031	    0.90000;
	4095	 1	 80.0888	 20.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4096	 1	 199.3	 53.7	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4097	 1	 65.6	 -382.0	 0.222924	 0.0	 1	    1.01314	    0.00000	 380.0	 1	    1.12627	    0.90000;
	4098	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00444	    0.00000	 220.0	 1	    1.10887	    0.90000;
	4099	 1	 20.72298	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4100	 1	 170.1	 -9.3	 0.0	 0.0	 1	    1.04255	    0.00000	 220.0	 1	    1.18510	    0.90000;
	4101	 1	 95.50589	 17.1	 0.0	 0.0	 1	    1.01385	    0.00000	 220.0	 1	    1.12770	    0.90000;
	4102	 2	 219.6	 62.5	 0.0	 0.0	 1	    1.01966	    0.00000	 220.0	 1	    1.13931	    0.90000;
	4103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01917	    0.00000	 380.0	 1	    1.13834	    0.90000;
	4104	 2	 62.36915	 21.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4105	 1	 77.98647	 30.8	 0.0	 0.0	 1	    1.01912	    0.00000	 150.0	 1	    1.13823	    0.90000;
	4106	 1	 75.38358	 21.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4107	 1	 81.8908	 19.9	 0.0	 0.0	 1	    1.01375	    0.00000	 220.0	 1	    1.12751	    0.90000;
	4108	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01329	    0.00000	 380.0	 1	    1.12658	    0.90000;
	4109	 1	 92.10212	 29.5	 0.0	 0.0	 1	    1.00940	    0.00000	 220.0	 1	    1.11880	    0.90000;
	4110	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4111	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4112	 1	 12.91432	 4.0	 0.0	 0.0	 1	    1.01252	    0.00000	 110.0	 1	    1.12504	    0.90000;
	4113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01525	    0.00000	 220.0	 1	    1.13049	    0.90000;
	4114	 1	 349.6	 22.0	 0.0	 0.0	 1	    1.02588	    0.00000	 380.0	 1	    1.15176	    0.90000;
	4115	 1	 91.10101	 36.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02894	    0.00000	 220.0	 1	    1.15788	    0.90000;
	4117	 2	 41.04551	 31.8	 0.0	 0.0	 1	    1.00761	    0.00000	 220.0	 1	    1.11521	    0.90000;
	4118	 1	 34.03774	 21.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4119	 1	 3.203552	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4120	 2	 58.2646	 12.2	 0.0	 0.0	 1	    1.03037	    0.00000	 220.0	 1	    1.16074	    0.90000;
	4121	 1	 15.31698	 9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4122	 1	 5.105661	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4123	 2	 405.5	 247.2	 0.0	 0.0	 1	    1.02518	    0.00000	 380.0	 1	    1.15036	    0.90000;
	4124	 1	 3.203552	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4125	 1	 0.0	 0.0	 0.159842	 0.0	 1	    1.01289	    0.00000	 380.0	 1	    1.12578	    0.90000;
	4126	 1	 14.91654	 5.4	 0.0	 0.0	 1	    1.01160	    0.00000	 110.0	 1	    1.12320	    0.90000;
	4127	 1	 7.708547	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4128	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4129	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4131	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01482	    0.00000	 380.0	 1	    1.12963	    0.90000;
	4132	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01083	    0.00000	 380.0	 1	    1.12166	    0.90000;
	4133	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02310	    0.00000	 380.0	 1	    1.14621	    0.90000;
	4134	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01774	    0.00000	 220.0	 1	    1.13548	    0.90000;
	4135	 1	 21.12342	 13.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4136	 1	 2.803108	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4137	 1	 33.03663	 10.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4138	 1	 20.0222	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4139	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02601	    0.00000	 220.0	 1	    1.15202	    0.90000;
	4140	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01635	    0.00000	 380.0	 1	    1.13270	    0.90000;
	4141	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4142	 1	 179.8	 76.5	 0.0	 0.0	 1	    1.00591	    0.00000	 220.0	 1	    1.11182	    0.90000;
	4143	 1	 119.0	 21.9	 0.0	 0.0	 1	    1.02285	    0.00000	 220.0	 1	    1.14571	    0.90000;
	4144	 1	 48.45372	 16.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4145	 1	 138.2	 21.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4146	 1	 93.0	 66.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4147	 1	 6.407104	 2.3	 0.0	 0.0	 1	    1.00757	    0.00000	 110.0	 1	    1.11513	    0.90000;
	4148	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4149	 1	 13.91543	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4150	 1	 101.0	 20.6	 0.0	 0.0	 1	    1.01789	    0.00000	 380.0	 1	    1.13578	    0.90000;
	4151	 1	 130.5	 25.7	 0.0	 0.0	 1	    1.02065	    0.00000	 220.0	 1	    1.14130	    0.90000;
	4152	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4153	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03410	    0.00000	 220.0	 1	    1.16820	    0.90000;
	4154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4155	 2	 77.58602	 -6.1	 0.0	 0.0	 1	    1.04451	    0.00000	 220.0	 1	    1.18902	    0.90000;
	4156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4157	 1	 0.0	 0.0	 0.139597	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4158	 1	 11.91321	 4.3	 0.0	 0.0	 1	    1.00909	    0.00000	 110.0	 1	    1.11818	    0.90000;
	4159	 1	 73.28124	 9.4	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4160	 1	 47.95317	 16.3	 0.0	 0.0	 1	    1.01833	    0.00000	 220.0	 1	    1.13666	    0.90000;
	4161	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4162	 1	 8.509435	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4163	 1	 311.4	 43.0	 0.0	 0.0	 1	    1.01151	    0.00000	 380.0	 1	    1.12303	    0.90000;
	4164	 1	 2.202442	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4165	 1	 50.65616	 56.5	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4166	 1	 19.52164	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4167	 1	 11.01221	 3.9	 0.0	 0.0	 1	    1.02120	    0.00000	 220.0	 1	    1.14239	    0.90000;
	4168	 2	 95.40578	 -22.5	 0.0	 0.0	 1	    1.03444	    0.00000	 220.0	 1	    1.16887	    0.90000;
	4169	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4170	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01776	    0.00000	 110.0	 1	    1.13552	    0.90000;
	4171	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4172	 2	 672.7	 107.6	 0.0	 0.0	 1	    1.01928	    0.00000	 150.0	 1	    1.13855	    0.90000;
	4173	 1	 12.21354	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4174	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02479	    0.00000	 380.0	 1	    1.14957	    0.90000;
	4175	 2	 6.407104	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4176	 1	 -6.7	 -7.5	 0.0	 0.0	 1	    1.00299	    0.00000	 150.0	 1	    1.10597	    0.90000;
	4177	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4178	 1	 183.8	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4179	 1	 20.32253	 -24.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4180	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00544	    0.00000	 380.0	 1	    1.11087	    0.90000;
	4181	 2	 107.9	 52.9	 0.0	 0.0	 1	    1.02851	    0.00000	 220.0	 1	    1.15702	    0.90000;
	4182	 1	 4.304773	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4183	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4184	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01383	    0.00000	 380.0	 1	    1.12767	    0.90000;
	4185	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02079	    0.00000	 110.0	 1	    1.14157	    0.90000;
	4186	 1	 19.1212	 7.4	 0.0	 0.0	 1	    1.01208	    0.00000	 380.0	 1	    1.12415	    0.90000;
	4187	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4188	 2	 37.94207	 18.9	 0.0	 0.0	 1	    1.03064	    0.00000	 380.0	 1	    1.16128	    0.90000;
	4189	 1	 70.27792	 10.3	 0.0	 0.0	 1	    1.01289	    0.00000	 220.0	 1	    1.12578	    0.90000;
	4190	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00295	    0.00000	 150.0	 1	    1.10589	    0.90000;
	4191	 1	 10.11121	 3.7	 0.0	 0.0	 1	    1.01072	    0.00000	 110.0	 1	    1.12144	    0.90000;
	4192	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03015	    0.00000	 380.0	 1	    1.16030	    0.90000;
	4193	 1	 10.11121	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4194	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01600	    0.00000	 380.0	 1	    1.13201	    0.90000;
	4195	 1	 16.51831	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4196	 1	 74.18224	 14.6	 0.0	 0.0	 1	    1.00302	    0.00000	 110.0	 1	    1.10604	    0.90000;
	4197	 1	 42.54717	 17.6	 0.0	 0.0	 1	    1.04270	    0.00000	 220.0	 1	    1.18541	    0.90000;
	4198	 1	 30.83419	 16.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4199	 1	 64.57159	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4200	 1	 1.902109	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4201	 1	 74.6828	 46.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4202	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00999	    0.00000	 380.0	 1	    1.11998	    0.90000;
	4203	 1	 26.02886	 16.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4204	 1	 40.0444	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4205	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00806	    0.00000	 380.0	 1	    1.11613	    0.90000;
	4206	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00410	    0.00000	 220.0	 1	    1.10819	    0.90000;
	4207	 1	 162.1	 73.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4208	 1	 350.0	 129.4	 0.0	 0.0	 1	    1.00422	    0.00000	 220.0	 1	    1.10845	    0.90000;
	4209	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4210	 1	 137.8	 64.5	 0.0	 0.0	 1	    1.00912	    0.00000	 380.0	 1	    1.11824	    0.90000;
	4211	 1	 16.11787	 4.3	 0.0	 0.0	 1	    1.00322	    0.00000	 110.0	 1	    1.10644	    0.90000;
	4212	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4213	 1	 75.5838	 -7.5	 0.0	 0.0	 1	    1.01148	    0.00000	 380.0	 1	    1.12296	    0.90000;
	4214	 2	 280.7	 53.7	 0.0	 0.0	 1	    1.02298	    0.00000	 380.0	 1	    1.14596	    0.90000;
	4215	 1	 17.91987	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4216	 1	 1.701887	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4217	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4218	 1	 3.704107	 1.3	 0.0	 0.0	 1	    1.00436	    0.00000	 110.0	 1	    1.10873	    0.90000;
	4219	 1	 18.2202	 8.6	 0.0	 0.0	 1	    1.01736	    0.00000	 380.0	 1	    1.13471	    0.90000;
	4220	 1	 0.0	 0.0	 0.278139	 0.0	 1	    1.01695	    0.00000	 380.0	 1	    1.13390	    0.90000;
	4221	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01803	    0.00000	 220.0	 1	    1.13607	    0.90000;
	4222	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01863	    0.00000	 380.0	 1	    1.13726	    0.90000;
	4223	 1	 41.74628	 13.2	 0.0	 0.0	 1	    1.01020	    0.00000	 110.0	 1	    1.12041	    0.90000;
	4224	 1	 5.00555	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4225	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4226	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00705	    0.00000	 220.0	 1	    1.11411	    0.90000;
	4227	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03118	    0.00000	 380.0	 1	    1.16236	    0.90000;
	4228	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4229	 1	 4.605106	 1.7	 0.0	 0.0	 1	    1.01037	    0.00000	 110.0	 1	    1.12074	    0.90000;
	4230	 1	 93.90411	 -0.4	 0.0	 0.0	 1	    1.01872	    0.00000	 220.0	 1	    1.13744	    0.90000;
	4231	 2	 68.37582	 -24.4	 0.0	 0.0	 1	    1.01182	    0.00000	 220.0	 1	    1.12365	    0.90000;
	4232	 1	 51.05661	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4233	 1	 27.13008	 16.8	 0.0	 0.0	 1	    1.00945	    0.00000	 150.0	 1	    1.11891	    0.90000;
	4234	 1	 16.51831	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4235	 2	 100.6	 15.7	 0.0	 0.0	 1	    1.01349	    0.00000	 220.0	 1	    1.12698	    0.90000;
	4236	 2	 87.9	 75.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4237	 2	 204.2	 41.1	 0.0	 0.0	 1	    1.00569	    0.00000	 220.0	 1	    1.11139	    0.90000;
	4238	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4239	 1	 390.5	 62.5	 0.0	 0.0	 1	    1.01625	    0.00000	 150.0	 1	    1.13249	    0.90000;
	4240	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4241	 1	 28.03108	 10.2	 0.0	 0.0	 1	    1.01567	    0.00000	 110.0	 1	    1.13133	    0.90000;
	4242	 1	 11.41265	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4243	 2	 0.300333	 97.4	 0.302736	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4244	 1	 44.34917	 14.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4245	 1	 91.2	 56.1	 0.0	 0.0	 1	    1.00663	    0.00000	 220.0	 1	    1.11326	    0.90000;
	4246	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4247	 1	 124.0	 29.2	 0.0	 0.0	 1	    1.00466	    0.00000	 220.0	 1	    1.10932	    0.90000;
	4248	 1	 0.200222	 0.8	 0.0	 0.0	 1	    1.01285	    0.00000	 220.0	 1	    1.12570	    0.90000;
	4249	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02627	    0.00000	 380.0	 1	    1.15254	    0.90000;
	4250	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4251	 1	 25.12786	 8.2	 0.0	 0.0	 1	    1.00533	    0.00000	 110.0	 1	    1.11065	    0.90000;
	4252	 1	 102.7	 17.8	 0.0	 0.0	 1	    1.02142	    0.00000	 220.0	 1	    1.14285	    0.90000;
	4253	 1	 344.7	 -31.1	 0.0	 0.0	 1	    1.02045	    0.00000	 380.0	 1	    1.14091	    0.90000;
	4254	 1	 84.09324	 1.0	 0.0	 0.0	 1	    1.01507	    0.00000	 380.0	 1	    1.13014	    0.90000;
	4255	 1	 2.502775	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4256	 1	 38.84307	 8.5	 0.0	 0.0	 1	    1.01970	    0.00000	 220.0	 1	    1.13941	    0.90000;
	4257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4258	 1	 46.15117	 11.2	 0.0	 0.0	 1	    1.01423	    0.00000	 220.0	 1	    1.12846	    0.90000;
	4259	 1	 16.01776	 5.1	 0.0	 0.0	 1	    1.00820	    0.00000	 110.0	 1	    1.11640	    0.90000;
	4260	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01227	    0.00000	 150.0	 1	    1.12454	    0.90000;
	4261	 1	 109.7	 15.0	 0.0	 0.0	 1	    1.02400	    0.00000	 220.0	 1	    1.14801	    0.90000;
	4262	 2	 0.800888	 45.3	 0.0	 0.0	 1	    1.01554	    0.00000	 380.0	 1	    1.13107	    0.90000;
	4263	 1	 0.0	 8.3	 0.0	 0.0	 1	    1.04688	    0.00000	 150.0	 1	    1.19376	    0.90000;
	4264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01173	    0.00000	 150.0	 1	    1.12346	    0.90000;
	4265	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01556	    0.00000	 110.0	 1	    1.13113	    0.90000;
	4266	 1	 10.81199	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4267	 2	 124.3	 42.0	 0.0	 0.0	 1	    1.01238	    0.00000	 220.0	 1	    1.12475	    0.90000;
	4268	 1	 15.81754	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4269	 1	 0.0	 0.0	 0.137257	 0.0	 1	    1.02886	    0.00000	 380.0	 1	    1.15773	    0.90000;
	4270	 1	 25.32808	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4272	 1	 162.0	 83.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4273	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02744	    0.00000	 380.0	 1	    1.15487	    0.90000;
	4274	 1	 136.8	 4.8	 0.0	 0.0	 1	    1.01681	    0.00000	 220.0	 1	    1.13362	    0.90000;
	4275	 1	 19.72187	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4276	 1	 0.0	 0.0	 0.363006	 0.0	 1	    1.03241	    0.00000	 380.0	 1	    1.16481	    0.90000;
	4277	 1	 19.62176	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02933	    0.00000	 380.0	 1	    1.15867	    0.90000;
	4279	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4280	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4281	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00653	    0.00000	 380.0	 1	    1.11307	    0.90000;
	4282	 2	 198.1	 78.0	 0.0	 0.0	 1	    1.01035	    0.00000	 220.0	 1	    1.12070	    0.90000;
	4283	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00844	    0.00000	 220.0	 1	    1.11688	    0.90000;
	4284	 1	 0.0	 0.0	 0.086002	 0.0	 1	    1.00601	    0.00000	 220.0	 1	    1.11201	    0.90000;
	4285	 1	 14.21576	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4286	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00879	    0.00000	 380.0	 1	    1.11757	    0.90000;
	4287	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01466	    0.00000	 220.0	 1	    1.12932	    0.90000;
	4288	 1	 392.0	 177.7	 0.191685	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4289	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02101	    0.00000	 380.0	 1	    1.14202	    0.90000;
	4290	 1	 97.0	 57.4	 0.0	 0.0	 1	    1.01988	    0.00000	 380.0	 1	    1.13976	    0.90000;
	4291	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01890	    0.00000	 220.0	 1	    1.13779	    0.90000;
	4292	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4293	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4294	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00710	    0.00000	 380.0	 1	    1.11421	    0.90000;
	4295	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4296	 1	 4.905439	 1.6	 0.0	 0.0	 1	    1.01482	    0.00000	 220.0	 1	    1.12964	    0.90000;
	4297	 2	 55.36138	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4298	 1	 2.00222	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4299	 1	 3.103441	 0.1	 0.0	 0.0	 1	    1.01774	    0.00000	 220.0	 1	    1.13548	    0.90000;
	4300	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01365	    0.00000	 220.0	 1	    1.12729	    0.90000;
	4301	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4302	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00498	    0.00000	 150.0	 1	    1.10996	    0.90000;
	4303	 1	 17.7	 -334.5	 0.144009	 0.0	 1	    1.01660	    0.00000	 380.0	 1	    1.13319	    0.90000;
	4304	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01382	    0.00000	 380.0	 1	    1.12764	    0.90000;
	4305	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4306	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01012	    0.00000	 380.0	 1	    1.12023	    0.90000;
	4307	 1	 0.0	 0.0	 0.090702	 0.0	 1	    1.02718	    0.00000	 380.0	 1	    1.15437	    0.90000;
	4308	 1	 277.9	 143.1	 0.0	 0.0	 1	    1.00745	    0.00000	 380.0	 1	    1.11489	    0.90000;
	4309	 2	 106.0	 27.3	 0.0	 0.0	 1	    1.02634	    0.00000	 220.0	 1	    1.15267	    0.90000;
	4310	 2	 0.400444	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4311	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02378	    0.00000	 110.0	 1	    1.14756	    0.90000;
	4312	 2	 16.4182	 9.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4313	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01428	    0.00000	 380.0	 1	    1.12856	    0.90000;
	4314	 2	 14.41598	 20.7	 0.0	 0.0	 1	    1.03105	    0.00000	 150.0	 1	    1.16209	    0.90000;
	4315	 1	 2.202442	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4316	 1	 63.67059	 21.3	 0.0	 0.0	 1	    1.00397	    0.00000	 220.0	 1	    1.10793	    0.90000;
	4317	 1	 0.0	 0.0	 0.191685	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4318	 1	 93.30344	 27.8	 0.0	 0.0	 1	    1.00886	    0.00000	 220.0	 1	    1.11771	    0.90000;
	4319	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02367	    0.00000	 220.0	 1	    1.14735	    0.90000;
	4320	 1	 137.7	 32.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4321	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4322	 1	 101.1	 19.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4324	 1	 59.1656	 14.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4325	 2	 28.93208	 9.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4326	 1	 147.0	 56.3	 0.0	 0.0	 1	    1.01839	    0.00000	 150.0	 1	    1.13679	    0.90000;
	4327	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00420	    0.00000	 380.0	 1	    1.10839	    0.90000;
	4328	 1	 45.04995	 19.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4329	 1	 65.07214	 30.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4330	 1	 173.4	 31.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4331	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01464	    0.00000	 150.0	 1	    1.12928	    0.90000;
	4332	 1	 31.93541	 10.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4333	 1	 14.91654	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4334	 1	 33.03663	 10.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4335	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01003	    0.00000	 380.0	 1	    1.12006	    0.90000;
	4336	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4337	 1	 51.85749	 19.2	 0.0	 0.0	 1	    1.01978	    0.00000	 220.0	 1	    1.13957	    0.90000;
	4338	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4339	 2	 87.49701	 25.9	 0.0	 0.0	 1	    1.00669	    0.00000	 220.0	 1	    1.11339	    0.90000;
	4340	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00293	    0.00000	 220.0	 1	    1.10586	    0.90000;
	4341	 1	 63.27015	 28.9	 0.0	 0.0	 1	    1.02357	    0.00000	 150.0	 1	    1.14714	    0.90000;
	4342	 1	 153.2	 31.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4343	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02026	    0.00000	 380.0	 1	    1.14052	    0.90000;
	4344	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4345	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01810	    0.00000	 380.0	 1	    1.13620	    0.90000;
	4346	 1	 2.502775	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4347	 1	 40.14451	 24.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4348	 1	 21.02331	 14.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4349	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00956	    0.00000	 220.0	 1	    1.11912	    0.90000;
	4350	 1	 69.77736	 22.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4351	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01955	    0.00000	 220.0	 1	    1.13910	    0.90000;
	4352	 1	 89.9	 40.2	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4353	 1	 71.9798	 27.1	 0.0	 0.0	 1	    1.00856	    0.00000	 380.0	 1	    1.11712	    0.90000;
	4354	 2	 30.53385	 10.9	 0.117	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4355	 1	 146.9	 -5.1	 0.0	 0.0	 1	    1.02541	    0.00000	 220.0	 1	    1.15083	    0.90000;
	4356	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4357	 1	 9.110101	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4358	 1	 0.0	 0.0	 0.0	 -15.677	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4359	 1	 336.9	 81.0	 0.0	 0.0	 1	    1.00367	    0.00000	 220.0	 1	    1.10734	    0.90000;
	4360	 1	 11.41265	 3.8	 0.0	 0.0	 1	    1.02156	    0.00000	 110.0	 1	    1.14311	    0.90000;
	4361	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03044	    0.00000	 380.0	 1	    1.16088	    0.90000;
	4362	 1	 -9.6	 -2.5	 0.0	 0.0	 1	    1.01149	    0.00000	 150.0	 1	    1.12297	    0.90000;
	4363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01535	    0.00000	 380.0	 1	    1.13070	    0.90000;
	4364	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4365	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4367	 1	 0.0	 0.0	 0.282417	 0.0	 1	    1.02288	    0.00000	 380.0	 1	    1.14576	    0.90000;
	4368	 1	 20.12231	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4369	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4370	 1	 118.6	 43.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4371	 2	 371.6	 100.4	 0.0	 0.0	 1	    1.02420	    0.00000	 220.0	 1	    1.14839	    0.90000;
	4372	 1	 210.8	 -0.7	 0.0	 0.0	 1	    1.01110	    0.00000	 220.0	 1	    1.12221	    0.90000;
	4373	 1	 39.84418	 6.4	 0.0	 0.0	 1	    1.01986	    0.00000	 380.0	 1	    1.13973	    0.90000;
	4374	 1	 7.00777	 1.0	 0.0	 0.0	 1	    1.01425	    0.00000	 150.0	 1	    1.12850	    0.90000;
	4375	 1	 151.0	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4376	 1	 0.0	 0.0	 0.073	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.20000	    0.80000;
	4377	 1	 -875.4	 -172.2	 0.0	 0.0	 1	    1.02439	    0.00000	 380.0	 1	    1.14877	    0.90000;
	4378	 1	 141.3567	 53.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4379	 1	 41.24573	 13.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4380	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4381	 2	 68.07548	 13.6	 0.0	 0.0	 1	    1.03260	    0.00000	 220.0	 1	    1.16521	    0.90000;
	4382	 1	 270.5	 77.8	 0.0	 0.0	 1	    1.02356	    0.00000	 380.0	 1	    1.14712	    0.90000;
	4383	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02147	    0.00000	 380.0	 1	    1.14294	    0.90000;
	4384	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03663	    0.00000	 120.0	 1	    1.17326	    0.90000;
	4385	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4386	 1	 78.48702	 48.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4387	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02425	    0.00000	 220.0	 1	    1.14850	    0.90000;
	4388	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02976	    0.00000	 380.0	 1	    1.15953	    0.90000;
	4389	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4390	 1	 103.6	 16.0	 0.0	 0.0	 1	    1.03583	    0.00000	 220.0	 1	    1.17167	    0.90000;
	4391	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4392	 1	 0.0	 0.0	 0.0	 11.65603	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4393	 1	 171.9	 39.1	 0.0	 0.0	 1	    1.01222	    0.00000	 220.0	 1	    1.12445	    0.90000;
	4394	 1	 0.0	 0.0	 0.126994	 0.0	 1	    1.02328	    0.00000	 380.0	 1	    1.14656	    0.90000;
	4395	 2	 136.5	 46.1	 0.0	 0.0	 1	    1.01101	    0.00000	 220.0	 1	    1.12202	    0.90000;
	4396	 1	 19.22131	 6.4	 0.0	 0.0	 1	    1.02786	    0.00000	 220.0	 1	    1.15572	    0.90000;
	4397	 1	 5.105661	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4398	 1	 34.13785	 21.1	 0.0	 0.0	 1	    1.04695	    0.00000	 150.0	 1	    1.19390	    0.90000;
	4399	 1	 0.0	 0.0	 0.114011	 0.0	 1	    1.02149	    0.00000	 380.0	 1	    1.14297	    0.90000;
	4400	 2	 14.61621	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4401	 1	 19.82198	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4402	 1	 121.6	 49.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4403	 1	 151.1	 66.9	 0.0	 0.0	 1	    1.00327	    0.00000	 380.0	 1	    1.10653	    0.90000;
	4404	 1	 25.22797	 15.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4405	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01040	    0.00000	 220.0	 1	    1.12080	    0.90000;
	4406	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02534	    0.00000	 380.0	 1	    1.15068	    0.90000;
	4407	 2	 173.202	 -7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4408	 2	 45.04995	 50.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4409	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00397	    0.00000	 150.0	 1	    1.10794	    0.90000;
	4410	 2	 347.3	 105.6	 0.0	 0.0	 1	    1.01531	    0.00000	 380.0	 1	    1.13062	    0.90000;
	4411	 2	 58.06438	 4.1	 0.0	 0.0	 1	    1.00597	    0.00000	 220.0	 1	    1.11194	    0.90000;
	4412	 1	 0.200222	 0.5	 0.656836	 0.0	 1	    1.01692	    0.00000	 380.0	 1	    1.13383	    0.90000;
	4413	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00945	    0.00000	 220.0	 1	    1.11890	    0.90000;
	4414	 1	 2.302553	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4415	 1	 45.5505	 -59.9	 0.0	 0.0	 1	    1.02151	    0.00000	 220.0	 1	    1.14302	    0.90000;
	4416	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4417	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4418	 1	 127.9	 -34.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4419	 1	 45.95095	 7.5	 0.0	 0.0	 1	    1.00413	    0.00000	 220.0	 1	    1.10825	    0.90000;
	4420	 1	 78.68724	 19.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4421	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01360	    0.00000	 380.0	 1	    1.12720	    0.90000;
	4422	 1	 261.2	 105.6	 0.0	 0.0	 1	    1.00724	    0.00000	 380.0	 1	    1.11448	    0.90000;
	4423	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01429	    0.00000	 380.0	 1	    1.12859	    0.90000;
	4424	 1	 0.0	 0.0	 0.086	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4425	 2	 12.01332	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4426	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4427	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01934	    0.00000	 220.0	 1	    1.13868	    0.90000;
	4428	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4429	 1	 169.0	 56.4	 0.0	 0.0	 1	    1.01361	    0.00000	 380.0	 1	    1.12723	    0.90000;
	4430	 1	 65.77292	 27.3	 0.0	 0.0	 1	    1.01860	    0.00000	 220.0	 1	    1.13719	    0.90000;
	4431	 1	 2.202442	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4432	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03399	    0.00000	 220.0	 1	    1.16798	    0.90000;
	4433	 2	 29.43263	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4434	 1	 15.41709	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4435	 1	 262.6	 31.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4436	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04481	    0.00000	 220.0	 1	    1.18962	    0.90000;
	4437	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4438	 1	 230.9	 42.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4439	 1	 0.900999	 0.3	 0.0	 0.0	 1	    1.00761	    0.00000	 110.0	 1	    1.11523	    0.90000;
	4440	 1	 5.105661	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4441	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00262	    0.00000	 380.0	 1	    1.10523	    0.90000;
	4442	 2	 135.9	 24.7	 0.0	 0.0	 1	    1.01395	    0.00000	 220.0	 1	    1.12789	    0.90000;
	4443	 1	 5.105661	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4445	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01441	    0.00000	 380.0	 1	    1.12881	    0.90000;
	4446	 1	 166.4	 50.4	 0.0	 0.0	 1	    1.03204	    0.00000	 220.0	 1	    1.16408	    0.90000;
	4447	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00858	    0.00000	 380.0	 1	    1.11715	    0.90000;
	4448	 1	 53.55938	 33.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4449	 1	 74.98314	 19.8	 0.0	 0.0	 1	    1.00557	    0.00000	 220.0	 1	    1.11113	    0.90000;
	4450	 1	 185.0	 43.6	 0.0	 0.0	 1	    1.00593	    0.00000	 220.0	 1	    1.11187	    0.90000;
	4451	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02260	    0.00000	 220.0	 1	    1.14521	    0.90000;
	4452	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4453	 1	 21.62398	 7.8	 0.0	 0.0	 1	    1.02883	    0.00000	 110.0	 1	    1.15766	    0.90000;
	4454	 1	 -7.60844	 2.5	 0.0	 0.0	 1	    1.00546	    0.00000	 150.0	 1	    1.11093	    0.90000;
	4455	 1	 329.7	 32.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4456	 2	 32.23574	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4457	 1	 0.0	 0.0	 0.119999	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4458	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4459	 1	 1.902109	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4460	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02380	    0.00000	 380.0	 1	    1.14761	    0.90000;
	4461	 1	 96.0	 33.3	 0.0	 0.0	 1	    1.01758	    0.00000	 220.0	 1	    1.13517	    0.90000;
	4462	 1	 17.11898	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4463	 1	 175.8	 70.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4464	 2	 125.6	 29.2	 0.0	 0.0	 1	    1.02940	    0.00000	 220.0	 1	    1.15881	    0.90000;
	4465	 1	 50.0555	 9.9	 0.0	 0.0	 1	    1.02056	    0.00000	 220.0	 1	    1.14111	    0.90000;
	4466	 1	 220.6	 83.4	 0.0	 0.0	 1	    1.00922	    0.00000	 380.0	 1	    1.11844	    0.90000;
	4467	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01078	    0.00000	 220.0	 1	    1.12156	    0.90000;
	4468	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00264	    0.00000	 150.0	 1	    1.10529	    0.90000;
	4469	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00546	    0.00000	 220.0	 1	    1.11092	    0.90000;
	4470	 1	 -24.0266	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4471	 2	 53.65949	 7.9	 0.0	 0.0	 1	    1.01923	    0.00000	 220.0	 1	    1.13846	    0.90000;
	4472	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4474	 2	 13.11454	 4.9	 0.0	 0.0	 1	    1.03623	    0.00000	 220.0	 1	    1.17247	    0.90000;
	4475	 1	 15.81754	 9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01075	    0.00000	 380.0	 1	    1.12150	    0.90000;
	4477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01121	    0.00000	 380.0	 1	    1.12242	    0.90000;
	4478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02348	    0.00000	 380.0	 1	    1.14697	    0.90000;
	4479	 2	 78.18668	 12.5	 0.0	 0.0	 1	    1.03844	    0.00000	 110.0	 1	    1.17687	    0.90000;
	4480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02780	    0.00000	 220.0	 1	    1.15560	    0.90000;
	4481	 1	 3.804218	 1.1	 0.0	 0.0	 1	    1.02028	    0.00000	 380.0	 1	    1.14055	    0.90000;
	4482	 1	 40.0444	 10.0	 0.0	 0.0	 1	    1.01223	    0.00000	 380.0	 1	    1.12447	    0.90000;
	4483	 1	 37.0	 8.7	 0.066781	 0.0	 1	    1.01847	    0.00000	 380.0	 1	    1.13693	    0.90000;
	4484	 1	 2.502775	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4485	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01982	    0.00000	 380.0	 1	    1.13965	    0.90000;
	4486	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4487	 1	 -19.2213	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4488	 1	 22.42486	 7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4489	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4490	 1	 312.2	 28.0	 0.0	 0.0	 1	    1.02401	    0.00000	 220.0	 1	    1.14801	    0.90000;
	4491	 1	 11.61288	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4492	 2	 0.0	 0.0	 0.112004	 0.0	 1	    1.01732	    0.00000	 380.0	 1	    1.13463	    0.90000;
	4493	 1	 56.76294	 31.1	 0.0	 0.0	 1	    1.01413	    0.00000	 220.0	 1	    1.12825	    0.90000;
	4494	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99615	    0.00000	 150.0	 1	    1.10000	    0.89230;
	4495	 1	 59.66615	 25.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4496	 1	 109.9	 33.6	 0.0	 0.0	 1	    1.02200	    0.00000	 220.0	 1	    1.14400	    0.90000;
	4497	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03297	    0.00000	 380.0	 1	    1.16595	    0.90000;
	4498	 2	 36.84085	 14.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4499	 2	 0.100111	 35.9	 0.0	 0.0	 1	    1.02035	    0.00000	 380.0	 1	    1.14070	    0.90000;
	4500	 1	 329.7	 220.4	 0.0	 0.0	 1	    1.00573	    0.00000	 380.0	 1	    1.11146	    0.90000;
	4501	 1	 88.2979	 2.8	 0.0	 0.0	 1	    1.00857	    0.00000	 220.0	 1	    1.11715	    0.90000;
	4502	 1	 10.21132	 -3.2	 0.0	 0.0	 1	    1.00788	    0.00000	 220.0	 1	    1.11576	    0.90000;
	4503	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02349	    0.00000	 110.0	 1	    1.14697	    0.90000;
	4504	 1	 218.7	 -9.1	 0.0	 0.0	 1	    1.02207	    0.00000	 220.0	 1	    1.14413	    0.90000;
	4505	 1	 71.9798	 34.1	 0.0	 0.0	 1	    1.02126	    0.00000	 220.0	 1	    1.14251	    0.90000;
	4506	 2	 67.3747	 31.4	 0.0	 0.0	 1	    1.00582	    0.00000	 220.0	 1	    1.11164	    0.90000;
	4507	 1	 66.77403	 11.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4508	 2	 52.7585	 5.9	 0.0	 0.0	 1	    1.00311	    0.00000	 220.0	 1	    1.10622	    0.90000;
	4509	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01955	    0.00000	 220.0	 1	    1.13909	    0.90000;
	4510	 2	 1.801998	 91.2	 0.0	 0.0	 1	    1.02004	    0.00000	 380.0	 1	    1.14008	    0.90000;
	4511	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4512	 1	 12.91432	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4513	 1	 62.96982	 68.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4514	 1	 29.1323	 18.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4515	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4516	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00631	    0.00000	 380.0	 1	    1.11261	    0.90000;
	4517	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4518	 1	 110.7	 78.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4519	 2	 292.0	 81.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4520	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01090	    0.00000	 380.0	 1	    1.12180	    0.90000;
	4521	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01417	    0.00000	 380.0	 1	    1.12833	    0.90000;
	4522	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02624	    0.00000	 380.0	 1	    1.15248	    0.90000;
	4523	 1	 130.0	 128.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4524	 1	 0.0	 0.0	 0.0	 10.72713	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4525	 2	 89.49923	 26.9	 0.0	 0.0	 1	    1.01297	    0.00000	 220.0	 1	    1.12594	    0.90000;
	4526	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98441	    0.00000	 150.0	 1	    1.10000	    0.86881;
	4527	 1	 23.42597	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4528	 1	 0.0	 0.0	 0.191685	 0.0	 1	    1.01305	    0.00000	 220.0	 1	    1.12610	    0.90000;
	4529	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4530	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03200	    0.00000	 380.0	 1	    1.16399	    0.90000;
	4531	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4532	 1	 4.805328	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4533	 1	 10.11121	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4534	 1	 32.5	 30.5	 0.0	 -25.6712	 1	    1.02206	    0.00000	 380.0	 1	    1.14411	    0.90000;
	4535	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4536	 2	 10.11121	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4537	 1	 11.41265	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4538	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4539	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4540	 1	 501.1	 10.7	 0.0	 0.0	 1	    1.01211	    0.00000	 380.0	 1	    1.12422	    0.90000;
	4541	 1	 58.36471	 42.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4542	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01608	    0.00000	 380.0	 1	    1.13215	    0.90000;
	4543	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01571	    0.00000	 380.0	 1	    1.13142	    0.90000;
	4544	 1	 80.28902	 28.4	 0.0	 0.0	 1	    1.00491	    0.00000	 220.0	 1	    1.10982	    0.90000;
	4545	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4546	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4547	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4548	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4549	 1	 82.49146	 24.5	 0.0	 0.0	 1	    1.02791	    0.00000	 110.0	 1	    1.15581	    0.90000;
	4550	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02628	    0.00000	 220.0	 1	    1.15256	    0.90000;
	4551	 2	 42.94762	 0.0	 0.0	 0.0	 1	    1.02335	    0.00000	 220.0	 1	    1.14669	    0.90000;
	4552	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02417	    0.00000	 220.0	 1	    1.14834	    0.90000;
	4553	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00892	    0.00000	 380.0	 1	    1.11784	    0.90000;
	4554	 1	 -58.7652	 18.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4555	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00369	    0.00000	 380.0	 1	    1.10737	    0.90000;
	4556	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00256	    0.00000	 380.0	 1	    1.10512	    0.90000;
	4557	 1	 0.0	 0.0	 0.296958	 0.0	 1	    1.02603	    0.00000	 380.0	 1	    1.15207	    0.90000;
	4558	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4559	 1	 5.105661	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4560	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4561	 1	 70.0777	 35.0	 0.0	 0.0	 1	    1.03248	    0.00000	 220.0	 1	    1.16495	    0.90000;
	4562	 1	 27.13008	 9.8	 0.0	 0.0	 1	    1.00445	    0.00000	 110.0	 1	    1.10889	    0.90000;
	4563	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01556	    0.00000	 380.0	 1	    1.13112	    0.90000;
	4564	 1	 0.100111	 -9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4565	 1	 9.510545	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4566	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02212	    0.00000	 220.0	 1	    1.14424	    0.90000;
	4567	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.20000	    0.80000;
	4568	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4569	 1	 38.64284	 23.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4570	 1	 9.510545	 3.1	 0.0	 0.0	 1	    1.00912	    0.00000	 110.0	 1	    1.11824	    0.90000;
	4571	 2	 162.6	 36.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4572	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01720	    0.00000	 380.0	 1	    1.13439	    0.90000;
	4573	 2	 130.1	 40.5	 0.0	 0.0	 1	    1.00989	    0.00000	 110.0	 1	    1.11977	    0.90000;
	4574	 2	 8.909878	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4575	 1	 30.33363	 18.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4576	 1	 174.7	 35.0	 0.0	 0.0	 1	    1.00528	    0.00000	 150.0	 1	    1.11056	    0.90000;
	4577	 1	 14.31587	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4578	 1	 32.23574	 4.8	 0.0	 0.0	 1	    1.00559	    0.00000	 220.0	 1	    1.11119	    0.90000;
	4579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00542	    0.00000	 380.0	 1	    1.11084	    0.90000;
	4580	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4581	 1	 10.31143	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4582	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 380.0	 1	    1.13335	    0.90000;
	4583	 1	 20.32253	 10.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4584	 1	 0.0	 8.8	 0.0	 0.0	 1	    1.02583	    0.00000	 150.0	 1	    1.15166	    0.90000;
	4585	 1	 24.32697	 10.0	 0.0	 0.0	 1	    1.01566	    0.00000	 380.0	 1	    1.13133	    0.90000;
	4586	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01067	    0.00000	 220.0	 1	    1.12133	    0.90000;
	4587	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02287	    0.00000	 380.0	 1	    1.14575	    0.90000;
	4588	 1	 11.41265	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4589	 1	 0.0	 0.0	 0.067054	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4590	 1	 139.8	 -25.8	 0.0	 0.0	 1	    1.01070	    0.00000	 220.0	 1	    1.12140	    0.90000;
	4591	 1	 4.605106	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4592	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00700	    0.00000	 380.0	 1	    1.11399	    0.90000;
	4593	 1	 136.6	 29.0	 0.0	 0.0	 1	    1.02859	    0.00000	 220.0	 1	    1.15718	    0.90000;
	4594	 1	 0.0	 0.0	 0.191685	 0.0	 1	    1.00528	    0.00000	 220.0	 1	    1.11057	    0.90000;
	4595	 2	 21.32364	 7.9	 0.0	 0.0	 1	    1.01192	    0.00000	 220.0	 1	    1.12384	    0.90000;
	4596	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4597	 1	 43.44817	 26.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4598	 1	 55.16116	 19.8	 0.0	 0.0	 1	    1.00256	    0.00000	 380.0	 1	    1.10513	    0.90000;
	4599	 1	 0.0	 0.0	 0.249	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4600	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4601	 1	 9.510545	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4602	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01229	    0.00000	 380.0	 1	    1.12459	    0.90000;
	4603	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03025	    0.00000	 380.0	 1	    1.16050	    0.90000;
	4604	 1	 205.8	 66.8	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4605	 1	 160.6	 51.2	 0.0	 0.0	 1	    1.02225	    0.00000	 380.0	 1	    1.14450	    0.90000;
	4606	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4607	 1	 22.32475	 7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4608	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02028	    0.00000	 380.0	 1	    1.14055	    0.90000;
	4609	 1	 35.63951	 22.0	 0.0	 0.0	 1	    0.99568	    0.00000	 150.0	 1	    1.10000	    0.89136;
	4610	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01461	    0.00000	 380.0	 1	    1.12923	    0.90000;
	4611	 1	 3.804218	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4612	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01106	    0.00000	 220.0	 1	    1.12213	    0.90000;
	4613	 1	 50.0555	 25.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4614	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4615	 1	 0.0	 0.0	 0.0	 -14.5987	 1	    1.04667	    0.00000	 150.0	 1	    1.19334	    0.90000;
	4616	 1	 5.105661	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4617	 2	 148.3	 12.1	 0.0	 0.0	 1	    1.00996	    0.00000	 220.0	 1	    1.11991	    0.90000;
	4618	 1	 19.1212	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4619	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00723	    0.00000	 220.0	 1	    1.11445	    0.90000;
	4620	 1	 92.40245	 6.3	 0.0	 0.0	 1	    1.01828	    0.00000	 220.0	 1	    1.13656	    0.90000;
	4621	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4622	 1	 3.704107	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4623	 1	 43.14784	 11.1	 0.0	 0.0	 1	    1.00532	    0.00000	 110.0	 1	    1.11064	    0.90000;
	4624	 1	 80.38913	 10.8	 0.0	 0.0	 1	    1.00650	    0.00000	 220.0	 1	    1.11300	    0.90000;
	4625	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00886	    0.00000	 750.0	 1	    1.11771	    0.90000;
	4626	 2	 185.6	 62.3	 0.0	 0.0	 1	    1.01527	    0.00000	 220.0	 1	    1.13053	    0.90000;
	4627	 1	 7.408214	 2.7	 0.0	 0.0	 1	    1.00920	    0.00000	 110.0	 1	    1.11839	    0.90000;
	4628	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01346	    0.00000	 110.0	 1	    1.12691	    0.90000;
	4629	 2	 90.0999	 21.0	 0.0	 0.0	 1	    1.00594	    0.00000	 220.0	 1	    1.11188	    0.90000;
	4630	 1	 155.2486	 23.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4631	 2	 71.57936	 57.6	 0.0	 0.0	 1	    1.02270	    0.00000	 380.0	 1	    1.14539	    0.90000;
	4632	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02109	    0.00000	 380.0	 1	    1.14219	    0.90000;
	4633	 1	 70.77847	 28.0	 0.0	 0.0	 1	    1.01453	    0.00000	 220.0	 1	    1.12905	    0.90000;
	4634	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00398	    0.00000	 220.0	 1	    1.10795	    0.90000;
	4635	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4636	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01792	    0.00000	 380.0	 1	    1.13585	    0.90000;
	4637	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02579	    0.00000	 150.0	 1	    1.15157	    0.90000;
	4638	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02916	    0.00000	 220.0	 1	    1.15831	    0.90000;
	4639	 1	 117.7	 115.0	 0.0	 0.0	 1	    1.01985	    0.00000	 380.0	 1	    1.13970	    0.90000;
	4640	 1	 0.0	 0.0	 0.090403	 64.52145	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4641	 1	 99.4	 -347.1	 0.0	 0.0	 1	    1.01669	    0.00000	 380.0	 1	    1.13337	    0.90000;
	4642	 1	 10.81199	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4643	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00749	    0.00000	 220.0	 1	    1.11499	    0.90000;
	4644	 1	 39.94429	 13.0	 0.0	 0.0	 1	    1.04422	    0.00000	 220.0	 1	    1.18843	    0.90000;
	4645	 1	 122.9	 19.3	 0.0	 0.0	 1	    1.02600	    0.00000	 380.0	 1	    1.15200	    0.90000;
	4646	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02732	    0.00000	 110.0	 1	    1.15465	    0.90000;
	4647	 1	 213.1	 -12.3	 0.0	 0.0	 1	    1.02215	    0.00000	 380.0	 1	    1.14430	    0.90000;
	4648	 2	 94.705	 15.6	 0.0	 0.0	 1	    1.01425	    0.00000	 220.0	 1	    1.12851	    0.90000;
	4649	 1	 139.9	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4650	 1	 41.34584	 25.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4651	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03427	    0.00000	 220.0	 1	    1.16855	    0.90000;
	4652	 2	 2.502775	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4653	 1	 124.9	 77.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4654	 1	 46.25128	 13.1	 0.0	 0.0	 1	    1.00670	    0.00000	 220.0	 1	    1.11339	    0.90000;
	4655	 1	 -5.5061	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4656	 2	 2.402664	 1.0	 0.0	 0.0	 1	    1.01981	    0.00000	 220.0	 1	    1.13963	    0.90000;
	4657	 2	 24.72742	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4658	 2	 4.104551	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4659	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01167	    0.00000	 380.0	 1	    1.12333	    0.90000;
	4660	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03775	    0.00000	 380.0	 1	    1.17551	    0.90000;
	4661	 1	 17.81976	 7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4662	 1	 66.4737	 22.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4663	 1	 572.3	 159.7	 0.0	 0.0	 1	    1.00957	    0.00000	 380.0	 1	    1.11914	    0.90000;
	4664	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03332	    0.00000	 220.0	 1	    1.16663	    0.90000;
	4665	 1	 12.31365	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4666	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4667	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4668	 1	 52.95872	 32.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4669	 1	 16.91876	 0.0	 0.0	 0.0	 1	    1.02223	    0.00000	 220.0	 1	    1.14445	    0.90000;
	4670	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02378	    0.00000	 380.0	 1	    1.14756	    0.90000;
	4671	 1	 24.62731	 2.1	 0.0	 0.0	 1	    1.02198	    0.00000	 220.0	 1	    1.14395	    0.90000;
	4672	 1	 26.34628	 30.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4673	 1	 18.92098	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4674	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4675	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4676	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02208	    0.00000	 380.0	 1	    1.14417	    0.90000;
	4677	 2	 0.6	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4678	 1	 229.9	 48.9	 0.0	 0.0	 1	    1.00419	    0.00000	 220.0	 1	    1.10839	    0.90000;
	4679	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01638	    0.00000	 380.0	 1	    1.13275	    0.90000;
	4680	 2	 198.2	 62.3	 0.0	 0.0	 1	    1.01249	    0.00000	 220.0	 1	    1.12498	    0.90000;
	4681	 1	 0.200222	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4682	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4683	 1	 0.0	 0.0	 0.0	 -33.7219	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4684	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01286	    0.00000	 220.0	 1	    1.12571	    0.90000;
	4685	 1	 18.52053	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4686	 2	 82.39135	 12.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4687	 1	 411.3	 168.0	 0.0	 0.0	 1	    1.01791	    0.00000	 150.0	 1	    1.13583	    0.90000;
	4688	 1	 0.0	 0.0	 0.0	 19.58753	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4690	 1	 34.03774	 11.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4691	 1	 21.12342	 7.7	 0.0	 0.0	 1	    1.01710	    0.00000	 110.0	 1	    1.13420	    0.90000;
	4692	 1	 0.0	 0.0	 0.086002	 0.0	 1	    1.00548	    0.00000	 220.0	 1	    1.11096	    0.90000;
	4693	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4694	 1	 55.26127	 0.0	 0.0	 0.0	 1	    1.00598	    0.00000	 220.0	 1	    1.11195	    0.90000;
	4695	 1	 -11.8131	 -12.0	 0.0	 0.0	 1	    1.00731	    0.00000	 220.0	 1	    1.11462	    0.90000;
	4696	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00747	    0.00000	 380.0	 1	    1.11494	    0.90000;
	4697	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4698	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4699	 1	 12.01332	 0.7	 0.0	 0.0	 1	    1.00454	    0.00000	 220.0	 1	    1.10907	    0.90000;
	4700	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4701	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00964	    0.00000	 380.0	 1	    1.11928	    0.90000;
	4702	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00850	    0.00000	 220.0	 1	    1.11699	    0.90000;
	4703	 2	 106.8	 28.8	 0.0	 0.0	 1	    1.00276	    0.00000	 220.0	 1	    1.10553	    0.90000;
	4704	 1	 3.00333	 1.7	 0.0	 0.0	 1	    1.01402	    0.00000	 110.0	 1	    1.12803	    0.90000;
	4705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4706	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01996	    0.00000	 220.0	 1	    1.13991	    0.90000;
	4707	 1	 0.0	 0.0	 0.067002	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4708	 1	 1.902109	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4709	 1	 0.0	 0.0	 0.457708	 0.0	 1	    1.01565	    0.00000	 380.0	 1	    1.13130	    0.90000;
	4710	 1	 90.2	 5.8	 0.0	 0.0	 1	    1.01339	    0.00000	 380.0	 1	    1.12679	    0.90000;
	4711	 2	 189.0	 10.9	 0.0	 0.0	 1	    1.02448	    0.00000	 220.0	 1	    1.14897	    0.90000;
	4712	 1	 45.04995	 15.3	 0.0	 0.0	 1	    1.01733	    0.00000	 220.0	 1	    1.13466	    0.90000;
	4713	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02405	    0.00000	 220.0	 1	    1.14811	    0.90000;
	4714	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4715	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4716	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.00645	    0.00000	 220.0	 1	    1.11291	    0.90000;
	4717	 1	 36.34029	 22.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4718	 1	 107.9	 17.6	 0.0	 0.0	 1	    1.01027	    0.00000	 150.0	 1	    1.12054	    0.90000;
	4719	 1	 24.32697	 5.8	 0.0	 0.0	 1	    1.00846	    0.00000	 220.0	 1	    1.11691	    0.90000;
	4720	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4721	 1	 67.97536	 9.2	 0.0	 0.0	 1	    1.00855	    0.00000	 220.0	 1	    1.11710	    0.90000;
	4722	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02116	    0.00000	 220.0	 1	    1.14232	    0.90000;
	4723	 2	 11.31254	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4724	 1	 102.7	 39.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4725	 1	 33.23685	 11.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4726	 1	 7.00777	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4727	 1	 35.13896	 12.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4728	 1	 7.408214	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4729	 1	 76.08436	 17.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4730	 1	 35.93985	 26.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.20000	    0.80000;
	4731	 1	 85.09435	 13.4	 0.0	 0.0	 1	    1.00722	    0.00000	 220.0	 1	    1.11444	    0.90000;
	4732	 1	 221.9	 86.3	 0.0	 0.0	 1	    1.01783	    0.00000	 150.0	 1	    1.13565	    0.90000;
	4733	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00954	    0.00000	 220.0	 1	    1.11907	    0.90000;
	4734	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4735	 1	 11.71299	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4736	 1	 41.64617	 13.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4737	 2	 222.7	 64.1	 0.0	 0.0	 1	    1.01086	    0.00000	 380.0	 1	    1.12172	    0.90000;
	4738	 2	 360.0	 84.1	 0.0	 0.0	 1	    1.01349	    0.00000	 220.0	 1	    1.12699	    0.90000;
	4739	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02395	    0.00000	 380.0	 1	    1.14791	    0.90000;
	4740	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00925	    0.00000	 220.0	 1	    1.11850	    0.90000;
	4741	 1	 246.8	 36.3	 0.0	 0.0	 1	    1.02907	    0.00000	 220.0	 1	    1.15814	    0.90000;
	4742	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02440	    0.00000	 220.0	 1	    1.14879	    0.90000;
	4743	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01115	    0.00000	 220.0	 1	    1.12230	    0.90000;
	4744	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4745	 1	 12.11343	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4746	 1	 68.67614	 21.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4747	 1	 23.02553	 8.3	 0.0	 0.0	 1	    1.00321	    0.00000	 110.0	 1	    1.10642	    0.90000;
	4748	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4749	 1	 4.605106	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4750	 1	 27.73075	 17.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4751	 2	 75.5838	 26.1	 0.0	 0.0	 1	    1.01823	    0.00000	 220.0	 1	    1.13645	    0.90000;
	4752	 2	 14.5	 3.1	 0.0	 0.0	 1	    1.00927	    0.00000	 380.0	 1	    1.11853	    0.90000;
	4753	 1	 1.301443	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4754	 1	 44.94984	 18.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4755	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4756	 2	 8.209102	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4757	 1	 53.45927	 15.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4758	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02707	    0.00000	 220.0	 1	    1.15415	    0.90000;
	4759	 1	 264.3	 111.6	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4760	 1	 14.21576	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4761	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01370	    0.00000	 220.0	 1	    1.12740	    0.90000;
	4762	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00936	    0.00000	 220.0	 1	    1.11873	    0.90000;
	4763	 1	 30.0333	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4764	 2	 344.4	 87.2	 0.0	 0.0	 1	    1.01142	    0.00000	 380.0	 1	    1.12285	    0.90000;
	4765	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01755	    0.00000	 380.0	 1	    1.13511	    0.90000;
	4766	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01675	    0.00000	 220.0	 1	    1.13350	    0.90000;
	4767	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4768	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01797	    0.00000	 150.0	 1	    1.13594	    0.90000;
	4769	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02380	    0.00000	 150.0	 1	    1.14761	    0.90000;
	4770	 1	 4.00444	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4771	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4772	 1	 101.2	 48.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4773	 2	 2.302553	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4774	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4775	 1	 69.1767	 38.1	 0.0	 0.0	 1	    1.02648	    0.00000	 220.0	 1	    1.15297	    0.90000;
	4776	 1	 0.0	 0.0	 0.0	 11.07044	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4777	 1	 43.94873	 8.5	 0.0	 0.0	 1	    1.01907	    0.00000	 150.0	 1	    1.13815	    0.90000;
	4778	 1	 91.0009	 36.0	 0.0	 0.0	 1	    1.01015	    0.00000	 220.0	 1	    1.12030	    0.90000;
	4779	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01782	    0.00000	 220.0	 1	    1.13565	    0.90000;
	4780	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4781	 2	 0.0	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4782	 1	 77.0	 -239.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4783	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02090	    0.00000	 380.0	 1	    1.14179	    0.90000;
	4784	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02186	    0.00000	 380.0	 1	    1.14372	    0.90000;
	4785	 1	 18.12009	 11.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4786	 1	 2.202442	 0.5	 0.0	 0.0	 1	    1.00397	    0.00000	 220.0	 1	    1.10795	    0.90000;
	4787	 1	 72.18002	 44.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4788	 1	 66.97426	 41.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4789	 1	 40.44484	 13.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4790	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02867	    0.00000	 220.0	 1	    1.15734	    0.90000;
	4791	 1	 69.1767	 19.7	 0.0	 0.0	 1	    1.00578	    0.00000	 150.0	 1	    1.11156	    0.90000;
	4792	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01361	    0.00000	 380.0	 1	    1.12723	    0.90000;
	4793	 2	 46.05106	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4794	 1	 2.202442	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4795	 2	 60.26682	 18.3	 0.0	 0.0	 1	    1.01215	    0.00000	 110.0	 1	    1.12430	    0.90000;
	4796	 1	 143.2	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4797	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01970	    0.00000	 220.0	 1	    1.13941	    0.90000;
	4798	 1	 158.8	 105.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4799	 2	 199.2	 22.8	 0.0	 0.0	 1	    1.00914	    0.00000	 220.0	 1	    1.11829	    0.90000;
	4800	 1	 19.82198	 12.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4801	 1	 13.91543	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4802	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4803	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4804	 1	 17.21909	 5.1	 0.0	 0.0	 1	    1.02789	    0.00000	 220.0	 1	    1.15578	    0.90000;
	4805	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00822	    0.00000	 380.0	 1	    1.11644	    0.90000;
	4806	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02955	    0.00000	 380.0	 1	    1.15911	    0.90000;
	4807	 2	 -40.3447	 18.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4808	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4809	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01520	    0.00000	 220.0	 1	    1.13040	    0.90000;
	4810	 1	 16.01776	 4.7	 0.0	 0.0	 1	    1.01130	    0.00000	 110.0	 1	    1.12259	    0.90000;
	4811	 1	 55.26127	 11.0	 0.0	 0.0	 1	    1.01916	    0.00000	 220.0	 1	    1.13833	    0.90000;
	4812	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01012	    0.00000	 150.0	 1	    1.12024	    0.90000;
	4813	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01462	    0.00000	 380.0	 1	    1.12924	    0.90000;
	4814	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00916	    0.00000	 220.0	 1	    1.11833	    0.90000;
	4815	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00659	    0.00000	 220.0	 1	    1.11318	    0.90000;
	4816	 1	 267.1	 57.4	 0.0	 0.0	 1	    1.01121	    0.00000	 380.0	 1	    1.12242	    0.90000;
	4817	 1	 40.0444	 20.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4818	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4819	 2	 180.2	 24.7	 0.0	 0.0	 1	    1.01466	    0.00000	 220.0	 1	    1.12932	    0.90000;
	4820	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4821	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4822	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00442	    0.00000	 380.0	 1	    1.10885	    0.90000;
	4823	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01613	    0.00000	 220.0	 1	    1.13226	    0.90000;
	4824	 2	 186.8	 38.3	 0.0	 0.0	 1	    1.01079	    0.00000	 220.0	 1	    1.12158	    0.90000;
	4825	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4826	 1	 59.86637	 19.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4827	 1	 15.21687	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4828	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02216	    0.00000	 380.0	 1	    1.14432	    0.90000;
	4829	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4830	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4831	 1	 293.2	 87.4	 0.0	 0.0	 1	    1.00924	    0.00000	 220.0	 1	    1.11849	    0.90000;
	4832	 1	 46.95206	 54.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4833	 1	 21.12342	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4834	 1	 18.12009	 5.9	 0.0	 0.0	 1	    1.01327	    0.00000	 150.0	 1	    1.12654	    0.90000;
	4835	 2	 51.05661	 59.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4836	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00387	    0.00000	 220.0	 1	    1.10774	    0.90000;
	4837	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4838	 1	 46.55161	 -18.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4839	 1	 42.44706	 -10.2	 0.0	 0.0	 1	    1.00442	    0.00000	 220.0	 1	    1.10884	    0.90000;
	4840	 1	 0.0	 0.0	 0.249309	 0.0	 1	    1.01843	    0.00000	 380.0	 1	    1.13685	    0.90000;
	4841	 1	 288.7	 117.3	 0.0	 0.0	 1	    1.02667	    0.00000	 380.0	 1	    1.15333	    0.90000;
	4842	 2	 75.68391	 18.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4843	 1	 -12.614	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4844	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4845	 1	 366.6	 57.4	 0.0	 0.0	 1	    1.00631	    0.00000	 380.0	 1	    1.11261	    0.90000;
	4846	 1	 83.59268	 -7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4847	 1	 17.51942	 6.6	 0.0	 0.0	 1	    1.00732	    0.00000	 220.0	 1	    1.11464	    0.90000;
	4848	 1	 1.601776	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4849	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4850	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4851	 1	 -16.6184	 8.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4852	 2	 220.8	 13.2	 0.0	 0.0	 1	    1.01638	    0.00000	 220.0	 1	    1.13276	    0.90000;
	4853	 1	 64.27126	 17.5	 0.0	 0.0	 1	    1.02516	    0.00000	 220.0	 1	    1.15033	    0.90000;
	4854	 1	 32.13563	 13.1	 0.0	 0.0	 1	    1.02418	    0.00000	 150.0	 1	    1.14835	    0.90000;
	4855	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01069	    0.00000	 380.0	 1	    1.12138	    0.90000;
	4856	 1	 21.72409	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4857	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00788	    0.00000	 110.0	 1	    1.11576	    0.90000;
	4858	 1	 8.709657	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4859	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4860	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4861	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01705	    0.00000	 220.0	 1	    1.13411	    0.90000;
	4862	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4863	 1	 70.1778	 19.5	 0.0	 0.0	 1	    1.02607	    0.00000	 220.0	 1	    1.15213	    0.90000;
	4864	 1	 229.0	 77.1	 0.0	 0.0	 1	    1.03042	    0.00000	 380.0	 1	    1.16083	    0.90000;
	4865	 1	 0.0	 0.0	 0.0	 25.27635	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4866	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4867	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98862	    0.00000	 150.0	 1	    1.10000	    0.87723;
	4868	 1	 173.6	 105.6	 0.0	 0.0	 1	    1.00345	    0.00000	 380.0	 1	    1.10691	    0.90000;
	4869	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4870	 1	 152.7336	 -17.2	 0.0	 0.0	 1	    1.03095	    0.00000	 220.0	 1	    1.16190	    0.90000;
	4871	 1	 79.78846	 49.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4872	 1	 110.6	 38.1	 0.0	 0.0	 1	    1.02032	    0.00000	 150.0	 1	    1.14064	    0.90000;
	4873	 2	 11.11232	 3.0	 0.0	 0.0	 1	    1.03499	    0.00000	 220.0	 1	    1.16998	    0.90000;
	4874	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02721	    0.00000	 110.0	 1	    1.15443	    0.90000;
	4875	 2	 118.5	 18.3	 0.0	 0.0	 1	    1.02155	    0.00000	 220.0	 1	    1.14309	    0.90000;
	4876	 1	 13.91543	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4877	 1	 -13.3148	 20.6	 0.0	 0.0	 1	    1.02495	    0.00000	 150.0	 1	    1.14989	    0.90000;
	4878	 1	 21.02331	 8.0	 0.0	 0.0	 1	    1.01572	    0.00000	 380.0	 1	    1.13145	    0.90000;
	4879	 1	 -8.70966	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4880	 2	 16.31809	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4881	 1	 408.3	 84.5	 0.0	 0.0	 1	    1.00830	    0.00000	 380.0	 1	    1.11661	    0.90000;
	4882	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4883	 1	 13.21465	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4884	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04374	    0.00000	 380.0	 1	    1.18747	    0.90000;
	4885	 1	 127.3	 90.5	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4886	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4887	 1	 0.800888	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4888	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01649	    0.00000	 220.0	 1	    1.13298	    0.90000;
	4889	 1	 48.05328	 28.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4890	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02387	    0.00000	 380.0	 1	    1.14774	    0.90000;
	4891	 2	 370.0	 159.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4892	 1	 37.94207	 51.4	 0.0	 0.0	 1	    1.00350	    0.00000	 380.0	 1	    1.10699	    0.90000;
	4893	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00578	    0.00000	 380.0	 1	    1.11157	    0.90000;
	4894	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4895	 1	 8.909878	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4896	 1	 57.06327	 11.9	 0.0	 0.0	 1	    1.00641	    0.00000	 220.0	 1	    1.11282	    0.90000;
	4897	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4898	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02395	    0.00000	 220.0	 1	    1.14790	    0.90000;
	4899	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03639	    0.00000	 220.0	 1	    1.17278	    0.90000;
	4900	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4901	 2	 186.2	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4902	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01343	    0.00000	 380.0	 1	    1.12686	    0.90000;
	4903	 2	 276.9	 61.1	 0.0	 0.0	 1	    1.02150	    0.00000	 220.0	 1	    1.14300	    0.90000;
	4904	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00900	    0.00000	 380.0	 1	    1.11799	    0.90000;
	4905	 1	 54.76072	 33.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4906	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4907	 1	 5.205771	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4908	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4909	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02248	    0.00000	 380.0	 1	    1.14495	    0.90000;
	4910	 1	 6.607326	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4911	 1	 11.91321	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4912	 2	 0.900999	 27.4	 0.0	 0.0	 1	    1.00476	    0.00000	 220.0	 1	    1.10952	    0.90000;
	4913	 1	 69.77736	 26.0	 0.0	 0.0	 1	    1.01069	    0.00000	 220.0	 1	    1.12138	    0.90000;
	4914	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01340	    0.00000	 380.0	 1	    1.12680	    0.90000;
	4915	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03284	    0.00000	 220.0	 1	    1.16569	    0.90000;
	4916	 1	 0.0	 0.0	 0.0	 11.0254	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4917	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01250	    0.00000	 380.0	 1	    1.12501	    0.90000;
	4918	 1	 32.7363	 5.3	 0.0	 0.0	 1	    1.03330	    0.00000	 220.0	 1	    1.16660	    0.90000;
	4919	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02057	    0.00000	 220.0	 1	    1.14115	    0.90000;
	4920	 1	 349.3	 144.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4921	 2	 75.5838	 8.6	 0.0	 0.0	 1	    1.01451	    0.00000	 380.0	 1	    1.12902	    0.90000;
	4922	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00819	    0.00000	 380.0	 1	    1.11639	    0.90000;
	4923	 1	 28.63174	 7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4924	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01759	    0.00000	 110.0	 1	    1.13517	    0.90000;
	4925	 2	 0.500555	 17.9	 0.0	 0.0	 1	    1.03215	    0.00000	 380.0	 1	    1.16430	    0.90000;
	4926	 1	 152.8	 38.0	 0.0	 0.0	 1	    1.00986	    0.00000	 150.0	 1	    1.11971	    0.90000;
	4927	 1	 53.35916	 44.2	 0.0	 0.0	 1	    1.01284	    0.00000	 380.0	 1	    1.12568	    0.90000;
	4928	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4929	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02822	    0.00000	 150.0	 1	    1.15644	    0.90000;
	4930	 1	 103.3	 24.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4931	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4932	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00634	    0.00000	 380.0	 1	    1.11269	    0.90000;
	4933	 1	 104.7	 -12.8	 0.0	 0.0	 1	    1.01400	    0.00000	 220.0	 1	    1.12800	    0.90000;
	4934	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4935	 1	 116.4	 -8.8	 0.0	 0.0	 1	    1.01706	    0.00000	 220.0	 1	    1.13413	    0.90000;
	4936	 2	 162.8	 45.7	 0.0	 0.0	 1	    1.02140	    0.00000	 220.0	 1	    1.14281	    0.90000;
	4937	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4938	 1	 2.803108	 1.0	 0.0	 0.0	 1	    1.00646	    0.00000	 110.0	 1	    1.11292	    0.90000;
	4939	 2	 0.0	 0.0	 0.0	 20.0	 1	    1.00400	    0.00000	 380.0	 1	    1.10800	    0.90000;
	4940	 1	 45.45039	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4941	 1	 9.610656	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4942	 2	 3.804218	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4943	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01430	    0.00000	 150.0	 1	    1.12859	    0.90000;
	4944	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03248	    0.00000	 150.0	 1	    1.16496	    0.90000;
	4945	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01188	    0.00000	 220.0	 1	    1.12376	    0.90000;
	4946	 1	 82.09102	 39.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4947	 2	 66.57381	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4948	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4949	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02405	    0.00000	 220.0	 1	    1.14810	    0.90000;
	4950	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4951	 2	 6.00666	 2.2	 0.0	 0.0	 1	    1.01841	    0.00000	 110.0	 1	    1.13682	    0.90000;
	4952	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02787	    0.00000	 220.0	 1	    1.15574	    0.90000;
	4953	 1	 211.3	 69.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4954	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4955	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02512	    0.00000	 380.0	 1	    1.15023	    0.90000;
	4956	 2	 217.1	 52.6	 0.0	 0.0	 1	    1.01784	    0.00000	 380.0	 1	    1.13567	    0.90000;
	4957	 1	 88.39801	 -5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4958	 1	 25.22797	 3.3	 0.0	 0.0	 1	    1.01989	    0.00000	 380.0	 1	    1.13978	    0.90000;
	4959	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4960	 1	 1.00111	 0.3	 0.0	 0.0	 1	    1.01250	    0.00000	 110.0	 1	    1.12500	    0.90000;
	4961	 2	 148.8	 24.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4962	 1	 106.6	 -18.8	 0.0	 0.0	 1	    1.03906	    0.00000	 220.0	 1	    1.17813	    0.90000;
	4963	 1	 3.303663	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4964	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00461	    0.00000	 380.0	 1	    1.10922	    0.90000;
	4965	 1	 1.301443	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4966	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4967	 1	 8.909878	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4968	 1	 1.00111	 1.0	 0.0	 0.0	 1	    1.00468	    0.00000	 110.0	 1	    1.10936	    0.90000;
	4969	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00920	    0.00000	 380.0	 1	    1.11841	    0.90000;
	4970	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03360	    0.00000	 220.0	 1	    1.16720	    0.90000;
	4971	 2	 25.32808	 70.8	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4972	 1	 30.9343	 5.8	 0.0	 0.0	 1	    1.03192	    0.00000	 220.0	 1	    1.16384	    0.90000;
	4973	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03573	    0.00000	 380.0	 1	    1.17145	    0.90000;
	4974	 1	 144.0	 56.6	 0.0	 0.0	 1	    1.01706	    0.00000	 220.0	 1	    1.13411	    0.90000;
	4975	 1	 0.0	 0.0	 0.0	 -22.8665	 1	    1.04638	    0.00000	 150.0	 1	    1.19276	    0.90000;
	4976	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4977	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02605	    0.00000	 380.0	 1	    1.15211	    0.90000;
	4978	 2	 0.0	 0.0	 0.041323	 0.0	 1	    1.00395	    0.00000	 220.0	 1	    1.10790	    0.90000;
	4979	 2	 148.2	 31.2	 0.0	 0.0	 1	    1.01428	    0.00000	 220.0	 1	    1.12856	    0.90000;
	4980	 1	 11.8131	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4981	 2	 0.0	 0.0	 0.0	 20.0	 1	    1.02929	    0.00000	 380.0	 1	    1.15859	    0.90000;
	4982	 1	 0.0	 0.0	 0.471696	 0.0	 1	    1.00592	    0.00000	 380.0	 1	    1.11184	    0.90000;
	4983	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4984	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00466	    0.00000	 220.0	 1	    1.10933	    0.90000;
	4985	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4986	 2	 0.0	 0.0	 0.0	 79.23356	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4987	 1	 1.62675	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4988	 1	 0.0	 0.0	 0.239002	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4989	 1	 574.3	 94.6	 0.0	 0.0	 1	    1.00310	    0.00000	 380.0	 1	    1.10619	    0.90000;
	4990	 1	 20.12231	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4991	 1	 111.5	 24.8	 0.0	 0.0	 1	    1.00499	    0.00000	 220.0	 1	    1.10999	    0.90000;
	4992	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4993	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02051	    0.00000	 220.0	 1	    1.14103	    0.90000;
	4994	 1	 342.7	 82.2	 0.0	 0.0	 1	    1.02106	    0.00000	 380.0	 1	    1.14212	    0.90000;
	4995	 2	 17.61954	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4996	 2	 164.7	 33.9	 0.0	 0.0	 1	    1.02588	    0.00000	 380.0	 1	    1.15175	    0.90000;
	4997	 1	 29.53274	 25.1	 0.0	 0.0	 1	    0.98232	    0.00000	 150.0	 1	    1.10000	    0.86463;
	4998	 1	 17.61954	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4999	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5000	 1	 0.0	 0.0	 0.287458	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5001	 1	 499.0	 191.1	 0.0	 0.0	 1	    1.01305	    0.00000	 380.0	 1	    1.12609	    0.90000;
	5002	 1	 67.67503	 6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5003	 2	 73.18114	 13.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5004	 2	 456.0	 123.8	 0.0	 0.0	 1	    1.00776	    0.00000	 220.0	 1	    1.11552	    0.90000;
	5005	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5006	 1	 22.12453	 8.0	 0.0	 0.0	 1	    1.01137	    0.00000	 110.0	 1	    1.12274	    0.90000;
	5007	 1	 18.2202	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5008	 1	 34.23796	 -19.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5009	 1	 4.404884	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5010	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01663	    0.00000	 220.0	 1	    1.13326	    0.90000;
	5011	 1	 30.43374	 10.1	 0.0	 0.0	 1	    1.02443	    0.00000	 110.0	 1	    1.14885	    0.90000;
	5012	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03158	    0.00000	 220.0	 1	    1.16317	    0.90000;
	5013	 1	 150.2	 25.5	 0.0	 0.0	 1	    1.00505	    0.00000	 380.0	 1	    1.11009	    0.90000;
	5014	 1	 14.51609	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5015	 2	 239.5	 61.6	 0.0	 0.0	 1	    1.01933	    0.00000	 220.0	 1	    1.13866	    0.90000;
	5016	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00526	    0.00000	 150.0	 1	    1.11051	    0.90000;
	5017	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01025	    0.00000	 380.0	 1	    1.12050	    0.90000;
	5018	 1	 93.6	 77.1	 0.0	 20.0	 1	    1.00295	    0.00000	 380.0	 1	    1.10590	    0.90000;
	5019	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02141	    0.00000	 220.0	 1	    1.14283	    0.90000;
	5020	 2	 154.9	 18.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5021	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00444	    0.00000	 220.0	 1	    1.10887	    0.90000;
	5022	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02678	    0.00000	 220.0	 1	    1.15355	    0.90000;
	5023	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01917	    0.00000	 220.0	 1	    1.13833	    0.90000;
	5024	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01112	    0.00000	 110.0	 1	    1.12225	    0.90000;
	5025	 1	 68.07548	 42.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5026	 2	 0.0	 0.0	 0.095843	 0.0	 1	    1.02000	    0.00000	 220.0	 1	    1.14001	    0.90000;
	5027	 1	 12.21354	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5028	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5029	 1	 11.71299	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5030	 1	 6.707437	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5031	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01085	    0.00000	 380.0	 1	    1.12169	    0.90000;
	5032	 1	 47.65283	 29.5	 0.0	 0.0	 1	    0.98819	    0.00000	 150.0	 1	    1.10000	    0.87639;
	5033	 1	 33.03663	 8.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5034	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01964	    0.00000	 220.0	 1	    1.13929	    0.90000;
	5035	 1	 10.0111	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5036	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5037	 1	 30.0333	 12.2	 0.0	 0.0	 1	    1.02394	    0.00000	 150.0	 1	    1.14788	    0.90000;
	5038	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02041	    0.00000	 220.0	 1	    1.14082	    0.90000;
	5039	 1	 15.11676	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5040	 1	 23.92653	 8.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5041	 1	 2.22375	 7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5042	 1	 50.25572	 16.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5043	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00410	    0.00000	 380.0	 1	    1.10820	    0.90000;
	5044	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00482	    0.00000	 380.0	 1	    1.10964	    0.90000;
	5045	 1	 21.22353	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5046	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00491	    0.00000	 380.0	 1	    1.10982	    0.90000;
	5047	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5048	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5049	 1	 31.13452	 12.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5050	 1	 0.0	 0.0	 0.221009	 0.0	 1	    1.03025	    0.00000	 380.0	 1	    1.16050	    0.90000;
	5051	 1	 21.62398	 7.8	 0.0	 0.0	 1	    1.01962	    0.00000	 110.0	 1	    1.13924	    0.90000;
	5052	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01630	    0.00000	 220.0	 1	    1.13260	    0.90000;
	5053	 1	 5.105661	 1.8	 0.0	 0.0	 1	    1.01582	    0.00000	 110.0	 1	    1.13165	    0.90000;
	5054	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00755	    0.00000	 380.0	 1	    1.11510	    0.90000;
	5055	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00887	    0.00000	 220.0	 1	    1.11775	    0.90000;
	5056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5057	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5058	 1	 23.52608	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5059	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02780	    0.00000	 220.0	 1	    1.15561	    0.90000;
	5060	 2	 0.0	 -0.1	 0.0	 0.0	 1	    1.03507	    0.00000	 220.0	 1	    1.17014	    0.90000;
	5061	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02153	    0.00000	 220.0	 1	    1.14306	    0.90000;
	5062	 1	 99.7	 6.0	 0.0	 0.0	 1	    1.00804	    0.00000	 220.0	 1	    1.11607	    0.90000;
	5063	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01446	    0.00000	 380.0	 1	    1.12893	    0.90000;
	5064	 1	 220.0	 68.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5065	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03495	    0.00000	 380.0	 1	    1.16989	    0.90000;
	5066	 1	 26.62953	 8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5067	 1	 16.21798	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5068	 1	 130.7	 89.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5069	 1	 3.203552	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5070	 1	 1.902109	 0.7	 0.0	 0.0	 1	    1.01131	    0.00000	 110.0	 1	    1.12261	    0.90000;
	5071	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5072	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5073	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02746	    0.00000	 220.0	 1	    1.15492	    0.90000;
	5074	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01934	    0.00000	 150.0	 1	    1.13868	    0.90000;
	5075	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5076	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01711	    0.00000	 380.0	 1	    1.13422	    0.90000;
	5077	 1	 118.6	 41.5	 0.0	 0.0	 1	    1.01978	    0.00000	 150.0	 1	    1.13956	    0.90000;
	5078	 1	 20.82309	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5079	 1	 19.52164	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5080	 2	 275.3	 55.2	 0.0	 0.0	 1	    1.01349	    0.00000	 220.0	 1	    1.12699	    0.90000;
	5081	 1	 168.5	 54.8	 0.0	 0.0	 1	    1.02251	    0.00000	 150.0	 1	    1.14503	    0.90000;
	5082	 1	 172.8	 11.3	 0.0	 0.0	 1	    1.01126	    0.00000	 220.0	 1	    1.12252	    0.90000;
	5083	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01458	    0.00000	 220.0	 1	    1.12917	    0.90000;
	5084	 1	 0.0	 0.0	 0.064829	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5085	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5086	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00337	    0.00000	 380.0	 1	    1.10675	    0.90000;
	5087	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5088	 1	 34.13785	 12.4	 0.0	 0.0	 1	    1.00663	    0.00000	 110.0	 1	    1.11325	    0.90000;
	5089	 1	 449.4	 14.6	 0.0	 0.0	 1	    1.01423	    0.00000	 380.0	 1	    1.12846	    0.90000;
	5090	 2	 30.33363	 -3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5091	 1	 99.5	 9.2	 0.0	 0.0	 1	    1.03152	    0.00000	 220.0	 1	    1.16305	    0.90000;
	5092	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03004	    0.00000	 380.0	 1	    1.16008	    0.90000;
	5093	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5094	 1	 225.2	 35.2	 0.0	 0.0	 1	    1.03685	    0.00000	 220.0	 1	    1.17371	    0.90000;
	5095	 1	 38.04218	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5096	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01860	    0.00000	 150.0	 1	    1.13720	    0.90000;
	5097	 1	 0.0	 0.0	 0.191685	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5098	 2	 301.6	 122.3	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5099	 1	 6.507215	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5100	 1	 158.3	 -20.5	 0.0	 0.0	 1	    1.01438	    0.00000	 220.0	 1	    1.12877	    0.90000;
	5101	 1	 513.4	 199.8	 0.0	 0.0	 1	    1.02888	    0.00000	 380.0	 1	    1.15776	    0.90000;
	5102	 1	 152.7	 6.0	 0.0	 0.0	 1	    1.01678	    0.00000	 120.0	 1	    1.13356	    0.90000;
	5103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02846	    0.00000	 380.0	 1	    1.15691	    0.90000;
	5104	 1	 13.71521	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5105	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01728	    0.00000	 220.0	 1	    1.13457	    0.90000;
	5106	 2	 5.405994	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5107	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5108	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01887	    0.00000	 220.0	 1	    1.13773	    0.90000;
	5109	 1	 105.5	 31.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5110	 2	 27.93097	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5111	 1	 29.1323	 13.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5112	 1	 21.12342	 13.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5114	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5115	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02707	    0.00000	 110.0	 1	    1.15414	    0.90000;
	5116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5117	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5118	 2	 172.9	 -29.6	 0.0	 0.0	 1	    1.01199	    0.00000	 220.0	 1	    1.12398	    0.90000;
	5119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00685	    0.00000	 220.0	 1	    1.11370	    0.90000;
	5120	 1	 72.78069	 45.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5122	 1	 45.04995	 40.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5123	 2	 26.4293	 21.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5124	 1	 20.0222	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5125	 1	 6.306993	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00824	    0.00000	 380.0	 1	    1.11648	    0.90000;
	5127	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01472	    0.00000	 380.0	 1	    1.12944	    0.90000;
	5128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5129	 1	 45.04995	 5.0	 0.0	 0.0	 1	    1.01605	    0.00000	 380.0	 1	    1.13210	    0.90000;
	5130	 2	 104.1	 9.8	 0.0	 0.0	 1	    1.00636	    0.00000	 220.0	 1	    1.11272	    0.90000;
	5131	 2	 5.506105	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5132	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00759	    0.00000	 150.0	 1	    1.11517	    0.90000;
	5133	 2	 198.7089	 60.3	 0.0	 0.0	 1	    1.01303	    0.00000	 220.0	 1	    1.12606	    0.90000;
	5134	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5135	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01487	    0.00000	 380.0	 1	    1.12973	    0.90000;
	5136	 1	 -27.4304	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5137	 1	 30.0333	 9.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5138	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5139	 1	 185.7	 18.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5140	 1	 0.0	 0.0	 0.0	 11.74184	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5141	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03223	    0.00000	 220.0	 1	    1.16447	    0.90000;
	5142	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5143	 1	 124.8	 34.7	 0.0	 0.0	 1	    1.01114	    0.00000	 220.0	 1	    1.12229	    0.90000;
	5144	 2	 89.69945	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5145	 2	 -218.342	 -16.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5146	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00377	    0.00000	 220.0	 1	    1.10754	    0.90000;
	5147	 1	 25.02775	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5148	 1	 139.7	 9.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5149	 1	 67.27459	 1.5	 0.0	 0.0	 1	    1.01907	    0.00000	 220.0	 1	    1.13814	    0.90000;
	5150	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5151	 1	 54.96094	 17.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5152	 1	 6.206882	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5153	 2	 43.44817	 7.0	 0.0	 0.0	 1	    1.01538	    0.00000	 220.0	 1	    1.13077	    0.90000;
	5154	 1	 25.12786	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5155	 2	 77.88636	 11.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5156	 1	 153.5	 46.0	 0.0	 0.0	 1	    1.00620	    0.00000	 220.0	 1	    1.11239	    0.90000;
	5157	 1	 198.1	 33.9	 0.0	 0.0	 1	    1.00829	    0.00000	 220.0	 1	    1.11657	    0.90000;
	5158	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00471	    0.00000	 380.0	 1	    1.10943	    0.90000;
	5159	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02950	    0.00000	 380.0	 1	    1.15899	    0.90000;
	5160	 1	 34.73852	 16.3	 0.0	 0.0	 1	    1.01996	    0.00000	 380.0	 1	    1.13992	    0.90000;
	5161	 1	 52.25794	 19.6	 0.0	 0.0	 1	    1.01187	    0.00000	 220.0	 1	    1.12374	    0.90000;
	5162	 1	 19.1212	 11.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5163	 1	 14.11565	 5.2	 0.0	 0.0	 1	    1.02153	    0.00000	 220.0	 1	    1.14306	    0.90000;
	5164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01354	    0.00000	 220.0	 1	    1.12708	    0.90000;
	5165	 1	 195.1	 -14.2	 0.0	 0.0	 1	    1.03169	    0.00000	 220.0	 1	    1.16338	    0.90000;
	5166	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02243	    0.00000	 380.0	 1	    1.14485	    0.90000;
	5167	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01076	    0.00000	 380.0	 1	    1.12153	    0.90000;
	5168	 1	 40.24462	 14.4	 0.0	 0.0	 1	    1.01630	    0.00000	 220.0	 1	    1.13261	    0.90000;
	5169	 1	 142.8	 20.3	 0.0	 0.0	 1	    1.01516	    0.00000	 220.0	 1	    1.13033	    0.90000;
	5170	 1	 45.35028	 28.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5171	 1	 131.6	 33.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5172	 1	 11.8131	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.20000	    0.80000;
	5173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01937	    0.00000	 220.0	 1	    1.13874	    0.90000;
	5174	 1	 31.93541	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5175	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5176	 1	 29.03219	 18.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5177	 1	 119.6	 10.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5178	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03670	    0.00000	 120.0	 1	    1.17340	    0.90000;
	5179	 1	 32.23574	 11.7	 0.0	 0.0	 1	    1.00276	    0.00000	 110.0	 1	    1.10552	    0.90000;
	5180	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5181	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02175	    0.00000	 380.0	 1	    1.14350	    0.90000;
	5182	 1	 0.400444	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5183	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5184	 2	 190.5	 48.3	 0.0	 0.0	 1	    1.01456	    0.00000	 220.0	 1	    1.12912	    0.90000;
	5185	 1	 20.72298	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5186	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00560	    0.00000	 220.0	 1	    1.11119	    0.90000;
	5187	 2	 99.51033	 -9.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5188	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01015	    0.00000	 380.0	 1	    1.12031	    0.90000;
	5189	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00702	    0.00000	 380.0	 1	    1.11404	    0.90000;
	5190	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5191	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5192	 1	 150.1	 35.0	 0.0	 0.0	 1	    1.01115	    0.00000	 220.0	 1	    1.12231	    0.90000;
	5193	 1	 337.6	 -15.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5194	 2	 7.708547	 2.2	 0.0	 0.0	 1	    1.00420	    0.00000	 110.0	 1	    1.10840	    0.90000;
	5195	 1	 141.2	 45.4	 0.0	 0.0	 1	    1.00635	    0.00000	 220.0	 1	    1.11269	    0.90000;
	5196	 1	 20.12231	 8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5197	 1	 19.42153	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5198	 2	 0.500555	 0.0	 0.0	 0.0	 1	    1.00285	    0.00000	 220.0	 1	    1.10570	    0.90000;
	5199	 1	 42.44706	 14.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5200	 1	 4.605106	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5201	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5202	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00609	    0.00000	 110.0	 1	    1.11219	    0.90000;
	5203	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5204	 2	 167.7	 60.2	 0.0	 0.0	 1	    1.00644	    0.00000	 220.0	 1	    1.11288	    0.90000;
	5205	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00884	    0.00000	 220.0	 1	    1.11768	    0.90000;
	5206	 2	 181.8	 18.1	 0.0	 0.0	 1	    1.03822	    0.00000	 220.0	 1	    1.17645	    0.90000;
	5207	 1	 15.31698	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5208	 2	 31.73519	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5209	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01455	    0.00000	 220.0	 1	    1.12910	    0.90000;
	5210	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5211	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00460	    0.00000	 150.0	 1	    1.10920	    0.90000;
	5212	 1	 38.64284	 13.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5213	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02894	    0.00000	 220.0	 1	    1.15787	    0.90000;
	5214	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01840	    0.00000	 220.0	 1	    1.13679	    0.90000;
	5215	 1	 13.71521	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5216	 1	 71.9798	 28.8	 0.0	 0.0	 1	    1.01673	    0.00000	 220.0	 1	    1.13347	    0.90000;
	5217	 1	 371.2	 73.5	 0.0	 0.0	 1	    1.01170	    0.00000	 380.0	 1	    1.12341	    0.90000;
	5218	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01797	    0.00000	 150.0	 1	    1.13593	    0.90000;
	5219	 1	 -928.0	 -491.4	 0.0	 0.0	 1	    1.01465	    0.00000	 380.0	 1	    1.12929	    0.90000;
	5220	 2	 174.0	 47.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5221	 1	 52.95872	 50.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.20000	    0.80000;
	5222	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01971	    0.00000	 220.0	 1	    1.13942	    0.90000;
	5223	 1	 222.6	 62.6	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5224	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5225	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5226	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02675	    0.00000	 380.0	 1	    1.15351	    0.90000;
	5227	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02441	    0.00000	 150.0	 1	    1.14881	    0.90000;
	5228	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00703	    0.00000	 150.0	 1	    1.11407	    0.90000;
	5229	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01080	    0.00000	 380.0	 1	    1.12160	    0.90000;
	5230	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01721	    0.00000	 220.0	 1	    1.13441	    0.90000;
	5231	 1	 99.4	 4.3	 0.0	 0.0	 1	    1.01296	    0.00000	 220.0	 1	    1.12592	    0.90000;
	5232	 1	 176.4	 17.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5233	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00683	    0.00000	 220.0	 1	    1.11366	    0.90000;
	5234	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01433	    0.00000	 380.0	 1	    1.12867	    0.90000;
	5235	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5236	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5237	 1	 190.5	 70.9	 0.0	 0.0	 1	    1.01000	    0.00000	 380.0	 1	    1.12001	    0.90000;
	5238	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02649	    0.00000	 150.0	 1	    1.15298	    0.90000;
	5239	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02396	    0.00000	 220.0	 1	    1.14793	    0.90000;
	5240	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02032	    0.00000	 380.0	 1	    1.14065	    0.90000;
	5241	 1	 30.0333	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5242	 1	 222.7	 80.5	 0.0	 0.0	 1	    1.01200	    0.00000	 150.0	 1	    1.12400	    0.90000;
	5243	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5244	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5245	 1	 86.19556	 -30.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5246	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00572	    0.00000	 220.0	 1	    1.11143	    0.90000;
	5247	 2	 0.0	 0.0	 0.0	 20.0	 1	    1.00944	    0.00000	 380.0	 1	    1.11889	    0.90000;
	5248	 1	 0.0	 0.0	 0.0	 -25.1413	 1	    1.02659	    0.00000	 150.0	 1	    1.15317	    0.90000;
	5249	 1	 69.07658	 -49.6	 0.0	 0.0	 1	    1.02217	    0.00000	 110.0	 1	    1.14434	    0.90000;
	5250	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5251	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5252	 2	 43.24795	 19.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5253	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01184	    0.00000	 220.0	 1	    1.12368	    0.90000;
	5254	 1	 4.404884	 1.1	 0.0	 0.0	 1	    1.00265	    0.00000	 220.0	 1	    1.10530	    0.90000;
	5255	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5256	 1	 40.9454	 13.4	 0.0	 0.0	 1	    1.01725	    0.00000	 150.0	 1	    1.13451	    0.90000;
	5257	 1	 6.106771	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5258	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5259	 1	 124.6	 15.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5260	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5261	 1	 334.1	 103.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5262	 1	 5.03807	 6.1	 0.0	 0.0	 1	    1.00895	    0.00000	 150.0	 1	    1.11790	    0.90000;
	5263	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03142	    0.00000	 220.0	 1	    1.16284	    0.90000;
	5264	 1	 0.0	 0.0	 0.0	 -25.7076	 1	    1.03164	    0.00000	 380.0	 1	    1.16328	    0.90000;
	5265	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5266	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02352	    0.00000	 220.0	 1	    1.14704	    0.90000;
	5267	 1	 36.24018	 12.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5268	 1	 167.6	 -9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5269	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5270	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5271	 1	 -7.90877	 2.6	 0.0	 0.0	 1	    1.00277	    0.00000	 150.0	 1	    1.10555	    0.90000;
	5272	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5273	 2	 32.03552	 14.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5274	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5276	 2	 190.6	 51.6	 0.0	 0.0	 1	    1.01150	    0.00000	 220.0	 1	    1.12300	    0.90000;
	5277	 1	 5.205771	 1.3	 0.0	 0.0	 1	    1.01933	    0.00000	 380.0	 1	    1.13865	    0.90000;
	5278	 1	 13.01443	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5279	 1	 0.0	 0.0	 0.0	 22.68425	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5280	 1	 343.1	 109.5	 0.0	 0.0	 1	    1.01966	    0.00000	 380.0	 1	    1.13931	    0.90000;
	5281	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5282	 2	 96.80733	 19.4	 0.0	 0.0	 1	    1.00433	    0.00000	 220.0	 1	    1.10867	    0.90000;
	5283	 2	 145.7	 -38.0	 0.0	 0.0	 1	    1.03543	    0.00000	 380.0	 1	    1.17085	    0.90000;
	5284	 2	 0.900999	 28.3	 0.0	 0.0	 1	    1.01625	    0.00000	 380.0	 1	    1.13250	    0.90000;
	5285	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01340	    0.00000	 380.0	 1	    1.12681	    0.90000;
	5286	 2	 -91.6016	 -4.9	 0.029998	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5287	 1	 83.5	 41.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5288	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01628	    0.00000	 220.0	 1	    1.13255	    0.90000;
	5289	 1	 155.5	 38.3	 0.0	 0.0	 1	    1.01122	    0.00000	 150.0	 1	    1.12243	    0.90000;
	5290	 1	 53.85971	 17.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5291	 2	 183.1	 33.9	 0.0	 0.0	 1	    1.01633	    0.00000	 380.0	 1	    1.13266	    0.90000;
	5292	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98618	    0.00000	 150.0	 1	    1.10000	    0.87236;
	5293	 1	 -46.1512	 15.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5294	 1	 0.900999	 0.3	 0.0	 0.0	 1	    1.01271	    0.00000	 110.0	 1	    1.12542	    0.90000;
	5295	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5296	 2	 277.3	 65.5	 0.0	 0.0	 1	    1.00695	    0.00000	 220.0	 1	    1.11389	    0.90000;
	5297	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01487	    0.00000	 380.0	 1	    1.12975	    0.90000;
	5298	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02449	    0.00000	 380.0	 1	    1.14898	    0.90000;
	5300	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5301	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00783	    0.00000	 380.0	 1	    1.11567	    0.90000;
	5302	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01305	    0.00000	 220.0	 1	    1.12610	    0.90000;
	5303	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00573	    0.00000	 220.0	 1	    1.11146	    0.90000;
	5304	 1	 0.0	 0.0	 0.294	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5305	 1	 20.52275	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5306	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01092	    0.00000	 380.0	 1	    1.12184	    0.90000;
	5307	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5308	 1	 122.5	 38.9	 0.0	 0.0	 1	    1.01448	    0.00000	 220.0	 1	    1.12896	    0.90000;
	5309	 1	 18.42042	 1.2	 0.0	 0.0	 1	    1.01326	    0.00000	 220.0	 1	    1.12651	    0.90000;
	5310	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01417	    0.00000	 380.0	 1	    1.12834	    0.90000;
	5311	 2	 105.9	 29.5	 0.0	 0.0	 1	    1.02639	    0.00000	 220.0	 1	    1.15278	    0.90000;
	5312	 1	 78.38691	 21.2	 0.0	 0.0	 1	    1.03799	    0.00000	 220.0	 1	    1.17598	    0.90000;
	5313	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5314	 2	 2.903219	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5315	 1	 18.52053	 11.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5316	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5317	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00752	    0.00000	 380.0	 1	    1.11504	    0.90000;
	5318	 2	 187.0	 108.2	 0.0	 0.0	 1	    1.01451	    0.00000	 220.0	 1	    1.12902	    0.90000;
	5319	 1	 20.72298	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5320	 1	 10.0111	 -30.0	 0.0	 0.0	 1	    1.02740	    0.00000	 220.0	 1	    1.15480	    0.90000;
	5321	 1	 55.26127	 34.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5322	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02175	    0.00000	 380.0	 1	    1.14351	    0.90000;
	5323	 1	 145.7	 122.2	 0.0	 0.0	 1	    1.01501	    0.00000	 220.0	 1	    1.13002	    0.90000;
	5324	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5325	 1	 28.83197	 -3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5326	 1	 177.5	 72.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5327	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01334	    0.00000	 380.0	 1	    1.12668	    0.90000;
	5328	 2	 39.84418	 13.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5329	 1	 2.00222	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5330	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5331	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02438	    0.00000	 380.0	 1	    1.14877	    0.90000;
	5332	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5333	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5334	 1	 159.9773	 76.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5335	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02160	    0.00000	 220.0	 1	    1.14321	    0.90000;
	5336	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01492	    0.00000	 380.0	 1	    1.12983	    0.90000;
	5337	 2	 25.2	 18.5	 0.0	 0.0	 1	    1.04279	    0.00000	 380.0	 1	    1.18559	    0.90000;
	5338	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01663	    0.00000	 380.0	 1	    1.13325	    0.90000;
	5339	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01491	    0.00000	 220.0	 1	    1.12983	    0.90000;
	5340	 1	 16.4182	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5341	 1	 6.907659	 -11.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5342	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01474	    0.00000	 380.0	 1	    1.12949	    0.90000;
	5343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01139	    0.00000	 220.0	 1	    1.12278	    0.90000;
	5344	 1	 14.01554	 5.5	 0.0	 0.0	 1	    1.00687	    0.00000	 220.0	 1	    1.11373	    0.90000;
	5345	 1	 49.85527	 14.1	 0.0	 0.0	 1	    1.00683	    0.00000	 220.0	 1	    1.11366	    0.90000;
	5346	 1	 26.02886	 10.6	 0.0	 0.0	 1	    1.02122	    0.00000	 110.0	 1	    1.14243	    0.90000;
	5347	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5348	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5349	 2	 0.0	 0.0	 0.0	 208.8414	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5350	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01358	    0.00000	 380.0	 1	    1.12715	    0.90000;
	5351	 1	 -85.695	 -2.0	 0.0	 0.0	 1	    1.02009	    0.00000	 220.0	 1	    1.14017	    0.90000;
	5352	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00460	    0.00000	 150.0	 1	    1.10920	    0.90000;
	5353	 1	 7.207992	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5354	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5355	 1	 0.0	 -7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5356	 1	 196.3	 -10.4	 0.0	 0.0	 1	    1.00821	    0.00000	 220.0	 1	    1.11643	    0.90000;
	5357	 1	 5.305883	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5358	 1	 186.1	 14.8	 0.0	 0.0	 1	    1.02670	    0.00000	 220.0	 1	    1.15340	    0.90000;
	5359	 1	 10.51165	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5360	 1	 181.9	 92.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5361	 1	 42.54717	 14.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5362	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00391	    0.00000	 220.0	 1	    1.10782	    0.90000;
	5364	 1	 80.9898	 30.1	 0.0	 0.0	 1	    1.00921	    0.00000	 220.0	 1	    1.11841	    0.90000;
	5365	 1	 94.1	 39.0	 0.0	 0.0	 1	    1.00597	    0.00000	 380.0	 1	    1.11194	    0.90000;
	5366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5367	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02611	    0.00000	 110.0	 1	    1.15223	    0.90000;
	5368	 1	 61.66837	 17.4	 0.0	 0.0	 1	    1.00374	    0.00000	 110.0	 1	    1.10747	    0.90000;
	5369	 2	 75.08324	 21.0	 0.0	 0.0	 1	    1.01581	    0.00000	 220.0	 1	    1.13162	    0.90000;
	5370	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02105	    0.00000	 380.0	 1	    1.14210	    0.90000;
	5371	 2	 26.4293	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5372	 1	 74.08214	 10.7	 0.0	 0.0	 1	    1.00668	    0.00000	 220.0	 1	    1.11336	    0.90000;
	5373	 1	 29.03219	 18.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5374	 1	 0.0	 0.0	 0.0	 11.08316	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5375	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03347	    0.00000	 220.0	 1	    1.16694	    0.90000;
	5376	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5377	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5378	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5379	 2	 5.205771	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5380	 1	 53.05883	 17.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5381	 1	 78.48702	 18.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5382	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02325	    0.00000	 220.0	 1	    1.14651	    0.90000;
	5383	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5384	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01302	    0.00000	 150.0	 1	    1.12604	    0.90000;
	5385	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01687	    0.00000	 380.0	 1	    1.13373	    0.90000;
	5386	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00613	    0.00000	 150.0	 1	    1.11225	    0.90000;
	5387	 2	 114.4	 34.2	 0.0	 0.0	 1	    1.00875	    0.00000	 220.0	 1	    1.11750	    0.90000;
	5388	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00984	    0.00000	 380.0	 1	    1.11967	    0.90000;
	5389	 1	 5.205771	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5390	 1	 15.11676	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5391	 1	 71.8797	 21.7	 0.0	 0.0	 1	    1.03207	    0.00000	 220.0	 1	    1.16414	    0.90000;
	5392	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01621	    0.00000	 220.0	 1	    1.13243	    0.90000;
	5393	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5394	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00285	    0.00000	 150.0	 1	    1.10570	    0.90000;
	5395	 1	 57.06327	 13.3	 0.0	 0.0	 1	    1.00659	    0.00000	 220.0	 1	    1.11318	    0.90000;
	5396	 1	 160.7	 40.3	 0.0	 0.0	 1	    1.00739	    0.00000	 150.0	 1	    1.11478	    0.90000;
	5397	 1	 24.92764	 22.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5398	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5399	 1	 40.34473	 15.9	 0.0	 0.0	 1	    1.02171	    0.00000	 150.0	 1	    1.14342	    0.90000;
	5400	 1	 -7.96759	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5401	 1	 106.7	 33.6	 0.0	 0.0	 1	    1.01119	    0.00000	 110.0	 1	    1.12238	    0.90000;
	5402	 2	 80.0888	 23.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5403	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5404	 2	 208.5	 36.6	 0.0	 0.0	 1	    1.02247	    0.00000	 220.0	 1	    1.14495	    0.90000;
	5405	 1	 209.8	 102.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5406	 1	 160.0	 50.0	 0.0	 0.0	 1	    1.00331	    0.00000	 220.0	 1	    1.10663	    0.90000;
	5407	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5408	 1	 113.5	 11.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5409	 1	 64.27126	 22.9	 0.0	 0.0	 1	    1.00421	    0.00000	 110.0	 1	    1.10841	    0.90000;
	5410	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00862	    0.00000	 380.0	 1	    1.11723	    0.90000;
	5411	 2	 43.24795	 15.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5412	 1	 144.5	 67.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5413	 1	 62.56937	 22.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5414	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5415	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5416	 1	 99.5	 28.1	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5417	 2	 24.22686	 9.3	 0.0	 0.0	 1	    1.00384	    0.00000	 220.0	 1	    1.10768	    0.90000;
	5418	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02012	    0.00000	 380.0	 1	    1.14025	    0.90000;
	5419	 1	 148.2	 65.3	 0.0	 0.0	 1	    1.00291	    0.00000	 380.0	 1	    1.10582	    0.90000;
	5420	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02178	    0.00000	 220.0	 1	    1.14357	    0.90000;
	5421	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5422	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5423	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5424	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5425	 1	 3.503885	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5426	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03167	    0.00000	 220.0	 1	    1.16334	    0.90000;
	5427	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5428	 1	 17.11898	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5429	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02569	    0.00000	 380.0	 1	    1.15139	    0.90000;
	5430	 2	 157.7	 39.7	 0.0	 0.0	 1	    1.03072	    0.00000	 380.0	 1	    1.16143	    0.90000;
	5431	 1	 27.53052	 12.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5432	 2	 37.94207	 15.6	 0.0	 0.0	 1	    1.03076	    0.00000	 380.0	 1	    1.16152	    0.90000;
	5433	 2	 198.6	 63.0	 0.0	 0.0	 1	    1.00352	    0.00000	 380.0	 1	    1.10704	    0.90000;
	5434	 2	 49.85527	 8.2	 0.0	 0.0	 1	    1.02446	    0.00000	 220.0	 1	    1.14892	    0.90000;
	5435	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01245	    0.00000	 380.0	 1	    1.12490	    0.90000;
	5436	 1	 83.1	 26.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5437	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01963	    0.00000	 220.0	 1	    1.13926	    0.90000;
	5438	 2	 241.4	 116.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5439	 1	 408.9	 77.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5440	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00925	    0.00000	 220.0	 1	    1.11849	    0.90000;
	5441	 2	 117.5	 36.4	 0.0	 0.0	 1	    1.01217	    0.00000	 220.0	 1	    1.12435	    0.90000;
	5442	 1	 18.52053	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5443	 1	 0.0	 0.0	 0.138277	 0.0	 1	    1.01077	    0.00000	 380.0	 1	    1.12155	    0.90000;
	5444	 1	 25.82864	 12.5	 0.0	 0.0	 1	    1.02103	    0.00000	 220.0	 1	    1.14207	    0.90000;
	5445	 1	 36.03996	 -8.0	 0.0	 0.0	 1	    1.01322	    0.00000	 220.0	 1	    1.12644	    0.90000;
	5446	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01644	    0.00000	 380.0	 1	    1.13289	    0.90000;
	5447	 1	 4.605106	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5448	 1	 7.00777	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02846	    0.00000	 380.0	 1	    1.15691	    0.90000;
	5450	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02290	    0.00000	 380.0	 1	    1.14581	    0.90000;
	5451	 1	 0.0	 0.0	 0.250997	 0.0	 1	    1.04575	    0.00000	 220.0	 1	    1.19150	    0.90000;
	5452	 2	 196.2	 50.1	 0.0	 0.0	 1	    1.01397	    0.00000	 380.0	 1	    1.12795	    0.90000;
	5453	 1	 20.82309	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5454	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04485	    0.00000	 220.0	 1	    1.18969	    0.90000;
	5455	 1	 11.41265	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5456	 1	 -8.80977	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5457	 1	 105.8	 51.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5458	 2	 0.300333	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02124	    0.00000	 150.0	 1	    1.14247	    0.90000;
	5460	 1	 92.10212	 45.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5461	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00585	    0.00000	 380.0	 1	    1.11170	    0.90000;
	5462	 1	 27.53052	 17.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5463	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00837	    0.00000	 380.0	 1	    1.11673	    0.90000;
	5464	 1	 0.100111	 -19.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5465	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5466	 1	 9.00999	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5467	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5468	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02293	    0.00000	 110.0	 1	    1.14585	    0.90000;
	5469	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5470	 1	 61.26793	 11.0	 0.0	 0.0	 1	    1.01040	    0.00000	 380.0	 1	    1.12081	    0.90000;
	5471	 1	 0.0	 0.0	 0.0	 66.25125	 1	    1.00462	    0.00000	 110.0	 1	    1.10925	    0.90000;
	5472	 1	 23.02553	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00379	    0.00000	 220.0	 1	    1.10758	    0.90000;
	5474	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5475	 2	 23.02553	 9.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5477	 1	 -18.5205	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5478	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01860	    0.00000	 380.0	 1	    1.13719	    0.90000;
	5479	 1	 21.62398	 9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5480	 1	 43.54828	 -20.5	 0.0	 0.0	 1	    1.00601	    0.00000	 220.0	 1	    1.11202	    0.90000;
	5481	 1	 165.9	 154.6	 0.0	 0.0	 1	    1.02228	    0.00000	 380.0	 1	    1.14455	    0.90000;
	5482	 1	 -57.4637	 -30.3	 0.0	 0.0	 1	    1.00952	    0.00000	 220.0	 1	    1.11905	    0.90000;
	5483	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03349	    0.00000	 220.0	 1	    1.16699	    0.90000;
	5484	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5485	 1	 49.75517	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5486	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02378	    0.00000	 150.0	 1	    1.14756	    0.90000;
	5487	 2	 60.56715	 39.0	 0.090998	 0.0	 1	    1.02310	    0.00000	 220.0	 1	    1.14620	    0.90000;
	5488	 1	 79.48813	 22.7	 0.0	 0.0	 1	    1.00614	    0.00000	 150.0	 1	    1.11227	    0.90000;
	5489	 1	 6.607326	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5490	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5491	 1	 5.606215	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5492	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01379	    0.00000	 150.0	 1	    1.12759	    0.90000;
	5493	 1	 412.1	 79.3	 0.0	 0.0	 1	    1.03558	    0.00000	 220.0	 1	    1.17116	    0.90000;
	5494	 1	 4.104551	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5495	 1	 19.32142	 7.0	 0.0	 0.0	 1	    1.01513	    0.00000	 110.0	 1	    1.13026	    0.90000;
	5496	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00344	    0.00000	 150.0	 1	    1.10688	    0.90000;
	5497	 1	 47.65283	 19.4	 0.0	 0.0	 1	    1.02114	    0.00000	 150.0	 1	    1.14229	    0.90000;
	5498	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00841	    0.00000	 110.0	 1	    1.11681	    0.90000;
	5499	 1	 35.13896	 14.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5500	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03002	    0.00000	 380.0	 1	    1.16005	    0.90000;
	5501	 1	 15.01665	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5502	 1	 13.31476	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5503	 2	 61.8686	 24.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5504	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04235	    0.00000	 380.0	 1	    1.18471	    0.90000;
	5505	 1	 25.72853	 9.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5506	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01082	    0.00000	 380.0	 1	    1.12165	    0.90000;
	5507	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00695	    0.00000	 220.0	 1	    1.11390	    0.90000;
	5508	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00749	    0.00000	 380.0	 1	    1.11498	    0.90000;
	5509	 1	 0.0	 0.0	 0.236732	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5510	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01114	    0.00000	 220.0	 1	    1.12228	    0.90000;
	5511	 1	 163.5	 35.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5512	 1	 47.6	 41.3	 0.0	 0.0	 1	    1.03142	    0.00000	 380.0	 1	    1.16284	    0.90000;
	5513	 1	 2.702997	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5514	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01815	    0.00000	 220.0	 1	    1.13629	    0.90000;
	5515	 1	 1.801998	 0.7	 0.0	 0.0	 1	    1.01594	    0.00000	 110.0	 1	    1.13189	    0.90000;
	5516	 1	 102.7	 -102.3	 0.0	 0.0	 1	    1.00578	    0.00000	 380.0	 1	    1.11157	    0.90000;
	5517	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5518	 1	 160.2	 89.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5519	 1	 0.0	 0.0	 0.396003	 0.0	 1	    1.02103	    0.00000	 380.0	 1	    1.14207	    0.90000;
	5520	 1	 5.806438	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5521	 1	 6.00666	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5522	 1	 111.5	 147.5	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5523	 1	 0.0	 0.0	 0.074818	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5524	 2	 353.0	 123.4	 0.0	 0.0	 1	    1.00657	    0.00000	 380.0	 1	    1.11315	    0.90000;
	5525	 1	 26.22908	 8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5526	 2	 0.0	 5.9	 0.0	 0.0	 1	    1.01489	    0.00000	 220.0	 1	    1.12978	    0.90000;
	5527	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00796	    0.00000	 220.0	 1	    1.11593	    0.90000;
	5528	 2	 1.801998	 72.0	 0.0	 0.0	 1	    1.01577	    0.00000	 380.0	 1	    1.13154	    0.90000;
	5529	 1	 21.02331	 12.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5530	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5531	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00984	    0.00000	 380.0	 1	    1.11968	    0.90000;
	5532	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5533	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5534	 1	 0.0	 0.0	 0.152776	 0.0	 1	    1.02565	    0.00000	 380.0	 1	    1.15131	    0.90000;
	5535	 1	 0.300333	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5536	 2	 521.7	 154.9	 0.0	 0.0	 1	    1.01125	    0.00000	 220.0	 1	    1.12251	    0.90000;
	5537	 1	 103.0	 40.2	 0.0	 0.0	 1	    1.01962	    0.00000	 220.0	 1	    1.13923	    0.90000;
	5538	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5539	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5540	 2	 107.4	 10.5	 0.0	 0.0	 1	    1.01797	    0.00000	 220.0	 1	    1.13595	    0.90000;
	5541	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5542	 1	 1.301443	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5543	 1	 128.6	 27.8	 0.0	 0.0	 1	    1.00303	    0.00000	 220.0	 1	    1.10606	    0.90000;
	5544	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01517	    0.00000	 380.0	 1	    1.13034	    0.90000;
	5545	 2	 291.7	 104.6	 0.0	 0.0	 1	    1.00334	    0.00000	 380.0	 1	    1.10667	    0.90000;
	5546	 1	 78.58714	 16.0	 0.0	 0.0	 1	    1.03017	    0.00000	 220.0	 1	    1.16034	    0.90000;
	5547	 2	 56.66282	 18.7	 0.0	 0.0	 1	    1.01876	    0.00000	 220.0	 1	    1.13753	    0.90000;
	5548	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5549	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01021	    0.00000	 220.0	 1	    1.12043	    0.90000;
	5550	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01043	    0.00000	 220.0	 1	    1.12085	    0.90000;
	5551	 1	 0.0	 0.0	 0.133294	 0.0	 1	    1.00384	    0.00000	 220.0	 1	    1.10768	    0.90000;
	5552	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5553	 2	 82.69168	 32.9	 0.0	 0.0	 1	    1.02863	    0.00000	 220.0	 1	    1.15727	    0.90000;
	5554	 2	 251.2	 82.6	 0.0	 0.0	 1	    1.01423	    0.00000	 220.0	 1	    1.12845	    0.90000;
	5555	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00272	    0.00000	 220.0	 1	    1.10544	    0.90000;
	5556	 1	 16.12131	 5.8	 0.0	 0.0	 1	    1.01391	    0.00000	 150.0	 1	    1.12781	    0.90000;
	5557	 1	 3.704107	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5558	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5559	 1	 -0.10011	 68.5	 0.0	 0.0	 1	    1.01572	    0.00000	 220.0	 1	    1.13145	    0.90000;
	5560	 1	 27.23019	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5561	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04060	    0.00000	 380.0	 1	    1.18119	    0.90000;
	5562	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5563	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03188	    0.00000	 150.0	 1	    1.16376	    0.90000;
	5564	 1	 60.66726	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5565	 1	 109.0	 28.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5566	 1	 42.54717	 6.5	 0.0	 0.0	 1	    1.00567	    0.00000	 220.0	 1	    1.11134	    0.90000;
	5567	 1	 2.202442	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5568	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01039	    0.00000	 380.0	 1	    1.12079	    0.90000;
	5569	 2	 162.0	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5570	 1	 76.88525	 35.1	 0.0	 0.0	 1	    1.03238	    0.00000	 150.0	 1	    1.16476	    0.90000;
	5571	 1	 11.51276	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5572	 1	 44.04884	 16.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5573	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5574	 2	 15.81754	 22.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5575	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02443	    0.00000	 220.0	 1	    1.14887	    0.90000;
	5576	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5577	 1	 8.709657	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5578	 1	 39.04329	 24.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5579	 1	 15.31698	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5580	 1	 60.66726	 33.2	 0.0	 0.0	 1	    1.02492	    0.00000	 220.0	 1	    1.14984	    0.90000;
	5581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5582	 2	 0.7	 0.0	 0.0	 0.0	 1	    1.01499	    0.00000	 380.0	 1	    1.12997	    0.90000;
	5583	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5584	 1	 67.97536	 54.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5585	 1	 95.9	 26.2	 0.0	 0.0	 1	    1.01814	    0.00000	 220.0	 1	    1.13628	    0.90000;
	5586	 1	 160.2	 88.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5587	 1	 0.0	 0.0	 0.250997	 0.0	 1	    1.01656	    0.00000	 220.0	 1	    1.13312	    0.90000;
	5588	 1	 0.0	 0.0	 0.143075	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5589	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00633	    0.00000	 380.0	 1	    1.11265	    0.90000;
	5590	 1	 383.6	 -37.9	 0.0	 0.0	 1	    1.01199	    0.00000	 380.0	 1	    1.12398	    0.90000;
	5591	 1	 0.0	 0.0	 0.0	 23.04696	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5592	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02682	    0.00000	 220.0	 1	    1.15363	    0.90000;
	5593	 1	 0.0	 0.0	 0.219948	 0.0	 1	    1.00383	    0.00000	 380.0	 1	    1.10765	    0.90000;
	5594	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5595	 2	 89.09879	 8.3	 0.0	 0.0	 1	    1.01608	    0.00000	 220.0	 1	    1.13216	    0.90000;
	5596	 1	 152.6	 61.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5597	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02032	    0.00000	 220.0	 1	    1.14064	    0.90000;
	5598	 2	 124.8	 -14.7	 0.0	 0.0	 1	    1.01028	    0.00000	 220.0	 1	    1.12056	    0.90000;
	5599	 1	 28.93208	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5600	 1	 66.97426	 14.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5601	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5602	 1	 289.1	 84.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5603	 1	 16.71854	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5604	 1	 18.42042	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5605	 1	 91.0009	 28.4	 0.0	 0.0	 1	    1.01871	    0.00000	 220.0	 1	    1.13743	    0.90000;
	5606	 2	 4.304773	 1.5	 0.0	 0.0	 1	    1.01146	    0.00000	 220.0	 1	    1.12292	    0.90000;
	5607	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01510	    0.00000	 380.0	 1	    1.13019	    0.90000;
	5608	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5609	 1	 59.36582	 12.7	 0.0	 0.0	 1	    1.00582	    0.00000	 220.0	 1	    1.11164	    0.90000;
	5610	 1	 16.71854	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5611	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5612	 1	 63.06993	 13.4	 0.0	 0.0	 1	    1.00546	    0.00000	 220.0	 1	    1.11091	    0.90000;
	5613	 1	 0.0	 0.0	 0.396	 0.0	 1	    1.01940	    0.00000	 380.0	 1	    1.13879	    0.90000;
	5614	 1	 209.9	 38.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5615	 1	 131.9	 50.6	 0.0	 0.0	 1	    1.01718	    0.00000	 380.0	 1	    1.13435	    0.90000;
	5616	 2	 206.2	 72.2	 0.0	 0.0	 1	    1.02560	    0.00000	 380.0	 1	    1.15119	    0.90000;
	5617	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01890	    0.00000	 220.0	 1	    1.13779	    0.90000;
	5618	 1	 50.55605	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5619	 1	 165.4	 130.5	 0.0	 0.0	 1	    1.00873	    0.00000	 380.0	 1	    1.11746	    0.90000;
	5620	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02287	    0.00000	 220.0	 1	    1.14574	    0.90000;
	5621	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00997	    0.00000	 150.0	 1	    1.11995	    0.90000;
	5622	 1	 17.51942	 6.1	 0.0	 0.0	 1	    1.01130	    0.00000	 110.0	 1	    1.12260	    0.90000;
	5623	 1	 126.7	 46.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5624	 2	 19.62176	 8.7	 0.0	 0.0	 1	    1.03401	    0.00000	 380.0	 1	    1.16801	    0.90000;
	5625	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5626	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02166	    0.00000	 380.0	 1	    1.14332	    0.90000;
	5627	 1	 83.7929	 33.1	 0.0	 0.0	 1	    1.02552	    0.00000	 150.0	 1	    1.15104	    0.90000;
	5628	 1	 14.01554	 5.6	 0.0	 0.0	 1	    1.04271	    0.00000	 220.0	 1	    1.18542	    0.90000;
	5629	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5630	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5631	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01852	    0.00000	 380.0	 1	    1.13704	    0.90000;
	5632	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04380	    0.00000	 380.0	 1	    1.18760	    0.90000;
	5633	 1	 18.72076	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5634	 1	 69.47704	 19.7	 0.0	 0.0	 1	    1.00696	    0.00000	 220.0	 1	    1.11392	    0.90000;
	5635	 1	 253.2	 78.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5636	 1	 117.0	 19.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5637	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5638	 1	 7.608436	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.20000	    0.80000;
	5639	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5640	 1	 13.71521	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5641	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02293	    0.00000	 380.0	 1	    1.14586	    0.90000;
	5642	 1	 88.79845	 35.1	 0.0	 0.0	 1	    1.01861	    0.00000	 150.0	 1	    1.13721	    0.90000;
	5643	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00733	    0.00000	 220.0	 1	    1.11465	    0.90000;
	5644	 1	 231.9	 27.6	 0.0	 0.0	 1	    1.03062	    0.00000	 220.0	 1	    1.16125	    0.90000;
	5645	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5646	 2	 0.0	 0.0	 0.108316	 45.08263	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5647	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5648	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01358	    0.00000	 380.0	 1	    1.12716	    0.90000;
	5649	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5650	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5651	 1	 88.0	 70.3	 0.0	 0.0	 1	    1.00634	    0.00000	 380.0	 1	    1.11268	    0.90000;
	5652	 1	 26.4293	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5653	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5654	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02170	    0.00000	 220.0	 1	    1.14339	    0.90000;
	5655	 1	 49.25461	 12.0	 0.0	 0.0	 1	    1.01420	    0.00000	 220.0	 1	    1.12841	    0.90000;
	5656	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01773	    0.00000	 380.0	 1	    1.13546	    0.90000;
	5657	 1	 227.6	 71.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5658	 1	 16.51831	 0.0	 0.0	 0.0	 1	    1.00681	    0.00000	 150.0	 1	    1.11362	    0.90000;
	5659	 1	 2.502775	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5660	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02307	    0.00000	 380.0	 1	    1.14614	    0.90000;
	5661	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01242	    0.00000	 220.0	 1	    1.12485	    0.90000;
	5662	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03964	    0.00000	 220.0	 1	    1.17927	    0.90000;
	5663	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5664	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5665	 2	 90.7	 36.9	 0.0	 0.0	 1	    1.00962	    0.00000	 220.0	 1	    1.11925	    0.90000;
	5666	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5667	 1	 0.0	 0.0	 0.296958	 0.0	 1	    1.02776	    0.00000	 380.0	 1	    1.15552	    0.90000;
	5668	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01833	    0.00000	 380.0	 1	    1.13666	    0.90000;
	5669	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5670	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02910	    0.00000	 380.0	 1	    1.15821	    0.90000;
	5671	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01331	    0.00000	 380.0	 1	    1.12663	    0.90000;
	5672	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5673	 2	 391.3	 118.9	 0.0	 0.0	 1	    1.00719	    0.00000	 380.0	 1	    1.11438	    0.90000;
	5674	 1	 164.7	 44.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5675	 1	 128.8	 29.3	 0.0	 0.0	 1	    1.01440	    0.00000	 220.0	 1	    1.12881	    0.90000;
	5676	 1	 0.0	 0.0	 0.0	 123.9802	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5677	 1	 0.0	 0.0	 0.0	 -16.4625	 1	    1.04726	    0.00000	 150.0	 1	    1.19453	    0.90000;
	5678	 1	 0.0	 0.0	 0.177284	 0.0	 1	    1.02846	    0.00000	 380.0	 1	    1.15691	    0.90000;
	5679	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03139	    0.00000	 380.0	 1	    1.16278	    0.90000;
	5680	 1	 11.61288	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5681	 1	 178.0	 33.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5682	 1	 47.55272	 29.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5683	 1	 75.88414	 11.2	 0.0	 0.0	 1	    1.00624	    0.00000	 220.0	 1	    1.11248	    0.90000;
	5684	 1	 12.81421	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5685	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00762	    0.00000	 380.0	 1	    1.11525	    0.90000;
	5686	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5687	 2	 61.36804	 13.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5688	 1	 91.30122	 18.1	 0.0	 0.0	 1	    1.01907	    0.00000	 220.0	 1	    1.13813	    0.90000;
	5689	 2	 266.1	 33.7	 0.0	 0.0	 1	    1.01413	    0.00000	 220.0	 1	    1.12826	    0.90000;
	5690	 1	 3.704107	 2.6	 0.0	 0.0	 1	    1.03770	    0.00000	 220.0	 1	    1.17539	    0.90000;
	5691	 1	 125.9	 -21.2	 0.0	 0.0	 1	    1.00903	    0.00000	 380.0	 1	    1.11807	    0.90000;
	5692	 1	 12.11343	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5693	 1	 441.2	 200.7	 0.0	 20.0	 1	    1.00966	    0.00000	 380.0	 1	    1.11932	    0.90000;
	5694	 1	 122.8	 37.2	 0.0	 0.0	 1	    1.01857	    0.00000	 150.0	 1	    1.13713	    0.90000;
	5695	 1	 65.07214	 40.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5696	 1	 15.21687	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5697	 2	 77.48591	 24.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5698	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5699	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03217	    0.00000	 220.0	 1	    1.16434	    0.90000;
	5700	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01129	    0.00000	 380.0	 1	    1.12258	    0.90000;
	5701	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00925	    0.00000	 380.0	 1	    1.11850	    0.90000;
	5702	 1	 51.95761	 22.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5703	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5704	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01124	    0.00000	 220.0	 1	    1.12248	    0.90000;
	5705	 1	 25.22797	 10.3	 0.0	 0.0	 1	    1.02128	    0.00000	 150.0	 1	    1.14256	    0.90000;
	5706	 1	 47.65283	 20.4	 0.0	 0.0	 1	    1.02016	    0.00000	 220.0	 1	    1.14033	    0.90000;
	5707	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01700	    0.00000	 220.0	 1	    1.13399	    0.90000;
	5708	 1	 186.5	 49.9	 0.0	 0.0	 1	    1.01088	    0.00000	 220.0	 1	    1.12176	    0.90000;
	5709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02830	    0.00000	 150.0	 1	    1.15660	    0.90000;
	5711	 1	 15.01665	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5712	 1	 20.0222	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5713	 1	 0.0	 0.0	 0.312993	 0.0	 1	    1.02070	    0.00000	 380.0	 1	    1.14140	    0.90000;
	5714	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00979	    0.00000	 220.0	 1	    1.11958	    0.90000;
	5715	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5716	 1	 134.0486	 13.3	 0.0	 0.0	 1	    1.00954	    0.00000	 220.0	 1	    1.11907	    0.90000;
	5717	 1	 49.95539	 15.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5718	 1	 1.701887	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5719	 1	 31.33474	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5720	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03653	    0.00000	 220.0	 1	    1.17305	    0.90000;
	5721	 1	 132.4	 -10.4	 0.0	 0.0	 1	    1.00673	    0.00000	 220.0	 1	    1.11346	    0.90000;
	5722	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01497	    0.00000	 220.0	 1	    1.12993	    0.90000;
	5723	 1	 0.0	 -7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5724	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5725	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5726	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01242	    0.00000	 220.0	 1	    1.12485	    0.90000;
	5727	 1	 48.95428	 14.9	 0.0	 0.0	 1	    1.02554	    0.00000	 220.0	 1	    1.15108	    0.90000;
	5728	 1	 30.0333	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5729	 1	 95.70611	 19.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5730	 1	 474.3	 203.4	 0.0	 0.0	 1	    1.02591	    0.00000	 380.0	 1	    1.15182	    0.90000;
	5731	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.00846	    0.00000	 220.0	 1	    1.11692	    0.90000;
	5732	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5733	 1	 0.0	 0.0	 0.148479	 0.0	 1	    1.01431	    0.00000	 380.0	 1	    1.12861	    0.90000;
	5734	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02009	    0.00000	 150.0	 1	    1.14018	    0.90000;
	5735	 1	 128.8	 70.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5736	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5737	 1	 116.1	 30.2	 0.0	 0.0	 1	    1.00554	    0.00000	 150.0	 1	    1.11108	    0.90000;
	5738	 1	 -5.00555	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5739	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5740	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5741	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5742	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02704	    0.00000	 220.0	 1	    1.15407	    0.90000;
	5743	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03530	    0.00000	 220.0	 1	    1.17060	    0.90000;
	5744	 1	 42.74739	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5745	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5746	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5747	 1	 245.5095	 46.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5748	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03921	    0.00000	 380.0	 1	    1.17841	    0.90000;
	5749	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5750	 1	 7.207992	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5751	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02310	    0.00000	 380.0	 1	    1.14620	    0.90000;
	5752	 1	 22.7252	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5753	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02483	    0.00000	 110.0	 1	    1.14966	    0.90000;
	5754	 1	 143.9	 123.3	 0.2259	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5755	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5756	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5757	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5758	 1	 22.22464	 13.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5759	 1	 32.03552	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5760	 1	 55.46149	 14.1	 0.0	 0.0	 1	    1.00598	    0.00000	 220.0	 1	    1.11196	    0.90000;
	5761	 1	 35.03885	 20.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5762	 2	 21.72409	 7.5	 0.0	 0.0	 1	    1.02347	    0.00000	 220.0	 1	    1.14695	    0.90000;
	5763	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5764	 1	 0.600666	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5765	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02303	    0.00000	 150.0	 1	    1.14605	    0.90000;
	5766	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00716	    0.00000	 150.0	 1	    1.11431	    0.90000;
	5767	 1	 44.94984	 12.8	 0.0	 0.0	 1	    1.00503	    0.00000	 150.0	 1	    1.11005	    0.90000;
	5768	 1	 430.8	 107.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5769	 2	 9.00999	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5770	 1	 74.6828	 10.8	 0.0	 0.0	 1	    1.00652	    0.00000	 220.0	 1	    1.11303	    0.90000;
	5771	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01474	    0.00000	 150.0	 1	    1.12948	    0.90000;
	5772	 1	 8.108991	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5773	 1	 24.02664	 8.0	 0.0	 0.0	 1	    1.03864	    0.00000	 120.0	 1	    1.17728	    0.90000;
	5774	 2	 13.41487	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5775	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5776	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5777	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01484	    0.00000	 380.0	 1	    1.12969	    0.90000;
	5778	 1	 7.408214	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5779	 2	 259.3	 91.5	 0.0	 0.0	 1	    1.00478	    0.00000	 220.0	 1	    1.10956	    0.90000;
	5780	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01417	    0.00000	 380.0	 1	    1.12834	    0.90000;
	5781	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02212	    0.00000	 220.0	 1	    1.14423	    0.90000;
	5782	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5783	 2	 325.0	 75.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5784	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5785	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01168	    0.00000	 220.0	 1	    1.12337	    0.90000;
	5786	 2	 251.0	 100.5	 0.0	 0.0	 1	    1.02205	    0.00000	 220.0	 1	    1.14410	    0.90000;
	5787	 1	 11.61288	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5788	 1	 11.31254	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5789	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00310	    0.00000	 150.0	 1	    1.10620	    0.90000;
	5790	 1	 246.2	 119.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5791	 2	 97.60822	 18.2	 0.0	 0.0	 1	    1.02329	    0.00000	 220.0	 1	    1.14658	    0.90000;
	5792	 1	 15.61732	 5.3	 0.0	 0.0	 1	    1.00600	    0.00000	 110.0	 1	    1.11200	    0.90000;
	5793	 1	 159.9	 47.4	 0.0	 0.0	 1	    1.02218	    0.00000	 220.0	 1	    1.14436	    0.90000;
	5794	 2	 6.00666	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5795	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00568	    0.00000	 220.0	 1	    1.11137	    0.90000;
	5796	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5797	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02847	    0.00000	 380.0	 1	    1.15694	    0.90000;
	5798	 2	 93.00311	 15.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5799	 1	 80.0888	 19.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5800	 1	 93.70389	 29.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5801	 1	 53.85971	 -15.3	 0.0	 0.0	 1	    1.00483	    0.00000	 220.0	 1	    1.10965	    0.90000;
	5802	 1	 154.7	 48.2	 0.0	 0.0	 1	    1.01650	    0.00000	 150.0	 1	    1.13301	    0.90000;
	5803	 1	 4.00444	 0.1	 0.0	 0.0	 1	    0.98435	    0.00000	 150.0	 1	    1.10000	    0.86870;
	5804	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5805	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00437	    0.00000	 750.0	 1	    1.10873	    0.90000;
	5806	 1	 44.04884	 18.0	 0.0	 0.0	 1	    1.02349	    0.00000	 150.0	 1	    1.14698	    0.90000;
	5807	 1	 7.908769	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5808	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5809	 1	 76.4848	 19.8	 0.0	 0.0	 1	    1.01562	    0.00000	 220.0	 1	    1.13125	    0.90000;
	5810	 1	 2.502775	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5811	 1	 0.300333	 -34.1	 0.0	 0.0	 1	    1.01976	    0.00000	 220.0	 1	    1.13951	    0.90000;
	5812	 1	 126.9	 80.5	 0.0	 0.0	 1	    1.03665	    0.00000	 380.0	 1	    1.17329	    0.90000;
	5813	 2	 15.31698	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5814	 1	 115.2	 38.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5815	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99215	    0.00000	 150.0	 1	    1.10000	    0.88431;
	5816	 2	 0.0	 0.0	 0.265355	 0.0	 1	    1.00986	    0.00000	 380.0	 1	    1.11972	    0.90000;
	5817	 2	 -119.633	 -2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5818	 1	 67.67503	 16.4	 0.0	 0.0	 1	    1.01001	    0.00000	 220.0	 1	    1.12001	    0.90000;
	5819	 1	 0.0	 0.0	 0.0	 11.34805	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5820	 1	 43.7485	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5821	 2	 0.0	 0.0	 0.0	 20.0	 1	    1.01143	    0.00000	 380.0	 1	    1.12286	    0.90000;
	5822	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99746	    0.00000	 150.0	 1	    1.10000	    0.89491;
	5823	 1	 174.3	 11.8	 0.0	 0.0	 1	    1.02157	    0.00000	 220.0	 1	    1.14314	    0.90000;
	5824	 2	 17.71965	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5825	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01872	    0.00000	 150.0	 1	    1.13744	    0.90000;
	5826	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01401	    0.00000	 380.0	 1	    1.12803	    0.90000;
	5827	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5828	 1	 10.21132	 3.8	 0.0	 0.0	 1	    1.02854	    0.00000	 220.0	 1	    1.15708	    0.90000;
	5829	 1	 83.19224	 22.9	 0.0	 0.0	 1	    1.01026	    0.00000	 380.0	 1	    1.12052	    0.90000;
	5830	 1	 93.1	 43.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5831	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02085	    0.00000	 220.0	 1	    1.14170	    0.90000;
	5832	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01926	    0.00000	 220.0	 1	    1.13851	    0.90000;
	5833	 1	 1.401554	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5834	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5835	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5836	 2	 69.77736	 35.9	 0.0	 0.0	 1	    1.02745	    0.00000	 220.0	 1	    1.15491	    0.90000;
	5837	 1	 28.63174	 11.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5838	 2	 91.70167	 17.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5839	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5840	 1	 0.100111	 -19.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5841	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01972	    0.00000	 150.0	 1	    1.13944	    0.90000;
	5842	 1	 81.79068	 10.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5843	 1	 3.904329	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5844	 1	 163.3	 70.3	 0.0	 0.0	 1	    1.01651	    0.00000	 150.0	 1	    1.13302	    0.90000;
	5845	 1	 43.94873	 15.5	 0.0	 0.0	 1	    1.00728	    0.00000	 220.0	 1	    1.11457	    0.90000;
	5846	 1	 193.8	 18.0	 0.0	 0.0	 1	    1.03736	    0.00000	 380.0	 1	    1.17472	    0.90000;
	5847	 1	 1.0	 -2.3	 0.0	 0.0	 1	    1.01045	    0.00000	 150.0	 1	    1.12089	    0.90000;
	5848	 1	 77.18558	 23.0	 0.0	 0.0	 1	    1.01927	    0.00000	 380.0	 1	    1.13853	    0.90000;
	5849	 1	 54.96094	 13.2	 0.0	 0.0	 1	    1.01055	    0.00000	 110.0	 1	    1.12110	    0.90000;
	5850	 2	 12.51387	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5851	 1	 0.0	 0.0	 0.148479	 0.0	 1	    1.02366	    0.00000	 380.0	 1	    1.14732	    0.90000;
	5852	 1	 5.506105	 2.1	 0.0	 0.0	 1	    1.01339	    0.00000	 220.0	 1	    1.12678	    0.90000;
	5853	 1	 132.1	 13.2	 0.0	 0.0	 1	    1.01601	    0.00000	 220.0	 1	    1.13201	    0.90000;
	5854	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00426	    0.00000	 220.0	 1	    1.10852	    0.90000;
	5855	 1	 8.309213	 3.0	 0.0	 0.0	 1	    1.01036	    0.00000	 110.0	 1	    1.12072	    0.90000;
	5856	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00667	    0.00000	 220.0	 1	    1.11334	    0.90000;
	5857	 1	 20.52275	 13.3	 0.0	 0.0	 1	    1.01929	    0.00000	 220.0	 1	    1.13857	    0.90000;
	5858	 1	 159.4	 28.4	 0.0	 0.0	 1	    1.00827	    0.00000	 220.0	 1	    1.11654	    0.90000;
	5859	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00970	    0.00000	 380.0	 1	    1.11940	    0.90000;
	5860	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5861	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5862	 1	 169.8	 -19.6	 0.0	 0.0	 1	    1.02180	    0.00000	 380.0	 1	    1.14361	    0.90000;
	5863	 1	 22.22464	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5864	 2	 5.706326	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5865	 1	 9.410433	 13.8	 0.0	 0.0	 1	    1.03045	    0.00000	 380.0	 1	    1.16090	    0.90000;
	5866	 1	 3.203552	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5867	 2	 24.02664	 0.1	 0.0	 0.0	 1	    1.00292	    0.00000	 380.0	 1	    1.10585	    0.90000;
	5868	 1	 172.5	 48.7	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5869	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5870	 1	 0.0	 0.0	 0.209494	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5871	 1	 34.13785	 11.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5872	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03058	    0.00000	 220.0	 1	    1.16117	    0.90000;
	5873	 2	 153.9	 11.5	 0.0	 0.0	 1	    1.02179	    0.00000	 220.0	 1	    1.14357	    0.90000;
	5874	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02078	    0.00000	 380.0	 1	    1.14156	    0.90000;
	5875	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01521	    0.00000	 220.0	 1	    1.13041	    0.90000;
	5876	 1	 141.2	 34.8	 0.0	 0.0	 1	    1.01731	    0.00000	 220.0	 1	    1.13462	    0.90000;
	5877	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5878	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00758	    0.00000	 150.0	 1	    1.11517	    0.90000;
	5879	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.01356	    0.00000	 220.0	 1	    1.12712	    0.90000;
	5880	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00665	    0.00000	 380.0	 1	    1.11330	    0.90000;
	5881	 2	 3.704107	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5882	 2	 2.1	 122.3	 0.0	 0.0	 1	    1.01673	    0.00000	 380.0	 1	    1.13346	    0.90000;
	5883	 1	 0.0	 0.0	 0.589275	 0.0	 1	    1.01750	    0.00000	 380.0	 1	    1.13499	    0.90000;
	5884	 1	 31.73519	 17.4	 0.0	 0.0	 1	    1.01558	    0.00000	 220.0	 1	    1.13115	    0.90000;
	5885	 1	 18.62065	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5886	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01554	    0.00000	 380.0	 1	    1.13108	    0.90000;
	5887	 1	 84.59379	 12.9	 0.0	 0.0	 1	    1.00547	    0.00000	 220.0	 1	    1.11094	    0.90000;
	5888	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02689	    0.00000	 380.0	 1	    1.15378	    0.90000;
	5889	 2	 0.0	 0.0	 0.060511	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5890	 1	 9.510545	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5891	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02074	    0.00000	 380.0	 1	    1.14148	    0.90000;
	5892	 1	 49.65505	 12.3	 0.0	 0.0	 1	    1.00952	    0.00000	 220.0	 1	    1.11904	    0.90000;
	5893	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01543	    0.00000	 380.0	 1	    1.13087	    0.90000;
	5894	 2	 0.0	 0.0	 0.225995	 0.0	 1	    1.02145	    0.00000	 380.0	 1	    1.14290	    0.90000;
	5895	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00947	    0.00000	 220.0	 1	    1.11895	    0.90000;
	5896	 1	 25.12786	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5897	 1	 25.82864	 9.4	 0.0	 0.0	 1	    1.01013	    0.00000	 110.0	 1	    1.12027	    0.90000;
	5898	 2	 4.605106	 2.6	 0.0	 0.0	 1	    1.01063	    0.00000	 110.0	 1	    1.12125	    0.90000;
	5899	 1	 13.21465	 3.5	 0.0	 0.0	 1	    1.02214	    0.00000	 110.0	 1	    1.14429	    0.90000;
	5900	 1	 49.25461	 30.9	 0.104003	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5901	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5902	 2	 41.34584	 7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5903	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01707	    0.00000	 380.0	 1	    1.13414	    0.90000;
	5904	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5905	 1	 88.19778	 26.7	 0.0	 0.0	 1	    1.01437	    0.00000	 220.0	 1	    1.12873	    0.90000;
	5906	 1	 20.0222	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5907	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5908	 1	 13.91543	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5909	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02649	    0.00000	 150.0	 1	    1.15297	    0.90000;
	5910	 1	 20.32253	 8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5911	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01998	    0.00000	 220.0	 1	    1.13996	    0.90000;
	5912	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5913	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5914	 1	 20.32253	 -22.0	 0.0	 0.0	 1	    1.01038	    0.00000	 220.0	 1	    1.12076	    0.90000;
	5915	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01747	    0.00000	 220.0	 1	    1.13494	    0.90000;
	5916	 1	 30.43374	 12.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5917	 1	 24.82753	 9.0	 0.0	 0.0	 1	    1.01280	    0.00000	 110.0	 1	    1.12560	    0.90000;
	5918	 1	 113.4	 61.9	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5919	 1	 8.409324	 2.6	 0.0	 0.0	 1	    1.00579	    0.00000	 110.0	 1	    1.11159	    0.90000;
	5920	 1	 100.1	 48.9	 0.0	 0.0	 1	    1.00276	    0.00000	 150.0	 1	    1.10553	    0.90000;
	5921	 1	 69.07658	 24.0	 0.0	 0.0	 1	    1.01837	    0.00000	 220.0	 1	    1.13673	    0.90000;
	5922	 1	 446.5	 105.6	 0.0	 0.0	 1	    1.00619	    0.00000	 380.0	 1	    1.11237	    0.90000;
	5923	 1	 42.8475	 14.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5924	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5925	 2	 136.6	 24.1	 0.0	 0.0	 1	    1.01748	    0.00000	 220.0	 1	    1.13497	    0.90000;
	5926	 2	 38.2424	 23.7	 0.0	 0.0	 1	    1.04637	    0.00000	 150.0	 1	    1.19274	    0.90000;
	5927	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5928	 1	 20.72298	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5929	 1	 349.2	 61.3	 0.238392	 0.0	 1	    1.00988	    0.00000	 380.0	 1	    1.11975	    0.90000;
	5930	 1	 68.47592	 22.4	 0.0	 0.0	 1	    1.01320	    0.00000	 150.0	 1	    1.12641	    0.90000;
	5931	 1	 0.900999	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5932	 1	 27.43041	 -36.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5933	 1	 208.2404	 11.9	 0.0	 0.0	 1	    1.02338	    0.00000	 220.0	 1	    1.14677	    0.90000;
	5934	 1	 118.4	 7.1	 0.0	 0.0	 1	    1.00656	    0.00000	 220.0	 1	    1.11312	    0.90000;
	5935	 1	 62.16893	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5936	 1	 1.101221	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5937	 1	 26.32919	 8.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5938	 1	 7.608436	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5939	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98221	    0.00000	 150.0	 1	    1.10000	    0.86442;
	5940	 1	 3.103441	 -5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5941	 2	 253.4	 57.4	 0.0	 0.0	 1	    1.01140	    0.00000	 220.0	 1	    1.12279	    0.90000;
	5942	 1	 262.1	 13.9	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5943	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02121	    0.00000	 380.0	 1	    1.14241	    0.90000;
	5944	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01686	    0.00000	 220.0	 1	    1.13373	    0.90000;
	5945	 1	 3.704107	 1.3	 0.0	 0.0	 1	    1.00759	    0.00000	 110.0	 1	    1.11519	    0.90000;
	5946	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00387	    0.00000	 380.0	 1	    1.10774	    0.90000;
	5947	 1	 105.5	 35.3	 0.0	 0.0	 1	    1.02217	    0.00000	 150.0	 1	    1.14434	    0.90000;
	5948	 1	 488.7	 118.4	 0.0	 0.0	 1	    1.01631	    0.00000	 380.0	 1	    1.13261	    0.90000;
	5949	 1	 216.0	 56.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5950	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5951	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01890	    0.00000	 220.0	 1	    1.13780	    0.90000;
	5952	 1	 328.9	 -9.3	 0.0	 0.0	 1	    1.01588	    0.00000	 380.0	 1	    1.13176	    0.90000;
	5953	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01496	    0.00000	 220.0	 1	    1.12993	    0.90000;
	5954	 1	 43.14784	 14.4	 0.0	 0.0	 1	    1.01648	    0.00000	 220.0	 1	    1.13296	    0.90000;
	5955	 1	 43.14784	 14.8	 0.0	 0.0	 1	    1.00915	    0.00000	 220.0	 1	    1.11830	    0.90000;
	5956	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01859	    0.00000	 380.0	 1	    1.13718	    0.90000;
	5957	 2	 205.4	 37.7	 0.0	 0.0	 1	    1.00377	    0.00000	 380.0	 1	    1.10753	    0.90000;
	5958	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02007	    0.00000	 220.0	 1	    1.14014	    0.90000;
	5959	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5960	 1	 23.92653	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5961	 1	 114.8	 33.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01819	    0.00000	 380.0	 1	    1.13638	    0.90000;
	5963	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02087	    0.00000	 380.0	 1	    1.14174	    0.90000;
	5964	 1	 51.75739	 21.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5965	 1	 15.1414	 11.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5966	 1	 8.909878	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5967	 1	 26.62953	 9.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5968	 1	 153.8	 23.4	 0.0	 0.0	 1	    1.02229	    0.00000	 380.0	 1	    1.14457	    0.90000;
	5969	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01720	    0.00000	 150.0	 1	    1.13439	    0.90000;
	5970	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5971	 2	 0.0	 0.0	 0.113564	 0.0	 1	    1.00620	    0.00000	 380.0	 1	    1.11241	    0.90000;
	5972	 1	 24.72742	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5973	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01788	    0.00000	 220.0	 1	    1.13577	    0.90000;
	5974	 1	 124.8	 45.6	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5975	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01921	    0.00000	 380.0	 1	    1.13842	    0.90000;
	5976	 2	 9.610656	 20.2	 0.0	 0.0	 1	    1.01418	    0.00000	 220.0	 1	    1.12835	    0.90000;
	5977	 1	 1.301443	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5978	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5979	 2	 117.7305	 51.5	 0.0	 0.0	 1	    1.01083	    0.00000	 220.0	 1	    1.12166	    0.90000;
	5980	 1	 8.809768	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5981	 1	 109.1	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5982	 1	 52.35805	 7.4	 0.0	 0.0	 1	    1.00714	    0.00000	 220.0	 1	    1.11427	    0.90000;
	5983	 1	 16.51831	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5984	 1	 69.97758	 23.1	 0.0	 0.0	 1	    1.01758	    0.00000	 110.0	 1	    1.13516	    0.90000;
	5985	 1	 25.82864	 7.2	 0.0	 0.0	 1	    1.02305	    0.00000	 110.0	 1	    1.14610	    0.90000;
	5986	 2	 91.70167	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5987	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5988	 1	 174.0	 49.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5989	 1	 15.21687	 7.2	 0.0	 0.0	 1	    1.01025	    0.00000	 220.0	 1	    1.12051	    0.90000;
	5990	 1	 137.4	 81.7	 0.0	 0.0	 1	    1.00479	    0.00000	 380.0	 1	    1.10958	    0.90000;
	5991	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5992	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01524	    0.00000	 380.0	 1	    1.13049	    0.90000;
	5993	 2	 65.77292	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5994	 1	 483.8	 105.2	 0.0	 0.0	 1	    1.00000	    0.00000	 120.0	 1	    1.10000	    0.90000;
	5995	 1	 14.01554	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5996	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00849	    0.00000	 380.0	 1	    1.11698	    0.90000;
	5997	 2	 44.84972	 17.4	 0.0	 0.0	 1	    1.01920	    0.00000	 220.0	 1	    1.13839	    0.90000;
	5998	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02304	    0.00000	 220.0	 1	    1.14609	    0.90000;
	5999	 1	 13.31476	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6000	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00780	    0.00000	 380.0	 1	    1.11560	    0.90000;
	6001	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00535	    0.00000	 220.0	 1	    1.11070	    0.90000;
	6002	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01525	    0.00000	 220.0	 1	    1.13050	    0.90000;
	6003	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6004	 2	 0.4	 191.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6005	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00471	    0.00000	 220.0	 1	    1.10942	    0.90000;
	6006	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02579	    0.00000	 380.0	 1	    1.15159	    0.90000;
	6007	 1	 18.82087	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6008	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6009	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00561	    0.00000	 110.0	 1	    1.11122	    0.90000;
	6010	 1	 35.03885	 12.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6011	 2	 63.06993	 16.3	 0.0	 0.0	 1	    1.03450	    0.00000	 220.0	 1	    1.16899	    0.90000;
	6012	 1	 134.1	 24.8	 0.0	 0.0	 1	    1.03089	    0.00000	 220.0	 1	    1.16178	    0.90000;
	6013	 1	 57.56382	 21.1	 0.0	 0.0	 1	    1.01656	    0.00000	 220.0	 1	    1.13313	    0.90000;
	6014	 2	 13.8	 461.3	 0.0	 0.0	 1	    1.02125	    0.00000	 380.0	 1	    1.14251	    0.90000;
	6015	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00935	    0.00000	 220.0	 1	    1.11870	    0.90000;
	6016	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03705	    0.00000	 220.0	 1	    1.17410	    0.90000;
	6017	 1	 23.42597	 14.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6018	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02442	    0.00000	 220.0	 1	    1.14884	    0.90000;
	6019	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02335	    0.00000	 380.0	 1	    1.14669	    0.90000;
	6020	 2	 72.78069	 13.3	 0.0	 0.0	 1	    1.01658	    0.00000	 220.0	 1	    1.13316	    0.90000;
	6021	 1	 176.7	 41.2	 0.0	 0.0	 1	    1.02814	    0.00000	 220.0	 1	    1.15627	    0.90000;
	6022	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6023	 1	 4.805328	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6024	 1	 0.0	 0.0	 0.0	 14.06254	 1	    0.98232	    0.00000	 150.0	 1	    1.10000	    0.86463;
	6025	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6026	 1	 27.63063	 17.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6027	 2	 13.91543	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6028	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03502	    0.00000	 220.0	 1	    1.17005	    0.90000;
	6029	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01837	    0.00000	 220.0	 1	    1.13675	    0.90000;
	6030	 1	 15.31698	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6031	 1	 4.605106	 1.7	 0.0	 0.0	 1	    1.01264	    0.00000	 110.0	 1	    1.12528	    0.90000;
	6032	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01527	    0.00000	 220.0	 1	    1.13053	    0.90000;
	6033	 1	 0.0	 0.0	 0.063758	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6034	 2	 30.83419	 80.0	 0.0	 0.0	 1	    1.00886	    0.00000	 220.0	 1	    1.11772	    0.90000;
	6035	 1	 117.5	 40.0	 0.0	 0.0	 1	    1.00679	    0.00000	 220.0	 1	    1.11357	    0.90000;
	6036	 2	 0.0	 0.0	 0.0	 -18.4703	 1	    1.01622	    0.00000	 220.0	 1	    1.13244	    0.90000;
	6037	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00725	    0.00000	 380.0	 1	    1.11450	    0.90000;
	6038	 1	 29.73297	 11.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6039	 1	 199.6	 27.1	 0.0	 0.0	 1	    1.01580	    0.00000	 380.0	 1	    1.13160	    0.90000;
	6040	 1	 435.2	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6041	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6042	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02009	    0.00000	 150.0	 1	    1.14018	    0.90000;
	6043	 1	 74.5827	 16.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6044	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03226	    0.00000	 220.0	 1	    1.16451	    0.90000;
	6045	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.00913	    0.00000	 220.0	 1	    1.11827	    0.90000;
	6046	 1	 0.0	 0.0	 0.215849	 0.0	 1	    1.01086	    0.00000	 380.0	 1	    1.12172	    0.90000;
	6047	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01412	    0.00000	 380.0	 1	    1.12824	    0.90000;
	6048	 1	 261.7	 104.6	 0.0	 0.0	 1	    1.00727	    0.00000	 380.0	 1	    1.11453	    0.90000;
	6049	 1	 132.9	 13.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6050	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01384	    0.00000	 220.0	 1	    1.12768	    0.90000;
	6051	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03993	    0.00000	 220.0	 1	    1.17986	    0.90000;
	6052	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6053	 1	 20.0222	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6054	 1	 37.94207	 7.5	 0.0	 0.0	 1	    1.01932	    0.00000	 220.0	 1	    1.13864	    0.90000;
	6055	 1	 27.93097	 17.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00533	    0.00000	 220.0	 1	    1.11066	    0.90000;
	6057	 2	 -8.2091	 -2.4	 0.0	 0.0	 1	    1.00514	    0.00000	 220.0	 1	    1.11029	    0.90000;
	6058	 2	 0.0	 0.0	 0.0	 -116.149	 1	    1.03156	    0.00000	 380.0	 1	    1.16312	    0.90000;
	6059	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6060	 1	 66.67392	 27.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6061	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01497	    0.00000	 220.0	 1	    1.12993	    0.90000;
	6062	 1	 70.67836	 11.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6063	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6064	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01405	    0.00000	 380.0	 1	    1.12811	    0.90000;
	6065	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02968	    0.00000	 380.0	 1	    1.15937	    0.90000;
	6066	 2	 2.803108	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6067	 1	 0.0	 0.0	 0.0	 18.58871	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6068	 1	 42.54717	 12.5	 0.0	 0.0	 1	    1.03775	    0.00000	 220.0	 1	    1.17550	    0.90000;
	6069	 2	 30.43374	 7.8	 0.0	 0.0	 1	    1.02238	    0.00000	 220.0	 1	    1.14476	    0.90000;
	6070	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02842	    0.00000	 380.0	 1	    1.15685	    0.90000;
	6071	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6072	 1	 45.95095	 16.7	 0.0	 0.0	 1	    1.00253	    0.00000	 110.0	 1	    1.10505	    0.90000;
	6073	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6074	 1	 309.0	 74.5	 0.0	 0.0	 1	    1.02546	    0.00000	 220.0	 1	    1.15091	    0.90000;
	6075	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00433	    0.00000	 150.0	 1	    1.10865	    0.90000;
	6076	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6077	 1	 11.91321	 1.8	 0.0	 0.0	 1	    1.00988	    0.00000	 220.0	 1	    1.11977	    0.90000;
	6078	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6079	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02382	    0.00000	 380.0	 1	    1.14764	    0.90000;
	6080	 1	 0.0	 0.0	 0.175312	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6081	 1	 89.2	 42.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6082	 1	 0.100111	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6083	 1	 119.5	 44.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6084	 2	 264.9	 46.8	 0.0	 0.0	 1	    1.01469	    0.00000	 220.0	 1	    1.12939	    0.90000;
	6085	 1	 33.23685	 11.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6086	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02867	    0.00000	 380.0	 1	    1.15734	    0.90000;
	6087	 1	 12.11343	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6088	 1	 7.608436	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6089	 1	 72.48036	 44.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6090	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02212	    0.00000	 220.0	 1	    1.14423	    0.90000;
	6091	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6092	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01781	    0.00000	 220.0	 1	    1.13562	    0.90000;
	6093	 1	 -20.8231	 -8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6094	 1	 139.8	 -23.6	 0.0	 0.0	 1	    1.00683	    0.00000	 220.0	 1	    1.11366	    0.90000;
	6095	 1	 61.06771	 11.1	 0.0	 0.0	 1	    1.00413	    0.00000	 220.0	 1	    1.10826	    0.90000;
	6096	 1	 -1.60178	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6097	 1	 32.53607	 11.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6098	 1	 18.01998	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6099	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01019	    0.00000	 220.0	 1	    1.12039	    0.90000;
	6100	 1	 151.5596	 -314.2	 0.0	 0.0	 1	    1.01993	    0.00000	 380.0	 1	    1.13986	    0.90000;
	6101	 1	 487.2	 116.7	 0.0	 0.0	 1	    1.01393	    0.00000	 380.0	 1	    1.12786	    0.90000;
	6102	 1	 18.12009	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6104	 1	 0.0	 0.0	 0.296959	 0.0	 1	    1.02131	    0.00000	 380.0	 1	    1.14261	    0.90000;
	6105	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02074	    0.00000	 220.0	 1	    1.14148	    0.90000;
	6106	 1	 -6.70744	 -2.4	 0.0	 0.0	 1	    1.02171	    0.00000	 110.0	 1	    1.14342	    0.90000;
	6107	 2	 39.24351	 11.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6108	 2	 279.5	 104.7	 0.0	 0.0	 1	    1.02074	    0.00000	 220.0	 1	    1.14147	    0.90000;
	6109	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01394	    0.00000	 380.0	 1	    1.12787	    0.90000;
	6110	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02894	    0.00000	 380.0	 1	    1.15787	    0.90000;
	6111	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01828	    0.00000	 220.0	 1	    1.13656	    0.90000;
	6112	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01919	    0.00000	 380.0	 1	    1.13839	    0.90000;
	6113	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01950	    0.00000	 110.0	 1	    1.13899	    0.90000;
	6114	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04157	    0.00000	 380.0	 1	    1.18314	    0.90000;
	6115	 1	 137.4	 23.9	 0.0	 0.0	 1	    1.02742	    0.00000	 220.0	 1	    1.15485	    0.90000;
	6116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03269	    0.00000	 380.0	 1	    1.16538	    0.90000;
	6117	 2	 248.5	 97.9	 0.0	 0.0	 1	    1.02264	    0.00000	 220.0	 1	    1.14528	    0.90000;
	6118	 1	 25.62842	 51.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01922	    0.00000	 150.0	 1	    1.13844	    0.90000;
	6120	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01882	    0.00000	 220.0	 1	    1.13765	    0.90000;
	6121	 1	 5.906549	 1.7	 0.0	 0.0	 1	    1.00704	    0.00000	 220.0	 1	    1.11408	    0.90000;
	6122	 1	 267.1	 57.4	 0.0	 0.0	 1	    1.00580	    0.00000	 380.0	 1	    1.11161	    0.90000;
	6123	 1	 6.807548	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6124	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6125	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02628	    0.00000	 380.0	 1	    1.15257	    0.90000;
	6126	 1	 18.42042	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6127	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00529	    0.00000	 220.0	 1	    1.11058	    0.90000;
	6128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01850	    0.00000	 380.0	 1	    1.13700	    0.90000;
	6129	 1	 53.65949	 19.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01084	    0.00000	 380.0	 1	    1.12168	    0.90000;
	6131	 1	 4.204662	 1.2	 0.0	 0.0	 1	    1.01842	    0.00000	 380.0	 1	    1.13685	    0.90000;
	6132	 2	 25.72853	 9.3	 0.0	 0.0	 1	    1.00364	    0.00000	 110.0	 1	    1.10728	    0.90000;
	6133	 1	 207.2	 28.6	 0.0	 0.0	 1	    1.01236	    0.00000	 220.0	 1	    1.12472	    0.90000;
	6134	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03098	    0.00000	 220.0	 1	    1.16197	    0.90000;
	6135	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6136	 1	 12.61399	 7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6137	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00579	    0.00000	 380.0	 1	    1.11158	    0.90000;
	6138	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99372	    0.00000	 150.0	 1	    1.10000	    0.88745;
	6139	 1	 27.53052	 9.9	 0.0	 0.0	 1	    1.01673	    0.00000	 380.0	 1	    1.13346	    0.90000;
	6140	 1	 99.0	 23.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6141	 1	 60.26682	 21.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6142	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00712	    0.00000	 380.0	 1	    1.11423	    0.90000;
	6143	 1	 61.36804	 23.2	 0.0	 0.0	 1	    1.03097	    0.00000	 220.0	 1	    1.16193	    0.90000;
	6144	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01945	    0.00000	 220.0	 1	    1.13890	    0.90000;
	6145	 1	 34.13785	 21.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6146	 1	 283.2	 101.8	 0.21599	 0.0	 1	    1.00445	    0.00000	 380.0	 1	    1.10889	    0.90000;
	6147	 1	 139.9	 -26.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6148	 1	 -1377.93	 -320.0	 0.0	 20.0	 1	    1.02439	    0.00000	 380.0	 1	    1.14878	    0.90000;
	6149	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01540	    0.00000	 380.0	 1	    1.13079	    0.90000;
	6150	 1	 74.6828	 46.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6151	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01193	    0.00000	 380.0	 1	    1.12386	    0.90000;
	6152	 1	 140.1	 25.5	 0.0	 0.0	 1	    1.00620	    0.00000	 220.0	 1	    1.11240	    0.90000;
	6153	 1	 11.91321	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02293	    0.00000	 220.0	 1	    1.14586	    0.90000;
	6155	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6156	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.00324	    0.00000	 220.0	 1	    1.10649	    0.90000;
	6157	 1	 15.21687	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6158	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6159	 1	 154.9	 25.0	 0.0	 0.0	 1	    1.02335	    0.00000	 380.0	 1	    1.14671	    0.90000;
	6160	 1	 46.35139	 9.1	 0.0	 0.0	 1	    1.01608	    0.00000	 220.0	 1	    1.13217	    0.90000;
	6161	 1	 43.34806	 16.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6162	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02218	    0.00000	 220.0	 1	    1.14436	    0.90000;
	6163	 1	 79.48813	 17.0	 0.0	 0.0	 1	    1.03777	    0.00000	 220.0	 1	    1.17554	    0.90000;
	6164	 1	 -73.982	 -29.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6165	 1	 42.24684	 5.9	 0.0	 0.0	 1	    1.00737	    0.00000	 220.0	 1	    1.11474	    0.90000;
	6166	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01797	    0.00000	 380.0	 1	    1.13595	    0.90000;
	6167	 1	 253.4	 81.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6168	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01258	    0.00000	 110.0	 1	    1.12515	    0.90000;
	6169	 1	 4.204662	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6170	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02006	    0.00000	 220.0	 1	    1.14013	    0.90000;
	6171	 1	 55.76183	 19.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6172	 1	 0.0	 0.0	 0.0	 15.18218	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6173	 2	 7.308103	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6174	 2	 140.4	 18.1	 0.0	 0.0	 1	    1.01108	    0.00000	 220.0	 1	    1.12217	    0.90000;
	6175	 2	 30.73408	 6.3	 0.0	 0.0	 1	    1.01553	    0.00000	 220.0	 1	    1.13105	    0.90000;
	6176	 2	 270.3	 86.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6177	 1	 76.78513	 30.7	 0.0	 0.0	 1	    1.01932	    0.00000	 220.0	 1	    1.13864	    0.90000;
	6178	 1	 20.0222	 10.0	 0.0	 0.0	 1	    1.02082	    0.00000	 220.0	 1	    1.14164	    0.90000;
	6179	 2	 0.5	 159.8	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6180	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01326	    0.00000	 380.0	 1	    1.12653	    0.90000;
	6181	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6182	 1	 3.403774	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6183	 2	 59.46593	 21.4	 0.0	 0.0	 1	    1.01843	    0.00000	 220.0	 1	    1.13686	    0.90000;
	6184	 1	 106.0	 24.6	 0.0	 0.0	 1	    1.00450	    0.00000	 220.0	 1	    1.10901	    0.90000;
	6185	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00601	    0.00000	 220.0	 1	    1.11202	    0.90000;
	6186	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6187	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01847	    0.00000	 220.0	 1	    1.13693	    0.90000;
	6188	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03195	    0.00000	 380.0	 1	    1.16389	    0.90000;
	6189	 1	 36.84085	 14.4	 0.0	 0.0	 1	    1.02529	    0.00000	 150.0	 1	    1.15059	    0.90000;
	6190	 1	 68.77625	 28.2	 0.0	 0.0	 1	    1.01694	    0.00000	 150.0	 1	    1.13387	    0.90000;
	6191	 1	 211.1	 93.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6192	 1	 326.9	 -82.3	 0.0	 0.0	 1	    1.01663	    0.00000	 150.0	 1	    1.13327	    0.90000;
	6193	 1	 55.46149	 18.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6194	 1	 58.16449	 16.5	 0.0	 0.0	 1	    1.01227	    0.00000	 220.0	 1	    1.12455	    0.90000;
	6195	 2	 196.4	 42.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6196	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6197	 2	 127.1	 44.7	 0.0	 0.0	 1	    1.00976	    0.00000	 220.0	 1	    1.11953	    0.90000;
	6198	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01555	    0.00000	 380.0	 1	    1.13109	    0.90000;
	6199	 1	 0.0	 0.0	 0.198044	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6200	 1	 3.804218	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6201	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00337	    0.00000	 220.0	 1	    1.10674	    0.90000;
	6202	 1	 184.8822	 -21.1	 0.0	 0.0	 1	    1.00692	    0.00000	 220.0	 1	    1.11383	    0.90000;
	6203	 1	 47.75294	 11.0	 0.0	 0.0	 1	    1.02998	    0.00000	 220.0	 1	    1.15996	    0.90000;
	6204	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02455	    0.00000	 150.0	 1	    1.14911	    0.90000;
	6205	 2	 89.49923	 21.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6206	 1	 122.8	 20.8	 0.0	 0.0	 1	    1.00701	    0.00000	 220.0	 1	    1.11402	    0.90000;
	6207	 1	 98.0	 21.7	 0.0	 0.0	 1	    1.02352	    0.00000	 220.0	 1	    1.14703	    0.90000;
	6208	 2	 29.03219	 11.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6209	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01780	    0.00000	 220.0	 1	    1.13560	    0.90000;
	6210	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01692	    0.00000	 220.0	 1	    1.13384	    0.90000;
	6211	 1	 44.34917	 19.3	 0.0	 0.0	 1	    1.01629	    0.00000	 220.0	 1	    1.13258	    0.90000;
	6212	 2	 0.300333	 0.5	 0.530634	 0.0	 1	    1.00357	    0.00000	 380.0	 1	    1.10714	    0.90000;
	6213	 1	 50.45594	 36.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6214	 1	 2.502775	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6215	 2	 372.4	 121.1	 0.0	 0.0	 1	    1.00283	    0.00000	 220.0	 1	    1.10565	    0.90000;
	6216	 1	 71.0788	 44.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6217	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03430	    0.00000	 220.0	 1	    1.16860	    0.90000;
	6218	 1	 -16.8186	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6219	 1	 16.51831	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6220	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01617	    0.00000	 380.0	 1	    1.13235	    0.90000;
	6221	 1	 0.0	 0.0	 0.0	 10.99016	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6222	 1	 0.0	 8.5	 0.0	 0.0	 1	    1.03042	    0.00000	 150.0	 1	    1.16084	    0.90000;
	6223	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6224	 2	 118.4	 18.6	 0.0	 0.0	 1	    1.02111	    0.00000	 220.0	 1	    1.14222	    0.90000;
	6225	 1	 -42.2468	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.20000	    0.80000;
	6226	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01143	    0.00000	 220.0	 1	    1.12286	    0.90000;
	6227	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00796	    0.00000	 380.0	 1	    1.11593	    0.90000;
	6228	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6229	 1	 6.407104	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6230	 1	 1.201332	 0.4	 0.0	 0.0	 1	    1.02851	    0.00000	 110.0	 1	    1.15702	    0.90000;
	6231	 1	 54.9	 -96.8	 0.0	 0.0	 1	    1.00532	    0.00000	 220.0	 1	    1.11065	    0.90000;
	6232	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6233	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6234	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6235	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6236	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04011	    0.00000	 380.0	 1	    1.18022	    0.90000;
	6237	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6238	 1	 1.801998	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6239	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02055	    0.00000	 380.0	 1	    1.14109	    0.90000;
	6240	 1	 25.22797	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6241	 1	 199.6	 24.4	 0.0	 0.0	 1	    1.00289	    0.00000	 220.0	 1	    1.10578	    0.90000;
	6242	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01472	    0.00000	 220.0	 1	    1.12944	    0.90000;
	6243	 1	 11.41265	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6244	 1	 67.47482	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6245	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02287	    0.00000	 380.0	 1	    1.14574	    0.90000;
	6246	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01549	    0.00000	 380.0	 1	    1.13098	    0.90000;
	6247	 1	 25.72853	 15.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6248	 1	 119.3	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6249	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02321	    0.00000	 220.0	 1	    1.14642	    0.90000;
	6250	 2	 109.0	 20.4	 0.0	 0.0	 1	    1.01966	    0.00000	 220.0	 1	    1.13931	    0.90000;
	6251	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01607	    0.00000	 380.0	 1	    1.13213	    0.90000;
	6252	 2	 156.7	 36.8	 0.0	 0.0	 1	    1.02410	    0.00000	 220.0	 1	    1.14820	    0.90000;
	6253	 1	 -53.0588	 -100.0	 0.0	 0.0	 1	    1.02844	    0.00000	 220.0	 1	    1.15688	    0.90000;
	6254	 1	 -1235.46	 -43.0	 0.0	 0.0	 1	    1.00686	    0.00000	 380.0	 1	    1.11372	    0.90000;
	6255	 1	 182.5	 47.0	 0.0	 0.0	 1	    1.01378	    0.00000	 380.0	 1	    1.12756	    0.90000;
	6256	 1	 8.309213	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6257	 1	 176.8	 39.4	 0.0	 0.0	 1	    1.02489	    0.00000	 380.0	 1	    1.14979	    0.90000;
	6258	 1	 31.03441	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6259	 1	 8.00888	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6260	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00755	    0.00000	 380.0	 1	    1.11510	    0.90000;
	6261	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01094	    0.00000	 380.0	 1	    1.12188	    0.90000;
	6262	 1	 0.300333	 -9.0	 0.0	 0.0	 1	    1.01975	    0.00000	 220.0	 1	    1.13951	    0.90000;
	6263	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6265	 1	 115.2	 55.1	 0.0	 0.0	 1	    1.00317	    0.00000	 380.0	 1	    1.10634	    0.90000;
	6266	 2	 214.8	 42.7	 0.0	 0.0	 1	    1.01792	    0.00000	 380.0	 1	    1.13585	    0.90000;
	6267	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02268	    0.00000	 220.0	 1	    1.14536	    0.90000;
	6268	 1	 122.5	 8.7	 0.0	 0.0	 1	    1.01943	    0.00000	 220.0	 1	    1.13886	    0.90000;
	6269	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00890	    0.00000	 380.0	 1	    1.11780	    0.90000;
	6270	 1	 18.72076	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6272	 1	 18.41154	 41.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6273	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00316	    0.00000	 380.0	 1	    1.10633	    0.90000;
	6274	 1	 11.71299	 3.7	 0.0	 0.0	 1	    1.01189	    0.00000	 110.0	 1	    1.12377	    0.90000;
	6275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01020	    0.00000	 150.0	 1	    1.12040	    0.90000;
	6276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02673	    0.00000	 380.0	 1	    1.15345	    0.90000;
	6277	 1	 6.707437	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6278	 1	 21.62398	 9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6279	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01824	    0.00000	 380.0	 1	    1.13647	    0.90000;
	6280	 1	 113.6	 44.7	 0.0	 0.0	 1	    1.00840	    0.00000	 220.0	 1	    1.11681	    0.90000;
	6281	 1	 33.33696	 8.6	 0.0	 0.0	 1	    1.02570	    0.00000	 110.0	 1	    1.15139	    0.90000;
	6282	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6283	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6284	 1	 124.5	 101.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6285	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6286	 2	 0.1	 0.1	 0.0	 0.0	 1	    1.02053	    0.00000	 380.0	 1	    1.14106	    0.90000;
	6287	 1	 117.0	 20.4	 0.0	 0.0	 1	    1.00602	    0.00000	 220.0	 1	    1.11203	    0.90000;
	6288	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00500	    0.00000	 110.0	 1	    1.11001	    0.90000;
	6289	 2	 76.38469	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6290	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6291	 2	 160.4	 63.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6292	 2	 197.7433	 31.6	 0.0	 0.0	 1	    1.01394	    0.00000	 220.0	 1	    1.12789	    0.90000;
	6293	 1	 3.203552	 1.1	 0.0	 0.0	 1	    1.00567	    0.00000	 110.0	 1	    1.11133	    0.90000;
	6294	 1	 135.0	 25.7	 0.0	 0.0	 1	    1.01485	    0.00000	 380.0	 1	    1.12970	    0.90000;
	6295	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03342	    0.00000	 220.0	 1	    1.16684	    0.90000;
	6296	 1	 21.62398	 7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6297	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6298	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6299	 1	 0.200222	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6300	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01629	    0.00000	 220.0	 1	    1.13259	    0.90000;
	6301	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6302	 1	 35.43929	 5.3	 0.0	 0.0	 1	    1.00557	    0.00000	 220.0	 1	    1.11115	    0.90000;
	6303	 1	 180.9	 33.2	 0.0	 0.0	 1	    1.03026	    0.00000	 220.0	 1	    1.16052	    0.90000;
	6304	 1	 61.76849	 10.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6305	 1	 18.12009	 10.0	 0.0	 0.0	 1	    1.01860	    0.00000	 220.0	 1	    1.13721	    0.90000;
	6306	 1	 0.0	 0.0	 0.0	 13.90073	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6307	 1	 86.4959	 29.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6308	 2	 28.53163	 17.7	 0.0	 0.0	 1	    1.04238	    0.00000	 150.0	 1	    1.18477	    0.90000;
	6309	 1	 20.0222	 9.0	 0.0	 0.0	 1	    1.02080	    0.00000	 220.0	 1	    1.14161	    0.90000;
	6310	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01510	    0.00000	 220.0	 1	    1.13020	    0.90000;
	6311	 1	 389.8	 -68.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6312	 1	 56.56271	 18.4	 0.0	 0.0	 1	    1.02242	    0.00000	 220.0	 1	    1.14483	    0.90000;
	6313	 1	 0.0	 0.0	 0.555664	 0.0	 1	    1.00684	    0.00000	 380.0	 1	    1.11368	    0.90000;
	6314	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03239	    0.00000	 220.0	 1	    1.16479	    0.90000;
	6315	 1	 120.1	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6316	 1	 125.0	 107.2	 0.216876	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6317	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00927	    0.00000	 220.0	 1	    1.11854	    0.90000;
	6318	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6319	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02187	    0.00000	 220.0	 1	    1.14373	    0.90000;
	6320	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01698	    0.00000	 380.0	 1	    1.13396	    0.90000;
	6321	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01163	    0.00000	 220.0	 1	    1.12325	    0.90000;
	6322	 2	 95.606	 7.6	 0.0	 0.0	 1	    1.02328	    0.00000	 220.0	 1	    1.14656	    0.90000;
	6323	 1	 92.1	 43.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6324	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6325	 1	 0.600666	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6326	 1	 36.03996	 22.3	 0.0	 0.0	 1	    0.99563	    0.00000	 150.0	 1	    1.10000	    0.89125;
	6327	 1	 53.05883	 75.8	 0.0	 0.0	 1	    1.00624	    0.00000	 380.0	 1	    1.11248	    0.90000;
	6328	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01441	    0.00000	 220.0	 1	    1.12881	    0.90000;
	6329	 1	 195.5	 67.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6330	 2	 89.09879	 20.2	 0.0	 0.0	 1	    1.01937	    0.00000	 220.0	 1	    1.13874	    0.90000;
	6331	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6332	 1	 0.0	 0.0	 0.0	 27.06707	 1	    0.96110	    0.00000	 150.0	 1	    1.10000	    0.82220;
	6333	 1	 125.2	 1.2	 0.0	 0.0	 1	    1.00708	    0.00000	 220.0	 1	    1.11416	    0.90000;
	6334	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6335	 1	 112.1	 36.3	 0.0	 0.0	 1	    1.02177	    0.00000	 150.0	 1	    1.14354	    0.90000;
	6336	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6337	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03136	    0.00000	 220.0	 1	    1.16272	    0.90000;
	6338	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01692	    0.00000	 220.0	 1	    1.13385	    0.90000;
	6339	 2	 4.304773	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6340	 1	 89.69945	 17.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6341	 2	 5.405994	 67.5	 0.0	 0.0	 1	    1.00603	    0.00000	 380.0	 1	    1.11207	    0.90000;
	6342	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00442	    0.00000	 220.0	 1	    1.10884	    0.90000;
	6343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6344	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00362	    0.00000	 220.0	 1	    1.10725	    0.90000;
	6345	 1	 190.3	 84.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6346	 1	 30.0333	 8.6	 0.0	 0.0	 1	    1.00602	    0.00000	 150.0	 1	    1.11204	    0.90000;
	6347	 2	 91.9	 41.9	 0.266883	 0.0	 1	    1.01491	    0.00000	 380.0	 1	    1.12982	    0.90000;
	6348	 1	 2.302553	 0.8	 0.0	 0.0	 1	    1.01384	    0.00000	 110.0	 1	    1.12768	    0.90000;
	6349	 1	 46.35139	 28.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6350	 1	 51.15672	 12.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6351	 1	 2.903219	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6352	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01381	    0.00000	 380.0	 1	    1.12761	    0.90000;
	6353	 1	 10.0111	 2.0	 0.0	 0.0	 1	    1.01458	    0.00000	 150.0	 1	    1.12917	    0.90000;
	6354	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6355	 1	 9.310323	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6356	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00713	    0.00000	 220.0	 1	    1.11426	    0.90000;
	6357	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6358	 1	 84.59379	 21.7	 0.0	 0.0	 1	    1.00412	    0.00000	 110.0	 1	    1.10825	    0.90000;
	6359	 1	 -15.1168	 5.0	 0.0	 0.0	 1	    1.00450	    0.00000	 150.0	 1	    1.10899	    0.90000;
	6360	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01766	    0.00000	 220.0	 1	    1.13533	    0.90000;
	6361	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00409	    0.00000	 150.0	 1	    1.10819	    0.90000;
	6362	 1	 190.0	 72.7	 0.0	 0.0	 1	    1.01773	    0.00000	 220.0	 1	    1.13545	    0.90000;
	6363	 1	 0.0	 0.0	 0.136054	 0.0	 1	    1.01475	    0.00000	 380.0	 1	    1.12950	    0.90000;
	6364	 1	 53.25905	 29.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6365	 1	 52.55827	 12.8	 0.0	 0.0	 1	    1.01399	    0.00000	 220.0	 1	    1.12797	    0.90000;
	6366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6367	 1	 226.8	 53.3	 0.0	 0.0	 1	    1.01082	    0.00000	 220.0	 1	    1.12163	    0.90000;
	6368	 1	 14.91654	 5.4	 0.0	 0.0	 1	    1.00496	    0.00000	 110.0	 1	    1.10992	    0.90000;
	6369	 1	 0.0	 0.0	 0.0	 15.27401	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6370	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6371	 2	 235.8	 23.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6372	 2	 285.7	 31.9	 0.0	 0.0	 1	    1.01016	    0.00000	 220.0	 1	    1.12033	    0.90000;
	6373	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6374	 2	 1.7	 145.9	 0.0	 0.0	 1	    1.02537	    0.00000	 380.0	 1	    1.15074	    0.90000;
	6375	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02179	    0.00000	 220.0	 1	    1.14358	    0.90000;
	6376	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01005	    0.00000	 380.0	 1	    1.12009	    0.90000;
	6377	 2	 16.71854	 6.4	 0.0	 0.0	 1	    1.00823	    0.00000	 110.0	 1	    1.11647	    0.90000;
	6378	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6379	 1	 0.0	 0.0	 0.368139	 296.694	 1	    1.00697	    0.00000	 380.0	 1	    1.11395	    0.90000;
	6380	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01630	    0.00000	 220.0	 1	    1.13260	    0.90000;
	6381	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6382	 1	 19.52164	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6383	 1	 324.9	 37.3	 0.0	 0.0	 1	    1.01969	    0.00000	 380.0	 1	    1.13937	    0.90000;
	6384	 1	 21.8242	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6385	 1	 -175.795	 -19.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6386	 2	 225.0	 92.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6387	 1	 6.907659	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6388	 1	 120.6	 35.1	 0.0	 0.0	 1	    1.01647	    0.00000	 380.0	 1	    1.13294	    0.90000;
	6389	 1	 1.902109	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6390	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00775	    0.00000	 150.0	 1	    1.11550	    0.90000;
	6391	 1	 339.9	 70.5	 0.0	 0.0	 1	    1.02691	    0.00000	 220.0	 1	    1.15382	    0.90000;
	6392	 1	 12.91432	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6393	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00474	    0.00000	 220.0	 1	    1.10948	    0.90000;
	6394	 1	 120.0	 26.0	 0.0	 0.0	 1	    1.02058	    0.00000	 220.0	 1	    1.14116	    0.90000;
	6395	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00460	    0.00000	 380.0	 1	    1.10920	    0.90000;
	6396	 1	 111.0	 36.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6397	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02354	    0.00000	 380.0	 1	    1.14708	    0.90000;
	6398	 1	 129.7	 27.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6399	 1	 125.2	 8.5	 0.0	 0.0	 1	    1.00707	    0.00000	 220.0	 1	    1.11414	    0.90000;
	6400	 2	 41.94651	 14.8	 0.0	 0.0	 1	    1.00837	    0.00000	 380.0	 1	    1.11673	    0.90000;
	6401	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6402	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00520	    0.00000	 220.0	 1	    1.11040	    0.90000;
	6403	 1	 28.93208	 8.3	 0.0	 0.0	 1	    1.00750	    0.00000	 150.0	 1	    1.11499	    0.90000;
	6404	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6405	 1	 -20.1223	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6406	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02374	    0.00000	 380.0	 1	    1.14748	    0.90000;
	6407	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6408	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6409	 1	 41.24573	 48.4	 0.0	 0.0	 1	    1.02806	    0.00000	 220.0	 1	    1.15612	    0.90000;
	6410	 1	 6.306993	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6411	 1	 2.803108	 1.0	 0.0	 0.0	 1	    1.00878	    0.00000	 110.0	 1	    1.11756	    0.90000;
	6412	 2	 260.8	 43.9	 0.0	 0.0	 1	    1.01611	    0.00000	 220.0	 1	    1.13222	    0.90000;
	6413	 1	 142.9	 25.8	 0.0	 0.0	 1	    1.01611	    0.00000	 220.0	 1	    1.13221	    0.90000;
	6414	 1	 80.1889	 23.6	 0.0	 0.0	 1	    1.00386	    0.00000	 220.0	 1	    1.10773	    0.90000;
	6415	 1	 62.66948	 14.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6416	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02459	    0.00000	 150.0	 1	    1.14917	    0.90000;
	6417	 1	 15.71743	 9.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6418	 2	 62.16893	 16.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6419	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00473	    0.00000	 220.0	 1	    1.10946	    0.90000;
	6420	 1	 18.82087	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6421	 1	 -13.8153	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6422	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01820	    0.00000	 380.0	 1	    1.13639	    0.90000;
	6423	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6424	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01929	    0.00000	 380.0	 1	    1.13857	    0.90000;
	6425	 1	 152.2	 53.2	 0.0	 0.0	 1	    1.01250	    0.00000	 380.0	 1	    1.12500	    0.90000;
	6426	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6427	 1	 10.81199	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6428	 1	 20.22242	 7.3	 0.0	 0.0	 1	    1.00381	    0.00000	 110.0	 1	    1.10763	    0.90000;
	6429	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6430	 2	 220.6	 70.7	 0.0	 0.0	 1	    1.01937	    0.00000	 380.0	 1	    1.13873	    0.90000;
	6431	 1	 82.89191	 41.3	 0.0	 0.0	 1	    1.02479	    0.00000	 150.0	 1	    1.14959	    0.90000;
	6432	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6433	 1	 44.6495	 8.8	 0.0	 0.0	 1	    1.01663	    0.00000	 220.0	 1	    1.13327	    0.90000;
	6434	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01483	    0.00000	 380.0	 1	    1.12965	    0.90000;
	6435	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6436	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03122	    0.00000	 380.0	 1	    1.16245	    0.90000;
	6437	 1	 109.5	 33.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6438	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02361	    0.00000	 220.0	 1	    1.14722	    0.90000;
	6439	 1	 102.0	 26.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6440	 1	 35.93985	 22.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6441	 1	 4.605106	 1.7	 0.0	 0.0	 1	    1.02252	    0.00000	 110.0	 1	    1.14505	    0.90000;
	6442	 1	 0.0	 0.0	 0.168227	 0.0	 1	    1.01696	    0.00000	 380.0	 1	    1.13393	    0.90000;
	6443	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00798	    0.00000	 220.0	 1	    1.11595	    0.90000;
	6444	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6445	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02497	    0.00000	 380.0	 1	    1.14993	    0.90000;
	6446	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00737	    0.00000	 150.0	 1	    1.11475	    0.90000;
	6447	 2	 316.0	 102.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6448	 1	 282.5	 56.2	 0.0	 0.0	 1	    1.00546	    0.00000	 380.0	 1	    1.11093	    0.90000;
	6449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6450	 1	 0.0	 0.0	 0.0	 -48.701	 1	    1.01110	    0.00000	 220.0	 1	    1.12221	    0.90000;
	6451	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01145	    0.00000	 110.0	 1	    1.12291	    0.90000;
	6452	 1	 0.100111	 0.0	 0.0	 0.0	 1	    1.00996	    0.00000	 110.0	 1	    1.11991	    0.90000;
	6453	 2	 301.6	 87.4	 0.0	 0.0	 1	    1.00381	    0.00000	 380.0	 1	    1.10762	    0.90000;
	6454	 2	 23.32586	 4.0	 0.0	 0.0	 1	    1.01629	    0.00000	 220.0	 1	    1.13259	    0.90000;
	6455	 1	 117.5	 91.0	 0.373248	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6456	 1	 0.0	 -0.6	 0.0	 0.0	 1	    1.00646	    0.00000	 110.0	 1	    1.11292	    0.90000;
	6457	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02163	    0.00000	 380.0	 1	    1.14326	    0.90000;
	6458	 1	 149.5267	 34.9	 0.0	 0.0	 1	    1.01425	    0.00000	 220.0	 1	    1.12849	    0.90000;
	6459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02743	    0.00000	 220.0	 1	    1.15487	    0.90000;
	6460	 1	 29.43263	 10.7	 0.0	 0.0	 1	    1.02226	    0.00000	 110.0	 1	    1.14452	    0.90000;
	6461	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03222	    0.00000	 380.0	 1	    1.16444	    0.90000;
	6462	 1	 38.34251	 12.5	 0.0	 0.0	 1	    1.01900	    0.00000	 220.0	 1	    1.13800	    0.90000;
	6463	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04336	    0.00000	 220.0	 1	    1.18672	    0.90000;
	6464	 1	 0.100111	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6465	 1	 5.706326	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6466	 1	 231.2	 103.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6467	 1	 33.33696	 5.0	 0.0	 0.0	 1	    1.02134	    0.00000	 220.0	 1	    1.14269	    0.90000;
	6468	 1	 19.32142	 7.0	 0.0	 0.0	 1	    1.00611	    0.00000	 110.0	 1	    1.11222	    0.90000;
	6469	 2	 15.01665	 5.6	 0.0	 0.0	 1	    1.00753	    0.00000	 110.0	 1	    1.11506	    0.90000;
	6470	 1	 222.0	 90.5	 0.0	 0.0	 1	    1.00846	    0.00000	 220.0	 1	    1.11691	    0.90000;
	6471	 1	 102.3	 19.0	 0.0	 0.0	 1	    1.01756	    0.00000	 220.0	 1	    1.13513	    0.90000;
	6472	 1	 0.0	 0.0	 0.314024	 0.0	 1	    1.02003	    0.00000	 380.0	 1	    1.14006	    0.90000;
	6473	 1	 29.23241	 9.4	 0.0	 0.0	 1	    1.00462	    0.00000	 110.0	 1	    1.10924	    0.90000;
	6474	 2	 244.0	 97.8	 0.0	 0.0	 1	    1.01702	    0.00000	 380.0	 1	    1.13405	    0.90000;
	6475	 1	 150.2	 51.6	 0.0	 0.0	 1	    1.01876	    0.00000	 150.0	 1	    1.13752	    0.90000;
	6476	 1	 99.4	 22.2	 0.0	 0.0	 1	    1.00515	    0.00000	 220.0	 1	    1.11030	    0.90000;
	6477	 1	 64.2	 26.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6478	 1	 32.33585	 16.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6480	 2	 14.71632	 1.6	 0.0	 0.0	 1	    1.00632	    0.00000	 220.0	 1	    1.11265	    0.90000;
	6481	 1	 46.75183	 24.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6482	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01558	    0.00000	 380.0	 1	    1.13116	    0.90000;
	6483	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03269	    0.00000	 220.0	 1	    1.16539	    0.90000;
	6484	 1	 6.00666	 2.0	 0.0	 0.0	 1	    1.00653	    0.00000	 110.0	 1	    1.11307	    0.90000;
	6485	 1	 26.02886	 -14.1	 0.0	 0.0	 1	    1.00813	    0.00000	 110.0	 1	    1.11626	    0.90000;
	6486	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6487	 1	 89.79956	 19.7	 0.0	 0.0	 1	    1.01734	    0.00000	 120.0	 1	    1.13469	    0.90000;
	6488	 2	 22.22464	 5.6	 0.0	 0.0	 1	    1.02016	    0.00000	 380.0	 1	    1.14032	    0.90000;
	6489	 1	 73.58158	 26.8	 0.0	 0.0	 1	    1.01873	    0.00000	 220.0	 1	    1.13746	    0.90000;
	6490	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6491	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02497	    0.00000	 150.0	 1	    1.14993	    0.90000;
	6492	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02602	    0.00000	 380.0	 1	    1.15204	    0.90000;
	6493	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00629	    0.00000	 380.0	 1	    1.11258	    0.90000;
	6494	 1	 122.8	 20.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6495	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01619	    0.00000	 220.0	 1	    1.13239	    0.90000;
	6496	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01728	    0.00000	 220.0	 1	    1.13456	    0.90000;
	6497	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01373	    0.00000	 380.0	 1	    1.12746	    0.90000;
	6498	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03710	    0.00000	 220.0	 1	    1.17420	    0.90000;
	6499	 2	 34.73852	 9.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6500	 1	 64.47148	 40.0	 0.0	 0.0	 1	    1.01552	    0.00000	 220.0	 1	    1.13103	    0.90000;
	6501	 1	 -20.8231	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6502	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00930	    0.00000	 380.0	 1	    1.11859	    0.90000;
	6503	 1	 -1083.9	 -433.7	 0.0	 0.0	 1	    1.02594	    0.00000	 380.0	 1	    1.15189	    0.90000;
	6504	 1	 0.100111	 -9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6505	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6506	 2	 151.1	 31.8	 0.0	 0.0	 1	    1.01701	    0.00000	 220.0	 1	    1.13403	    0.90000;
	6507	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00817	    0.00000	 380.0	 1	    1.11634	    0.90000;
	6508	 1	 10.21132	 3.3	 0.0	 0.0	 1	    1.00345	    0.00000	 110.0	 1	    1.10690	    0.90000;
	6509	 1	 17.61954	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6510	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01515	    0.00000	 220.0	 1	    1.13030	    0.90000;
	6511	 1	 0.0	 0.0	 0.195349	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6512	 1	 1.00111	 0.2	 0.0	 0.0	 1	    1.00775	    0.00000	 110.0	 1	    1.11549	    0.90000;
	6513	 1	 290.8	 30.5	 0.0	 0.0	 1	    1.00494	    0.00000	 380.0	 1	    1.10988	    0.90000;
	6514	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04369	    0.00000	 380.0	 1	    1.18739	    0.90000;
	6515	 1	 -18.5205	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6516	 2	 19.62176	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6517	 1	 7.207992	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6518	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01466	    0.00000	 220.0	 1	    1.12932	    0.90000;
	6519	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6520	 1	 55.46149	 15.7	 0.0	 0.0	 1	    1.00708	    0.00000	 220.0	 1	    1.11415	    0.90000;
	6521	 1	 0.0	 0.0	 0.0	 21.91948	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6522	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6523	 1	 456.6	 227.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6524	 1	 99.9	 19.9	 0.0	 0.0	 1	    1.01296	    0.00000	 150.0	 1	    1.12592	    0.90000;
	6525	 1	 72.68058	 1.1	 0.0	 0.0	 1	    1.00598	    0.00000	 220.0	 1	    1.11195	    0.90000;
	6526	 1	 0.0	 0.0	 0.080003	 0.0	 1	    1.01732	    0.00000	 380.0	 1	    1.13464	    0.90000;
	6527	 1	 83.19224	 21.8	 0.0	 0.0	 1	    1.00469	    0.00000	 220.0	 1	    1.10939	    0.90000;
	6528	 1	 6.306993	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6529	 2	 21.92431	 14.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6530	 1	 8.108991	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6531	 1	 18.62065	 6.1	 0.0	 0.0	 1	    1.01582	    0.00000	 220.0	 1	    1.13164	    0.90000;
	6532	 1	 43.24795	 15.7	 0.0	 0.0	 1	    1.00330	    0.00000	 110.0	 1	    1.10660	    0.90000;
	6533	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00750	    0.00000	 220.0	 1	    1.11501	    0.90000;
	6534	 1	 48.05328	 23.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6535	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01476	    0.00000	 380.0	 1	    1.12952	    0.90000;
	6536	 1	 46.55161	 15.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6537	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01930	    0.00000	 220.0	 1	    1.13859	    0.90000;
	6538	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6539	 1	 6.607326	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6540	 2	 0.700777	 1.5	 0.0	 0.0	 1	    1.01419	    0.00000	 380.0	 1	    1.12837	    0.90000;
	6541	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01337	    0.00000	 380.0	 1	    1.12674	    0.90000;
	6542	 1	 19.22131	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6543	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6544	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00965	    0.00000	 220.0	 1	    1.11931	    0.90000;
	6545	 1	 89.69945	 40.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6546	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.00380	    0.00000	 220.0	 1	    1.10760	    0.90000;
	6547	 1	 17.71965	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6548	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03351	    0.00000	 220.0	 1	    1.16701	    0.90000;
	6549	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6550	 1	 0.0	 0.0	 0.191685	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6551	 1	 144.0	 31.3	 0.0	 0.0	 1	    1.01026	    0.00000	 220.0	 1	    1.12053	    0.90000;
	6552	 2	 3.1	 6.8	 0.0	 0.0	 1	    1.04242	    0.00000	 380.0	 1	    1.18485	    0.90000;
	6553	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6554	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6555	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00848	    0.00000	 220.0	 1	    1.11695	    0.90000;
	6556	 1	 7.608436	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6557	 1	 0.0	 0.0	 0.0	 -25.4492	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6558	 1	 388.7	 97.7	 0.0	 0.0	 1	    1.00595	    0.00000	 380.0	 1	    1.11189	    0.90000;
	6559	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6560	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6561	 1	 0.0	 0.0	 0.0	 23.0549	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6562	 1	 200.4	 115.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6563	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6564	 1	 11.21243	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6565	 1	 3.403774	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6566	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6567	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6568	 1	 7.408214	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6569	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6570	 1	 233.2	 39.4	 0.0	 0.0	 1	    1.02518	    0.00000	 380.0	 1	    1.15037	    0.90000;
	6571	 1	 37.94207	 9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6572	 2	 20.0222	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6574	 1	 220.8	 68.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6575	 1	 7.508325	 3.1	 0.0	 0.0	 1	    1.02457	    0.00000	 220.0	 1	    1.14914	    0.90000;
	6576	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6577	 1	 4.605106	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6578	 2	 422.0	 107.1	 0.0	 0.0	 1	    1.01592	    0.00000	 220.0	 1	    1.13185	    0.90000;
	6579	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01629	    0.00000	 380.0	 1	    1.13258	    0.90000;
	6580	 1	 10.61177	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6581	 1	 82.39135	 0.0	 0.0	 0.0	 1	    1.02169	    0.00000	 220.0	 1	    1.14339	    0.90000;
	6582	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6583	 1	 96.7	 23.7	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6584	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02964	    0.00000	 380.0	 1	    1.15928	    0.90000;
	6585	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01069	    0.00000	 220.0	 1	    1.12138	    0.90000;
	6586	 1	 7.608436	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6587	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01287	    0.00000	 220.0	 1	    1.12574	    0.90000;
	6588	 2	 207.7	 63.0	 0.0	 0.0	 1	    1.01158	    0.00000	 380.0	 1	    1.12316	    0.90000;
	6589	 1	 406.3	 92.5	 0.0	 0.0	 1	    1.01632	    0.00000	 380.0	 1	    1.13263	    0.90000;
	6590	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6591	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02035	    0.00000	 380.0	 1	    1.14069	    0.90000;
	6592	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6593	 1	 18.62065	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6594	 1	 219.6	 36.4	 0.0	 0.0	 1	    1.03143	    0.00000	 220.0	 1	    1.16286	    0.90000;
	6595	 2	 55.26127	 16.5	 0.0	 0.0	 1	    1.01701	    0.00000	 220.0	 1	    1.13402	    0.90000;
	6596	 1	 79.38802	 31.3	 0.0	 0.0	 1	    1.02303	    0.00000	 150.0	 1	    1.14606	    0.90000;
	6597	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6598	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01943	    0.00000	 220.0	 1	    1.13887	    0.90000;
	6599	 2	 715.8	 24.1	 0.0	 0.0	 1	    1.01498	    0.00000	 150.0	 1	    1.12995	    0.90000;
	6600	 1	 7.408214	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6601	 2	 124.0	 24.4	 0.0	 0.0	 1	    1.02505	    0.00000	 380.0	 1	    1.15009	    0.90000;
	6602	 1	 101.1	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05227	    0.00000	 220.0	 1	    1.20454	    0.90000;
	6604	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02738	    0.00000	 380.0	 1	    1.15477	    0.90000;
	6605	 1	 11.91321	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6606	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01612	    0.00000	 380.0	 1	    1.13224	    0.90000;
	6607	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03297	    0.00000	 220.0	 1	    1.16594	    0.90000;
	6608	 1	 0.0	 0.0	 0.0	 -16.3585	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02030	    0.00000	 380.0	 1	    1.14060	    0.90000;
	6610	 1	 11.71299	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6611	 2	 114.7	 4.1	 0.0	 0.0	 1	    1.01556	    0.00000	 220.0	 1	    1.13112	    0.90000;
	6612	 1	 2.702997	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6613	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02593	    0.00000	 150.0	 1	    1.15186	    0.90000;
	6614	 1	 36.84085	 13.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6615	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02592	    0.00000	 150.0	 1	    1.15185	    0.90000;
	6616	 2	 217.1	 22.6	 0.0	 0.0	 1	    1.02116	    0.00000	 220.0	 1	    1.14231	    0.90000;
	6617	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6618	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6619	 1	 36.03996	 12.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6620	 2	 2.502775	 94.6	 0.0	 0.0	 1	    1.01493	    0.00000	 380.0	 1	    1.12985	    0.90000;
	6621	 1	 0.400444	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6622	 1	 82.89191	 32.6	 0.0	 0.0	 1	    1.02640	    0.00000	 150.0	 1	    1.15281	    0.90000;
	6623	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00311	    0.00000	 220.0	 1	    1.10621	    0.90000;
	6624	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6625	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6626	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03430	    0.00000	 220.0	 1	    1.16860	    0.90000;
	6627	 1	 256.0	 69.9	 0.0	 0.0	 1	    1.01605	    0.00000	 380.0	 1	    1.13210	    0.90000;
	6628	 1	 102.6	 12.0	 0.0	 0.0	 1	    1.00273	    0.00000	 380.0	 1	    1.10546	    0.90000;
	6629	 1	 56.66282	 15.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6630	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03922	    0.00000	 380.0	 1	    1.17844	    0.90000;
	6631	 1	 0.0	 0.0	 0.13851	 0.0	 1	    1.02847	    0.00000	 380.0	 1	    1.15693	    0.90000;
	6632	 1	 29.53274	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6633	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01542	    0.00000	 220.0	 1	    1.13085	    0.90000;
	6634	 1	 210.9	 48.3	 0.0	 0.0	 1	    1.02632	    0.00000	 220.0	 1	    1.15264	    0.90000;
	6635	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00276	    0.00000	 380.0	 1	    1.10552	    0.90000;
	6636	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6637	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02141	    0.00000	 220.0	 1	    1.14282	    0.90000;
	6638	 1	 201.4	 47.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6639	 1	 36.94096	 62.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6640	 1	 18.2202	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6641	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6642	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01687	    0.00000	 220.0	 1	    1.13374	    0.90000;
	6643	 2	 34.93874	 8.6	 0.0	 0.0	 1	    1.00620	    0.00000	 220.0	 1	    1.11240	    0.90000;
	6644	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01235	    0.00000	 380.0	 1	    1.12470	    0.90000;
	6645	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00494	    0.00000	 220.0	 1	    1.10987	    0.90000;
	6646	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04156	    0.00000	 380.0	 1	    1.18312	    0.90000;
	6647	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01288	    0.00000	 110.0	 1	    1.12576	    0.90000;
	6648	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00642	    0.00000	 220.0	 1	    1.11285	    0.90000;
	6649	 1	 36.54051	 22.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6650	 1	 26.4293	 9.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6651	 1	 25.12786	 14.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6652	 1	 45.75072	 15.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6653	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01774	    0.00000	 220.0	 1	    1.13549	    0.90000;
	6654	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6655	 1	 23.82642	 8.6	 0.0	 0.0	 1	    1.01611	    0.00000	 110.0	 1	    1.13222	    0.90000;
	6656	 1	 37.44151	 0.0	 0.0	 0.0	 1	    1.02349	    0.00000	 220.0	 1	    1.14698	    0.90000;
	6657	 1	 169.0	 70.8	 0.0	 0.0	 1	    1.00386	    0.00000	 220.0	 1	    1.10773	    0.90000;
	6658	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02179	    0.00000	 380.0	 1	    1.14357	    0.90000;
	6659	 1	 31.03441	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6660	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6661	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01877	    0.00000	 380.0	 1	    1.13754	    0.90000;
	6662	 1	 101.3	 17.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6663	 1	 16.51831	 6.3	 0.0	 0.0	 1	    1.03058	    0.00000	 110.0	 1	    1.16116	    0.90000;
	6664	 2	 77.28568	 13.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6665	 1	 61.66837	 16.3	 0.0	 0.0	 1	    1.02130	    0.00000	 220.0	 1	    1.14260	    0.90000;
	6666	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00968	    0.00000	 380.0	 1	    1.11937	    0.90000;
	6667	 1	 127.3	 26.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6668	 1	 28.53163	 11.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6669	 1	 12.7141	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6670	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6671	 1	 -40.9454	 -28.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6672	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02449	    0.00000	 380.0	 1	    1.14898	    0.90000;
	6673	 1	 88.19778	 21.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6674	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03128	    0.00000	 220.0	 1	    1.16256	    0.90000;
	6675	 1	 223.3053	 61.3	 0.0	 0.0	 1	    1.02033	    0.00000	 220.0	 1	    1.14067	    0.90000;
	6676	 1	 0.0	 0.0	 0.261498	 0.0	 1	    1.02909	    0.00000	 380.0	 1	    1.15817	    0.90000;
	6677	 1	 6.306993	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6678	 1	 70.47814	 22.5	 0.0	 0.0	 1	    1.00362	    0.00000	 220.0	 1	    1.10724	    0.90000;
	6679	 1	 1.501665	 0.4	 0.0	 0.0	 1	    1.00653	    0.00000	 220.0	 1	    1.11305	    0.90000;
	6680	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6681	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00263	    0.00000	 380.0	 1	    1.10527	    0.90000;
	6682	 1	 10.0111	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6683	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03035	    0.00000	 220.0	 1	    1.16070	    0.90000;
	6684	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01957	    0.00000	 150.0	 1	    1.13913	    0.90000;
	6685	 1	 53.05883	 19.2	 0.0	 0.0	 1	    1.00575	    0.00000	 110.0	 1	    1.11150	    0.90000;
	6686	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6687	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01413	    0.00000	 220.0	 1	    1.12826	    0.90000;
	6688	 2	 132.7	 11.7	 0.0	 0.0	 1	    1.00879	    0.00000	 380.0	 1	    1.11759	    0.90000;
	6689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6690	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6691	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6692	 1	 6.106771	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6693	 1	 1.101221	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6694	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6695	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01558	    0.00000	 380.0	 1	    1.13116	    0.90000;
	6696	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6697	 1	 16.61843	 5.5	 0.0	 0.0	 1	    1.02378	    0.00000	 110.0	 1	    1.14755	    0.90000;
	6698	 1	 -23.8264	 7.8	 0.0	 0.0	 1	    1.00324	    0.00000	 150.0	 1	    1.10648	    0.90000;
	6699	 1	 142.0	 27.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6700	 2	 41.04551	 -46.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6701	 1	 55.66171	 22.4	 0.0	 0.0	 1	    1.01257	    0.00000	 110.0	 1	    1.12514	    0.90000;
	6702	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01566	    0.00000	 380.0	 1	    1.13132	    0.90000;
	6703	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00812	    0.00000	 220.0	 1	    1.11624	    0.90000;
	6704	 1	 41.44595	 17.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6705	 1	 100.3	 17.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6706	 1	 168.9	 113.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6707	 1	 30.0333	 18.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6708	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6710	 1	 59.66615	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6711	 1	 19.02109	 5.4	 0.0	 0.0	 1	    1.01962	    0.00000	 110.0	 1	    1.13924	    0.90000;
	6712	 1	 0.0	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6713	 1	 94.50478	 -27.8	 0.0	 0.0	 1	    1.00712	    0.00000	 220.0	 1	    1.11423	    0.90000;
	6714	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02117	    0.00000	 150.0	 1	    1.14234	    0.90000;
	6715	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.96934	    0.00000	 150.0	 1	    1.10000	    0.83868;
	6716	 1	 107.2	 45.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6717	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6718	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6719	 1	 33.63729	 13.7	 0.0	 0.0	 1	    1.00520	    0.00000	 220.0	 1	    1.11039	    0.90000;
	6720	 1	 23.42597	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6721	 1	 16.21798	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6722	 1	 0.0	 0.0	 0.155865	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6723	 1	 106.4	 19.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6724	 1	 0.0	 0.0	 0.090703	 0.0	 1	    1.02170	    0.00000	 380.0	 1	    1.14340	    0.90000;
	6725	 1	 18.01998	 12.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6726	 1	 415.5	 103.4	 0.0	 0.0	 1	    1.00971	    0.00000	 380.0	 1	    1.11942	    0.90000;
	6727	 1	 8.108991	 2.7	 0.0	 0.0	 1	    1.01086	    0.00000	 110.0	 1	    1.12173	    0.90000;
	6728	 1	 65.67281	 25.6	 0.0	 0.0	 1	    1.02244	    0.00000	 220.0	 1	    1.14488	    0.90000;
	6729	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01026	    0.00000	 220.0	 1	    1.12052	    0.90000;
	6730	 1	 123.1	 20.9	 0.0	 0.0	 1	    1.01114	    0.00000	 380.0	 1	    1.12228	    0.90000;
	6731	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02717	    0.00000	 150.0	 1	    1.15435	    0.90000;
	6732	 1	 1.801998	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6733	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01197	    0.00000	 380.0	 1	    1.12395	    0.90000;
	6734	 1	 0.0	 0.0	 0.0	 -130.727	 1	    1.02454	    0.00000	 380.0	 1	    1.14907	    0.90000;
	6735	 1	 60.36693	 54.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6736	 2	 0.0	 0.0	 0.0	 -87.5013	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6737	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00632	    0.00000	 220.0	 1	    1.11264	    0.90000;
	6738	 1	 116.8	 59.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6739	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6740	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01531	    0.00000	 380.0	 1	    1.13063	    0.90000;
	6741	 1	 18.32031	 5.3	 0.0	 0.0	 1	    1.03013	    0.00000	 220.0	 1	    1.16025	    0.90000;
	6742	 1	 121.3	 20.7	 0.0	 0.0	 1	    1.00868	    0.00000	 220.0	 1	    1.11735	    0.90000;
	6743	 1	 12.7141	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6744	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00961	    0.00000	 380.0	 1	    1.11923	    0.90000;
	6745	 2	 15.21687	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6746	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6747	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01464	    0.00000	 380.0	 1	    1.12929	    0.90000;
	6748	 1	 111.9	 118.3	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6749	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00288	    0.00000	 220.0	 1	    1.10576	    0.90000;
	6750	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6751	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02388	    0.00000	 380.0	 1	    1.14777	    0.90000;
	6752	 2	 16.01776	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6753	 1	 108.8	 28.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6754	 1	 227.4892	 61.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6755	 1	 49.45483	 16.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6756	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6757	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01812	    0.00000	 220.0	 1	    1.13624	    0.90000;
	6758	 1	 0.0	 0.0	 0.147237	 0.0	 1	    1.03148	    0.00000	 380.0	 1	    1.16297	    0.90000;
	6759	 1	 9.00999	 3.3	 0.0	 0.0	 1	    1.02072	    0.00000	 110.0	 1	    1.14143	    0.90000;
	6760	 1	 96.2	 23.3	 0.0	 0.0	 1	    1.00526	    0.00000	 220.0	 1	    1.11051	    0.90000;
	6761	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02185	    0.00000	 380.0	 1	    1.14369	    0.90000;
	6762	 1	 -7.40821	 -1.6	 0.0	 0.0	 1	    1.01248	    0.00000	 220.0	 1	    1.12495	    0.90000;
	6763	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01006	    0.00000	 380.0	 1	    1.12012	    0.90000;
	6764	 1	 10.11121	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6765	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00454	    0.00000	 150.0	 1	    1.10907	    0.90000;
	6766	 1	 178.7	 31.3	 0.0	 0.0	 1	    1.00631	    0.00000	 220.0	 1	    1.11263	    0.90000;
	6767	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01622	    0.00000	 220.0	 1	    1.13245	    0.90000;
	6768	 2	 45.45039	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6769	 2	 244.0	 30.2	 0.0	 0.0	 1	    1.03177	    0.00000	 220.0	 1	    1.16353	    0.90000;
	6770	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01105	    0.00000	 220.0	 1	    1.12210	    0.90000;
	6771	 1	 15.71743	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6772	 1	 1.501665	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6773	 1	 13.71521	 8.5	 0.0	 0.0	 1	    1.03918	    0.00000	 150.0	 1	    1.17836	    0.90000;
	6774	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01726	    0.00000	 380.0	 1	    1.13452	    0.90000;
	6775	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01075	    0.00000	 380.0	 1	    1.12150	    0.90000;
	6776	 2	 253.9	 94.2	 0.0	 0.0	 1	    1.01376	    0.00000	 220.0	 1	    1.12753	    0.90000;
	6777	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00824	    0.00000	 220.0	 1	    1.11647	    0.90000;
	6778	 1	 84.79401	 12.5	 0.0	 0.0	 1	    1.00573	    0.00000	 220.0	 1	    1.11146	    0.90000;
	6779	 1	 59.66615	 27.1	 0.0	 0.0	 1	    1.02215	    0.00000	 150.0	 1	    1.14431	    0.90000;
	6780	 1	 106.8	 22.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6781	 1	 47.95317	 29.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6782	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6783	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6784	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6785	 1	 -1316.59	 -129.9	 0.205959	 0.0	 1	    1.00910	    0.00000	 380.0	 1	    1.11820	    0.90000;
	6786	 1	 0.400444	 0.1	 0.0	 0.0	 1	    1.00872	    0.00000	 110.0	 1	    1.11743	    0.90000;
	6787	 1	 44.34917	 10.8	 0.0	 0.0	 1	    1.01415	    0.00000	 220.0	 1	    1.12830	    0.90000;
	6788	 1	 4.404884	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6789	 1	 38.04218	 18.0	 0.0	 0.0	 1	    1.00936	    0.00000	 220.0	 1	    1.11871	    0.90000;
	6790	 1	 0.200222	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6791	 1	 70.0777	 35.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6792	 2	 198.6	 282.2	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6793	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02564	    0.00000	 220.0	 1	    1.15129	    0.90000;
	6794	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01817	    0.00000	 380.0	 1	    1.13633	    0.90000;
	6795	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02171	    0.00000	 220.0	 1	    1.14342	    0.90000;
	6796	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01889	    0.00000	 220.0	 1	    1.13777	    0.90000;
	6797	 2	 113.4	 19.7	 0.0	 0.0	 1	    1.01214	    0.00000	 220.0	 1	    1.12429	    0.90000;
	6798	 1	 10.11121	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6799	 1	 4.404884	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6800	 2	 100.6	 49.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6801	 1	 136.2	 4.8	 0.0	 0.0	 1	    1.01694	    0.00000	 220.0	 1	    1.13387	    0.90000;
	6802	 1	 39.84418	 24.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6803	 1	 128.9	 73.7	 0.0	 0.0	 1	    1.01753	    0.00000	 380.0	 1	    1.13505	    0.90000;
	6804	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6805	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6806	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01979	    0.00000	 380.0	 1	    1.13959	    0.90000;
	6807	 1	 0.0	 0.0	 0.148479	 0.0	 1	    1.02244	    0.00000	 380.0	 1	    1.14489	    0.90000;
	6808	 1	 4.00444	 0.8	 0.0	 0.0	 1	    1.01677	    0.00000	 220.0	 1	    1.13354	    0.90000;
	6809	 2	 2.8	 264.7	 0.0	 0.0	 1	    1.01771	    0.00000	 380.0	 1	    1.13542	    0.90000;
	6810	 1	 87.99757	 36.2	 0.0	 0.0	 1	    1.02531	    0.00000	 380.0	 1	    1.15061	    0.90000;
	6811	 1	 46.35139	 14.9	 0.0	 0.0	 1	    1.01016	    0.00000	 220.0	 1	    1.12031	    0.90000;
	6812	 1	 0.100111	 0.0	 0.0	 0.0	 1	    1.01344	    0.00000	 220.0	 1	    1.12688	    0.90000;
	6813	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00854	    0.00000	 380.0	 1	    1.11709	    0.90000;
	6814	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00973	    0.00000	 380.0	 1	    1.11947	    0.90000;
	6815	 1	 1.4	 100.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6816	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.01674	    0.00000	 220.0	 1	    1.13348	    0.90000;
	6817	 1	 3.804218	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6818	 1	 9.00999	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6819	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6820	 2	 120.9	 41.4	 0.0	 0.0	 1	    1.02369	    0.00000	 220.0	 1	    1.14737	    0.90000;
	6821	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00746	    0.00000	 380.0	 1	    1.11492	    0.90000;
	6822	 1	 0.0	 0.0	 0.148	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6823	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00360	    0.00000	 380.0	 1	    1.10720	    0.90000;
	6824	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02738	    0.00000	 220.0	 1	    1.15477	    0.90000;
	6825	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6826	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6827	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6828	 1	 211.0	 59.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6829	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6830	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02494	    0.00000	 380.0	 1	    1.14987	    0.90000;
	6831	 1	 26.22908	 8.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6832	 1	 13.81532	 5.0	 0.0	 0.0	 1	    1.05232	    0.00000	 220.0	 1	    1.20464	    0.90000;
	6833	 1	 43.14784	 15.4	 0.0	 0.0	 1	    1.00306	    0.00000	 110.0	 1	    1.10612	    0.90000;
	6834	 1	 20.62287	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6835	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6836	 1	 21.8242	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6837	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00355	    0.00000	 380.0	 1	    1.10711	    0.90000;
	6838	 1	 130.5	 17.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6839	 1	 40.84529	 15.7	 0.0	 0.0	 1	    1.01713	    0.00000	 220.0	 1	    1.13425	    0.90000;
	6840	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6841	 2	 355.5	 92.9	 0.0	 0.0	 1	    1.02703	    0.00000	 380.0	 1	    1.15405	    0.90000;
	6842	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00310	    0.00000	 150.0	 1	    1.10620	    0.90000;
	6843	 1	 72.48036	 44.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6844	 2	 43.64839	 10.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6845	 1	 0.0	 0.0	 0.265633	 487.2386	 1	    1.01487	    0.00000	 380.0	 1	    1.12974	    0.90000;
	6846	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99605	    0.00000	 150.0	 1	    1.10000	    0.89211;
	6847	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01641	    0.00000	 380.0	 1	    1.13283	    0.90000;
	6848	 1	 281.3	 40.9	 0.0	 0.0	 1	    1.00974	    0.00000	 220.0	 1	    1.11948	    0.90000;
	6849	 2	 26.82975	 11.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6850	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6851	 2	 227.4	 73.1	 0.0	 0.0	 1	    1.00740	    0.00000	 220.0	 1	    1.11481	    0.90000;
	6852	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6853	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02328	    0.00000	 380.0	 1	    1.14657	    0.90000;
	6854	 1	 2.903219	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6855	 1	 2.102331	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6856	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00361	    0.00000	 220.0	 1	    1.10722	    0.90000;
	6857	 1	 34.43818	 12.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6858	 2	 9.00999	 -2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6859	 1	 34.6384	 12.4	 0.0	 0.0	 1	    1.00555	    0.00000	 110.0	 1	    1.11110	    0.90000;
	6860	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6861	 1	 218.0	 18.6	 0.0	 0.0	 1	    1.01959	    0.00000	 380.0	 1	    1.13918	    0.90000;
	6862	 1	 531.7	 -12.8	 0.0	 0.0	 1	    1.02013	    0.00000	 150.0	 1	    1.14026	    0.90000;
	6863	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6864	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02322	    0.00000	 110.0	 1	    1.14645	    0.90000;
	6865	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6866	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6867	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6868	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02634	    0.00000	 220.0	 1	    1.15269	    0.90000;
	6869	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02010	    0.00000	 380.0	 1	    1.14019	    0.90000;
	6870	 1	 126.6	 28.7	 0.0	 0.0	 1	    1.00524	    0.00000	 220.0	 1	    1.11049	    0.90000;
	6871	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01176	    0.00000	 220.0	 1	    1.12353	    0.90000;
	6872	 1	 29.03219	 6.1	 0.0	 0.0	 1	    1.01588	    0.00000	 110.0	 1	    1.13176	    0.90000;
	6873	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00695	    0.00000	 220.0	 1	    1.11391	    0.90000;
	6874	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01208	    0.00000	 220.0	 1	    1.12417	    0.90000;
	6875	 1	 45.95095	 15.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6876	 1	 136.9	 11.4	 0.0	 0.0	 1	    1.01900	    0.00000	 220.0	 1	    1.13799	    0.90000;
	6877	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01823	    0.00000	 220.0	 1	    1.13646	    0.90000;
	6878	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02646	    0.00000	 220.0	 1	    1.15293	    0.90000;
	6879	 1	 5.00555	 1.8	 0.0	 0.0	 1	    1.02329	    0.00000	 220.0	 1	    1.14659	    0.90000;
	6880	 1	 127.6	 45.3	 0.0	 0.0	 1	    1.02332	    0.00000	 150.0	 1	    1.14664	    0.90000;
	6881	 1	 27.93097	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6882	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01977	    0.00000	 150.0	 1	    1.13953	    0.90000;
	6883	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6884	 1	 10.11121	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6885	 1	 9.710767	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6886	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6887	 1	 11.21243	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6888	 1	 159.4	 -7.3	 0.0	 0.0	 1	    1.02508	    0.00000	 220.0	 1	    1.15017	    0.90000;
	6889	 1	 58.76516	 16.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6890	 1	 116.5	 33.4	 0.0	 0.0	 1	    1.01143	    0.00000	 110.0	 1	    1.12285	    0.90000;
	6891	 1	 30.43374	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6892	 1	 59.06549	 23.4	 0.0	 0.0	 1	    1.01986	    0.00000	 150.0	 1	    1.13972	    0.90000;
	6893	 1	 18.01998	 4.0	 0.0	 0.0	 1	    1.02461	    0.00000	 220.0	 1	    1.14922	    0.90000;
	6894	 1	 0.500555	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6895	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02007	    0.00000	 220.0	 1	    1.14014	    0.90000;
	6896	 1	 119.0	 31.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6897	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6898	 1	 119.7	 43.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6899	 1	 5.506105	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6900	 1	 86.99646	 30.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6901	 1	 0.0	 0.0	 0.0	 12.05509	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6902	 1	 2.803108	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6903	 2	 13.11454	 2.8	 0.0	 0.0	 1	    1.00716	    0.00000	 110.0	 1	    1.11433	    0.90000;
	6904	 1	 8.309213	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6905	 1	 24.02664	 -56.8	 0.0	 0.0	 1	    1.00838	    0.00000	 220.0	 1	    1.11677	    0.90000;
	6906	 1	 26.82131	 24.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6907	 1	 115.4	 31.0	 0.0	 0.0	 1	    1.00934	    0.00000	 220.0	 1	    1.11867	    0.90000;
	6908	 1	 -20.1223	 6.6	 0.0	 0.0	 1	    1.00461	    0.00000	 150.0	 1	    1.10923	    0.90000;
	6909	 1	 6.306993	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6910	 1	 70.47814	 17.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6911	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02882	    0.00000	 380.0	 1	    1.15764	    0.90000;
	6912	 1	 0.0	 0.0	 0.242637	 0.0	 1	    1.01222	    0.00000	 380.0	 1	    1.12443	    0.90000;
	6913	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00902	    0.00000	 220.0	 1	    1.11803	    0.90000;
	6914	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01502	    0.00000	 380.0	 1	    1.13003	    0.90000;
	6915	 1	 136.9518	 87.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6916	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6917	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02252	    0.00000	 220.0	 1	    1.14504	    0.90000;
	6918	 1	 32.7363	 10.5	 0.0	 0.0	 1	    1.02710	    0.00000	 220.0	 1	    1.15420	    0.90000;
	6919	 2	 312.1	 159.9	 0.0	 0.0	 1	    1.02572	    0.00000	 380.0	 1	    1.15144	    0.90000;
	6920	 1	 78.88747	 45.6	 0.0	 0.0	 1	    1.00422	    0.00000	 220.0	 1	    1.10844	    0.90000;
	6921	 2	 27.43041	 15.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6922	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02582	    0.00000	 150.0	 1	    1.15164	    0.90000;
	6923	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6924	 2	 10.31143	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6925	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6926	 1	 37.94207	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6927	 1	 91.60156	 20.3	 0.0	 0.0	 1	    1.02190	    0.00000	 220.0	 1	    1.14379	    0.90000;
	6928	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02969	    0.00000	 220.0	 1	    1.15938	    0.90000;
	6929	 1	 -12.614	 11.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6930	 1	 0.0	 0.0	 0.294	 0.0	 1	    1.00877	    0.00000	 380.0	 1	    1.11754	    0.90000;
	6931	 1	 429.5	 163.1	 0.0	 0.0	 1	    1.00537	    0.00000	 220.0	 1	    1.11075	    0.90000;
	6932	 2	 110.1	 44.6	 0.0	 0.0	 1	    1.00362	    0.00000	 220.0	 1	    1.10725	    0.90000;
	6933	 1	 68.77625	 35.0	 0.0	 0.0	 1	    1.02205	    0.00000	 380.0	 1	    1.14410	    0.90000;
	6934	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00992	    0.00000	 220.0	 1	    1.11984	    0.90000;
	6935	 1	 90.30012	 5.7	 0.0	 0.0	 1	    1.01177	    0.00000	 380.0	 1	    1.12354	    0.90000;
	6936	 1	 124.1	 -30.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6937	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01809	    0.00000	 380.0	 1	    1.13618	    0.90000;
	6938	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04080	    0.00000	 220.0	 1	    1.18161	    0.90000;
	6939	 1	 15.11676	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6940	 1	 29.1323	 11.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6941	 1	 439.0	 254.8	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6942	 1	 61.96871	 38.4	 0.0	 0.0	 1	    1.00819	    0.00000	 150.0	 1	    1.11638	    0.90000;
	6943	 1	 255.3	 78.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6944	 1	 33.93763	 11.4	 0.0	 0.0	 1	    1.01899	    0.00000	 220.0	 1	    1.13798	    0.90000;
	6945	 1	 117.0	 15.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6946	 2	 0.2	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6947	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02403	    0.00000	 380.0	 1	    1.14806	    0.90000;
	6948	 2	 142.3	 19.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6949	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.01056	    0.00000	 220.0	 1	    1.12112	    0.90000;
	6950	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00492	    0.00000	 220.0	 1	    1.10984	    0.90000;
	6951	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00763	    0.00000	 150.0	 1	    1.11526	    0.90000;
	6952	 1	 37.14118	 2.7	 0.0	 0.0	 1	    1.01041	    0.00000	 220.0	 1	    1.12082	    0.90000;
	6953	 1	 256.8	 -61.8	 0.0	 0.0	 1	    1.03767	    0.00000	 380.0	 1	    1.17535	    0.90000;
	6954	 1	 16.51831	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6955	 1	 93.4	 27.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6956	 2	 44.04884	 17.5	 0.0	 0.0	 1	    1.01953	    0.00000	 220.0	 1	    1.13906	    0.90000;
	6957	 1	 67.07436	 25.2	 0.0	 0.0	 1	    1.00661	    0.00000	 220.0	 1	    1.11321	    0.90000;
	6958	 2	 63.06993	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6959	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02433	    0.00000	 220.0	 1	    1.14866	    0.90000;
	6960	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02783	    0.00000	 380.0	 1	    1.15565	    0.90000;
	6961	 1	 20.82309	 7.9	 0.0	 0.0	 1	    1.01697	    0.00000	 380.0	 1	    1.13393	    0.90000;
	6962	 1	 0.0	 0.0	 0.236673	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	6963	 1	 66.07326	 21.6	 0.0	 0.0	 1	    1.01037	    0.00000	 150.0	 1	    1.12075	    0.90000;
	6964	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00750	    0.00000	 380.0	 1	    1.11500	    0.90000;
	6965	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00780	    0.00000	 220.0	 1	    1.11561	    0.90000;
	6966	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01298	    0.00000	 220.0	 1	    1.12596	    0.90000;
	6967	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00297	    0.00000	 380.0	 1	    1.10595	    0.90000;
	6968	 2	 36.94096	 15.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6969	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6970	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6971	 1	 49.45483	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6972	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01982	    0.00000	 380.0	 1	    1.13964	    0.90000;
	6973	 2	 90.2	 30.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6974	 1	 12.7141	 5.1	 0.0	 0.0	 1	    1.01914	    0.00000	 380.0	 1	    1.13827	    0.90000;
	6975	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01352	    0.00000	 380.0	 1	    1.12704	    0.90000;
	6976	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01832	    0.00000	 380.0	 1	    1.13665	    0.90000;
	6977	 1	 0.0	 0.0	 0.133168	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6978	 1	 25.12786	 15.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6979	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02020	    0.00000	 220.0	 1	    1.14041	    0.90000;
	6980	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6981	 1	 10.9121	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6982	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01998	    0.00000	 220.0	 1	    1.13997	    0.90000;
	6983	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6984	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00782	    0.00000	 380.0	 1	    1.11565	    0.90000;
	6985	 1	 66.17337	 27.4	 0.0	 0.0	 1	    1.01739	    0.00000	 220.0	 1	    1.13478	    0.90000;
	6986	 1	 11.91321	 3.5	 0.0	 0.0	 1	    1.00456	    0.00000	 150.0	 1	    1.10912	    0.90000;
	6987	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02228	    0.00000	 220.0	 1	    1.14457	    0.90000;
	6988	 1	 51.95761	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6989	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6990	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6991	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01813	    0.00000	 220.0	 1	    1.13626	    0.90000;
	6992	 2	 131.3	 19.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6993	 1	 0.200222	 88.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6994	 1	 2.202442	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6995	 1	 60.0666	 36.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6996	 1	 126.2	 -12.5	 0.0	 0.0	 1	    1.02231	    0.00000	 220.0	 1	    1.14462	    0.90000;
	6997	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6998	 1	 15.11676	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6999	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7000	 1	 85.9	 93.8	 0.0	 0.0	 1	    1.00300	    0.00000	 380.0	 1	    1.10601	    0.90000;
	7001	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01462	    0.00000	 220.0	 1	    1.12925	    0.90000;
	7002	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01823	    0.00000	 220.0	 1	    1.13645	    0.90000;
	7003	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7004	 1	 70.77847	 43.8	 0.0	 0.0	 1	    0.97190	    0.00000	 150.0	 1	    1.10000	    0.84379;
	7005	 1	 38.94318	 11.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.20000	    0.80000;
	7006	 1	 17.01887	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7007	 1	 220.2	 83.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7008	 1	 39.64395	 4.4	 0.0	 0.0	 1	    1.00983	    0.00000	 110.0	 1	    1.11966	    0.90000;
	7009	 1	 65.97314	 64.1	 0.0	 0.0	 1	    1.00341	    0.00000	 380.0	 1	    1.10683	    0.90000;
	7010	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01722	    0.00000	 220.0	 1	    1.13444	    0.90000;
	7011	 1	 46.05106	 22.0	 0.0	 0.0	 1	    1.01185	    0.00000	 220.0	 1	    1.12370	    0.90000;
	7012	 1	 20.82309	 6.7	 0.0	 0.0	 1	    1.00546	    0.00000	 110.0	 1	    1.11092	    0.90000;
	7013	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7014	 1	 71.57936	 48.2	 0.289482	 0.0	 1	    1.01047	    0.00000	 380.0	 1	    1.12095	    0.90000;
	7015	 1	 137.0	 33.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7016	 1	 65.5727	 44.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7017	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7018	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02391	    0.00000	 150.0	 1	    1.14782	    0.90000;
	7019	 2	 35.73963	 11.1	 0.0	 0.0	 1	    1.01193	    0.00000	 110.0	 1	    1.12386	    0.90000;
	7020	 1	 31.8353	 9.2	 0.0	 0.0	 1	    1.01569	    0.00000	 220.0	 1	    1.13138	    0.90000;
	7021	 1	 82.29124	 29.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7022	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7023	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7024	 2	 39.04329	 12.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7025	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7026	 1	 8.309213	 3.0	 0.0	 0.0	 1	    1.00408	    0.00000	 110.0	 1	    1.10816	    0.90000;
	7027	 1	 24.22686	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7028	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7029	 1	 122.7	 -29.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7030	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01958	    0.00000	 220.0	 1	    1.13916	    0.90000;
	7031	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02326	    0.00000	 150.0	 1	    1.14652	    0.90000;
	7032	 1	 524.5	 126.0	 0.0	 0.0	 1	    1.03177	    0.00000	 220.0	 1	    1.16355	    0.90000;
	7033	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7034	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01713	    0.00000	 380.0	 1	    1.13427	    0.90000;
	7035	 2	 8.609546	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7036	 1	 17.51942	 5.7	 0.0	 0.0	 1	    1.01968	    0.00000	 110.0	 1	    1.13937	    0.90000;
	7037	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02176	    0.00000	 380.0	 1	    1.14351	    0.90000;
	7038	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04337	    0.00000	 380.0	 1	    1.18674	    0.90000;
	7039	 1	 10.61177	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7040	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7041	 1	 0.0	 0.0	 0.261317	 20.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7042	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7043	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02118	    0.00000	 380.0	 1	    1.14236	    0.90000;
	7044	 1	 11.01221	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7045	 1	 78.88747	 25.6	 0.0	 0.0	 1	    1.00724	    0.00000	 220.0	 1	    1.11447	    0.90000;
	7046	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01705	    0.00000	 220.0	 1	    1.13410	    0.90000;
	7047	 1	 11.91321	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7048	 1	 47.15228	 15.5	 0.0	 0.0	 1	    1.01049	    0.00000	 220.0	 1	    1.12098	    0.90000;
	7049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00868	    0.00000	 380.0	 1	    1.11737	    0.90000;
	7050	 1	 223.6	 51.8	 0.0	 0.0	 1	    1.01366	    0.00000	 220.0	 1	    1.12731	    0.90000;
	7051	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7052	 1	 27.23019	 10.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7053	 1	 151.5	 7.9	 0.0	 0.0	 1	    1.03292	    0.00000	 220.0	 1	    1.16585	    0.90000;
	7054	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02008	    0.00000	 380.0	 1	    1.14016	    0.90000;
	7055	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01185	    0.00000	 380.0	 1	    1.12369	    0.90000;
	7056	 1	 153.0	 21.5	 0.0	 0.0	 1	    1.02543	    0.00000	 380.0	 1	    1.15086	    0.90000;
	7057	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02853	    0.00000	 150.0	 1	    1.15706	    0.90000;
	7058	 1	 108.5	 35.3	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7059	 1	 1.401554	 0.5	 0.0	 0.0	 1	    1.02364	    0.00000	 110.0	 1	    1.14727	    0.90000;
	7060	 1	 26.12897	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7061	 1	 11.01221	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7062	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01155	    0.00000	 220.0	 1	    1.12311	    0.90000;
	7063	 1	 113.4	 11.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7064	 1	 30.0333	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7065	 1	 0.0	 0.0	 0.096002	 0.0	 1	    1.00673	    0.00000	 220.0	 1	    1.11346	    0.90000;
	7066	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00632	    0.00000	 220.0	 1	    1.11265	    0.90000;
	7067	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7068	 1	 7.808658	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7069	 1	 44.34917	 5.1	 0.0	 0.0	 1	    1.00879	    0.00000	 220.0	 1	    1.11759	    0.90000;
	7070	 1	 12.91432	 4.7	 0.0	 0.0	 1	    1.01123	    0.00000	 110.0	 1	    1.12247	    0.90000;
	7071	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01783	    0.00000	 220.0	 1	    1.13567	    0.90000;
	7072	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7073	 1	 86.4959	 29.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7074	 2	 9.610656	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7075	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7076	 1	 0.0	 0.0	 0.373992	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7077	 1	 91.10101	 33.5	 0.0	 0.0	 1	    1.01712	    0.00000	 220.0	 1	    1.13424	    0.90000;
	7078	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00593	    0.00000	 220.0	 1	    1.11187	    0.90000;
	7079	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7080	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02282	    0.00000	 380.0	 1	    1.14563	    0.90000;
	7081	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02653	    0.00000	 380.0	 1	    1.15305	    0.90000;
	7082	 1	 169.5	 27.7	 0.0	 0.0	 1	    1.00978	    0.00000	 220.0	 1	    1.11956	    0.90000;
	7083	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02242	    0.00000	 380.0	 1	    1.14484	    0.90000;
	7084	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00289	    0.00000	 220.0	 1	    1.10579	    0.90000;
	7085	 1	 22.82531	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7086	 1	 1.801998	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7087	 1	 149.1	 -18.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7088	 1	 40.24462	 16.0	 0.0	 0.0	 1	    1.01599	    0.00000	 380.0	 1	    1.13197	    0.90000;
	7089	 1	 14.81643	 0.0	 0.0	 0.0	 1	    1.02052	    0.00000	 220.0	 1	    1.14104	    0.90000;
	7090	 1	 -41.6462	 13.7	 0.0	 0.0	 1	    1.00439	    0.00000	 150.0	 1	    1.10879	    0.90000;
	7091	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01351	    0.00000	 220.0	 1	    1.12702	    0.90000;
	7092	 1	 127.2	 -10.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7093	 1	 179.0	 22.9	 0.0	 0.0	 1	    1.01354	    0.00000	 380.0	 1	    1.12708	    0.90000;
	7094	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94750	    0.00000	 150.0	 1	    1.10000	    0.79500;
	7095	 1	 34.33807	 12.2	 0.0	 0.0	 1	    1.00697	    0.00000	 110.0	 1	    1.11395	    0.90000;
	7096	 1	 9.210212	 3.4	 0.0	 0.0	 1	    1.01782	    0.00000	 220.0	 1	    1.13564	    0.90000;
	7097	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7098	 1	 32.43596	 20.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7099	 1	 137.2	 41.9	 0.110996	 0.0	 1	    1.01681	    0.00000	 380.0	 1	    1.13363	    0.90000;
	7100	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.01302	    0.00000	 220.0	 1	    1.12604	    0.90000;
	7101	 1	 -3.20355	 -7.9	 0.0	 0.0	 1	    1.01833	    0.00000	 220.0	 1	    1.13667	    0.90000;
	7102	 1	 0.0	 0.0	 0.152776	 0.0	 1	    1.01869	    0.00000	 380.0	 1	    1.13738	    0.90000;
	7103	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01272	    0.00000	 380.0	 1	    1.12544	    0.90000;
	7104	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7105	 2	 193.3	 42.0	 0.0	 0.0	 1	    1.00844	    0.00000	 220.0	 1	    1.11688	    0.90000;
	7106	 1	 134.7	 17.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7107	 2	 110.3	 10.7	 0.0	 0.0	 1	    1.01436	    0.00000	 220.0	 1	    1.12873	    0.90000;
	7108	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7109	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7110	 1	 10.11121	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7111	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02473	    0.00000	 220.0	 1	    1.14946	    0.90000;
	7113	 1	 26.52941	 7.1	 0.0	 0.0	 1	    1.01202	    0.00000	 220.0	 1	    1.12403	    0.90000;
	7114	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01311	    0.00000	 380.0	 1	    1.12622	    0.90000;
	7115	 2	 0.0	 0.0	 0.083	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02498	    0.00000	 150.0	 1	    1.14997	    0.90000;
	7117	 1	 38.64284	 6.0	 0.0	 0.0	 1	    1.00539	    0.00000	 220.0	 1	    1.11078	    0.90000;
	7118	 1	 0.0	 0.0	 0.0	 11.48854	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00965	    0.00000	 220.0	 1	    1.11930	    0.90000;
	7120	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01323	    0.00000	 380.0	 1	    1.12647	    0.90000;
	7122	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7123	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01128	    0.00000	 150.0	 1	    1.12256	    0.90000;
	7124	 1	 40.64506	 16.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7125	 2	 316.5	 100.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00319	    0.00000	 220.0	 1	    1.10637	    0.90000;
	7127	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01375	    0.00000	 380.0	 1	    1.12751	    0.90000;
	7128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02555	    0.00000	 220.0	 1	    1.15110	    0.90000;
	7129	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7131	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02162	    0.00000	 380.0	 1	    1.14324	    0.90000;
	7132	 1	 178.9	 9.1	 0.0	 0.0	 1	    1.00482	    0.00000	 220.0	 1	    1.10963	    0.90000;
	7133	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02862	    0.00000	 220.0	 1	    1.15724	    0.90000;
	7134	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7135	 1	 11.41265	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7136	 1	 84.99424	 19.6	 0.0	 0.0	 1	    1.03315	    0.00000	 220.0	 1	    1.16631	    0.90000;
	7137	 1	 2.202442	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7138	 1	 88.49812	 10.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7139	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7140	 1	 101.9	 20.0	 0.0	 0.0	 1	    1.00900	    0.00000	 220.0	 1	    1.11800	    0.90000;
	7141	 1	 0.0	 0.0	 0.0	 -91.049	 1	    1.02365	    0.00000	 380.0	 1	    1.14730	    0.90000;
	7142	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7143	 1	 17.01887	 2.0	 0.0	 0.0	 1	    1.00761	    0.00000	 220.0	 1	    1.11522	    0.90000;
	7144	 2	 13.31476	 2.4	 0.0	 0.0	 1	    1.01751	    0.00000	 220.0	 1	    1.13502	    0.90000;
	7145	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7146	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7147	 1	 0.0	 0.0	 0.037402	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7148	 2	 65.77292	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7149	 1	 0.300333	 -97.2	 0.0	 0.0	 1	    1.02487	    0.00000	 220.0	 1	    1.14973	    0.90000;
	7150	 1	 73.58158	 48.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7151	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00389	    0.00000	 380.0	 1	    1.10778	    0.90000;
	7152	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03109	    0.00000	 220.0	 1	    1.16219	    0.90000;
	7153	 1	 26.62953	 9.7	 0.0	 0.0	 1	    1.00784	    0.00000	 110.0	 1	    1.11568	    0.90000;
	7154	 1	 47.55272	 17.8	 0.0	 0.0	 1	    1.01879	    0.00000	 220.0	 1	    1.13759	    0.90000;
	7155	 1	 35.83974	 14.1	 0.0	 0.0	 1	    1.02698	    0.00000	 150.0	 1	    1.15396	    0.90000;
	7156	 1	 142.4	 20.0	 0.0	 0.0	 1	    1.02053	    0.00000	 220.0	 1	    1.14106	    0.90000;
	7157	 1	 162.5	 42.7	 0.0	 0.0	 1	    1.00755	    0.00000	 220.0	 1	    1.11510	    0.90000;
	7158	 2	 51.75739	 6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7159	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.01558	    0.00000	 220.0	 1	    1.13116	    0.90000;
	7160	 2	 125.3	 7.7	 0.0	 0.0	 1	    1.03199	    0.00000	 220.0	 1	    1.16398	    0.90000;
	7161	 1	 427.9	 145.8	 0.0	 0.0	 1	    1.01343	    0.00000	 380.0	 1	    1.12685	    0.90000;
	7162	 1	 36.94096	 11.0	 0.0	 0.0	 1	    1.01585	    0.00000	 220.0	 1	    1.13171	    0.90000;
	7163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7164	 1	 338.7	 52.5	 0.0	 0.0	 1	    1.04002	    0.00000	 220.0	 1	    1.18004	    0.90000;
	7165	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02169	    0.00000	 220.0	 1	    1.14338	    0.90000;
	7166	 1	 3.203552	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7167	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7168	 1	 31.73519	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7169	 1	 26.92986	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7170	 1	 191.7	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7171	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7172	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04209	    0.00000	 220.0	 1	    1.18419	    0.90000;
	7173	 1	 30.34628	 30.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7174	 1	 347.1	 87.2	 0.0	 0.0	 1	    1.02490	    0.00000	 380.0	 1	    1.14980	    0.90000;
	7175	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7176	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7177	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01206	    0.00000	 380.0	 1	    1.12413	    0.90000;
	7178	 1	 0.0	 8.3	 0.0	 0.0	 1	    1.04654	    0.00000	 150.0	 1	    1.19309	    0.90000;
	7179	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7180	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03571	    0.00000	 380.0	 1	    1.17141	    0.90000;
	7181	 1	 -596.4	 -284.9	 0.321115	 0.0	 1	    1.02516	    0.00000	 380.0	 1	    1.15031	    0.90000;
	7182	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7183	 1	 35.13896	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7184	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01116	    0.00000	 380.0	 1	    1.12231	    0.90000;
	7185	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01614	    0.00000	 380.0	 1	    1.13229	    0.90000;
	7186	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00347	    0.00000	 380.0	 1	    1.10694	    0.90000;
	7187	 1	 160.3	 89.7	 0.0	 0.0	 1	    1.01078	    0.00000	 380.0	 1	    1.12155	    0.90000;
	7188	 1	 38.14229	 23.6	 0.0	 0.0	 1	    1.00413	    0.00000	 150.0	 1	    1.10827	    0.90000;
	7189	 1	 0.0	 0.0	 0.129001	 0.0	 1	    1.04398	    0.00000	 380.0	 1	    1.18796	    0.90000;
	7190	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01983	    0.00000	 220.0	 1	    1.13965	    0.90000;
	7191	 1	 106.1	 -6.8	 0.0	 0.0	 1	    1.00784	    0.00000	 380.0	 1	    1.11568	    0.90000;
	7192	 1	 36.84085	 14.1	 0.0	 0.0	 1	    1.03198	    0.00000	 380.0	 1	    1.16397	    0.90000;
	7193	 1	 2.202442	 0.5	 0.0	 0.0	 1	    1.00580	    0.00000	 220.0	 1	    1.11160	    0.90000;
	7194	 2	 302.1	 216.0	 0.0	 0.0	 1	    1.01256	    0.00000	 380.0	 1	    1.12513	    0.90000;
	7195	 1	 17.51942	 9.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7196	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00627	    0.00000	 220.0	 1	    1.11254	    0.90000;
	7197	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7198	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7199	 2	 0.0	 0.0	 0.546086	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7200	 1	 4.504995	 1.1	 0.0	 0.0	 1	    1.02546	    0.00000	 380.0	 1	    1.15093	    0.90000;
	7201	 1	 115.8	 29.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7202	 1	 56.06216	 17.0	 0.0	 0.0	 1	    1.00996	    0.00000	 220.0	 1	    1.11993	    0.90000;
	7203	 1	 31.03441	 10.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7204	 1	 0.0	 0.0	 0.0	 15.5502	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7205	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04380	    0.00000	 380.0	 1	    1.18760	    0.90000;
	7206	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7207	 1	 100.9	 26.7	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7208	 1	 38.44262	 2.0	 0.0	 0.0	 1	    1.00612	    0.00000	 220.0	 1	    1.11223	    0.90000;
	7209	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00755	    0.00000	 220.0	 1	    1.11510	    0.90000;
	7210	 1	 17.91987	 5.8	 0.0	 0.0	 1	    1.01153	    0.00000	 220.0	 1	    1.12307	    0.90000;
	7211	 1	 0.0	 0.0	 0.191685	 0.0	 1	    1.01771	    0.00000	 220.0	 1	    1.13543	    0.90000;
	7212	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01167	    0.00000	 380.0	 1	    1.12333	    0.90000;
	7213	 1	 56.56271	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7214	 1	 156.0	 60.7	 0.0	 0.0	 1	    1.01151	    0.00000	 150.0	 1	    1.12303	    0.90000;
	7215	 1	 60.0666	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7216	 2	 488.7	 184.7	 0.0	 0.0	 1	    1.01701	    0.00000	 380.0	 1	    1.13403	    0.90000;
	7217	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00483	    0.00000	 380.0	 1	    1.10966	    0.90000;
	7218	 1	 111.6	 8.9	 0.0	 0.0	 1	    1.03140	    0.00000	 220.0	 1	    1.16279	    0.90000;
	7219	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7220	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01410	    0.00000	 220.0	 1	    1.12819	    0.90000;
	7221	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02381	    0.00000	 150.0	 1	    1.14761	    0.90000;
	7222	 1	 0.0	 0.0	 0.0	 -25.7039	 1	    1.03163	    0.00000	 380.0	 1	    1.16326	    0.90000;
	7223	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01753	    0.00000	 380.0	 1	    1.13506	    0.90000;
	7224	 1	 50.55605	 8.1	 0.0	 0.0	 1	    1.02189	    0.00000	 220.0	 1	    1.14378	    0.90000;
	7225	 1	 0.0	 0.0	 0.0	 15.16794	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7226	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03003	    0.00000	 380.0	 1	    1.16006	    0.90000;
	7227	 1	 124.5	 59.2	 0.0	 0.0	 1	    1.02149	    0.00000	 380.0	 1	    1.14298	    0.90000;
	7228	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00848	    0.00000	 220.0	 1	    1.11696	    0.90000;
	7229	 1	 4.805328	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7230	 1	 0.0	 0.0	 0.275009	 0.0	 1	    1.01844	    0.00000	 380.0	 1	    1.13689	    0.90000;
	7231	 1	 30.0333	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7232	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00701	    0.00000	 380.0	 1	    1.11403	    0.90000;
	7233	 1	 237.9	 68.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7234	 1	 115.7	 10.7	 0.0	 0.0	 1	    1.00638	    0.00000	 220.0	 1	    1.11276	    0.90000;
	7235	 1	 234.0	 13.1	 0.0	 0.0	 1	    1.01876	    0.00000	 220.0	 1	    1.13752	    0.90000;
	7236	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7237	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99598	    0.00000	 150.0	 1	    1.10000	    0.89197;
	7238	 1	 0.0	 0.0	 0.118998	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7239	 2	 253.7	 85.0	 0.0	 0.0	 1	    1.02259	    0.00000	 380.0	 1	    1.14518	    0.90000;
	7240	 1	 233.5	 151.0	 0.0	 0.0	 1	    1.01637	    0.00000	 380.0	 1	    1.13275	    0.90000;
	7241	 1	 3.00333	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7242	 1	 112.0	 19.7	 0.0	 0.0	 1	    1.01963	    0.00000	 220.0	 1	    1.13927	    0.90000;
	7243	 2	 254.5	 67.3	 0.0	 0.0	 1	    1.00757	    0.00000	 220.0	 1	    1.11514	    0.90000;
	7244	 1	 0.0	 -8.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7245	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01798	    0.00000	 380.0	 1	    1.13596	    0.90000;
	7246	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01971	    0.00000	 220.0	 1	    1.13941	    0.90000;
	7247	 1	 12.61399	 7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7248	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7249	 1	 400.4	 23.6	 0.534155	 0.0	 1	    1.01580	    0.00000	 380.0	 1	    1.13160	    0.90000;
	7250	 1	 18.2202	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7251	 1	 11.91321	 3.3	 0.0	 0.0	 1	    1.01325	    0.00000	 220.0	 1	    1.12650	    0.90000;
	7252	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02268	    0.00000	 150.0	 1	    1.14536	    0.90000;
	7253	 1	 25.22797	 47.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7254	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01136	    0.00000	 380.0	 1	    1.12272	    0.90000;
	7255	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00719	    0.00000	 220.0	 1	    1.11438	    0.90000;
	7256	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7258	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7259	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7260	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7261	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02244	    0.00000	 220.0	 1	    1.14488	    0.90000;
	7262	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01130	    0.00000	 380.0	 1	    1.12260	    0.90000;
	7263	 1	 7.908769	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02293	    0.00000	 380.0	 1	    1.14586	    0.90000;
	7265	 1	 3.203552	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7266	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99184	    0.00000	 150.0	 1	    1.10000	    0.88368;
	7267	 1	 36.84085	 14.1	 0.0	 0.0	 1	    1.02571	    0.00000	 380.0	 1	    1.15141	    0.90000;
	7268	 1	 40.0444	 15.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7269	 1	 149.6277	 59.0	 0.0	 0.0	 1	    1.01761	    0.00000	 220.0	 1	    1.13523	    0.90000;
	7270	 1	 28.83197	 10.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7271	 1	 23.32586	 9.1	 0.0	 0.0	 1	    1.01988	    0.00000	 150.0	 1	    1.13976	    0.90000;
	7272	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7273	 1	 9.410433	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7274	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7275	 1	 1.801998	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7276	 1	 14.21576	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7277	 1	 209.1	 1.7	 0.0	 0.0	 1	    1.01079	    0.00000	 220.0	 1	    1.12159	    0.90000;
	7278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03970	    0.00000	 150.0	 1	    1.17940	    0.90000;
	7279	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7280	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7281	 2	 52.55827	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7282	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01439	    0.00000	 380.0	 1	    1.12878	    0.90000;
	7283	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7284	 1	 8.309213	 3.0	 0.0	 0.0	 1	    1.01308	    0.00000	 110.0	 1	    1.12616	    0.90000;
	7285	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02019	    0.00000	 380.0	 1	    1.14038	    0.90000;
	7286	 1	 12.91432	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7287	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7288	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7289	 1	 83.99313	 6.0	 0.0	 0.0	 1	    1.02411	    0.00000	 380.0	 1	    1.14823	    0.90000;
	7290	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02169	    0.00000	 220.0	 1	    1.14339	    0.90000;
	7291	 2	 37.84196	 12.3	 0.0	 0.0	 1	    1.00787	    0.00000	 220.0	 1	    1.11574	    0.90000;
	7292	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01958	    0.00000	 150.0	 1	    1.13916	    0.90000;
	7293	 1	 12.11343	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7294	 1	 70.37804	 27.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7295	 1	 93.804	 15.9	 0.0	 0.0	 1	    1.04139	    0.00000	 110.0	 1	    1.18277	    0.90000;
	7296	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01001	    0.00000	 150.0	 1	    1.12002	    0.90000;
	7297	 2	 123.8	 40.2	 0.0	 0.0	 1	    1.02134	    0.00000	 220.0	 1	    1.14267	    0.90000;
	7298	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00886	    0.00000	 110.0	 1	    1.11772	    0.90000;
	7299	 2	 3.303663	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7300	 1	 106.4	 24.2	 0.0	 0.0	 1	    1.00274	    0.00000	 110.0	 1	    1.10547	    0.90000;
	7301	 1	 0.0	 0.0	 0.0	 11.992	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7302	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03406	    0.00000	 380.0	 1	    1.16811	    0.90000;
	7303	 1	 42.34695	 13.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7304	 1	 19.02109	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7305	 1	 53.55938	 18.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7306	 1	 0.0	 0.0	 0.0	 11.367	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7307	 1	 28.63174	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7308	 1	 14.31587	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7309	 1	 69.1767	 9.5	 0.0	 0.0	 1	    1.02628	    0.00000	 220.0	 1	    1.15255	    0.90000;
	7310	 1	 10.71188	 17.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7311	 1	 170.8	 70.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7312	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01619	    0.00000	 220.0	 1	    1.13237	    0.90000;
	7313	 1	 -19.3214	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7314	 1	 25.32808	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7315	 1	 135.2	 70.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7316	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02243	    0.00000	 380.0	 1	    1.14487	    0.90000;
	7317	 2	 199.1	 23.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7318	 1	 66.77403	 19.8	 0.0	 0.0	 1	    1.00898	    0.00000	 110.0	 1	    1.11796	    0.90000;
	7319	 1	 41.74628	 7.4	 0.0	 0.0	 1	    1.00576	    0.00000	 220.0	 1	    1.11152	    0.90000;
	7320	 1	 174.2	 54.3	 0.0	 0.0	 1	    1.00526	    0.00000	 380.0	 1	    1.11051	    0.90000;
	7321	 1	 3.804218	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7322	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02284	    0.00000	 220.0	 1	    1.14568	    0.90000;
	7324	 1	 68.47592	 42.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7325	 1	 33.13674	 20.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7326	 1	 6.206882	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7327	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7328	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7329	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7330	 1	 35.93985	 22.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7331	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04292	    0.00000	 150.0	 1	    1.18584	    0.90000;
	7332	 1	 35.13896	 11.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7333	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00857	    0.00000	 380.0	 1	    1.11714	    0.90000;
	7334	 2	 70.57825	 60.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7335	 1	 0.0	 0.0	 0.411998	 0.0	 1	    1.01818	    0.00000	 380.0	 1	    1.13636	    0.90000;
	7336	 1	 39.34362	 24.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7337	 1	 73.18114	 23.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7338	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7339	 1	 41.84639	 15.2	 0.0	 0.0	 1	    1.01425	    0.00000	 110.0	 1	    1.12850	    0.90000;
	7340	 1	 0.0	 0.0	 0.0	 11.90083	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7341	 2	 30.0333	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7342	 2	 2.702997	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7343	 1	 7.608436	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7344	 1	 206.4	 21.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7345	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01319	    0.00000	 380.0	 1	    1.12637	    0.90000;
	7346	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00516	    0.00000	 220.0	 1	    1.11032	    0.90000;
	7347	 1	 82.1	 29.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7348	 1	 39.34362	 -10.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7349	 1	 127.2	 40.8	 0.0	 0.0	 1	    1.03071	    0.00000	 220.0	 1	    1.16142	    0.90000;
	7350	 1	 68.17558	 16.1	 0.0	 0.0	 1	    1.01905	    0.00000	 220.0	 1	    1.13809	    0.90000;
	7351	 1	 35.83974	 13.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7352	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01913	    0.00000	 380.0	 1	    1.13826	    0.90000;
	7353	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7354	 1	 87.89746	 29.3	 0.0	 0.0	 1	    1.01859	    0.00000	 220.0	 1	    1.13717	    0.90000;
	7355	 1	 107.0	 43.0	 0.0	 0.0	 1	    1.00434	    0.00000	 220.0	 1	    1.10868	    0.90000;
	7356	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7357	 1	 19.02109	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7358	 2	 73.98203	 -7.4	 0.0	 0.0	 1	    1.01811	    0.00000	 380.0	 1	    1.13622	    0.90000;
	7359	 1	 111.1	 35.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7360	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7361	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01302	    0.00000	 380.0	 1	    1.12604	    0.90000;
	7362	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7363	 1	 80.48924	 7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7364	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02256	    0.00000	 220.0	 1	    1.14512	    0.90000;
	7365	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01428	    0.00000	 380.0	 1	    1.12856	    0.90000;
	7366	 1	 8.909878	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7367	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03921	    0.00000	 380.0	 1	    1.17841	    0.90000;
	7368	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7369	 1	 34.43818	 27.0	 0.0	 0.0	 1	    0.98441	    0.00000	 150.0	 1	    1.10000	    0.86881;
	7370	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7371	 1	 12.61399	 6.3	 0.0	 0.0	 1	    1.02207	    0.00000	 220.0	 1	    1.14414	    0.90000;
	7372	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7373	 1	 0.0	 0.0	 0.045353	 0.0	 1	    1.02494	    0.00000	 380.0	 1	    1.14988	    0.90000;
	7374	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01166	    0.00000	 220.0	 1	    1.12331	    0.90000;
	7375	 1	 242.4	 46.7	 0.0	 0.0	 1	    1.02639	    0.00000	 380.0	 1	    1.15278	    0.90000;
	7376	 1	 18.72076	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7377	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02870	    0.00000	 150.0	 1	    1.15739	    0.90000;
	7378	 1	 10.0111	 2.0	 0.0	 0.0	 1	    1.01025	    0.00000	 150.0	 1	    1.12051	    0.90000;
	7379	 1	 22.32475	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7380	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01462	    0.00000	 110.0	 1	    1.12924	    0.90000;
	7381	 2	 171.0	 43.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7382	 1	 0.0	 0.0	 0.0	 12.27504	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7383	 1	 303.5	 56.2	 0.0	 0.0	 1	    1.00732	    0.00000	 220.0	 1	    1.11464	    0.90000;
	7384	 1	 3.804218	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7385	 2	 112.2	 28.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7386	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01489	    0.00000	 220.0	 1	    1.12979	    0.90000;
	7387	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7388	 1	 21.52386	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7389	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7390	 1	 125.3	 34.6	 0.0	 0.0	 1	    1.01971	    0.00000	 150.0	 1	    1.13942	    0.90000;
	7391	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01326	    0.00000	 380.0	 1	    1.12653	    0.90000;
	7392	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01600	    0.00000	 380.0	 1	    1.13200	    0.90000;
	7393	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02756	    0.00000	 220.0	 1	    1.15513	    0.90000;
	7394	 2	 2.1	 396.2	 0.0	 0.0	 1	    1.01476	    0.00000	 380.0	 1	    1.12952	    0.90000;
	7395	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7396	 1	 -34.0377	 -2.0	 0.0	 0.0	 1	    1.02286	    0.00000	 380.0	 1	    1.14571	    0.90000;
	7397	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7398	 1	 76.58492	 16.2	 0.0	 0.0	 1	    1.00514	    0.00000	 220.0	 1	    1.11028	    0.90000;
	7399	 1	 1.801998	 0.6	 0.0	 0.0	 1	    1.00488	    0.00000	 150.0	 1	    1.10977	    0.90000;
	7400	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02074	    0.00000	 220.0	 1	    1.14149	    0.90000;
	7401	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.01247	    0.00000	 220.0	 1	    1.12494	    0.90000;
	7402	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00461	    0.00000	 150.0	 1	    1.10922	    0.90000;
	7403	 1	 20.62287	 7.5	 0.0	 0.0	 1	    1.00603	    0.00000	 110.0	 1	    1.11206	    0.90000;
	7404	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7405	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02285	    0.00000	 220.0	 1	    1.14569	    0.90000;
	7406	 1	 2.8	 14.6	 0.0	 0.0	 1	    1.02780	    0.00000	 380.0	 1	    1.15560	    0.90000;
	7407	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7408	 1	 22.12453	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7409	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00961	    0.00000	 110.0	 1	    1.11923	    0.90000;
	7410	 1	 13.11454	 3.6	 0.0	 0.0	 1	    1.00992	    0.00000	 220.0	 1	    1.11984	    0.90000;
	7411	 1	 10.81199	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7412	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7413	 1	 0.0	 0.0	 0.165589	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7414	 1	 291.6	 47.0	 0.0	 0.0	 1	    1.04630	    0.00000	 220.0	 1	    1.19260	    0.90000;
	7415	 1	 0.0	 0.0	 0.181698	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7416	 1	 73.58158	 -13.1	 0.0	 0.0	 1	    1.00695	    0.00000	 220.0	 1	    1.11390	    0.90000;
	7417	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02846	    0.00000	 380.0	 1	    1.15693	    0.90000;
	7418	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7419	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00890	    0.00000	 380.0	 1	    1.11780	    0.90000;
	7420	 1	 99.6	 22.9	 0.0	 0.0	 1	    1.00519	    0.00000	 220.0	 1	    1.11039	    0.90000;
	7421	 2	 54.96094	 62.6	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7422	 1	 120.2	 30.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7423	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00613	    0.00000	 220.0	 1	    1.11226	    0.90000;
	7424	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01022	    0.00000	 220.0	 1	    1.12044	    0.90000;
	7425	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01603	    0.00000	 220.0	 1	    1.13206	    0.90000;
	7426	 1	 2.00222	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7427	 1	 0.0	 0.0	 0.564347	 0.0	 1	    1.00722	    0.00000	 380.0	 1	    1.11444	    0.90000;
	7428	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7429	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7430	 1	 -134.349	 -6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7431	 1	 165.9	 49.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7432	 1	 169.6	 98.3	 0.0	 0.0	 1	    1.00376	    0.00000	 380.0	 1	    1.10751	    0.90000;
	7433	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01739	    0.00000	 380.0	 1	    1.13478	    0.90000;
	7434	 2	 0.200222	 87.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7435	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02677	    0.00000	 150.0	 1	    1.15354	    0.90000;
	7436	 1	 4.00444	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7437	 1	 0.0	 0.0	 0.06131	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7438	 2	 49.1545	 12.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7439	 1	 3.804218	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7440	 1	 83.39246	 16.5	 0.0	 0.0	 1	    1.01855	    0.00000	 220.0	 1	    1.13711	    0.90000;
	7441	 2	 7.5	 173.3	 0.0	 0.0	 1	    1.02417	    0.00000	 380.0	 1	    1.14834	    0.90000;
	7442	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00535	    0.00000	 380.0	 1	    1.11071	    0.90000;
	7443	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7444	 1	 207.9	 25.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7445	 1	 58.96538	 11.1	 0.0	 0.0	 1	    1.00828	    0.00000	 220.0	 1	    1.11656	    0.90000;
	7446	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02808	    0.00000	 220.0	 1	    1.15615	    0.90000;
	7447	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00678	    0.00000	 220.0	 1	    1.11356	    0.90000;
	7448	 1	 63.77071	 39.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01591	    0.00000	 110.0	 1	    1.13181	    0.90000;
	7450	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01169	    0.00000	 150.0	 1	    1.12339	    0.90000;
	7451	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7452	 2	 7.207992	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7453	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00414	    0.00000	 380.0	 1	    1.10828	    0.90000;
	7454	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01660	    0.00000	 380.0	 1	    1.13319	    0.90000;
	7455	 1	 92.70278	 -5.6	 0.284	 0.0	 1	    1.01856	    0.00000	 380.0	 1	    1.13712	    0.90000;
	7456	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02519	    0.00000	 220.0	 1	    1.15037	    0.90000;
	7457	 1	 0.0	 0.0	 0.482331	 0.0	 1	    1.01225	    0.00000	 380.0	 1	    1.12449	    0.90000;
	7458	 1	 0.0	 0.0	 0.0	 64.04321	 1	    1.01200	    0.00000	 150.0	 1	    1.12400	    0.90000;
	7459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00575	    0.00000	 380.0	 1	    1.11151	    0.90000;
	7460	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7461	 1	 1.801998	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7462	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7463	 1	 0.0	 0.0	 0.0	 11.1728	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7464	 1	 1.902109	 1.3	 0.0	 0.0	 1	    1.01256	    0.00000	 110.0	 1	    1.12513	    0.90000;
	7465	 1	 118.1	 20.2	 0.0	 0.0	 1	    1.00561	    0.00000	 220.0	 1	    1.11122	    0.90000;
	7466	 1	 370.2	 107.7	 0.0	 0.0	 1	    1.02614	    0.00000	 380.0	 1	    1.15228	    0.90000;
	7467	 1	 0.0	 0.0	 0.0	 24.63838	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7468	 1	 16.51831	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7469	 2	 36.84085	 14.1	 0.0	 0.0	 1	    1.02304	    0.00000	 380.0	 1	    1.14609	    0.90000;
	7470	 1	 5.105661	 2.5	 0.0	 0.0	 1	    1.01548	    0.00000	 110.0	 1	    1.13096	    0.90000;
	7471	 2	 38.54273	 49.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7472	 1	 44.74961	 27.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01412	    0.00000	 380.0	 1	    1.12823	    0.90000;
	7474	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7475	 1	 216.8	 30.7	 0.0	 0.0	 1	    1.02607	    0.00000	 380.0	 1	    1.15213	    0.90000;
	7476	 1	 50.75628	 17.5	 0.0	 0.0	 1	    1.00908	    0.00000	 220.0	 1	    1.11816	    0.90000;
	7477	 2	 0.4	 182.7	 0.0	 0.0	 1	    1.02499	    0.00000	 380.0	 1	    1.14999	    0.90000;
	7478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7479	 1	 196.1	 32.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7480	 1	 9.610656	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7481	 2	 3.00333	 0.0	 0.0	 0.0	 1	    1.01553	    0.00000	 380.0	 1	    1.13107	    0.90000;
	7482	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7483	 1	 39.04329	 13.1	 0.0	 0.0	 1	    1.01926	    0.00000	 220.0	 1	    1.13852	    0.90000;
	7484	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01911	    0.00000	 380.0	 1	    1.13822	    0.90000;
	7485	 1	 70.0777	 43.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7486	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03884	    0.00000	 380.0	 1	    1.17769	    0.90000;
	7487	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02103	    0.00000	 380.0	 1	    1.14207	    0.90000;
	7488	 1	 69.37692	 22.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7489	 1	 255.9	 128.3	 0.0	 0.0	 1	    1.00882	    0.00000	 380.0	 1	    1.11763	    0.90000;
	7490	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00538	    0.00000	 380.0	 1	    1.11075	    0.90000;
	7491	 1	 40.44484	 20.5	 0.0	 0.0	 1	    1.03230	    0.00000	 220.0	 1	    1.16460	    0.90000;
	7492	 1	 316.7	 46.1	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7493	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02738	    0.00000	 380.0	 1	    1.15475	    0.90000;
	7494	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03310	    0.00000	 380.0	 1	    1.16620	    0.90000;
	7495	 2	 12.11343	 4.7	 0.0	 0.0	 1	    1.00379	    0.00000	 110.0	 1	    1.10757	    0.90000;
	7496	 1	 -632.101	 -447.0	 0.0	 0.0	 1	    1.00294	    0.00000	 380.0	 1	    1.10588	    0.90000;
	7497	 1	 15.61732	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7498	 1	 7.408214	 2.7	 0.0	 0.0	 1	    1.01407	    0.00000	 110.0	 1	    1.12813	    0.90000;
	7499	 1	 120.6	 35.7	 0.0	 0.0	 1	    1.00825	    0.00000	 380.0	 1	    1.11651	    0.90000;
	7500	 1	 15.61732	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7501	 1	 40.0444	 20.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7502	 1	 73.68169	 15.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7503	 1	 57.66393	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7504	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7505	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01398	    0.00000	 380.0	 1	    1.12796	    0.90000;
	7506	 1	 14.31587	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7507	 1	 9.410433	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7508	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03016	    0.00000	 380.0	 1	    1.16032	    0.90000;
	7509	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7510	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01551	    0.00000	 380.0	 1	    1.13103	    0.90000;
	7511	 1	 156.6	 16.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7512	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7513	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00308	    0.00000	 220.0	 1	    1.10616	    0.90000;
	7514	 1	 16.01776	 5.1	 0.0	 0.0	 1	    1.01953	    0.00000	 110.0	 1	    1.13906	    0.90000;
	7515	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02239	    0.00000	 110.0	 1	    1.14478	    0.90000;
	7516	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7517	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02513	    0.00000	 220.0	 1	    1.15026	    0.90000;
	7518	 1	 141.5	 70.8	 0.0	 0.0	 1	    1.00926	    0.00000	 380.0	 1	    1.11852	    0.90000;
	7519	 1	 112.7	 14.5	 0.0	 0.0	 1	    1.01639	    0.00000	 220.0	 1	    1.13278	    0.90000;
	7520	 1	 14.21576	 6.3	 0.0	 0.0	 1	    1.01130	    0.00000	 220.0	 1	    1.12259	    0.90000;
	7521	 1	 5.00555	 2.0	 0.0	 0.0	 1	    1.00977	    0.00000	 110.0	 1	    1.11955	    0.90000;
	7522	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7523	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01568	    0.00000	 380.0	 1	    1.13135	    0.90000;
	7524	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7525	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02374	    0.00000	 220.0	 1	    1.14748	    0.90000;
	7526	 1	 59.66615	 9.2	 0.0	 0.0	 1	    1.00672	    0.00000	 220.0	 1	    1.11343	    0.90000;
	7527	 1	 13.91543	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7528	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7529	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04379	    0.00000	 380.0	 1	    1.18758	    0.90000;
	7530	 1	 99.3	 23.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7531	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01599	    0.00000	 220.0	 1	    1.13198	    0.90000;
	7532	 1	 33.43707	 11.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7533	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00829	    0.00000	 220.0	 1	    1.11659	    0.90000;
	7534	 2	 43.44817	 15.9	 0.0	 0.0	 1	    1.01469	    0.00000	 220.0	 1	    1.12937	    0.90000;
	7535	 2	 0.0	 0.0	 0.0	 20.0	 1	    1.03452	    0.00000	 380.0	 1	    1.16904	    0.90000;
	7536	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7537	 1	 13.91543	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7538	 1	 19.32142	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7539	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03050	    0.00000	 220.0	 1	    1.16100	    0.90000;
	7540	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01378	    0.00000	 380.0	 1	    1.12755	    0.90000;
	7541	 1	 18.01998	 6.5	 0.0	 0.0	 1	    1.02876	    0.00000	 110.0	 1	    1.15752	    0.90000;
	7542	 1	 313.7526	 96.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7543	 1	 74.78291	 26.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7544	 1	 0.0	 0.0	 0.276	 20.0	 1	    1.00604	    0.00000	 380.0	 1	    1.11209	    0.90000;
	7545	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7546	 1	 41.44595	 56.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7547	 1	 0.0	 -8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7548	 1	 82.39135	 14.4	 0.0	 0.0	 1	    1.01918	    0.00000	 220.0	 1	    1.13836	    0.90000;
	7549	 1	 0.0	 0.0	 0.14255	 0.0	 1	    1.01421	    0.00000	 380.0	 1	    1.12841	    0.90000;
	7550	 2	 205.8	 113.2	 0.0	 0.0	 1	    1.00620	    0.00000	 220.0	 1	    1.11240	    0.90000;
	7551	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02208	    0.00000	 220.0	 1	    1.14416	    0.90000;
	7552	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00706	    0.00000	 380.0	 1	    1.11413	    0.90000;
	7553	 1	 174.7	 31.0	 0.231652	 0.0	 1	    1.01011	    0.00000	 380.0	 1	    1.12023	    0.90000;
	7554	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00590	    0.00000	 380.0	 1	    1.11181	    0.90000;
	7555	 2	 658.8	 156.2	 0.0	 0.0	 1	    1.00648	    0.00000	 150.0	 1	    1.11296	    0.90000;
	7556	 2	 257.8	 102.0	 0.23336	 503.4284	 1	    1.01415	    0.00000	 380.0	 1	    1.12829	    0.90000;
	7557	 1	 149.9	 0.0	 0.0	 0.0	 1	    1.01129	    0.00000	 380.0	 1	    1.12257	    0.90000;
	7558	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7559	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7560	 2	 29.74906	 27.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7561	 1	 97.0	 -539.3	 0.0	 0.0	 1	    1.02076	    0.00000	 380.0	 1	    1.14152	    0.90000;
	7562	 1	 44.04884	 14.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7563	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03201	    0.00000	 380.0	 1	    1.16402	    0.90000;
	7564	 1	 19.2	 9.3	 0.0	 0.0	 1	    1.01263	    0.00000	 380.0	 1	    1.12526	    0.90000;
	7565	 1	 80.28902	 -4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7566	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00616	    0.00000	 380.0	 1	    1.11232	    0.90000;
	7567	 1	 2.502775	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7568	 1	 0.100111	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7569	 2	 19.82198	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7570	 1	 67.27459	 15.9	 0.0	 0.0	 1	    1.00392	    0.00000	 220.0	 1	    1.10784	    0.90000;
	7571	 1	 155.1	 39.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7572	 1	 32.83641	 20.3	 0.0	 0.0	 1	    1.00282	    0.00000	 150.0	 1	    1.10565	    0.90000;
	7573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00320	    0.00000	 380.0	 1	    1.10639	    0.90000;
	7574	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01490	    0.00000	 150.0	 1	    1.12980	    0.90000;
	7575	 1	 50.9565	 17.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7576	 1	 0.0	 0.0	 0.152776	 0.0	 1	    1.02196	    0.00000	 380.0	 1	    1.14393	    0.90000;
	7577	 1	 2.803108	 1.0	 0.0	 0.0	 1	    1.01231	    0.00000	 110.0	 1	    1.12463	    0.90000;
	7578	 1	 126.5403	 29.1	 0.0	 0.0	 1	    1.03286	    0.00000	 220.0	 1	    1.16573	    0.90000;
	7579	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01553	    0.00000	 220.0	 1	    1.13106	    0.90000;
	7580	 1	 6.306993	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7581	 1	 12.01332	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7582	 1	 77.98647	 19.3	 0.0	 0.0	 1	    1.02027	    0.00000	 220.0	 1	    1.14055	    0.90000;
	7583	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7584	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01047	    0.00000	 220.0	 1	    1.12095	    0.90000;
	7585	 1	 81.19002	 23.4	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7586	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02861	    0.00000	 380.0	 1	    1.15722	    0.90000;
	7587	 1	 14.71632	 5.3	 0.0	 0.0	 1	    1.00359	    0.00000	 110.0	 1	    1.10719	    0.90000;
	7588	 1	 216.3	 -6.9	 0.0	 0.0	 1	    1.03322	    0.00000	 220.0	 1	    1.16644	    0.90000;
	7589	 1	 153.4	 86.8	 0.0	 0.0	 1	    1.02811	    0.00000	 380.0	 1	    1.15621	    0.90000;
	7590	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00808	    0.00000	 380.0	 1	    1.11616	    0.90000;
	7591	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01645	    0.00000	 380.0	 1	    1.13290	    0.90000;
	7592	 2	 60.86749	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7593	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01464	    0.00000	 220.0	 1	    1.12928	    0.90000;
	7594	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7595	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01121	    0.00000	 110.0	 1	    1.12241	    0.90000;
	7596	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03058	    0.00000	 380.0	 1	    1.16116	    0.90000;
	7597	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7598	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7599	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01025	    0.00000	 150.0	 1	    1.12050	    0.90000;
	7600	 1	 6.73241	 14.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7601	 2	 229.3	 31.3	 0.0	 0.0	 1	    1.01103	    0.00000	 220.0	 1	    1.12207	    0.90000;
	7602	 1	 96.8	 76.1	 0.210661	 0.0	 1	    1.00382	    0.00000	 380.0	 1	    1.10763	    0.90000;
	7603	 1	 72.18002	 49.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7604	 1	 100.8	 32.3	 0.0	 0.0	 1	    1.02423	    0.00000	 150.0	 1	    1.14847	    0.90000;
	7605	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7606	 1	 70.87859	 43.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7607	 2	 117.8	 35.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7608	 1	 131.7	 32.9	 0.0	 0.0	 1	    1.02765	    0.00000	 380.0	 1	    1.15530	    0.90000;
	7609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01408	    0.00000	 220.0	 1	    1.12815	    0.90000;
	7610	 2	 18.42042	 7.0	 0.0	 0.0	 1	    1.01272	    0.00000	 110.0	 1	    1.12544	    0.90000;
	7611	 1	 79.38802	 24.7	 0.0	 0.0	 1	    1.03013	    0.00000	 380.0	 1	    1.16027	    0.90000;
	7612	 1	 15.81754	 9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7613	 2	 28.03108	 58.8	 0.0	 0.0	 1	    1.02565	    0.00000	 380.0	 1	    1.15129	    0.90000;
	7614	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7615	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7616	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00763	    0.00000	 380.0	 1	    1.11526	    0.90000;
	7617	 1	 40.74517	 12.5	 0.0	 0.0	 1	    1.01029	    0.00000	 220.0	 1	    1.12057	    0.90000;
	7618	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01777	    0.00000	 220.0	 1	    1.13554	    0.90000;
	7619	 1	 39.94429	 13.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7620	 1	 64.57159	 23.1	 0.0	 0.0	 1	    1.00684	    0.00000	 110.0	 1	    1.11369	    0.90000;
	7621	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01508	    0.00000	 150.0	 1	    1.13015	    0.90000;
	7622	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7623	 1	 39.64395	 9.6	 0.0	 0.0	 1	    1.01415	    0.00000	 220.0	 1	    1.12829	    0.90000;
	7624	 1	 33.83752	 11.1	 0.0	 0.0	 1	    1.00610	    0.00000	 110.0	 1	    1.11219	    0.90000;
	7625	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03077	    0.00000	 380.0	 1	    1.16155	    0.90000;
	7626	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.05249	    0.00000	 220.0	 1	    1.20497	    0.90000;
	7627	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00512	    0.00000	 380.0	 1	    1.11023	    0.90000;
	7628	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03839	    0.00000	 380.0	 1	    1.17678	    0.90000;
	7629	 1	 266.0	 62.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7630	 1	 18.52053	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7631	 1	 99.1	 -98.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7632	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02525	    0.00000	 150.0	 1	    1.15050	    0.90000;
	7633	 1	 223.3	 -7.6	 0.0	 0.0	 1	    1.00605	    0.00000	 380.0	 1	    1.11209	    0.90000;
	7634	 1	 19.72187	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7635	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7636	 1	 11.21243	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7637	 1	 176.2	 -46.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7638	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00494	    0.00000	 380.0	 1	    1.10988	    0.90000;
	7639	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01238	    0.00000	 220.0	 1	    1.12476	    0.90000;
	7640	 1	 0.0	 0.0	 0.0	 -33.6445	 1	    1.01431	    0.00000	 380.0	 1	    1.12861	    0.90000;
	7641	 1	 88.49812	 27.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7642	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7643	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00628	    0.00000	 380.0	 1	    1.11257	    0.90000;
	7644	 2	 374.4	 85.5	 0.0	 0.0	 1	    1.01594	    0.00000	 380.0	 1	    1.13189	    0.90000;
	7645	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7646	 1	 8.809768	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7647	 1	 35.03885	 12.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7648	 1	 125.5	 22.5	 0.0	 0.0	 1	    1.00853	    0.00000	 220.0	 1	    1.11705	    0.90000;
	7649	 1	 380.8	 62.8	 0.0	 0.0	 1	    1.02216	    0.00000	 220.0	 1	    1.14432	    0.90000;
	7650	 1	 31.43485	 12.4	 0.0	 0.0	 1	    1.02579	    0.00000	 150.0	 1	    1.15158	    0.90000;
	7651	 1	 332.8	 92.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7652	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7653	 1	 -7.6	 28.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7654	 1	 33.63729	 4.5	 0.0	 0.0	 1	    1.02196	    0.00000	 110.0	 1	    1.14393	    0.90000;
	7655	 1	 17.01887	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7656	 1	 286.1	 89.3	 0.0	 0.0	 1	    1.02798	    0.00000	 220.0	 1	    1.15596	    0.90000;
	7657	 2	 179.4	 -18.6	 0.0	 0.0	 1	    1.01593	    0.00000	 220.0	 1	    1.13186	    0.90000;
	7658	 1	 19.82198	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7659	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7660	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7661	 1	 35.83974	 10.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7662	 1	 143.3	 71.4	 0.0	 0.0	 1	    1.00864	    0.00000	 380.0	 1	    1.11729	    0.90000;
	7663	 1	 13.91543	 10.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7664	 2	 38.04218	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7665	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7666	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02668	    0.00000	 380.0	 1	    1.15337	    0.90000;
	7667	 1	 285.2	 83.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7668	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7669	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7670	 1	 24.12675	 10.8	 0.0	 0.0	 1	    1.02246	    0.00000	 150.0	 1	    1.14491	    0.90000;
	7671	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7672	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7673	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01475	    0.00000	 220.0	 1	    1.12950	    0.90000;
	7674	 1	 216.2	 75.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7675	 1	 21.42375	 11.8	 0.0	 0.0	 1	    1.01173	    0.00000	 380.0	 1	    1.12346	    0.90000;
	7676	 1	 10.81199	 3.9	 0.0	 0.0	 1	    1.00364	    0.00000	 110.0	 1	    1.10729	    0.90000;
	7677	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7678	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7679	 2	 299.5	 48.7	 0.0	 0.0	 1	    1.02302	    0.00000	 220.0	 1	    1.14604	    0.90000;
	7680	 2	 55.96205	 30.0	 0.0	 0.0	 1	    1.02600	    0.00000	 380.0	 1	    1.15201	    0.90000;
	7681	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03352	    0.00000	 220.0	 1	    1.16704	    0.90000;
	7682	 1	 17.11898	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7683	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02711	    0.00000	 220.0	 1	    1.15422	    0.90000;
	7684	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02729	    0.00000	 220.0	 1	    1.15457	    0.90000;
	7685	 1	 161.2788	 54.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7686	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02291	    0.00000	 110.0	 1	    1.14583	    0.90000;
	7687	 2	 18.01998	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7688	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7689	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01393	    0.00000	 380.0	 1	    1.12786	    0.90000;
	7690	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02149	    0.00000	 220.0	 1	    1.14297	    0.90000;
	7691	 1	 149.0	 99.8	 0.0	 0.0	 1	    1.00477	    0.00000	 220.0	 1	    1.10955	    0.90000;
	7692	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02518	    0.00000	 380.0	 1	    1.15036	    0.90000;
	7693	 2	 51.05661	 11.3	 0.0	 0.0	 1	    1.00439	    0.00000	 380.0	 1	    1.10878	    0.90000;
	7694	 1	 66.67392	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7695	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01097	    0.00000	 150.0	 1	    1.12193	    0.90000;
	7696	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01961	    0.00000	 150.0	 1	    1.13922	    0.90000;
	7697	 1	 98.6	 27.1	 0.0	 0.0	 1	    1.02109	    0.00000	 150.0	 1	    1.14217	    0.90000;
	7698	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7699	 2	 244.0	 38.0	 0.0	 0.0	 1	    1.03868	    0.00000	 380.0	 1	    1.17736	    0.90000;
	7700	 1	 9.510545	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7701	 1	 0.0	 0.0	 0.128449	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.20000	    0.80000;
	7702	 1	 38.84307	 14.2	 0.0	 0.0	 1	    1.02635	    0.00000	 220.0	 1	    1.15271	    0.90000;
	7703	 2	 51.75739	 -47.0	 0.0	 0.0	 1	    1.00351	    0.00000	 220.0	 1	    1.10702	    0.90000;
	7704	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00973	    0.00000	 380.0	 1	    1.11947	    0.90000;
	7706	 1	 10.11121	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7707	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7708	 1	 97.6	 33.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7709	 1	 6.407104	 2.2	 0.0	 0.0	 1	    1.02873	    0.00000	 380.0	 1	    1.15747	    0.90000;
	7710	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00471	    0.00000	 110.0	 1	    1.10941	    0.90000;
	7711	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7712	 1	 37.44151	 9.1	 0.0	 0.0	 1	    1.03321	    0.00000	 220.0	 1	    1.16642	    0.90000;
	7713	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7714	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01762	    0.00000	 220.0	 1	    1.13523	    0.90000;
	7715	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7716	 1	 93.6	 -43.5	 0.0	 0.0	 1	    1.01907	    0.00000	 220.0	 1	    1.13815	    0.90000;
	7717	 1	 140.7	 10.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7718	 1	 13.51498	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7719	 1	 30.33363	 11.0	 0.0	 0.0	 1	    1.01353	    0.00000	 110.0	 1	    1.12705	    0.90000;
	7720	 2	 101.7	 59.8	 0.0	 0.0	 1	    1.02696	    0.00000	 220.0	 1	    1.15393	    0.90000;
	7721	 1	 104.3	 12.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7722	 1	 268.2	 -257.9	 0.0	 0.0	 1	    1.01253	    0.00000	 380.0	 1	    1.12507	    0.90000;
	7723	 1	 13.71521	 8.5	 0.0	 0.0	 1	    1.00346	    0.00000	 150.0	 1	    1.10693	    0.90000;
	7724	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01886	    0.00000	 220.0	 1	    1.13773	    0.90000;
	7725	 1	 53.85971	 33.4	 0.0	 0.0	 1	    1.01303	    0.00000	 220.0	 1	    1.12605	    0.90000;
	7726	 2	 83.99313	 19.4	 0.0	 0.0	 1	    1.00947	    0.00000	 220.0	 1	    1.11894	    0.90000;
	7727	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02394	    0.00000	 220.0	 1	    1.14789	    0.90000;
	7728	 1	 0.0	 -3.7	 0.0	 0.0	 1	    1.00709	    0.00000	 110.0	 1	    1.11418	    0.90000;
	7729	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01795	    0.00000	 380.0	 1	    1.13591	    0.90000;
	7730	 1	 28.13119	 10.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7731	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7732	 1	 76.98536	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7733	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7734	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7735	 2	 825.87	 363.57	 0.0	 0.0	 1	    1.04349	    0.00000	 380.0	 1	    1.18698	    0.90000;
	7736	 1	 12.31365	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7737	 1	 295.2	 39.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7738	 1	 72.68058	 24.3	 0.0	 0.0	 1	    1.02683	    0.00000	 220.0	 1	    1.15366	    0.90000;
	7739	 1	 36.4404	 22.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7740	 2	 213.3	 42.6	 0.0	 0.0	 1	    1.02396	    0.00000	 220.0	 1	    1.14791	    0.90000;
	7741	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7742	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01687	    0.00000	 380.0	 1	    1.13375	    0.90000;
	7743	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7744	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7745	 1	 87.69723	 26.0	 0.0	 0.0	 1	    1.01989	    0.00000	 220.0	 1	    1.13978	    0.90000;
	7746	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7747	 1	 9.910988	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7748	 1	 5.00555	 1.8	 0.0	 0.0	 1	    1.02630	    0.00000	 220.0	 1	    1.15261	    0.90000;
	7749	 1	 21.22353	 9.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7750	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7751	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7752	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7753	 1	 0.0	 0.0	 0.157206	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7754	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7755	 2	 0.0	 0.0	 0.095323	 0.0	 1	    1.00927	    0.00000	 380.0	 1	    1.11854	    0.90000;
	7756	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00826	    0.00000	 150.0	 1	    1.11653	    0.90000;
	7757	 1	 22.02442	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7758	 1	 128.1	 42.8	 0.0	 0.0	 1	    1.01054	    0.00000	 380.0	 1	    1.12108	    0.90000;
	7759	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7760	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7761	 1	 0.0	 -7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7762	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00443	    0.00000	 380.0	 1	    1.10886	    0.90000;
	7763	 1	 0.0	 0.0	 0.0	 -260.038	 1	    1.03153	    0.00000	 380.0	 1	    1.16306	    0.90000;
	7764	 1	 0.0	 0.0	 0.415286	 0.0	 1	    1.02077	    0.00000	 380.0	 1	    1.14153	    0.90000;
	7765	 2	 179.6	 3.0	 0.0	 0.0	 1	    1.00811	    0.00000	 220.0	 1	    1.11622	    0.90000;
	7766	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02502	    0.00000	 150.0	 1	    1.15004	    0.90000;
	7767	 1	 38.04218	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7768	 1	 15.41709	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7769	 1	 175.7	 56.2	 0.0	 0.0	 1	    1.01027	    0.00000	 220.0	 1	    1.12054	    0.90000;
	7770	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01540	    0.00000	 380.0	 1	    1.13080	    0.90000;
	7771	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7772	 1	 126.8	 21.4	 0.0	 0.0	 1	    1.00698	    0.00000	 220.0	 1	    1.11396	    0.90000;
	7773	 2	 5.305883	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7774	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01259	    0.00000	 380.0	 1	    1.12519	    0.90000;
	7775	 1	 0.0	 0.0	 0.392784	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7776	 1	 89.59934	 13.1	 0.0	 0.0	 1	    1.00604	    0.00000	 220.0	 1	    1.11209	    0.90000;
	7777	 1	 10.9121	 3.6	 0.0	 0.0	 1	    1.02552	    0.00000	 110.0	 1	    1.15104	    0.90000;
	7778	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01321	    0.00000	 220.0	 1	    1.12643	    0.90000;
	7779	 1	 9.910988	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7780	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02684	    0.00000	 380.0	 1	    1.15367	    0.90000;
	7781	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00254	    0.00000	 380.0	 1	    1.10508	    0.90000;
	7782	 1	 27.83086	 -2.6	 0.0	 0.0	 1	    1.00496	    0.00000	 220.0	 1	    1.10993	    0.90000;
	7783	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02724	    0.00000	 220.0	 1	    1.15448	    0.90000;
	7784	 1	 0.0	 0.0	 0.0	 20.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7785	 2	 13.6151	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7786	 1	 27.53052	 17.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7787	 1	 317.9	 55.4	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7788	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7789	 1	 -33.7374	 11.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7790	 2	 12.31365	 7.4	 0.0	 0.0	 1	    1.01115	    0.00000	 150.0	 1	    1.12231	    0.90000;
	7791	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01823	    0.00000	 220.0	 1	    1.13646	    0.90000;
	7792	 1	 171.3	 13.9	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7793	 1	 3.804218	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7794	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98436	    0.00000	 150.0	 1	    1.10000	    0.86872;
	7795	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7796	 1	 26.92986	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7797	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02681	    0.00000	 220.0	 1	    1.15361	    0.90000;
	7798	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01820	    0.00000	 380.0	 1	    1.13639	    0.90000;
	7799	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7800	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7801	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00510	    0.00000	 380.0	 1	    1.11020	    0.90000;
	7802	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00965	    0.00000	 380.0	 1	    1.11930	    0.90000;
	7803	 1	 0.0	 0.0	 0.0	 19.20831	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7804	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7805	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02933	    0.00000	 380.0	 1	    1.15866	    0.90000;
	7806	 1	 382.4	 86.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7807	 2	 471.7872	 140.6	 0.0	 0.0	 1	    1.02824	    0.00000	 220.0	 1	    1.15647	    0.90000;
	7808	 2	 77.98647	 18.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7809	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7810	 1	 101.8	 20.2	 0.0	 0.0	 1	    1.01096	    0.00000	 150.0	 1	    1.12193	    0.90000;
	7811	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00861	    0.00000	 380.0	 1	    1.11722	    0.90000;
	7812	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00475	    0.00000	 150.0	 1	    1.10950	    0.90000;
	7813	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7814	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7815	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7816	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7817	 1	 76.68502	 23.3	 0.0	 0.0	 1	    1.01761	    0.00000	 220.0	 1	    1.13521	    0.90000;
	7818	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7819	 2	 -8.4	 -17.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7820	 2	 -26.0289	 -2.9	 0.0	 0.0	 1	    1.01965	    0.00000	 380.0	 1	    1.13930	    0.90000;
	7821	 1	 25.02775	 18.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7822	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01523	    0.00000	 380.0	 1	    1.13045	    0.90000;
	7823	 1	 136.0	 36.1	 0.0	 0.0	 1	    1.00761	    0.00000	 220.0	 1	    1.11522	    0.90000;
	7824	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03015	    0.00000	 220.0	 1	    1.16030	    0.90000;
	7825	 1	 277.1	 37.0	 0.0	 0.0	 1	    1.03189	    0.00000	 220.0	 1	    1.16377	    0.90000;
	7826	 1	 98.60933	 50.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7827	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02842	    0.00000	 380.0	 1	    1.15684	    0.90000;
	7828	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99716	    0.00000	 150.0	 1	    1.10000	    0.89432;
	7829	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7830	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7831	 1	 74.18224	 27.3	 0.0	 0.0	 1	    1.00867	    0.00000	 220.0	 1	    1.11733	    0.90000;
	7832	 1	 282.0	 21.5	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7833	 1	 31.43485	 10.6	 0.0	 0.0	 1	    1.01400	    0.00000	 220.0	 1	    1.12800	    0.90000;
	7834	 1	 -20.3225	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7835	 1	 62.26904	 23.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7836	 1	 130.2	 88.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7837	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04326	    0.00000	 380.0	 1	    1.18653	    0.90000;
	7838	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02868	    0.00000	 380.0	 1	    1.15736	    0.90000;
	7839	 1	 163.2	 31.9	 0.0	 0.0	 1	    1.01812	    0.00000	 150.0	 1	    1.13624	    0.90000;
	7840	 1	 29.1323	 9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7841	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 380.0	 1	    1.18445	    0.90000;
	7842	 2	 49.95539	 13.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7843	 1	 -2.30255	 -0.8	 0.0	 0.0	 1	    1.01082	    0.00000	 110.0	 1	    1.12163	    0.90000;
	7844	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01385	    0.00000	 380.0	 1	    1.12770	    0.90000;
	7845	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00426	    0.00000	 150.0	 1	    1.10851	    0.90000;
	7846	 1	 4.404884	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7847	 2	 176.4	 50.6	 0.0	 0.0	 1	    1.00900	    0.00000	 220.0	 1	    1.11801	    0.90000;
	7848	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02275	    0.00000	 220.0	 1	    1.14551	    0.90000;
	7849	 1	 44.54939	 7.5	 0.0	 0.0	 1	    1.01867	    0.00000	 220.0	 1	    1.13733	    0.90000;
	7850	 1	 -16.4182	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7851	 1	 5.506105	 1.3	 0.0	 0.0	 1	    1.01364	    0.00000	 220.0	 1	    1.12727	    0.90000;
	7852	 1	 38.54273	 12.0	 0.0	 0.0	 1	    1.00505	    0.00000	 220.0	 1	    1.11010	    0.90000;
	7853	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7854	 1	 129.8	 67.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7855	 1	 226.7	 39.3	 0.0	 0.0	 1	    1.00752	    0.00000	 220.0	 1	    1.11503	    0.90000;
	7856	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01590	    0.00000	 380.0	 1	    1.13180	    0.90000;
	7857	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01219	    0.00000	 380.0	 1	    1.12439	    0.90000;
	7858	 1	 34.53829	 15.4	 0.0	 0.0	 1	    1.02909	    0.00000	 380.0	 1	    1.15819	    0.90000;
	7859	 1	 45.45039	 14.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7860	 1	 1.301443	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7861	 1	 9.910988	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7862	 1	 69.87748	 19.3	 0.0	 0.0	 1	    1.01019	    0.00000	 110.0	 1	    1.12039	    0.90000;
	7863	 1	 74.98314	 10.5	 0.0	 0.0	 1	    1.01554	    0.00000	 220.0	 1	    1.13108	    0.90000;
	7864	 2	 192.1	 33.4	 0.0	 0.0	 1	    1.01936	    0.00000	 220.0	 1	    1.13872	    0.90000;
	7865	 1	 62.7696	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7866	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01289	    0.00000	 380.0	 1	    1.12578	    0.90000;
	7867	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7868	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7869	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01060	    0.00000	 220.0	 1	    1.12120	    0.90000;
	7870	 2	 334.5	 135.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7871	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01583	    0.00000	 220.0	 1	    1.13166	    0.90000;
	7872	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7873	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7874	 2	 143.8	 23.7	 0.0	 0.0	 1	    1.01943	    0.00000	 220.0	 1	    1.13886	    0.90000;
	7875	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7876	 2	 230.1	 62.8	 0.0	 0.0	 1	    1.00957	    0.00000	 380.0	 1	    1.11914	    0.90000;
	7877	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7878	 2	 0.0	 0.0	 0.38558	 0.0	 1	    1.00328	    0.00000	 380.0	 1	    1.10656	    0.90000;
	7879	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00819	    0.00000	 150.0	 1	    1.11638	    0.90000;
	7880	 1	 42.64728	 18.2	 0.0	 0.0	 1	    1.01948	    0.00000	 220.0	 1	    1.13897	    0.90000;
	7881	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01077	    0.00000	 380.0	 1	    1.12155	    0.90000;
	7882	 2	 315.2	 82.6	 0.0	 0.0	 1	    1.02015	    0.00000	 220.0	 1	    1.14031	    0.90000;
	7883	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.01432	    0.00000	 220.0	 1	    1.12865	    0.90000;
	7884	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00869	    0.00000	 380.0	 1	    1.11738	    0.90000;
	7885	 1	 0.0	 0.0	 0.0	 -16.4305	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7886	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01210	    0.00000	 220.0	 1	    1.12421	    0.90000;
	7887	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01012	    0.00000	 150.0	 1	    1.12023	    0.90000;
	7888	 1	 20.0222	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7889	 1	 89.299	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7890	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7891	 1	 82.59157	 23.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7892	 2	 12.11343	 -4.0	 0.0	 0.0	 1	    1.00725	    0.00000	 220.0	 1	    1.11451	    0.90000;
	7893	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7894	 1	 180.7	 71.8	 0.0	 0.0	 1	    1.01300	    0.00000	 220.0	 1	    1.12601	    0.90000;
	7895	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7896	 1	 40.34473	 15.9	 0.0	 0.0	 1	    1.01699	    0.00000	 150.0	 1	    1.13399	    0.90000;
	7897	 1	 101.9	 24.3	 0.0	 0.0	 1	    1.02670	    0.00000	 220.0	 1	    1.15339	    0.90000;
	7898	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02569	    0.00000	 380.0	 1	    1.15138	    0.90000;
	7899	 1	 3.704107	 1.3	 0.0	 0.0	 1	    1.00930	    0.00000	 110.0	 1	    1.11860	    0.90000;
	7900	 1	 124.5	 -6.0	 0.0	 0.0	 1	    1.00607	    0.00000	 220.0	 1	    1.11213	    0.90000;
	7901	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00719	    0.00000	 220.0	 1	    1.11438	    0.90000;
	7902	 2	 4.00444	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7903	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7904	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02736	    0.00000	 380.0	 1	    1.15472	    0.90000;
	7905	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7906	 1	 23.52608	 8.5	 0.0	 0.0	 1	    1.02192	    0.00000	 110.0	 1	    1.14385	    0.90000;
	7907	 1	 15.31698	 5.0	 0.0	 0.0	 1	    1.01097	    0.00000	 110.0	 1	    1.12194	    0.90000;
	7908	 1	 91.80178	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7909	 1	 3.503885	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7910	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02495	    0.00000	 380.0	 1	    1.14989	    0.90000;
	7911	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03129	    0.00000	 220.0	 1	    1.16257	    0.90000;
	7912	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03887	    0.00000	 220.0	 1	    1.17774	    0.90000;
	7913	 1	 127.9	 3.7	 0.0	 0.0	 1	    1.02161	    0.00000	 380.0	 1	    1.14322	    0.90000;
	7914	 1	 126.3	 109.2	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7915	 1	 100.4	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7916	 1	 0.0	 0.0	 0.0	 13.29987	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7917	 1	 443.8	 172.1	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7918	 2	 12.11343	 -1.7	 0.0	 0.0	 1	    1.00798	    0.00000	 220.0	 1	    1.11597	    0.90000;
	7919	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00287	    0.00000	 150.0	 1	    1.10574	    0.90000;
	7920	 1	 191.2	 16.4	 0.0	 0.0	 1	    1.01773	    0.00000	 380.0	 1	    1.13546	    0.90000;
	7921	 1	 66.27348	 19.3	 0.0	 0.0	 1	    1.02066	    0.00000	 220.0	 1	    1.14131	    0.90000;
	7922	 1	 0.0	 0.0	 0.124999	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7923	 1	 13.41487	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7924	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7925	 2	 61.96871	 38.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7926	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02037	    0.00000	 150.0	 1	    1.14074	    0.90000;
	7927	 1	 105.8	 53.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7928	 1	 2.502775	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7929	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03015	    0.00000	 380.0	 1	    1.16030	    0.90000;
	7930	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01585	    0.00000	 380.0	 1	    1.13169	    0.90000;
	7931	 1	 11.61288	 7.6	 0.0	 0.0	 1	    1.01750	    0.00000	 220.0	 1	    1.13499	    0.90000;
	7932	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7933	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7934	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00358	    0.00000	 110.0	 1	    1.10715	    0.90000;
	7935	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7936	 1	 279.7	 4.6	 0.0	 0.0	 1	    1.03122	    0.00000	 220.0	 1	    1.16245	    0.90000;
	7937	 1	 5.105661	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7938	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7939	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01858	    0.00000	 220.0	 1	    1.13716	    0.90000;
	7940	 1	 61.98314	 39.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7941	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01804	    0.00000	 220.0	 1	    1.13608	    0.90000;
	7942	 1	 30.0333	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7943	 1	 19.02109	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7944	 1	 54.6606	 18.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7945	 1	 43.04773	 25.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7946	 2	 62.96982	 57.7	 0.0	 0.0	 1	    1.03266	    0.00000	 220.0	 1	    1.16532	    0.90000;
	7947	 1	 0.0	 0.0	 0.213168	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7948	 1	 92.10212	 38.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7949	 2	 18.62065	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7950	 2	 58.76516	 19.5	 0.0	 0.0	 1	    1.01039	    0.00000	 380.0	 1	    1.12078	    0.90000;
	7951	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01629	    0.00000	 380.0	 1	    1.13258	    0.90000;
	7952	 2	 201.8	 71.2	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7953	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01566	    0.00000	 220.0	 1	    1.13131	    0.90000;
	7954	 1	 17.51942	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7955	 1	 25.72853	 9.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7956	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00413	    0.00000	 150.0	 1	    1.10827	    0.90000;
	7957	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7958	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00602	    0.00000	 150.0	 1	    1.11204	    0.90000;
	7959	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7960	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01423	    0.00000	 220.0	 1	    1.12847	    0.90000;
	7961	 1	 45.25017	 19.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7963	 1	 7.608436	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7964	 1	 35.33918	 37.8	 0.0	 0.0	 1	    1.00657	    0.00000	 220.0	 1	    1.11314	    0.90000;
	7965	 1	 292.4	 -228.7	 0.0	 0.0	 1	    1.01711	    0.00000	 380.0	 1	    1.13422	    0.90000;
	7966	 1	 1.801998	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7967	 1	 8.809768	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7968	 1	 26.22908	 9.5	 0.0	 0.0	 1	    1.02059	    0.00000	 110.0	 1	    1.14119	    0.90000;
	7969	 1	 11.51276	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7970	 1	 100.5	 19.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7971	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02310	    0.00000	 220.0	 1	    1.14619	    0.90000;
	7972	 1	 128.8	 54.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7973	 1	 22.82531	 8.0	 0.0	 0.0	 1	    1.04364	    0.00000	 220.0	 1	    1.18729	    0.90000;
	7974	 2	 148.2	 48.9	 0.0	 0.0	 1	    1.01217	    0.00000	 220.0	 1	    1.12435	    0.90000;
	7975	 1	 -29.733	 23.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7976	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03184	    0.00000	 220.0	 1	    1.16368	    0.90000;
	7977	 1	 107.9	 35.9	 0.0	 0.0	 1	    1.01924	    0.00000	 150.0	 1	    1.13848	    0.90000;
	7978	 1	 3.804218	 -12.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7979	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02877	    0.00000	 220.0	 1	    1.15754	    0.90000;
	7980	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7981	 1	 80.58935	 5.2	 0.0	 0.0	 1	    1.00379	    0.00000	 220.0	 1	    1.10757	    0.90000;
	7982	 1	 24.02664	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7983	 1	 9.910988	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7984	 1	 31.03441	 8.9	 0.0	 0.0	 1	    1.01638	    0.00000	 110.0	 1	    1.13275	    0.90000;
	7985	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7986	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02119	    0.00000	 110.0	 1	    1.14238	    0.90000;
	7987	 1	 22.02442	 4.4	 0.0	 0.0	 1	    1.01138	    0.00000	 220.0	 1	    1.12277	    0.90000;
	7988	 1	 35.23907	 11.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7989	 1	 0.0	 0.0	 0.0	 -262.278	 1	    1.03313	    0.00000	 380.0	 1	    1.16626	    0.90000;
	7990	 2	 373.0	 131.1	 0.0	 0.0	 1	    1.01599	    0.00000	 220.0	 1	    1.13198	    0.90000;
	7991	 2	 226.9	 29.2	 0.0	 0.0	 1	    1.03239	    0.00000	 220.0	 1	    1.16478	    0.90000;
	7992	 1	 101.2	 -2.9	 0.0	 0.0	 1	    1.01694	    0.00000	 220.0	 1	    1.13388	    0.90000;
	7993	 1	 0.300333	 1.5	 0.0	 0.0	 1	    1.02455	    0.00000	 220.0	 1	    1.14909	    0.90000;
	7994	 1	 47.3525	 15.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7995	 1	 32.23574	 10.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7996	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7997	 1	 89.89967	 29.3	 0.0	 0.0	 1	    1.01362	    0.00000	 150.0	 1	    1.12724	    0.90000;
	7998	 2	 12.51387	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7999	 1	 82.19112	 15.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8000	 2	 37.3414	 12.1	 0.0	 0.0	 1	    1.02455	    0.00000	 220.0	 1	    1.14910	    0.90000;
	8001	 2	 47.65283	 14.0	 0.0	 0.0	 1	    1.00632	    0.00000	 220.0	 1	    1.11263	    0.90000;
	8002	 2	 0.0	 0.0	 0.155331	 0.0	 1	    1.00999	    0.00000	 220.0	 1	    1.11998	    0.90000;
	8003	 1	 8.309213	 3.0	 0.0	 0.0	 1	    1.02542	    0.00000	 110.0	 1	    1.15084	    0.90000;
	8004	 2	 289.7	 128.5	 0.0	 0.0	 1	    1.02588	    0.00000	 380.0	 1	    1.15176	    0.90000;
	8005	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8006	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00439	    0.00000	 380.0	 1	    1.10879	    0.90000;
	8007	 1	 75.3	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8008	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8009	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00457	    0.00000	 150.0	 1	    1.10914	    0.90000;
	8010	 1	 91.60156	 27.1	 0.0	 0.0	 1	    1.01549	    0.00000	 220.0	 1	    1.13098	    0.90000;
	8011	 1	 21.32364	 7.2	 0.0	 0.0	 1	    1.01391	    0.00000	 110.0	 1	    1.12783	    0.90000;
	8012	 1	 26.32919	 10.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8013	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01928	    0.00000	 150.0	 1	    1.13857	    0.90000;
	8014	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8015	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02191	    0.00000	 220.0	 1	    1.14382	    0.90000;
	8016	 1	 113.7	 22.3	 0.0	 0.0	 1	    1.02006	    0.00000	 220.0	 1	    1.14013	    0.90000;
	8017	 1	 54.56049	 16.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8018	 1	 13.31476	 4.4	 0.0	 0.0	 1	    1.01629	    0.00000	 110.0	 1	    1.13258	    0.90000;
	8019	 1	 20.0222	 12.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8020	 1	 86.7	 41.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8021	 1	 1.501665	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8022	 1	 8.309213	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8023	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8024	 1	 208.7	 63.0	 0.0	 0.0	 1	    1.01593	    0.00000	 220.0	 1	    1.13186	    0.90000;
	8025	 1	 1.301443	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8026	 1	 13.0	 8.8	 0.0	 20.0	 1	    1.01605	    0.00000	 380.0	 1	    1.13210	    0.90000;
	8027	 1	 20.82309	 0.0	 0.0	 0.0	 1	    1.00896	    0.00000	 220.0	 1	    1.11792	    0.90000;
	8028	 1	 0.0	 0.0	 0.160798	 0.0	 1	    1.00450	    0.00000	 380.0	 1	    1.10899	    0.90000;
	8029	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98986	    0.00000	 150.0	 1	    1.10000	    0.87973;
	8030	 1	 4.404884	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8031	 1	 7.408214	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8032	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00358	    0.00000	 380.0	 1	    1.10715	    0.90000;
	8033	 1	 6.00666	 2.2	 0.0	 0.0	 1	    1.01038	    0.00000	 110.0	 1	    1.12077	    0.90000;
	8034	 1	 410.3	 91.6	 0.0	 0.0	 1	    1.02787	    0.00000	 220.0	 1	    1.15575	    0.90000;
	8035	 1	 69.1767	 35.1	 0.0	 0.0	 1	    1.00885	    0.00000	 220.0	 1	    1.11770	    0.90000;
	8036	 1	 88.4	 51.1	 0.154992	 0.0	 1	    1.01137	    0.00000	 380.0	 1	    1.12273	    0.90000;
	8037	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8038	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00298	    0.00000	 220.0	 1	    1.10596	    0.90000;
	8039	 2	 207.4	 44.3	 0.0	 0.0	 1	    1.00746	    0.00000	 220.0	 1	    1.11492	    0.90000;
	8040	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8041	 1	 57.16338	 19.7	 0.0	 0.0	 1	    1.01815	    0.00000	 220.0	 1	    1.13630	    0.90000;
	8042	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8043	 1	 50.9565	 15.7	 0.0	 0.0	 1	    1.01785	    0.00000	 110.0	 1	    1.13571	    0.90000;
	8044	 1	 55.5616	 34.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8045	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01931	    0.00000	 220.0	 1	    1.13862	    0.90000;
	8046	 1	 50.9565	 16.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8047	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01462	    0.00000	 220.0	 1	    1.12925	    0.90000;
	8048	 1	 131.5	 12.9	 0.0	 0.0	 1	    1.00668	    0.00000	 220.0	 1	    1.11336	    0.90000;
	8049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00764	    0.00000	 380.0	 1	    1.11529	    0.90000;
	8050	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03067	    0.00000	 380.0	 1	    1.16135	    0.90000;
	8051	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02336	    0.00000	 380.0	 1	    1.14671	    0.90000;
	8052	 2	 426.6	 32.4	 0.0	 0.0	 1	    1.00757	    0.00000	 220.0	 1	    1.11513	    0.90000;
	8053	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02484	    0.00000	 380.0	 1	    1.14968	    0.90000;
	8054	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04305	    0.00000	 220.0	 1	    1.18609	    0.90000;
	8055	 1	 285.2	 61.4	 0.0	 0.0	 1	    1.01808	    0.00000	 220.0	 1	    1.13615	    0.90000;
	8056	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02088	    0.00000	 150.0	 1	    1.14175	    0.90000;
	8057	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01485	    0.00000	 380.0	 1	    1.12970	    0.90000;
	8058	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02114	    0.00000	 220.0	 1	    1.14228	    0.90000;
	8059	 1	 58.2646	 16.9	 0.0	 0.0	 1	    1.00589	    0.00000	 110.0	 1	    1.11179	    0.90000;
	8060	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02784	    0.00000	 220.0	 1	    1.15569	    0.90000;
	8061	 1	 9.210212	 3.4	 0.0	 0.0	 1	    1.00801	    0.00000	 110.0	 1	    1.11601	    0.90000;
	8062	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02326	    0.00000	 150.0	 1	    1.14652	    0.90000;
	8063	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01963	    0.00000	 110.0	 1	    1.13926	    0.90000;
	8064	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02401	    0.00000	 380.0	 1	    1.14801	    0.90000;
	8065	 1	 35.63951	 10.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8066	 1	 0.0	 0.0	 0.155011	 0.0	 1	    1.03196	    0.00000	 380.0	 1	    1.16393	    0.90000;
	8067	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8068	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01067	    0.00000	 380.0	 1	    1.12134	    0.90000;
	8069	 1	 101.6	 4.5	 0.0	 0.0	 1	    1.02647	    0.00000	 220.0	 1	    1.15294	    0.90000;
	8070	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02543	    0.00000	 150.0	 1	    1.15087	    0.90000;
	8071	 1	 22.12453	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8072	 1	 18.32031	 6.6	 0.0	 0.0	 1	    1.01121	    0.00000	 110.0	 1	    1.12241	    0.90000;
	8073	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8074	 1	 278.3	 33.6	 0.0	 0.0	 1	    1.01567	    0.00000	 220.0	 1	    1.13135	    0.90000;
	8075	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02828	    0.00000	 380.0	 1	    1.15655	    0.90000;
	8076	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02120	    0.00000	 150.0	 1	    1.14241	    0.90000;
	8077	 2	 48.95428	 21.4	 0.0	 0.0	 1	    1.00894	    0.00000	 110.0	 1	    1.11787	    0.90000;
	8078	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01379	    0.00000	 380.0	 1	    1.12759	    0.90000;
	8079	 1	 0.0	 0.0	 0.224857	 0.0	 1	    1.01154	    0.00000	 380.0	 1	    1.12309	    0.90000;
	8080	 1	 3.103441	 1.6	 0.0	 0.0	 1	    1.03113	    0.00000	 220.0	 1	    1.16227	    0.90000;
	8081	 1	 36.03996	 22.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8082	 1	 5.506105	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8083	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00982	    0.00000	 380.0	 1	    1.11965	    0.90000;
	8084	 1	 24.62731	 15.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8085	 1	 0.0	 0.0	 0.107995	 0.0	 1	    1.00712	    0.00000	 380.0	 1	    1.11424	    0.90000;
	8086	 1	 91.0009	 21.0	 0.0	 0.0	 1	    1.01896	    0.00000	 220.0	 1	    1.13792	    0.90000;
	8087	 1	 29.23241	 -49.9	 0.0	 0.0	 1	    1.01345	    0.00000	 220.0	 1	    1.12690	    0.90000;
	8088	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8089	 1	 33.53718	 12.2	 0.0	 0.0	 1	    1.01528	    0.00000	 110.0	 1	    1.13055	    0.90000;
	8090	 1	 -6.80755	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8091	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02067	    0.00000	 220.0	 1	    1.14133	    0.90000;
	8092	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8093	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8094	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02239	    0.00000	 220.0	 1	    1.14479	    0.90000;
	8095	 1	 59.66615	 13.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8096	 1	 10.11121	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8097	 2	 99.10989	 -12.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8098	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8099	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8100	 1	 3.403774	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8101	 1	 7.408214	 2.7	 0.0	 0.0	 1	    1.01609	    0.00000	 110.0	 1	    1.13219	    0.90000;
	8102	 2	 88.2979	 8.9	 0.0	 0.0	 1	    1.01599	    0.00000	 220.0	 1	    1.13199	    0.90000;
	8103	 1	 6.407104	 2.3	 0.0	 0.0	 1	    1.00483	    0.00000	 110.0	 1	    1.10965	    0.90000;
	8104	 1	 67.07436	 35.5	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8105	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8106	 1	 93.9	 21.6	 0.0	 0.0	 1	    1.00374	    0.00000	 220.0	 1	    1.10748	    0.90000;
	8107	 1	 139.4	 21.2	 0.0	 0.0	 1	    1.00620	    0.00000	 220.0	 1	    1.11241	    0.90000;
	8108	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03900	    0.00000	 380.0	 1	    1.17800	    0.90000;
	8109	 1	 0.0	 -7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8110	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8111	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01442	    0.00000	 380.0	 1	    1.12885	    0.90000;
	8113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00725	    0.00000	 220.0	 1	    1.11451	    0.90000;
	8114	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8115	 1	 186.8	 22.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8116	 1	 15.81754	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8117	 1	 4.204662	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8118	 1	 19.92209	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8120	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00273	    0.00000	 220.0	 1	    1.10546	    0.90000;
	8121	 2	 1.601776	 88.5	 0.0	 0.0	 1	    1.01413	    0.00000	 380.0	 1	    1.12825	    0.90000;
	8122	 1	 3.704107	 0.2	 0.0	 0.0	 1	    1.00848	    0.00000	 220.0	 1	    1.11695	    0.90000;
	8123	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00611	    0.00000	 380.0	 1	    1.11221	    0.90000;
	8124	 1	 20.32253	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8125	 2	 300.1013	 73.7	 0.0	 0.0	 1	    1.00279	    0.00000	 220.0	 1	    1.10558	    0.90000;
	8126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8127	 1	 142.2	 33.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8128	 1	 516.7	 144.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8129	 1	 51.55716	 18.7	 0.0	 0.0	 1	    1.00402	    0.00000	 110.0	 1	    1.10804	    0.90000;
	8130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8131	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01845	    0.00000	 380.0	 1	    1.13691	    0.90000;
	8132	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8133	 1	 28.63174	 17.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8134	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00258	    0.00000	 380.0	 1	    1.10516	    0.90000;
	8136	 2	 100.7	 20.5	 0.0	 0.0	 1	    1.01776	    0.00000	 220.0	 1	    1.13553	    0.90000;
	8137	 1	 44.04884	 21.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8138	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8139	 2	 926.5	 150.4	 0.0	 0.0	 1	    1.02198	    0.00000	 150.0	 1	    1.14397	    0.90000;
	8140	 1	 45.04995	 12.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8141	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00958	    0.00000	 380.0	 1	    1.11917	    0.90000;
	8142	 1	 23.42597	 8.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8143	 1	 261.5	 95.0	 0.0	 0.0	 1	    1.01344	    0.00000	 380.0	 1	    1.12687	    0.90000;
	8144	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8145	 1	 -17.3192	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8146	 2	 298.3991	 122.5	 0.0	 0.0	 1	    1.01251	    0.00000	 220.0	 1	    1.12502	    0.90000;
	8147	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8148	 2	 274.3	 269.4	 0.0	 0.0	 1	    1.01780	    0.00000	 380.0	 1	    1.13559	    0.90000;
	8149	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01952	    0.00000	 380.0	 1	    1.13905	    0.90000;
	8150	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01958	    0.00000	 220.0	 1	    1.13915	    0.90000;
	8151	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00665	    0.00000	 220.0	 1	    1.11330	    0.90000;
	8152	 1	 81.29012	 26.5	 0.0	 0.0	 1	    1.01280	    0.00000	 150.0	 1	    1.12560	    0.90000;
	8153	 2	 60.56715	 30.7	 0.0	 0.0	 1	    1.01737	    0.00000	 110.0	 1	    1.13475	    0.90000;
	8154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8155	 1	 63.97093	 12.8	 0.0	 0.0	 1	    1.00900	    0.00000	 220.0	 1	    1.11799	    0.90000;
	8156	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8157	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8158	 1	 4.104551	 1.5	 0.0	 0.0	 1	    1.01134	    0.00000	 110.0	 1	    1.12268	    0.90000;
	8159	 1	 18.52053	 11.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8160	 1	 0.0	 0.0	 0.0	 11.28922	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8161	 1	 92.9	 48.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8162	 2	 44.94984	 21.2	 0.0	 0.0	 1	    1.02755	    0.00000	 380.0	 1	    1.15509	    0.90000;
	8163	 1	 88.49812	 24.5	 0.0	 0.0	 1	    1.01393	    0.00000	 220.0	 1	    1.12787	    0.90000;
	8164	 1	 2.00222	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8165	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00574	    0.00000	 150.0	 1	    1.11147	    0.90000;
	8166	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01676	    0.00000	 220.0	 1	    1.13353	    0.90000;
	8167	 2	 79.38802	 16.8	 0.0	 0.0	 1	    1.01488	    0.00000	 220.0	 1	    1.12977	    0.90000;
	8168	 1	 69.27681	 31.3	 0.0	 0.0	 1	    1.02213	    0.00000	 150.0	 1	    1.14425	    0.90000;
	8169	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01413	    0.00000	 380.0	 1	    1.12826	    0.90000;
	8170	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8171	 1	 41.14562	 10.3	 0.0	 0.0	 1	    1.01012	    0.00000	 220.0	 1	    1.12023	    0.90000;
	8172	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01737	    0.00000	 380.0	 1	    1.13474	    0.90000;
	8173	 2	 79.2879	 46.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8174	 2	 120.6	 13.2	 0.0	 0.0	 1	    1.01821	    0.00000	 220.0	 1	    1.13641	    0.90000;
	8175	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01085	    0.00000	 380.0	 1	    1.12169	    0.90000;
	8176	 1	 102.6	 14.7	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8177	 1	 0.0	 0.0	 0.059549	 0.0	 1	    1.00863	    0.00000	 220.0	 1	    1.11725	    0.90000;
	8178	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01307	    0.00000	 380.0	 1	    1.12614	    0.90000;
	8179	 1	 73.68169	 24.0	 0.0	 0.0	 1	    1.00976	    0.00000	 150.0	 1	    1.11953	    0.90000;
	8180	 1	 27.13008	 16.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8181	 1	 145.3	 3.8	 0.0	 0.0	 1	    1.02563	    0.00000	 380.0	 1	    1.15127	    0.90000;
	8182	 1	 0.0	 0.0	 0.269993	 0.0	 1	    1.01751	    0.00000	 380.0	 1	    1.13503	    0.90000;
	8183	 1	 88.39802	 25.2	 0.0	 0.0	 1	    1.01980	    0.00000	 220.0	 1	    1.13960	    0.90000;
	8184	 1	 25.62842	 6.5	 0.0	 0.0	 1	    1.02610	    0.00000	 220.0	 1	    1.15220	    0.90000;
	8185	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00426	    0.00000	 220.0	 1	    1.10852	    0.90000;
	8186	 1	 70.77847	 19.6	 0.0	 0.0	 1	    1.03182	    0.00000	 220.0	 1	    1.16363	    0.90000;
	8187	 2	 20.52275	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8188	 1	 0.0	 0.0	 0.275618	 0.0	 1	    1.01654	    0.00000	 380.0	 1	    1.13308	    0.90000;
	8189	 1	 5.105661	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8190	 1	 55.46149	 16.9	 0.0	 0.0	 1	    1.01259	    0.00000	 220.0	 1	    1.12518	    0.90000;
	8191	 1	 91.40134	 18.1	 0.0	 0.0	 1	    1.01881	    0.00000	 220.0	 1	    1.13762	    0.90000;
	8192	 1	 6.407104	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8193	 2	 154.4	 23.3	 0.0	 0.0	 1	    1.01556	    0.00000	 220.0	 1	    1.13112	    0.90000;
	8194	 1	 80.48924	 30.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8195	 1	 0.0	 0.0	 0.14273	 0.0	 1	    1.02164	    0.00000	 380.0	 1	    1.14328	    0.90000;
	8196	 1	 0.0	 0.0	 0.177458	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8197	 1	 0.200222	 0.1	 0.0	 0.0	 1	    1.01302	    0.00000	 110.0	 1	    1.12603	    0.90000;
	8198	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02748	    0.00000	 380.0	 1	    1.15497	    0.90000;
	8199	 1	 81.99091	 32.2	 0.0	 0.0	 1	    1.00894	    0.00000	 220.0	 1	    1.11789	    0.90000;
	8200	 1	 0.0	 0.0	 0.0	 -18.3313	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8201	 1	 132.2	 49.1	 0.0	 0.0	 1	    1.01996	    0.00000	 380.0	 1	    1.13992	    0.90000;
	8202	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02846	    0.00000	 380.0	 1	    1.15691	    0.90000;
	8203	 1	 76.88525	 16.4	 0.0	 0.0	 1	    1.01422	    0.00000	 220.0	 1	    1.12843	    0.90000;
	8204	 2	 33.73741	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8205	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8206	 2	 0.0	 0.0	 0.199988	 0.0	 1	    1.04007	    0.00000	 380.0	 1	    1.18014	    0.90000;
	8207	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00929	    0.00000	 150.0	 1	    1.11857	    0.90000;
	8208	 2	 45.04995	 -2.2	 0.0	 0.0	 1	    1.00267	    0.00000	 220.0	 1	    1.10535	    0.90000;
	8209	 2	 151.0	 30.9	 0.0	 0.0	 1	    1.01715	    0.00000	 220.0	 1	    1.13430	    0.90000;
	8210	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8211	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02025	    0.00000	 380.0	 1	    1.14049	    0.90000;
	8212	 2	 44.6495	 -1.6	 0.0	 0.0	 1	    1.01324	    0.00000	 220.0	 1	    1.12647	    0.90000;
	8213	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8214	 1	 60.56715	 18.9	 0.0	 0.0	 1	    1.01794	    0.00000	 220.0	 1	    1.13588	    0.90000;
	8215	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00835	    0.00000	 380.0	 1	    1.11669	    0.90000;
	8216	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8217	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01889	    0.00000	 220.0	 1	    1.13778	    0.90000;
	8218	 1	 36.84085	 14.1	 0.0	 0.0	 1	    1.00297	    0.00000	 220.0	 1	    1.10593	    0.90000;
	8219	 1	 0.0	 0.0	 0.0	 26.62507	 1	    0.97349	    0.00000	 150.0	 1	    1.10000	    0.84698;
	8220	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02442	    0.00000	 220.0	 1	    1.14884	    0.90000;
	8221	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8222	 2	 27.93097	 11.1	 0.0	 0.0	 1	    1.02978	    0.00000	 380.0	 1	    1.15956	    0.90000;
	8223	 2	 100.9	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8224	 2	 21.22353	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8225	 1	 72.38026	 23.0	 0.0	 0.0	 1	    1.00650	    0.00000	 220.0	 1	    1.11300	    0.90000;
	8226	 2	 42.44706	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8227	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04372	    0.00000	 220.0	 1	    1.18743	    0.90000;
	8228	 2	 492.4	 162.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8229	 1	 86.1	 40.6	 0.0	 0.0	 1	    1.00460	    0.00000	 150.0	 1	    1.10920	    0.90000;
	8230	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01570	    0.00000	 150.0	 1	    1.13141	    0.90000;
	8231	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8232	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01607	    0.00000	 380.0	 1	    1.13214	    0.90000;
	8233	 2	 25.62842	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8234	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02631	    0.00000	 220.0	 1	    1.15262	    0.90000;
	8235	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00759	    0.00000	 220.0	 1	    1.11519	    0.90000;
	8236	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8237	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02474	    0.00000	 150.0	 1	    1.14949	    0.90000;
	8238	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8239	 1	 242.4	 5.1	 0.0	 0.0	 1	    1.02577	    0.00000	 220.0	 1	    1.15153	    0.90000;
	8240	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8241	 1	 213.6002	 50.1	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8242	 1	 24.32697	 9.9	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8243	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8244	 1	 188.6	 164.9	 0.0	 0.0	 1	    1.01625	    0.00000	 380.0	 1	    1.13249	    0.90000;
	8245	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00410	    0.00000	 150.0	 1	    1.10820	    0.90000;
	8246	 1	 88.09768	 36.0	 0.0	 0.0	 1	    1.02620	    0.00000	 150.0	 1	    1.15239	    0.90000;
	8247	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01534	    0.00000	 380.0	 1	    1.13068	    0.90000;
	8248	 1	 125.0	 9.6	 0.0	 0.0	 1	    1.00708	    0.00000	 220.0	 1	    1.11416	    0.90000;
	8249	 1	 55.9	 102.9	 0.0	 0.0	 1	    1.01065	    0.00000	 380.0	 1	    1.12130	    0.90000;
	8250	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8251	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02102	    0.00000	 220.0	 1	    1.14204	    0.90000;
	8252	 1	 13.94129	 9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8253	 1	 3.804218	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8254	 1	 187.4	 72.8	 0.0	 0.0	 1	    1.02191	    0.00000	 150.0	 1	    1.14382	    0.90000;
	8255	 1	 119.0	 97.8	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8256	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00426	    0.00000	 220.0	 1	    1.10851	    0.90000;
	8257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8258	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00706	    0.00000	 380.0	 1	    1.11413	    0.90000;
	8259	 2	 140.8	 44.9	 0.0	 0.0	 1	    1.00848	    0.00000	 380.0	 1	    1.11696	    0.90000;
	8260	 1	 11.31254	 13.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8261	 2	 0.0	 -0.3	 0.0	 0.0	 1	    1.03272	    0.00000	 110.0	 1	    1.16543	    0.90000;
	8262	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8263	 1	 87.3969	 35.5	 0.0	 0.0	 1	    1.02534	    0.00000	 380.0	 1	    1.15068	    0.90000;
	8264	 2	 59.26571	 13.3	 0.0	 0.0	 1	    1.00565	    0.00000	 220.0	 1	    1.11130	    0.90000;
	8265	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02442	    0.00000	 220.0	 1	    1.14884	    0.90000;
	8266	 2	 -61.7	 -30.3	 0.0	 0.0	 1	    1.02741	    0.00000	 380.0	 1	    1.15482	    0.90000;
	8267	 1	 35.13896	 12.7	 0.0	 0.0	 1	    1.01078	    0.00000	 110.0	 1	    1.12156	    0.90000;
	8268	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02208	    0.00000	 220.0	 1	    1.14416	    0.90000;
	8269	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02109	    0.00000	 220.0	 1	    1.14218	    0.90000;
	8270	 1	 25.02775	 12.0	 0.0	 0.0	 1	    1.00639	    0.00000	 220.0	 1	    1.11278	    0.90000;
	8271	 1	 152.7	 81.0	 0.0	 0.0	 1	    1.01161	    0.00000	 380.0	 1	    1.12321	    0.90000;
	8272	 1	 36.74074	 14.1	 0.0	 0.0	 1	    1.00992	    0.00000	 380.0	 1	    1.11983	    0.90000;
	8273	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01386	    0.00000	 150.0	 1	    1.12771	    0.90000;
	8274	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02087	    0.00000	 220.0	 1	    1.14174	    0.90000;
	8275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00914	    0.00000	 150.0	 1	    1.11828	    0.90000;
	8276	 1	 349.6	 96.3	 0.0	 0.0	 1	    1.01448	    0.00000	 380.0	 1	    1.12895	    0.90000;
	8277	 1	 50.45594	 -10.8	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	8278	 1	 22.02442	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8279	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00647	    0.00000	 220.0	 1	    1.11295	    0.90000;
	8280	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01175	    0.00000	 380.0	 1	    1.12351	    0.90000;
	8281	 1	 38.84307	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8282	 1	 50.55605	 8.7	 0.0	 0.0	 1	    1.01742	    0.00000	 220.0	 1	    1.13484	    0.90000;
	8283	 2	 255.8	 17.7	 0.0	 0.0	 1	    1.02179	    0.00000	 220.0	 1	    1.14358	    0.90000;
	8284	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01784	    0.00000	 220.0	 1	    1.13567	    0.90000;
	8285	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04063	    0.00000	 380.0	 1	    1.18127	    0.90000;
	8286	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00673	    0.00000	 380.0	 1	    1.11346	    0.90000;
	8287	 1	 21.72409	 13.4	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8288	 1	 169.0395	 33.9	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8289	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8290	 2	 253.4	 111.3	 0.0	 0.0	 1	    1.00479	    0.00000	 220.0	 1	    1.10958	    0.90000;
	8291	 1	 431.5	 111.5	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8292	 2	 158.4	 31.0	 0.0	 0.0	 1	    1.02060	    0.00000	 220.0	 1	    1.14120	    0.90000;
	8293	 1	 0.0	 0.0	 0.0	 19.10083	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8294	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8295	 1	 89.6	 96.2	 0.0	 0.0	 1	    1.00255	    0.00000	 380.0	 1	    1.10509	    0.90000;
	8296	 1	 0.0	 0.0	 0.237999	 0.0	 1	    1.03906	    0.00000	 220.0	 1	    1.17812	    0.90000;
	8297	 1	 66.57381	 23.6	 0.0	 0.0	 1	    1.01254	    0.00000	 110.0	 1	    1.12508	    0.90000;
	8298	 1	 35.43929	 11.4	 0.0	 0.0	 1	    1.00353	    0.00000	 110.0	 1	    1.10707	    0.90000;
	8299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8300	 1	 15.21687	 5.1	 0.0	 0.0	 1	    1.02775	    0.00000	 110.0	 1	    1.15550	    0.90000;
	8301	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8302	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02552	    0.00000	 380.0	 1	    1.15103	    0.90000;
	8303	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01878	    0.00000	 380.0	 1	    1.13757	    0.90000;
	8304	 1	 2.202442	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8305	 1	 83.19224	 37.3	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8306	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00348	    0.00000	 220.0	 1	    1.10696	    0.90000;
	8307	 1	 0.0	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8308	 1	 0.0	 0.0	 0.0	 22.88222	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8309	 2	 60.36693	 10.5	 0.0	 0.0	 1	    1.02338	    0.00000	 220.0	 1	    1.14676	    0.90000;
	8310	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02701	    0.00000	 380.0	 1	    1.15401	    0.90000;
	8311	 1	 311.4	 310.5	 0.196284	 0.0	 1	    1.00624	    0.00000	 380.0	 1	    1.11248	    0.90000;
	8312	 2	 1.601776	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8313	 1	 94.9	 40.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8314	 1	 0.0	 0.0	 0.0	 19.91451	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8315	 1	 7.708547	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8316	 1	 244.6	 96.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8317	 1	 9.910988	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8318	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02476	    0.00000	 380.0	 1	    1.14951	    0.90000;
	8319	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01148	    0.00000	 220.0	 1	    1.12296	    0.90000;
	8320	 2	 66.67392	 11.1	 0.0	 0.0	 1	    1.01035	    0.00000	 220.0	 1	    1.12070	    0.90000;
	8321	 1	 43.14784	 26.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8322	 1	 6.00666	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8324	 1	 66.07326	 15.6	 0.0	 0.0	 1	    1.01829	    0.00000	 220.0	 1	    1.13658	    0.90000;
	8325	 2	 489.8	 162.0	 0.0	 0.0	 1	    1.01623	    0.00000	 380.0	 1	    1.13247	    0.90000;
	8326	 1	 20.32253	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8327	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02221	    0.00000	 220.0	 1	    1.14441	    0.90000;
	8328	 1	 11.41265	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8329	 1	 4.605106	 0.8	 0.0	 0.0	 1	    1.00447	    0.00000	 110.0	 1	    1.10893	    0.90000;
	8330	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8331	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02808	    0.00000	 220.0	 1	    1.15616	    0.90000;
	8332	 2	 8.00888	 3.0	 0.0	 0.0	 1	    1.01019	    0.00000	 220.0	 1	    1.12037	    0.90000;
	8333	 1	 156.3	 34.9	 0.0	 0.0	 1	    1.02411	    0.00000	 380.0	 1	    1.14822	    0.90000;
	8334	 1	 50.0555	 44.0	 0.0	 0.0	 1	    1.00432	    0.00000	 220.0	 1	    1.10863	    0.90000;
	8335	 1	 66.97426	 18.6	 0.0	 0.0	 1	    1.03214	    0.00000	 220.0	 1	    1.16428	    0.90000;
	8336	 1	 -28.3314	 9.3	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8337	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00853	    0.00000	 220.0	 1	    1.11705	    0.90000;
	8338	 1	 62.56937	 -61.0	 0.0	 0.0	 1	    1.01654	    0.00000	 220.0	 1	    1.13308	    0.90000;
	8339	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8340	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03195	    0.00000	 220.0	 1	    1.16389	    0.90000;
	8341	 1	 17.91987	 23.3	 0.0	 0.0	 1	    1.02283	    0.00000	 150.0	 1	    1.14566	    0.90000;
	8342	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8343	 1	 0.0	 0.0	 0.239999	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8344	 2	 35.63951	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8345	 2	 19.82198	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8346	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8347	 1	 282.2	 268.3	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8348	 1	 14.41598	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8349	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8350	 1	 137.9	 25.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8351	 1	 15.41709	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8352	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01295	    0.00000	 380.0	 1	    1.12590	    0.90000;
	8353	 1	 11.71299	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8354	 1	 23.42597	 7.3	 0.0	 0.0	 1	    1.01161	    0.00000	 110.0	 1	    1.12323	    0.90000;
	8355	 1	 226.1	 88.8	 0.0	 0.0	 1	    1.02140	    0.00000	 150.0	 1	    1.14279	    0.90000;
	8356	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02455	    0.00000	 220.0	 1	    1.14910	    0.90000;
	8357	 2	 16.21798	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8358	 1	 12.11343	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8359	 1	 217.7	 164.6	 0.0	 0.0	 1	    1.01220	    0.00000	 380.0	 1	    1.12441	    0.90000;
	8360	 1	 14.81643	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8361	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01665	    0.00000	 380.0	 1	    1.13330	    0.90000;
	8362	 1	 1.301443	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8363	 2	 23.52608	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8364	 1	 103.6	 4.7	 0.0	 0.0	 1	    1.00681	    0.00000	 220.0	 1	    1.11361	    0.90000;
	8365	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00947	    0.00000	 220.0	 1	    1.11893	    0.90000;
	8366	 1	 0.0	 0.0	 0.059549	 0.0	 1	    1.00707	    0.00000	 220.0	 1	    1.11414	    0.90000;
	8367	 1	 39.34362	 13.3	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8368	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8369	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02334	    0.00000	 380.0	 1	    1.14667	    0.90000;
	8370	 1	 133.5	 24.1	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8371	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00275	    0.00000	 220.0	 1	    1.10549	    0.90000;
	8372	 1	 0.0	 0.0	 0.0	 10.83751	 1	    1.00282	    0.00000	 150.0	 1	    1.10565	    0.90000;
	8373	 1	 0.0	 0.0	 0.095843	 0.0	 1	    1.00337	    0.00000	 220.0	 1	    1.10673	    0.90000;
	8374	 1	 0.0	 0.0	 0.0	 85.96878	 1	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8375	 1	 38.34251	 12.6	 0.0	 0.0	 1	    1.01119	    0.00000	 110.0	 1	    1.12239	    0.90000;
	8376	 2	 415.8	 126.6	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8377	 2	 255.7	 65.6	 0.0	 0.0	 1	    1.02074	    0.00000	 220.0	 1	    1.14149	    0.90000;
	8378	 1	 31.93541	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8379	 1	 157.0	 44.2	 0.0	 0.0	 1	    1.02188	    0.00000	 220.0	 1	    1.14377	    0.90000;
	8380	 2	 2.00222	 0.0	 0.0	 0.0	 1	    1.01316	    0.00000	 220.0	 1	    1.12632	    0.90000;
	8381	 2	 5.606215	 2.2	 0.0	 0.0	 1	    1.02211	    0.00000	 380.0	 1	    1.14421	    0.90000;
	8382	 1	 246.5	 -1.9	 0.0	 0.0	 1	    1.02740	    0.00000	 380.0	 1	    1.15481	    0.90000;
	8383	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01409	    0.00000	 110.0	 1	    1.12818	    0.90000;
	8384	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03454	    0.00000	 380.0	 1	    1.16909	    0.90000;
	8385	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01754	    0.00000	 380.0	 1	    1.13507	    0.90000;
	8386	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8387	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01139	    0.00000	 220.0	 1	    1.12278	    0.90000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin
mpc.gen = [
	5	 1044.4	 140.4	 524.5259	 -211.567	 1.060105	 1580.692228	 1	 1200.0	 399.999996; % COW
	10	 31.25	 13.32	 9999.0	 -9999.0	 1.045776	 50.95553	 1	 9999.0	 -9999.0; % COW
	14	 467.5	 104.0	 212.965	 -93.4811	 1.040474	 718.392346	 1	 500.0	 166.666665; % COW
	20	 319.6	 86.8	 179.4347	 -66.2055	 1.012955	 496.765941	 1	 400.0	 0.0; % NG
	27	 8.0	 0.8	 0.8	 0.8	 1.020864	 12.059851	 1	 8.0	 8.0; % NG
	28	 5.3	 0.1	 0.1	 0.1	 1.025773	 7.951415	 1	 5.3	 5.3; % PEL
	34	 34.3	 1.2	 17.7615	 -7.14375	 1.023133	 51.481477	 1	 40.0	 0.0; % NG
	35	 8.01	 3.26	 9999.0	 -9999.0	 0.952528	 12.971982	 1	 9999.0	 -9999.0; % NUC
	42	 309.2	 59.2	 218.5186	 -75.9716	 1.051136	 472.224396	 1	 480.0	 0.0; % NG
	43	 7.3	 1.8	 1.8	 1.8	 1.026	 11.277965	 1	 7.3	 7.3; % NG
	51	 4.87	 2.96	 9999.0	 -9999.0	 1.030763	 8.548487	 1	 9999.0	 -9999.0; % COW
	70	 180.5	 28.3	 139.9369	 -43.7779	 1.022545	 274.057594	 1	 300.0	 100.0; % NG
	71	 0.02	 0.52	 9999.0	 -9999.0	 1.048726	 0.780577	 1	 9999.0	 -9999.0; % NUC
	79	 1.95	 1.11	 9999.0	 -9999.0	 1.031659	 3.365687	 1	 9999.0	 -9999.0; % COW
	85	 19.73	 8.33	 9999.0	 -9999.0	 1.068345	 32.124586	 1	 9999.0	 -9999.0; % COW
	96	 570.0	 10.2	 253.8527	 -113.787	 1.103763	 855.136884	 1	 600.0	 199.999998; % NG
	109	 24.9	 10.2	 18.84201	 -6.06272	 1.066727	 40.362266	 1	 40.0	 0.0; % NG
	110	 861.3	 112.3	 440.32	 -172.589	 1.066	 1302.885338	 1	 1000.0	 333.333333; % COW
	111	 4.79	 1.72	 9999.0	 -9999.0	 1.0287	 7.634175	 1	 9999.0	 -9999.0; % NG
	121	 5.05	 3.39	 9999.0	 -9999.0	 1.029075	 9.123478	 1	 9999.0	 -9999.0; % NUC
	125	 27.7	 5.9	 18.59004	 -6.32799	 1.002727	 42.482055	 1	 40.0	 0.0; % COW
	126	 158.7	 14.4	 78.14512	 -32.3995	 1.080818	 239.027953	 1	 180.0	 0.0; % NG
	131	 144.0	 4.8	 70.12466	 -29.5005	 1.095727	 216.119967	 1	 160.0	 0.0; % COW
	134	 79.6	 9.6	 77.09313	 -22.5412	 1.0975	 120.265207	 1	 160.0	 0.0; % NG
	144	 4.64	 2.37	 9999.0	 -9999.0	 1.073994	 7.815345	 1	 9999.0	 -9999.0; % COW
	147	 292.2	 63.3	 127.6701	 -56.5257	 1.030091	 448.466713	 1	 300.0	 0.0; % NG
	152	 2.2	 0.94	 9999.0	 -9999.0	 1.0096	 3.588607	 1	 9999.0	 -9999.0; % COW
	153	 14.02	 5.75	 9999.0	 -9999.0	 1.0196	 22.72997	 1	 9999.0	 -9999.0; % COW
	156	 0.69	 5.46	 9999.0	 -9999.0	 1.008891	 8.255139	 1	 9999.0	 -9999.0; % COW
	159	 31.2	 3.1	 52.63864	 -51.7172	 1.089842	 47.030442	 1	 158.0808	 0.0; % COW
	169	 19.85	 6.42	 9999.0	 -9999.0	 0.998323	 31.29357	 1	 9999.0	 -9999.0; % COW
	170	 99.9	 20.7	 54.23686	 -20.6272	 0.993364	 153.033085	 1	 120.0	 0.0; % NG
	172	 135.8	 13.0	 91.61313	 -30.9805	 1.087684	 204.631229	 1	 200.0	 0.0; % NG
	174	 268.6	 61.3	 130.1877	 -53.534	 1.075867	 413.259256	 1	 300.0	 100.0; % COW
	175	 2.64	 3.05	 9999.0	 -9999.0	 1.092354	 6.050804	 1	 9999.0	 -9999.0; % NUC
	177	 292.2	 -21.9	 123.8859	 -59.5392	 1.105553	 439.529308	 1	 300.0	 0.0; % COW
	181	 5.2	 0.3	 0.3	 0.3	 1.057864	 7.81297	 1	 5.2	 5.2; % NG
	186	 0.42	 0.0	 9999.0	 -9999.0	 1.03615	 0.63	 1	 9999.0	 -9999.0; % NG
	188	 25.4	 5.3	 18.70203	 -6.16587	 0.972727	 38.920592	 1	 40.0	 0.0; % COW
	191	 123.91	 52.96	 9999.0	 -9999.0	 1.040354	 202.129938	 1	 9999.0	 -9999.0; % NG
	193	 164.8	 64.9	 191.9957	 -52.889	 1.056395	 265.678118	 1	 400.0	 133.333333; % NG
	197	 11.16	 5.88	 9999.0	 -9999.0	 1.049023	 18.921416	 1	 9999.0	 -9999.0; % NG
	198	 1171.0	 381.4	 937.433	 -288.159	 1.079342	 1847.319859	 1	 2000.0	 666.666666; % COW
	199	 668.7	 -45.9	 402.9197	 -146.951	 1.0985	 1005.410177	 1	 900.0	 300.0; % COW
	200	 296.0	 62.0	 183.9209	 -65.2995	 1.076684	 453.635316	 1	 400.0	 133.33333; % NG
	201	 28.9	 2.9	 12.50527	 -5.62181	 0.944667	 43.567706	 1	 29.60204	 9.867347; % NG
	209	 2.13	 0.78	 9999.0	 -9999.0	 1.011746	 3.402488	 1	 9999.0	 -9999.0; % COW
	210	 0.13	 1.0	 9999.0	 -9999.0	 1.04248	 1.512622	 1	 9999.0	 -9999.0; % COW
	217	 39.0	 15.8	 38.52133	 -11.2425	 1.036909	 63.11846	 1	 80.0	 0.0; % NG
	224	 439.0	 127.6	 378.0823	 -112.594	 1.057909	 685.752295	 1	 800.0	 266.666666; % COW
	226	 52.2	 9.6	 37.47434	 -12.3498	 1.0115	 79.613127	 1	 80.0	 0.0; % NG
	232	 423.2	 37.6	 220.6567	 -85.886	 1.102342	 637.300557	 1	 500.0	 166.666667; % COW
	235	 0.68	 14.79	 9999.0	 -9999.0	 1.033422	 22.208436	 1	 9999.0	 -9999.0; % COW
	238	 45.4	 9.6	 38.09511	 -11.7155	 1.028136	 69.605819	 1	 80.0	 0.0; % NG
	243	 0.13	 1.0	 9999.0	 -9999.0	 1.079235	 1.512622	 1	 9999.0	 -9999.0; % COW
	253	 49.2	 10.0	 37.70184	 -12.0883	 0.979909	 75.308964	 1	 80.0	 0.0; % NG
	257	 1295.6	 65.4	 924.6445	 -300.349	 1.104	 1945.874397	 1	 2000.0	 666.666666; % COW
	263	 52.7	 -0.5	 26.01981	 -10.8118	 1.090773	 79.053558	 1	 60.0	 0.0; % PEL
	272	 1204.0	 144.4	 721.2503	 -258.712	 1.078658	 1818.942429	 1	 1600.0	 533.333332; % NUC
	274	 14.85	 4.95	 9999.0	 -9999.0	 0.97336	 23.479912	 1	 9999.0	 -9999.0; % COW
	281	 95.1	 21.4	 42.62279	 -18.7213	 1.014045	 146.217073	 1	 100.0	 0.0; % COW
	282	 -2.1	 286.38	 99999.0	 -99999.0	 1.092632	 429.581549	 1	 -2.1	 -2.1; % SYNC
	284	 0.16	 2.91	 9999.0	 -9999.0	 1.075726	 4.371593	 1	 9999.0	 -9999.0; % NUC
	292	 94.0	 22.2	 95.31674	 -27.2949	 1.087711	 144.87888	 1	 200.0	 0.0; % NG
	295	 213.6	 26.5	 188.9056	 -56.1422	 0.948091	 322.85635	 1	 400.0	 133.333333; % NG
	303	 -1.81	 1.5	 9999.0	 -9999.0	 1.030147	 3.526149	 1	 9999.0	 -9999.0; % COW
	304	 83.7	 12.6	 55.54403	 -19.1586	 1.076818	 126.964611	 1	 120.0	 0.0; % NG
	308	 12.84	 3.2	 9999.0	 -9999.0	 1.060331	 19.849121	 1	 9999.0	 -9999.0; % PEL
	313	 160.4	 20.8	 110.5715	 -36.9041	 1.102211	 242.614509	 1	 240.0	 0.0; % NG
	316	 0.15	 1.93	 9999.0	 -9999.0	 1.029313	 2.90373	 1	 9999.0	 -9999.0; % COW
	317	 1250.4	 256.2	 926.3492	 -297.678	 1.092132	 1914.565708	 1	 2000.0	 666.666666; % COW
	320	 4.86	 2.15	 9999.0	 -9999.0	 0.975854	 7.971495	 1	 9999.0	 -9999.0; % COW
	325	 238.3	 26.9	 186.3895	 -58.5035	 1.095395	 359.720204	 1	 400.0	 133.333333; % NG
	326	 0.03	 0.68	 9999.0	 -9999.0	 0.97953	 1.020992	 1	 9999.0	 -9999.0; % COW
	334	 318.8	 103.6	 282.9458	 -84.3021	 1.092053	 502.816468	 1	 600.0	 200.0; % COW
	338	 0.18	 1.0	 9999.0	 -9999.0	 1.064448	 1.524106	 1	 9999.0	 -9999.0; % COW
	339	 106.95	 44.5	 9999.0	 -9999.0	 0.999614	 173.757714	 1	 9999.0	 -9999.0; % PEL
	343	 42.2	 17.4	 38.39833	 -11.4385	 1.090682	 68.469701	 1	 80.0	 0.0; % NG
	348	 0.19	 4.38	 9999.0	 -9999.0	 1.086247	 6.576179	 1	 9999.0	 -9999.0; % COW
	350	 69.0	 6.0	 56.72846	 -17.8435	 1.0236	 103.890567	 1	 120.0	 0.0; % COW
	355	 2404.4	 187.9	 1224.256	 -490.165	 1.082	 3617.596299	 1	 2800.0	 933.333331; % COW
	361	 30.67	 11.83	 9999.0	 -9999.0	 0.997732	 49.308671	 1	 9999.0	 -9999.0; % COW
	362	 6.57	 4.31	 9999.0	 -9999.0	 1.021904	 11.786316	 1	 9999.0	 -9999.0; % COW
	365	 9.81	 3.56	 9999.0	 -9999.0	 1.012912	 15.653972	 1	 9999.0	 -9999.0; % COW
	367	 30.4	 -0.7	 22.21964	 -17.3452	 0.949182	 45.612087	 1	 61.22614	 0.0; % NG
	369	 3.31	 1.62	 9999.0	 -9999.0	 1.034669	 5.527759	 1	 9999.0	 -9999.0; % COW
	370	 35.9	 4.4	 17.65988	 -7.27293	 1.024636	 54.252949	 1	 40.0	 0.0; % COW
	371	 231.0	 24.5	 124.1169	 -49.8432	 1.014864	 348.443414	 1	 280.0	 0.0; % NG
	381	 636.3	 103.6	 304.3814	 -125.481	 1.070579	 967.018078	 1	 700.0	 233.333331; % COW
	388	 142.98	 57.87	 9999.0	 -9999.0	 1.059877	 231.37089	 1	 9999.0	 -9999.0; % COW
	390	 436.0	 105.5	 217.1751	 -89.2166	 1.047842	 672.873734	 1	 500.0	 166.666665; % NG
	394	 74.0	 7.0	 45.10484	 -16.1804	 1.021182	 111.495516	 1	 100.0	 0.0; % NG
	395	 308.6	 -28.2	 175.156	 -69.2068	 1.098682	 464.828678	 1	 400.0	 0.0; % NG
	396	 83.1	 9.9	 55.72715	 -19.0053	 1.085545	 125.53145	 1	 120.0	 0.0; % NG
	398	 4.5	 0.6	 0.6	 0.6	 1.0075	 6.809736	 1	 4.5	 4.5; % PEL
	402	 5.37	 2.33	 9999.0	 -9999.0	 1.045887	 8.78055	 1	 9999.0	 -9999.0; % COW
	403	 39.9	 3.6	 16.84024	 -8.04071	 1.001545	 60.093115	 1	 40.0	 0.0; % NG
	408	 47.6	 11.8	 37.86198	 -11.9408	 1.012818	 73.561199	 1	 80.0	 0.0; % PEL
	409	 260.1	 75.6	 257.2252	 -74.3989	 1.077842	 406.296176	 1	 540.0	 0.0; % COW
	410	 6.88	 3.44	 9999.0	 -9999.0	 1.057826	 11.538111	 1	 9999.0	 -9999.0; % COW
	411	 42.5	 6.1	 44.79799	 -39.8056	 0.996818	 64.4033	 1	 129.18183	 0.0; % NG
	427	 16.34	 5.12	 9999.0	 -9999.0	 1.045996	 25.685064	 1	 9999.0	 -9999.0; % COW
	438	 229.5	 -11.1	 132.4063	 -50.8474	 0.989364	 344.652412	 1	 300.0	 0.0; % NG
	441	 3.8	 2.48	 9999.0	 -9999.0	 1.011891	 6.806497	 1	 9999.0	 -9999.0; % COW
	442	 8.5	 1.1	 1.1	 1.1	 1.031	 12.856321	 1	 8.5	 8.5; % NG
	444	 105.4	 38.0	 94.56444	 -28.1008	 1.099	 168.061328	 1	 200.0	 0.0; % NG
	451	 135.89	 60.88	 9999.0	 -9999.0	 1.032798	 223.356329	 1	 9999.0	 -9999.0; % COW
	459	 19.83	 5.95	 9999.0	 -9999.0	 0.960088	 31.055123	 1	 9999.0	 -9999.0; % COW
	462	 101.4	 5.8	 94.3813	 -28.0441	 1.078553	 152.348613	 1	 200.0	 0.0; % NG
	466	 129.6	 25.6	 72.50375	 -27.2399	 1.075364	 198.156302	 1	 160.0	 0.0; % NG
	467	 539.4	 133.2	 261.7932	 -106.67	 1.075818	 833.404374	 1	 600.0	 199.999998; % COW
	469	 192.6	 28.0	 85.62814	 -37.2118	 1.031395	 291.936997	 1	 200.0	 66.666666; % NG
	503	 0.18	 3.57	 9999.0	 -9999.0	 1.04818	 5.361802	 1	 9999.0	 -9999.0; % COW
	509	 6.9	 3.0	 18.46584	 -19.3502	 1.040727	 11.285943	 1	 56.816328	 0.0; % NG
	522	 0.13	 1.0	 9999.0	 -9999.0	 1.078858	 1.512622	 1	 9999.0	 -9999.0; % COW
	523	 55.7	 4.4	 25.87924	 -11.0132	 0.997091	 83.810277	 1	 60.0	 0.0; % PEL
	527	 33.6	 7.3	 17.88329	 -7.03048	 1.057636	 51.575794	 1	 40.0	 0.0; % COW
	531	 249.0	 66.8	 185.5624	 -59.3858	 1.0595	 386.706982	 1	 400.0	 133.333333; % NG
	534	 400.8	 78.8	 380.3121	 -110.078	 1.094921	 612.709295	 1	 800.0	 266.666666; % COW
	557	 38.2	 -3.3	 17.0903	 -7.78858	 1.096591	 57.513411	 1	 40.0	 0.0; % NG
	558	 379.2	 55.2	 217.8958	 -81.1598	 1.079273	 574.79499	 1	 480.0	 159.999996; % COW
	559	 9.73	 6.29	 9999.0	 -9999.0	 0.973935	 17.379104	 1	 9999.0	 -9999.0; % NUC
	560	 671.2	 61.6	 351.176	 -139.111	 1.082368	 1011.031157	 1	 800.0	 266.666664; % COW
	569	 152.4	 5.7	 78.788	 -31.6917	 0.992455	 228.759836	 1	 180.0	 0.0; % NG
	576	 109.8	 21.6	 52.99446	 -21.8745	 1.056636	 167.856635	 1	 120.0	 0.0; % NG
	577	 20.59	 8.08	 9999.0	 -9999.0	 1.020676	 33.177969	 1	 9999.0	 -9999.0; % COW
	578	 133.7	 56.0	 135.5178	 -38.9046	 1.050773	 217.431144	 1	 280.0	 0.0; % NG
	580	 1.23	 -0.1	 9999.0	 -9999.0	 1.081123	 1.851088	 1	 9999.0	 -9999.0; % NUC
	581	 38.7	 4.0	 90.12852	 -93.0288	 1.085368	 58.359254	 1	 276.09134	 0.0; % NG
	584	 0.59	 0.83	 9999.0	 -9999.0	 1.05456	 1.527498	 1	 9999.0	 -9999.0; % COW
	586	 47.2	 5.6	 37.9476	 -11.8693	 1.054773	 71.296564	 1	 80.0	 0.0; % COW
	589	 17.53	 3.75	 9999.0	 -9999.0	 0.950047	 26.889917	 1	 9999.0	 -9999.0; % COW
	593	 0.15	 1.93	 9999.0	 -9999.0	 1.029293	 2.90373	 1	 9999.0	 -9999.0; % COW
	603	 5.61	 2.79	 9999.0	 -9999.0	 1.07087	 9.398215	 1	 9999.0	 -9999.0; % COW
	608	 67.0	 11.9	 71.32494	 -62.9243	 1.063974	 102.072878	 1	 205.80612	 0.0; % NG
	618	 37.4	 12.2	 38.76588	 -11.0648	 1.084227	 59.009321	 1	 80.0	 0.0; % PEL
	622	 20.7	 5.2	 34.74669	 -34.262	 1.053045	 32.014723	 1	 104.27135	 0.0; % NG
	627	 274.8	 -4.8	 182.1713	 -62.7871	 1.09875	 412.262877	 1	 400.0	 133.333332; % COW
	631	 0.61	 1.21	 9999.0	 -9999.0	 1.073545	 2.032597	 1	 9999.0	 -9999.0; % COW
	632	 634.8	 61.4	 357.3998	 -132.748	 1.096316	 956.643742	 1	 800.0	 266.666666; % NUC
	633	 274.8	 8.2	 129.9381	 -53.9068	 1.016727	 412.383474	 1	 300.0	 100.0; % COW
	643	 16.0	 1.4	 22.22661	 -20.8341	 1.085395	 24.0917	 1	 65.29948	 0.0; % PEL
	645	 451.2	 139.2	 377.0113	 -113.626	 1.055184	 708.276556	 1	 800.0	 266.666666; % COW
	647	 99.3	 9.3	 53.98251	 -20.7936	 0.991455	 149.601822	 1	 120.0	 0.0; % NG
	648	 453.4	 122.2	 376.3604	 -114.083	 1.092237	 704.368441	 1	 800.0	 266.666666; % COW
	651	 17.19	 5.2	 9999.0	 -9999.0	 1.039331	 26.938935	 1	 9999.0	 -9999.0; % COW
	652	 0.54	 0.99	 9999.0	 -9999.0	 1.043796	 1.691545	 1	 9999.0	 -9999.0; % COW
	659	 419.2	 174.6	 379.6141	 -111.091	 1.097447	 681.161545	 1	 800.0	 266.666666; % COW
	665	 96.77	 44.54	 9999.0	 -9999.0	 1.04125	 159.792209	 1	 9999.0	 -9999.0; % COW
	666	 14.71	 4.51	 9999.0	 -9999.0	 1.033004	 23.078766	 1	 9999.0	 -9999.0; % COW
	668	 102.0	 22.0	 107.8562	 -95.1534	 1.016545	 156.51837	 1	 311.391	 34.599; % COW
	669	 467.0	 46.0	 212.9697	 -93.4506	 1.079789	 703.890084	 1	 500.0	 166.666665; % COW
	677	 49.2	 10.4	 37.77862	 -12.0423	 0.989364	 75.430763	 1	 80.0	 0.0; % COW
	679	 215.4	 61.2	 105.6865	 -43.844	 0.995136	 335.888151	 1	 240.0	 0.0; % NG
	681	 208.5	 30.0	 136.9403	 -47.2439	 1.023545	 315.970825	 1	 300.0	 0.0; % NG
	686	 116.7	 11.4	 51.29568	 -23.4138	 1.066816	 175.883235	 1	 120.0	 0.0; % COW
	692	 37.3	 6.7	 27.88098	 -8.97053	 1.081455	 56.845448	 1	 60.0	 0.0; % NG
	693	 361.7	 56.6	 174.172	 -71.125	 1.000409	 549.15254	 1	 400.0	 133.333333; % NG
	694	 170.7	 3.9	 76.76137	 -33.8382	 1.062591	 256.116819	 1	 180.0	 0.0; % COW
	698	 0.43	 0.0	 9999.0	 -9999.0	 1.065508	 0.645	 1	 9999.0	 -9999.0; % COW
	702	 14.87	 4.17	 9999.0	 -9999.0	 0.988124	 23.165449	 1	 9999.0	 -9999.0; % COW
	703	 55.14	 27.14	 9999.0	 -9999.0	 1.081084	 92.185944	 1	 9999.0	 -9999.0; % COW
	704	 30.8	 3.3	 18.16351	 -6.7311	 1.063773	 46.464422	 1	 40.0	 0.0; % NG
	705	 16.5	 2.0	 12.36838	 -9.36122	 1.078	 24.931155	 1	 33.58376	 0.0; % NG
	706	 37.8	 8.7	 17.34023	 -7.58033	 1.068842	 58.182407	 1	 45.0	 0.0; % NG
	707	 50.8	 3.2	 37.43079	 -12.3168	 1.024136	 76.351031	 1	 80.0	 0.0; % NG
	711	 26.0	 14.72	 9999.0	 -9999.0	 1.076152	 44.816586	 1	 9999.0	 -9999.0; % COW
	716	 0.15	 1.0	 9999.0	 -9999.0	 1.077179	 1.516781	 1	 9999.0	 -9999.0; % COW
	717	 621.8	 175.4	 567.628	 -167.477	 1.103342	 969.097983	 1	 1200.0	 399.999999; % COW
	720	 58.4	 9.8	 36.75392	 -13.0447	 1.073864	 88.824828	 1	 80.0	 0.0; % COW
	721	 31.6	 14.2	 39.0043	 -10.7449	 1.014545	 51.965854	 1	 80.0	 0.0; % NG
	728	 111.2	 22.4	 74.03435	 -25.5438	 1.038955	 170.150522	 1	 160.0	 0.0; % NG
	732	 1820.0	 154.0	 864.4675	 -360.968	 1.085842	 2739.755646	 1	 2000.0	 666.666665; % COW
	736	 -17.83	 9.5	 9999.0	 -9999.0	 1.059217	 30.304414	 1	 9999.0	 -9999.0; % COW
	739	 -3.15	 1.79	 9999.0	 -9999.0	 1.03953	 5.434598	 1	 9999.0	 -9999.0; % COW
	746	 1274.2	 277.8	 926.6834	 -298.308	 1.084658	 1956.196969	 1	 2000.0	 666.666666; % NUC
	752	 85.2	 10.2	 55.58738	 -19.18	 0.999909	 128.712587	 1	 120.0	 0.0; % NG
	753	 507.0	 76.4	 264.7092	 -102.832	 1.013227	 769.086088	 1	 600.0	 200.0; % COW
	757	 44.0	 4.2	 27.19461	 -9.66223	 1.066136	 66.3	 1	 60.0	 0.0; % PEL
	764	 97.5	 15.9	 54.35089	 -20.4699	 1.091289	 148.181932	 1	 120.0	 0.0; % NG
	767	 66.8	 3.9	 49.63444	 -38.1223	 1.045867	 100.370626	 1	 136.7347	 22.789117; % NG
	768	 8.7	 1.1	 1.1	 1.1	 1.087553	 13.153897	 1	 8.7	 8.7; % NG
	770	 94.0	 32.5	 96.63999	 -27.8097	 1.065727	 149.189686	 1	 200.0	 0.0; % NG
	776	 855.6	 159.3	 440.6747	 -172.154	 1.081211	 1305.454964	 1	 1000.0	 333.333333; % NUC
	778	 55.8	 15.9	 57.97606	 -16.677	 1.054545	 87.031675	 1	 120.0	 0.0; % NG
	787	 11.81	 4.86	 9999.0	 -9999.0	 1.057058	 19.156339	 1	 9999.0	 -9999.0; % COW
	790	 343.5	 24.0	 228.1617	 -78.185	 1.081263	 516.506111	 1	 500.0	 166.666665; % COW
	801	 2.85	 7.24	 9999.0	 -9999.0	 1.032767	 11.671128	 1	 9999.0	 -9999.0; % COW
	803	 199.4	 58.9	 138.6001	 -45.2708	 1.061636	 311.875829	 1	 300.0	 100.0; % COW
	806	 1702.8	 411.6	 1097.413	 -373.912	 1.068474	 2627.759578	 1	 2400.0	 799.999998; % COW
	807	 56.7	 22.2	 58.05788	 -16.6605	 1.044273	 91.336699	 1	 120.0	 0.0; % NG
	809	 289.6	 55.2	 141.9267	 -57.7392	 1.016409	 442.220759	 1	 320.0	 0.0; % NG
	815	 4.94	 3.67	 9999.0	 -9999.0	 0.996099	 9.231096	 1	 9999.0	 -9999.0; % COW
	825	 1249.4	 419.0	 772.113	 -269.937	 1.047395	 1976.679807	 1	 1700.0	 566.666665; % COW
	828	 231.0	 20.0	 134.4455	 -49.7625	 1.079591	 347.796277	 1	 300.0	 0.0; % COW
	829	 32.0	 6.4	 18.22456	 -6.72812	 1.014182	 48.950587	 1	 40.0	 0.0; % NG
	838	 27.4	 9.3	 28.69322	 -8.15604	 1.067318	 43.402909	 1	 60.0	 0.0; % PEL
	841	 680.7	 26.7	 406.6568	 -144.751	 1.099553	 1021.835165	 1	 900.0	 300.0; % COW
	864	 10.1	 3.95	 9999.0	 -9999.0	 1.066541	 16.267395	 1	 9999.0	 -9999.0; % COW
	877	 24.29	 8.74	 9999.0	 -9999.0	 0.992788	 38.721846	 1	 9999.0	 -9999.0; % COW
	882	 1221.2	 346.2	 934.725	 -291.521	 1.101711	 1903.986274	 1	 2000.0	 666.666666; % COW
	884	 90.6	 12.0	 54.3648	 -20.2118	 0.989091	 137.08687	 1	 120.0	 0.0; % COW
	886	 21.3	 1.8	 36.01688	 -35.3457	 1.084026	 32.063882	 1	 107.8283	 0.0; % NG
	887	 70.12	 21.9	 9999.0	 -9999.0	 1.091167	 110.190539	 1	 9999.0	 -9999.0; % COW
	888	 14.9	 1.6	 1.6	 1.6	 1.016636	 22.47849	 1	 14.9	 14.9; % NG
	892	 1034.8	 111.2	 948.357	 -277.27	 1.101921	 1561.136471	 1	 2000.0	 666.666666; % COW
	893	 1029.2	 138.4	 738.935	 -240.835	 1.097158	 1557.695798	 1	 1600.0	 533.333332; % COW
	895	 20.86	 4.14	 9999.0	 -9999.0	 1.072235	 31.900285	 1	 9999.0	 -9999.0; % COW
	900	 39.8	 2.3	 16.8293	 -8.04593	 0.980455	 59.799603	 1	 40.0	 0.0; % NG
	901	 53.3	 6.7	 25.96651	 -10.8717	 1.062909	 80.579185	 1	 60.0	 0.0; % COW
	902	 34.1	 3.9	 17.84731	 -7.07292	 0.996763	 51.483444	 1	 40.0	 0.0; % NG
	910	 92.1	 29.1	 55.01811	 -19.8133	 1.074682	 144.881831	 1	 120.0	 0.0; % NG
	911	 171.0	 28.0	 89.55361	 -35.1511	 1.080409	 259.915852	 1	 200.0	 0.0; % NG
	913	 86.4	 22.7	 43.98878	 -17.3978	 0.994409	 133.998368	 1	 100.0	 0.0; % COW
	920	 0.2	 1.0	 9999.0	 -9999.0	 1.064428	 1.529706	 1	 9999.0	 -9999.0; % COW
	922	 1.04	 0.6	 9999.0	 -9999.0	 1.014597	 1.801	 1	 9999.0	 -9999.0; % COW
	930	 48.6	 10.5	 58.33813	 -16.2312	 1.010682	 74.581985	 1	 120.0	 0.0; % COW
	935	 5.91	 2.33	 9999.0	 -9999.0	 1.036036	 9.529074	 1	 9999.0	 -9999.0; % COW
	937	 138.6	 11.0	 90.64089	 -31.7295	 1.047364	 208.553734	 1	 200.0	 0.0; % COW
	938	 130.4	 11.6	 71.66254	 -27.8871	 1.028955	 196.372401	 1	 160.0	 0.0; % NG
	943	 10.1	 5.4	 9999.0	 -9999.0	 1.057995	 17.179421	 1	 9999.0	 -9999.0; % COW
	944	 202.5	 10.5	 137.3939	 -46.4522	 1.065182	 304.158059	 1	 300.0	 99.999999; % NG
	951	 829.5	 71.1	 387.8762	 -163.395	 1.079053	 1248.81235	 1	 900.0	 300.0; % NUC
	955	 0.43	 0.73	 9999.0	 -9999.0	 0.970967	 1.270846	 1	 9999.0	 -9999.0; % COW
	957	 484.82	 93.74	 173.501	 -71.7856	 1.076682	 740.698755	 1	 518.72	 252.053333; % COW
	981	 18.55	 1.66	 9999.0	 -9999.0	 1.097121	 27.93619	 1	 9999.0	 -9999.0; % COW
	986	 6.14	 1.95	 9999.0	 -9999.0	 1.090124	 9.663319	 1	 9999.0	 -9999.0; % COW
	987	 364.4	 7.6	 171.6218	 -73.4993	 1.074737	 546.718867	 1	 400.0	 133.333332; % COW
	988	 91.8	 21.0	 54.91012	 -19.8779	 1.059409	 141.257	 1	 120.0	 0.0; % NG
	995	 24.85	 3.56	 9999.0	 -9999.0	 1.03649	 37.65556	 1	 9999.0	 -9999.0; % COW
	997	 837.0	 135.6	 550.6898	 -185.152	 1.088579	 1271.869415	 1	 1200.0	 399.999999; % COW
	1001	 139.6	 46.2	 91.41771	 -31.2436	 1.073	 220.569377	 1	 200.0	 66.666666; % NG
	1003	 58.2	 7.4	 36.80028	 -13.0061	 1.079182	 88.002841	 1	 80.0	 0.0; % NG
	1005	 56.22	 14.15	 38.05292	 -11.5858	 1.014591	 86.960046	 1	 94.82	 14.82; % NG
	1006	 419.0	 4.4	 376.6637	 -112.659	 1.105132	 628.534653	 1	 800.0	 266.666666; % COW
	1013	 75.26	 27.37	 9999.0	 -9999.0	 1.008854	 120.123541	 1	 9999.0	 -9999.0; % NUC
	1020	 298.7	 48.1	 126.491	 -57.3311	 1.078545	 453.822019	 1	 300.0	 100.0; % COW
	1022	 301.2	 28.2	 158.2033	 -62.8062	 1.075	 453.775859	 1	 360.0	 0.0; % NG
	1023	 75.2	 10.2	 68.00069	 -56.0836	 1.090727	 113.832904	 1	 190.2778	 0.0; % NG
	1024	 9.0	 10.19	 9999.0	 -9999.0	 1.054154	 20.393166	 1	 9999.0	 -9999.0; % NG
	1026	 129.6	 27.6	 114.5684	 -34.7375	 1.045455	 198.759453	 1	 240.0	 0.0; % COW
	1029	 37.83	 16.27	 9999.0	 -9999.0	 1.06054	 61.770535	 1	 9999.0	 -9999.0; % COW
	1030	 667.5	 11.1	 407.6605	 -143.61	 1.085658	 1001.388429	 1	 900.0	 300.0; % COW
	1036	 930.3	 134.3	 432.4411	 -180.696	 1.081658	 1409.915886	 1	 1000.0	 333.333333; % NUC
	1037	 194.4	 44.4	 107.8861	 -41.504	 1.0165	 299.108876	 1	 240.0	 0.0; % NG
	1043	 111.7	 28.6	 153.0727	 -144.243	 1.082591	 172.954944	 1	 452.5252	 37.710433; % NG
	1064	 9.51	 3.12	 9999.0	 -9999.0	 1.013588	 15.013082	 1	 9999.0	 -9999.0; % NG
	1067	 4.4	 0.2	 0.2	 0.2	 1.027727	 6.606815	 1	 4.4	 4.4; % NG
	1068	 26.8	 2.3	 18.61375	 -6.27599	 1.022467	 40.347769	 1	 40.0	 0.0; % NG
	1069	 180.8	 22.0	 108.3462	 -39.116	 1.078727	 273.200366	 1	 240.0	 0.0; % COW
	1070	 99.4	 19.8	 94.12515	 -28.0909	 1.015	 152.029273	 1	 200.0	 66.666666; % NG
	1071	 2.35	 2.06	 9999.0	 -9999.0	 1.000338	 4.687614	 1	 9999.0	 -9999.0; % COW
	1078	 329.2	 100.0	 178.017	 -67.5522	 1.068421	 516.079878	 1	 400.0	 0.0; % COW
	1096	 0.19	 1.0	 9999.0	 -9999.0	 1.063104	 1.526835	 1	 9999.0	 -9999.0; % PEL
	1101	 0.59	 2.55	 9999.0	 -9999.0	 1.09671	 3.926048	 1	 9999.0	 -9999.0; % COW
	1109	 107.4	 33.3	 84.07069	 -26.4829	 1.023727	 168.665979	 1	 180.0	 0.0; % COW
	1113	 282.8	 28.0	 118.8385	 -55.6368	 1.091909	 426.274137	 1	 290.43	 0.0; % NG
	1115	 0.18	 1.0	 9999.0	 -9999.0	 1.064464	 1.524106	 1	 9999.0	 -9999.0; % COW
	1123	 1504.8	 284.8	 906.6108	 -319.442	 1.100237	 2297.270485	 1	 2000.0	 666.666666; % COW
	1127	 16.0	 1.1	 22.29117	 -20.9811	 1.079727	 24.056652	 1	 65.63264	 0.0; % PEL
	1129	 81.7	 2.0	 44.29841	 -17.0198	 1.086316	 122.586714	 1	 100.0	 0.0; % COW
	1130	 9.78	 3.51	 9999.0	 -9999.0	 1.014258	 15.586184	 1	 9999.0	 -9999.0; % COW
	1136	 837.0	 134.7	 550.6898	 -185.152	 1.088632	 1271.654219	 1	 1200.0	 399.999999; % COW
	1143	 71.0	 8.6	 34.913	 -14.828	 1.014591	 107.278423	 1	 80.0	 0.0; % NG
	1152	 158.4	 48.4	 191.3772	 -52.8968	 1.008409	 248.444199	 1	 400.0	 133.333333; % NG
	1156	 19.1	 2.7	 32.54085	 -32.1088	 1.003864	 28.934841	 1	 97.7041	 0.0; % NG
	1162	 0.2	 1.0	 9999.0	 -9999.0	 1.064562	 1.529706	 1	 9999.0	 -9999.0; % COW
	1172	 0.19	 78.58	 9999.0	 -9999.0	 1.080647	 117.870345	 1	 9999.0	 -9999.0; % COW
	1178	 57.0	 9.2	 36.92151	 -12.8801	 1.055364	 86.606524	 1	 80.0	 0.0; % NG
	1185	 19.83	 6.01	 9999.0	 -9999.0	 0.968529	 31.081108	 1	 9999.0	 -9999.0; % COW
	1190	 69.2	 10.0	 35.48049	 -14.3412	 1.080632	 104.878215	 1	 80.0	 0.0; % NG
	1195	 36.9	 4.4	 17.51154	 -7.41836	 1.022455	 55.742107	 1	 40.0	 0.0; % NG
	1197	 43.2	 12.8	 38.25805	 -11.5515	 1.085868	 67.584614	 1	 80.0	 0.0; % NG
	1202	 279.6	 46.8	 160.6208	 -60.2991	 1.023136	 425.234524	 1	 360.0	 0.0; % COW
	1207	 -37.69	 19.49	 9999.0	 -9999.0	 1.049571	 63.646614	 1	 9999.0	 -9999.0; % COW
	1212	 0.17	 1.82	 9999.0	 -9999.0	 1.082965	 2.741883	 1	 9999.0	 -9999.0; % COW
	1217	 184.1	 44.5	 190.6658	 -54.1992	 1.100789	 284.102772	 1	 400.0	 133.333333; % NG
	1221	 67.2	 26.7	 57.02725	 -17.6161	 1.033955	 108.464937	 1	 120.0	 0.0; % COW
	1222	 16.82	 7.63	 9999.0	 -9999.0	 1.06053	 27.704529	 1	 9999.0	 -9999.0; % COW
	1225	 0.09	 2.05	 9999.0	 -9999.0	 1.013458	 3.077962	 1	 9999.0	 -9999.0; % COW
	1232	 45.4	 13.6	 38.08381	 -11.7299	 1.035273	 71.089873	 1	 80.0	 0.0; % NG
	1233	 3.29	 1.32	 9999.0	 -9999.0	 1.085148	 5.317389	 1	 9999.0	 -9999.0; % COW
	1238	 128.2	 17.8	 91.50876	 -30.7596	 0.951545	 194.14474	 1	 200.0	 66.666666; % COW
	1242	 314.0	 52.0	 179.34	 -66.1002	 1.068711	 477.414914	 1	 400.0	 133.333332; % NG
	1254	 0.69	 3.65	 9999.0	 -9999.0	 0.987636	 5.57197	 1	 9999.0	 -9999.0; % NUC
	1259	 5.07	 3.17	 9999.0	 -9999.0	 1.014707	 8.969172	 1	 9999.0	 -9999.0; % COW
	1261	 363.9	 67.3	 174.1079	 -71.2403	 0.980591	 555.106409	 1	 400.0	 133.333333; % NG
	1264	 299.2	 47.0	 126.7997	 -57.0953	 1.054273	 454.303522	 1	 301.01	 100.336667; % NG
	1265	 26.2	 4.2	 18.74091	 -6.17365	 1.076227	 39.801759	 1	 40.0	 0.0; % COW
	1273	 10.9	 0.9	 11.63997	 -10.2023	 1.080763	 16.405639	 1	 33.33672	 0.0; % PEL
	1276	 200.2	 13.3	 136.4827	 -46.6725	 1.037682	 300.961945	 1	 300.0	 100.0; % NG
	1277	 22.07	 1.97	 9999.0	 -9999.0	 1.037614	 33.236622	 1	 9999.0	 -9999.0; % COW
	1282	 766.4	 63.2	 338.6569	 -151.759	 1.065091	 1153.502146	 1	 800.0	 266.666664; % COW
	1290	 44.8	 6.6	 38.08405	 -11.7045	 0.983273	 67.925327	 1	 80.0	 0.0; % PEL
	1294	 31.2	 4.6	 18.09436	 -6.79388	 1.036182	 47.305919	 1	 40.0	 0.0; % NG
	1296	 4.89	 2.35	 9999.0	 -9999.0	 0.994613	 8.13805	 1	 9999.0	 -9999.0; % NUC
	1298	 416.5	 69.0	 220.3241	 -86.2224	 1.073684	 633.265199	 1	 500.0	 0.0; % COW
	1307	 49.4	 6.8	 37.72001	 -12.0877	 1.060455	 74.79873	 1	 80.0	 0.0; % NG
	1312	 126.74	 44.57	 9999.0	 -9999.0	 1.07671	 201.522711	 1	 9999.0	 -9999.0; % COW
	1326	 1592.0	 80.5	 895.2274	 -330.781	 1.098447	 2391.050933	 1	 2000.0	 666.666665; % NG
	1332	 11.03	 5.11	 9999.0	 -9999.0	 1.044907	 18.234288	 1	 9999.0	 -9999.0; % COW
	1341	 785.4	 87.6	 394.4526	 -156.998	 1.073316	 1185.405235	 1	 900.0	 300.0; % COW
	1344	 62.6	 15.4	 36.39672	 -13.4413	 1.060909	 96.699638	 1	 80.0	 0.0; % COW
	1347	 925.6	 186.3	 539.9899	 -195.853	 1.041864	 1416.243928	 1	 1200.0	 399.999999; % COW
	1350	 288.3	 7.2	 127.7235	 -56.3612	 1.055227	 432.584838	 1	 300.0	 0.0; % COW
	1353	 360.0	 25.0	 176.6219	 -72.7521	 1.094409	 541.300517	 1	 400.0	 0.0; % COW
	1358	 455.4	 118.8	 376.3053	 -114.176	 1.072636	 705.960941	 1	 800.0	 266.666666; % COW
	1360	 1.85	 1.63	 9999.0	 -9999.0	 1.061162	 3.698466	 1	 9999.0	 -9999.0; % COW
	1364	 5.2	 0.2	 0.2	 0.2	 1.097789	 7.805767	 1	 5.2	 5.2; % COW
	1373	 26.2	 5.3	 18.77376	 -6.1563	 1.064091	 40.096041	 1	 40.0	 0.0; % PEL
	1374	 149.2	 35.0	 90.08666	 -32.4922	 1.065364	 229.875379	 1	 200.0	 0.0; % NG
	1391	 10.86	 5.93	 9999.0	 -9999.0	 1.052282	 18.56031	 1	 9999.0	 -9999.0; % NUC
	1403	 33.12	 9.16	 9999.0	 -9999.0	 1.088761	 51.545029	 1	 9999.0	 -9999.0; % NUC
	1410	 341.2	 44.0	 175.2955	 -69.9556	 1.066526	 516.038022	 1	 400.0	 133.333332; % COW
	1414	 350.0	 3.1	 174.2149	 -70.7485	 1.103737	 525.020592	 1	 400.0	 133.333333; % NG
	1419	 453.4	 122.0	 376.3604	 -114.083	 1.092237	 704.29043	 1	 800.0	 266.666666; % COW
	1421	 993.3	 173.8	 478.4516	 -196.844	 1.064211	 1512.585698	 1	 1100.0	 366.666663; % COW
	1422	 0.5	 1.0	 9999.0	 -9999.0	 1.040733	 1.677051	 1	 9999.0	 -9999.0; % NG
	1431	 121.4	 13.4	 93.1621	 -29.4852	 1.095842	 183.20595	 1	 200.0	 66.666666; % NG
	1442	 312.0	 18.8	 177.9814	 -67.0068	 1.084737	 468.848846	 1	 400.0	 0.0; % COW
	1443	 9.85	 3.73	 9999.0	 -9999.0	 0.98905	 15.798881	 1	 9999.0	 -9999.0; % COW
	1450	 0.16	 11.88	 9999.0	 -9999.0	 1.04174	 17.821616	 1	 9999.0	 -9999.0; % COW
	1453	 23.34	 8.13	 9999.0	 -9999.0	 1.046454	 37.073146	 1	 9999.0	 -9999.0; % COW
	1462	 50.6	 13.2	 37.66067	 -12.1682	 1.0405	 78.440105	 1	 80.0	 0.0; % NG
	1464	 358.2	 56.4	 174.6007	 -70.7064	 1.097816	 543.919525	 1	 400.0	 133.333333; % NG
	1475	 15.5	 2.4	 21.27174	 -20.0725	 1.071632	 23.527059	 1	 62.70708	 0.0; % NG
	1478	 0.22	 0.4	 9999.0	 -9999.0	 1.030136	 0.684763	 1	 9999.0	 -9999.0; % COW
	1490	 0.18	 1.06	 9999.0	 -9999.0	 1.059861	 1.612762	 1	 9999.0	 -9999.0; % COW
	1496	 50.4	 14.8	 37.73852	 -12.1144	 1.078	 78.792132	 1	 80.0	 0.0; % PEL
	1498	 33.1	 14.35	 9999.0	 -9999.0	 1.085557	 54.115138	 1	 9999.0	 -9999.0; % COW
	1500	 0.18	 2.5	 9999.0	 -9999.0	 1.041667	 3.759707	 1	 9999.0	 -9999.0; % NG
	1515	 15.35	 6.56	 9999.0	 -9999.0	 1.076143	 25.039493	 1	 9999.0	 -9999.0; % NUC
	1519	 0.75	 5.36	 9999.0	 -9999.0	 1.094364	 8.118326	 1	 9999.0	 -9999.0; % COW
	1524	 28.13	 0.83	 9999.0	 -9999.0	 1.095247	 42.213363	 1	 9999.0	 -9999.0; % NG
	1525	 0.03	 0.99	 9999.0	 -9999.0	 1.047019	 1.485682	 1	 9999.0	 -9999.0; % COW
	1532	 1250.4	 281.6	 928.8886	 -296.103	 1.084579	 1922.575647	 1	 2000.0	 666.666666; % NUC
	1534	 -2.06	 1.63	 9999.0	 -9999.0	 1.047354	 3.94032	 1	 9999.0	 -9999.0; % COW
	1536	 1014.8	 137.8	 530.3008	 -205.674	 1.062921	 1536.169825	 1	 1200.0	 399.999998; % NUC
	1537	 62.7	 8.4	 57.40759	 -17.2186	 1.0234	 94.890266	 1	 120.0	 0.0; % NG
	1544	 0.49	 1.27	 9999.0	 -9999.0	 0.941739	 2.041874	 1	 9999.0	 -9999.0; % NG
	1547	 18.9	 2.1	 31.94427	 -31.2368	 1.087842	 28.524463	 1	 95.45455	 0.0; % NG
	1554	 0.41	 0.0	 9999.0	 -9999.0	 1.048673	 0.615	 1	 9999.0	 -9999.0; % COW
	1558	 860.8	 118.8	 439.3657	 -173.297	 1.079342	 1303.43879	 1	 1000.0	 333.333333; % COW
	1559	 15.38	 4.94	 9999.0	 -9999.0	 1.064406	 24.230827	 1	 9999.0	 -9999.0; % COW
	1565	 73.6	 26.8	 35.11255	 -14.7618	 1.019636	 117.491276	 1	 80.0	 0.0; % NG
	1567	 19.9	 4.3	 19.24783	 -5.64568	 0.981	 30.53891	 1	 40.0	 0.0; % NG
	1569	 426.8	 112.0	 378.6989	 -111.847	 1.065273	 661.876152	 1	 800.0	 266.666666; % COW
	1570	 994.5	 270.3	 534.2367	 -201.816	 1.052079	 1545.867965	 1	 1200.0	 399.999999; % PEL
	1571	 28.1	 1.7	 18.52145	 -6.38562	 1.096591	 42.227065	 1	 40.0	 0.0; % NG
	1572	 0.2	 1.0	 9999.0	 -9999.0	 1.066343	 1.529706	 1	 9999.0	 -9999.0; % COW
	1576	 86.7	 24.3	 55.28327	 -19.4424	 1.0735	 135.061486	 1	 120.0	 0.0; % NG
	1580	 17.18	 4.35	 9999.0	 -9999.0	 1.038717	 26.583238	 1	 9999.0	 -9999.0; % COW
	1586	 200.0	 35.0	 84.74093	 -38.128	 1.011364	 304.559108	 1	 202.58	 67.526666; % NG
	1592	 79.6	 2.8	 55.21395	 -18.4759	 1.085591	 119.473847	 1	 125.0	 0.0; % NG
	1596	 835.5	 187.8	 387.6747	 -163.732	 1.073026	 1284.519542	 1	 900.0	 300.0; % COW
	1597	 326.8	 47.6	 176.6853	 -68.4505	 1.068105	 495.372587	 1	 400.0	 133.333332; % NG
	1603	 40.0	 4.6	 16.99073	 -7.92455	 1.063	 60.395447	 1	 41.06	 0.0; % NG
	1604	 9.78	 3.29	 9999.0	 -9999.0	 1.021069	 15.477827	 1	 9999.0	 -9999.0; % COW
	1605	 178.8	 20.0	 87.4773	 -35.3658	 1.024682	 269.872637	 1	 200.0	 66.666666; % NG
	1624	 595.0	 -83.34	 99999.0	 -99999.0	 1.084526	 901.212378	 1	 624.75	 0.0; % COW
	1626	 0.18	 3.85	 9999.0	 -9999.0	 1.043385	 5.781308	 1	 9999.0	 -9999.0; % COW
	1633	 108.3	 6.0	 51.65595	 -22.8464	 0.967727	 162.699116	 1	 120.0	 0.0; % NG
	1634	 1142.4	 182.4	 515.0866	 -220.893	 1.098053	 1735.304561	 1	 1200.0	 399.999999; % COW
	1636	 430.2	 116.6	 272.2458	 -94.9153	 1.043079	 668.582157	 1	 600.0	 200.0; % COW
	1641	 75.8	 6.0	 34.63629	 -15.1999	 1.017091	 114.055644	 1	 80.0	 0.0; % PEL
	1642	 1250.4	 259.8	 926.3492	 -297.678	 1.092	 1915.656924	 1	 2000.0	 666.666666; % COW
	1645	 54.6	 8.2	 36.93058	 -12.7888	 0.979909	 82.818476	 1	 80.0	 0.0; % NG
	1646	 0.63	 0.83	 9999.0	 -9999.0	 1.037611	 1.563026	 1	 9999.0	 -9999.0; % NUC
	1653	 165.6	 24.0	 111.2286	 -38.158	 1.075182	 250.995139	 1	 240.0	 0.0; % COW
	1657	 27.88	 10.61	 9999.0	 -9999.0	 1.036709	 44.745945	 1	 9999.0	 -9999.0; % COW
	1658	 345.6	 -3.6	 174.2199	 -70.909	 1.088474	 518.428124	 1	 400.0	 133.333332; % NG
	1661	 0.59	 0.0	 9999.0	 -9999.0	 1.069693	 0.885	 1	 9999.0	 -9999.0; % COW
	1663	 246.0	 -5.5	 132.4556	 -51.7136	 1.093263	 369.092214	 1	 300.0	 0.0; % COW
	1666	 658.2	 80.2	 356.0514	 -134.469	 1.065737	 994.602121	 1	 800.0	 266.666666; % COW
	1667	 64.8	 17.8	 36.03834	 -13.7799	 1.030737	 100.800446	 1	 80.0	 0.0; % NG
	1668	 0.65	 1.81	 9999.0	 -9999.0	 1.041029	 2.884762	 1	 9999.0	 -9999.0; % COW
	1678	 57.97	 23.21	 9999.0	 -9999.0	 1.021406	 93.665662	 1	 9999.0	 -9999.0; % COW
	1680	 89.13	 38.73	 9999.0	 -9999.0	 1.041069	 145.771678	 1	 9999.0	 -9999.0; % COW
	1686	 59.7	 32.7	 58.01401	 -16.804	 1.029	 102.103403	 1	 120.0	 0.0; % PEL
	1687	 28.14	 0.76	 9999.0	 -9999.0	 1.095264	 42.225392	 1	 9999.0	 -9999.0; % COW
	1688	 40.6	 9.2	 38.41651	 -11.3627	 0.977909	 62.443975	 1	 80.0	 0.0; % COW
	1691	 10.7	 1.2	 11.51823	 -10.0851	 1.081318	 16.150619	 1	 32.9694	 0.0; % PEL
	1692	 15.6	 0.9	 11.76153	 -8.88877	 1.060364	 23.43891	 1	 31.91836	 0.0; % PEL
	1693	 54.0	 21.3	 58.16419	 -16.5195	 1.047409	 87.073546	 1	 120.0	 0.0; % NG
	1710	 2.23	 1.27	 9999.0	 -9999.0	 1.053042	 3.849422	 1	 9999.0	 -9999.0; % COW
	1712	 43.4	 9.1	 27.30786	 -9.5627	 1.013818	 66.515656	 1	 60.0	 0.0; % NG
	1718	 100.2	 43.2	 117.1385	 -32.3714	 1.073867	 163.673853	 1	 240.0	 0.0; % NG
	1724	 25.07	 9.51	 9999.0	 -9999.0	 1.082211	 40.219725	 1	 9999.0	 -9999.0; % COW
	1727	 768.78	 150.0	 396.0222	 -155.827	 1.084227	 1174.915337	 1	 912.78	 312.779997; % COW
	1729	 1526.0	 296.8	 686.7284	 -294.622	 1.042605	 2331.892802	 1	 1600.0	 533.333332; % NG
	1736	 246.5	 12.5	 133.1073	 -51.2529	 1.096079	 370.2251	 1	 300.0	 0.0; % NG
	1738	 478.2	 -4.6	 263.4934	 -103.767	 1.078947	 717.333186	 1	 600.0	 0.0; % COW
	1743	 330.6	 152.0	 283.4205	 -84.4476	 1.064237	 545.802904	 1	 600.0	 200.0; % COW
	1744	 76.2	 6.2	 44.8563	 -16.4272	 1.021227	 114.677722	 1	 100.0	 0.0; % NG
	1745	 14.85	 4.92	 9999.0	 -9999.0	 0.983988	 23.46572	 1	 9999.0	 -9999.0; % NG
	1746	 37.2	 8.0	 38.67061	 -11.1014	 1.068591	 57.075739	 1	 80.0	 0.0; % NG
	1751	 115.5	 15.6	 160.3622	 -150.947	 1.054545	 174.823118	 1	 472.16328	 39.346941; % COW
	1756	 411.8	 5.6	 274.1207	 -93.0109	 1.099158	 617.757112	 1	 600.0	 200.0; % COW
	1760	 2.89	 1.8	 9999.0	 -9999.0	 1.049394	 5.107076	 1	 9999.0	 -9999.0; % NUC
	1763	 413.5	 113.0	 221.3513	 -85.3618	 1.044864	 642.993245	 1	 500.0	 0.0; % COW
	1772	 11.44	 3.29	 9999.0	 -9999.0	 1.060729	 17.855526	 1	 9999.0	 -9999.0; % COW
	1779	 4.8	 0.4	 0.4	 0.4	 1.087289	 7.224957	 1	 4.8	 4.8; % PEL
	1789	 31.0	 -2.5	 18.14115	 -6.75433	 1.097227	 46.650965	 1	 40.0	 0.0; % COW
	1800	 99.9	 20.7	 54.23686	 -20.6272	 0.993364	 153.033085	 1	 120.0	 0.0; % NG
	1818	 44.0	 4.2	 27.19461	 -9.66223	 1.066136	 66.3	 1	 60.0	 0.0; % NG
	1825	 141.6	 7.2	 80.51183	 -30.0723	 1.101763	 212.674399	 1	 180.0	 0.0; % NG
	1841	 216.0	 83.5	 239.7539	 -66.8644	 1.088409	 347.366611	 1	 500.0	 166.666665; % NG
	1842	 42.8	 4.2	 38.09945	 -11.6185	 1.014636	 64.508372	 1	 80.0	 0.0; % NG
	1853	 576.0	 126.6	 257.0038	 -110.847	 1.096267	 884.623089	 1	 600.0	 200.0; % NUC
	1858	 855.6	 155.8	 441.8502	 -171.271	 1.079974	 1304.504216	 1	 1000.0	 333.333333; % COW
	1869	 234.0	 15.6	 133.486	 -50.2551	 1.084289	 351.779135	 1	 300.0	 0.0; % NG
	1870	 0.65	 1.44	 9999.0	 -9999.0	 1.000074	 2.369858	 1	 9999.0	 -9999.0; % COW
	1872	 836.2	 234.8	 962.2016	 -263.654	 1.090211	 1302.809783	 1	 2000.0	 666.666666; % NG
	1873	 71.0	 9.2	 98.71382	 -92.6957	 1.083842	 107.390363	 1	 290.28568	 0.0; % NG
	1876	 1.8	 0.3	 0.3	 0.3	 1.085182	 2.737243	 1	 1.8	 1.8; % PEL
	1884	 0.61	 1.33	 9999.0	 -9999.0	 1.007601	 2.194823	 1	 9999.0	 -9999.0; % COW
	1885	 156.3	 22.7	 67.03379	 -30.8274	 1.089182	 236.909698	 1	 159.9082	 53.302733; % NG
	1902	 176.0	 30.5	 88.39104	 -36.1858	 1.081368	 267.93481	 1	 200.0	 0.0; % NG
	1903	 64.2	 7.4	 36.34278	 -13.5403	 1.053682	 96.937609	 1	 80.0	 0.0; % NG
	1905	 8.64	 3.97	 9999.0	 -9999.0	 1.053687	 14.262665	 1	 9999.0	 -9999.0; % PEL
	1906	 33.9	 2.7	 17.87846	 -7.04432	 1.083955	 51.011028	 1	 40.0	 0.0; % NG
	1907	 0.51	 0.58	 9999.0	 -9999.0	 0.975669	 1.158501	 1	 9999.0	 -9999.0; % COW
	1908	 5.64	 2.84	 9999.0	 -9999.0	 1.058741	 9.472022	 1	 9999.0	 -9999.0; % COW
	1911	 1066.8	 92.4	 522.7406	 -212.369	 1.092184	 1606.191147	 1	 1200.0	 400.0; % COW
	1913	 178.0	 29.4	 86.24416	 -36.2867	 1.049526	 270.617461	 1	 200.0	 66.666666; % COW
	1915	 152.3	 16.4	 160.6927	 -140.967	 1.082447	 229.770674	 1	 462.7272	 51.414133; % COW
	1921	 1269.4	 343.9	 661.9019	 -257.621	 1.054316	 1972.738714	 1	 1500.0	 499.999998; % COW
	1927	 379.2	 33.5	 172.0666	 -73.2919	 1.095395	 571.015326	 1	 400.0	 133.333333; % NG
	1929	 4.82	 1.45	 9999.0	 -9999.0	 0.964327	 7.550068	 1	 9999.0	 -9999.0; % COW
	1931	 0.2	 1.0	 9999.0	 -9999.0	 1.064571	 1.529706	 1	 9999.0	 -9999.0; % NUC
	1933	 0.19	 3.76	 9999.0	 -9999.0	 1.088007	 5.647196	 1	 9999.0	 -9999.0; % NUC
	1936	 0.04	 0.97	 9999.0	 -9999.0	 1.02989	 1.456237	 1	 9999.0	 -9999.0; % NUC
	1959	 498.4	 113.4	 266.1681	 -101.497	 1.099816	 766.707095	 1	 600.0	 200.0; % COW
	1961	 211.9	 49.5	 137.4139	 -46.4711	 1.043842	 326.407238	 1	 300.0	 100.0; % NG
	1969	 16.5	 11.49	 9999.0	 -9999.0	 1.041988	 30.159704	 1	 9999.0	 -9999.0; % COW
	1971	 39.7	 7.4	 17.2416	 -7.71534	 1.034909	 60.575676	 1	 40.0	 0.0; % NG
	1974	 125.0	 42.2	 92.3537	 -30.1097	 1.046818	 197.896791	 1	 200.0	 66.666666; % NG
	1975	 12.02	 7.68	 9999.0	 -9999.0	 1.071915	 21.396058	 1	 9999.0	 -9999.0; % NUC
	1982	 45.8	 16.6	 38.20466	 -11.6772	 1.066132	 73.073251	 1	 80.0	 0.0; % NG
	1983	 49.8	 27.9	 58.35417	 -16.2626	 1.038045	 85.624252	 1	 120.0	 0.0; % COW
	1989	 99.3	 3.6	 53.94042	 -20.8278	 1.076727	 149.047853	 1	 120.0	 0.0; % COW
	1990	 668.4	 -16.8	 405.2462	 -145.323	 1.096947	 1002.916647	 1	 900.0	 300.0; % COW
	1993	 14.27	 6.6	 9999.0	 -9999.0	 1.088696	 23.583554	 1	 9999.0	 -9999.0; % COW
	1995	 19.79	 21.11	 9999.0	 -9999.0	 1.086015	 43.403588	 1	 9999.0	 -9999.0; % NG
	1996	 7.9	 3.5	 3.5	 3.5	 1.034636	 12.960903	 1	 7.9	 7.9; % NG
	2000	 26.0	 1.9	 19.50505	 -14.7367	 1.080421	 39.103996	 1	 52.9137	 0.0; % NG
	2009	 204.3	 14.1	 137.2936	 -46.5789	 1.0354	 307.178979	 1	 300.0	 99.999999; % NG
	2010	 31.6	 10.8	 38.95567	 -10.7555	 0.996182	 50.091916	 1	 80.0	 0.0; % PEL
	2017	 0.04	 1.32	 9999.0	 -9999.0	 0.979656	 1.980909	 1	 9999.0	 -9999.0; % COW
	2023	 9.87	 3.63	 9999.0	 -9999.0	 0.971857	 15.774538	 1	 9999.0	 -9999.0; % COW
	2027	 5.2	 1.1	 1.1	 1.1	 1.077	 7.972609	 1	 5.2	 5.2; % NG
	2038	 5.3	 0.5	 0.5	 0.5	 1.046182	 7.985299	 1	 5.3	 5.3; % NG
	2039	 100.0	 16.4	 94.84088	 -27.7595	 1.067455	 152.003816	 1	 200.0	 0.0; % COW
	2041	 4.81	 1.82	 9999.0	 -9999.0	 0.991489	 7.714216	 1	 9999.0	 -9999.0; % COW
	2046	 14.31	 4.06	 9999.0	 -9999.0	 0.979297	 22.312201	 1	 9999.0	 -9999.0; % NG
	2049	 54.4	 8.4	 26.07309	 -10.8235	 0.994045	 82.567064	 1	 60.0	 0.0; % NG
	2052	 706.8	 164.6	 351.2981	 -139.521	 1.079368	 1088.569543	 1	 800.0	 266.666666; % COW
	2056	 14.83	 3.56	 9999.0	 -9999.0	 1.041035	 22.876967	 1	 9999.0	 -9999.0; % COW
	2062	 362.0	 105.5	 228.1609	 -78.8258	 1.073816	 565.590013	 1	 500.0	 166.666665; % NG
	2069	 73.54	 31.68	 9999.0	 -9999.0	 0.968259	 120.110143	 1	 9999.0	 -9999.0; % COW
	2071	 38.9	 4.9	 41.66955	 -36.497	 1.078364	 58.811096	 1	 119.29593	 0.0; % NG
	2077	 41.2	 11.2	 38.47569	 -11.352	 1.083909	 64.042798	 1	 80.0	 0.0; % NG
	2079	 0.42	 0.0	 9999.0	 -9999.0	 1.063189	 0.63	 1	 9999.0	 -9999.0; % COW
	2082	 110.5	 32.0	 95.68823	 -28.9294	 1.078591	 172.560316	 1	 200.0	 0.0; % NG
	2096	 27.25	 9.38	 9999.0	 -9999.0	 1.087726	 43.228816	 1	 9999.0	 -9999.0; % COW
	2099	 1.8	 12.01	 9999.0	 -9999.0	 1.092555	 18.216208	 1	 9999.0	 -9999.0; % COW
	2100	 164.5	 18.9	 141.3924	 -42.3685	 1.040318	 248.373278	 1	 300.0	 100.0; % COW
	2109	 82.2	 17.8	 54.86086	 -18.7998	 1.057636	 126.157758	 1	 120.0	 0.0; % NG
	2117	 0.2	 1.33	 9999.0	 -9999.0	 1.04909	 2.01743	 1	 9999.0	 -9999.0; % NUC
	2118	 0.15	 1.4	 9999.0	 -9999.0	 1.045999	 2.112019	 1	 9999.0	 -9999.0; % NUC
	2122	 431.2	 112.0	 273.4914	 -94.1036	 1.086467	 668.262104	 1	 600.0	 200.0; % NUC
	2136	 49.0	 5.3	 47.28096	 -13.9058	 1.008533	 73.928699	 1	 100.0	 33.333333; % NG
	2141	 41.8	 14.6	 38.31299	 -11.4668	 1.053447	 66.414607	 1	 80.0	 0.0; % NG
	2143	 78.2	 3.6	 34.35174	 -15.4997	 1.076342	 117.424231	 1	 80.0	 0.0; % NG
	2145	 6.43	 3.05	 9999.0	 -9999.0	 1.054551	 10.675048	 1	 9999.0	 -9999.0; % COW
	2146	 662.2	 -29.8	 351.4238	 -138.017	 1.100553	 994.305275	 1	 800.0	 266.666666; % COW
	2153	 129.4	 35.8	 92.71762	 -30.0438	 1.092955	 201.39141	 1	 200.0	 66.666666; % COW
	2175	 400.8	 78.4	 380.3121	 -110.078	 1.094947	 612.59383	 1	 800.0	 266.666666; % NG
	2178	 548.6	 178.8	 368.841	 -121.978	 1.079237	 865.50312	 1	 800.0	 266.666666; % COW
	2181	 179.5	 33.5	 88.69579	 -36.0649	 1.054682	 273.898932	 1	 200.0	 0.0; % NG
	2189	 67.3	 13.5	 134.543	 -136.293	 1.060091	 102.960988	 1	 409.09092	 0.0; % NG
	2190	 145.2	 48.4	 90.67669	 -31.9333	 0.992136	 229.581358	 1	 200.0	 0.0; % COW
	2193	 0.54	 1.0	 9999.0	 -9999.0	 1.006357	 1.704729	 1	 9999.0	 -9999.0; % NUC
	2197	 53.4	 10.6	 37.38561	 -12.4525	 1.076909	 81.662843	 1	 80.0	 0.0; % NG
	2201	 96.9	 14.1	 54.30003	 -20.4859	 1.073773	 146.880717	 1	 120.0	 0.0; % PEL
	2202	 76.2	 9.6	 105.3378	 -99.0244	 1.083545	 115.203516	 1	 309.92896	 0.0; % NG
	2205	 470.0	 109.0	 214.104	 -92.6526	 1.047289	 723.71075	 1	 500.0	 166.666665; % COW
	2220	 1367.0	 312.6	 921.6151	 -304.728	 1.104211	 2103.429928	 1	 2000.0	 666.666666; % COW
	2224	 90.74	 39.27	 9999.0	 -9999.0	 1.049729	 148.309579	 1	 9999.0	 -9999.0; % COW
	2230	 44.6	 5.6	 38.01075	 -11.7382	 0.992364	 67.425292	 1	 80.0	 0.0; % NG
	2232	 9.83	 3.77	 9999.0	 -9999.0	 1.013914	 15.792215	 1	 9999.0	 -9999.0; % NUC
	2235	 9.75	 5.49	 9999.0	 -9999.0	 1.048703	 16.784095	 1	 9999.0	 -9999.0; % COW
	2238	 46.8	 9.6	 38.01763	 -11.8145	 1.076591	 71.661705	 1	 80.0	 0.0; % PEL
	2248	 2.65	 1.17	 9999.0	 -9999.0	 1.081245	 4.345187	 1	 9999.0	 -9999.0; % COW
	2250	 31.8	 17.2	 39.1164	 -10.7096	 1.057	 54.230342	 1	 80.0	 0.0; % NG
	2251	 0.21	 1.98	 9999.0	 -9999.0	 1.060382	 2.986658	 1	 9999.0	 -9999.0; % COW
	2256	 286.5	 31.2	 162.3973	 -61.7859	 1.08	 432.290762	 1	 360.0	 0.0; % NG
	2265	 76.8	 9.6	 34.56102	 -15.292	 1.091591	 116.096512	 1	 80.0	 0.0; % NG
	2270	 14.9	 4.81	 9999.0	 -9999.0	 0.969104	 23.485713	 1	 9999.0	 -9999.0; % NUC
	2272	 41.2	 11.4	 38.46016	 -11.36	 1.081045	 64.122149	 1	 80.0	 0.0; % NG
	2273	 26.83	 5.39	 9999.0	 -9999.0	 1.092711	 41.049083	 1	 9999.0	 -9999.0; % COW
	2277	 27.7	 3.7	 18.42517	 -6.43617	 0.981636	 41.919029	 1	 40.0	 0.0; % NG
	2279	 46.1	 11.8	 78.13037	 -77.0658	 1.022273	 71.379356	 1	 234.51775	 0.0; % NG
	2280	 5.29	 1.91	 9999.0	 -9999.0	 1.062122	 8.436377	 1	 9999.0	 -9999.0; % COW
	2281	 41.8	 2.5	 27.23773	 -9.55191	 0.997533	 62.812041	 1	 60.0	 0.0; % PEL
	2286	 36.65	 16.14	 9999.0	 -9999.0	 1.040521	 60.069749	 1	 9999.0	 -9999.0; % NUC
	2293	 179.0	 11.2	 86.22723	 -36.3258	 1.060318	 269.025073	 1	 200.0	 66.666666; % COW
	2298	 55.0	 8.1	 25.99267	 -10.9039	 0.994318	 83.389882	 1	 60.0	 0.0; % NG
	2300	 123.2	 27.6	 73.33611	 -26.4443	 1.050067	 189.380569	 1	 160.0	 0.0; % NG
	2308	 54.3	 18.6	 58.22931	 -16.4918	 1.078227	 86.095949	 1	 120.0	 0.0; % PEL
	2311	 66.73	 12.2	 9999.0	 -9999.0	 1.09233	 101.754111	 1	 9999.0	 -9999.0; % NG
	2313	 0.15	 1.0	 9999.0	 -9999.0	 1.077179	 1.516781	 1	 9999.0	 -9999.0; % COW
	2316	 1.33	 1.29	 9999.0	 -9999.0	 1.059808	 2.779253	 1	 9999.0	 -9999.0; % COW
	2326	 159.5	 41.5	 91.24639	 -33.5163	 0.968364	 247.215746	 1	 200.0	 0.0; % NG
	2327	 24.4	 2.4	 18.86354	 -6.03025	 1.055933	 36.776623	 1	 40.0	 0.0; % NG
	2328	 28.96	 8.62	 9999.0	 -9999.0	 1.069898	 45.323487	 1	 9999.0	 -9999.0; % COW
	2330	 411.2	 115.2	 276.1909	 -91.6307	 1.098133	 640.548265	 1	 600.0	 200.0; % COW
	2331	 103.52	 43.41	 9999.0	 -9999.0	 1.015822	 168.380051	 1	 9999.0	 -9999.0; % NUC
	2345	 39.0	 5.4	 17.0554	 -7.84143	 1.028545	 59.058107	 1	 40.0	 0.0; % PEL
	2346	 567.0	 -47.4	 250.6568	 -116.19	 1.055579	 853.46673	 1	 600.0	 199.999998; % COW
	2348	 0.43	 0.0	 9999.0	 -9999.0	 1.063811	 0.645	 1	 9999.0	 -9999.0; % COW
	2351	 127.2	 1.5	 81.7908	 -28.6771	 1.096818	 190.813266	 1	 180.0	 0.0; % COW
	2352	 994.2	 273.0	 533.8653	 -202.071	 1.048921	 1546.501193	 1	 1200.0	 399.999999; % COW
	2356	 92.8	 25.2	 76.08315	 -23.5873	 1.084818	 144.241048	 1	 160.0	 0.0; % NG
	2360	 37.8	 3.6	 17.14383	 -7.73222	 0.978909	 56.956562	 1	 40.0	 0.0; % NG
	2362	 291.9	 62.4	 128.018	 -56.2324	 1.035727	 447.742764	 1	 300.0	 0.0; % NG
	2375	 201.0	 20.4	 107.6217	 -41.9226	 1.031455	 303.048857	 1	 240.0	 0.0; % NG
	2377	 53.4	 20.1	 58.26545	 -16.4419	 1.084136	 85.586404	 1	 120.0	 0.0; % NG
	2380	 1367.0	 318.8	 921.522	 -304.789	 1.103421	 2105.522617	 1	 2000.0	 666.666666; % NUC
	2394	 1984.8	 108.2	 848.7641	 -377.669	 1.079184	 2981.620554	 1	 2000.0	 666.666666; % COW
	2401	 156.9	 45.3	 141.8499	 -42.116	 1.099211	 244.962905	 1	 300.0	 99.999999; % COW
	2402	 116.6	 2.6	 50.85036	 -22.9062	 1.078591	 174.943477	 1	 120.0	 0.0; % NG
	2405	 113.4	 16.8	 51.94106	 -22.8025	 1.060818	 171.956535	 1	 120.0	 0.0; % NG
	2408	 0.72	 0.0	 9999.0	 -9999.0	 1.051348	 1.08	 1	 9999.0	 -9999.0; % NG
	2410	 297.5	 7.5	 124.6845	 -59.3932	 1.048773	 446.391784	 1	 300.0	 0.0; % NG
	2411	 144.9	 3.6	 79.68832	 -30.775	 1.032533	 217.41707	 1	 180.0	 0.0; % NG
	2413	 34.8	 3.7	 27.99116	 -8.80931	 1.041933	 52.494214	 1	 60.0	 0.0; % NG
	2415	 378.8	 38.9	 171.7157	 -73.5513	 1.0764	 571.188202	 1	 400.0	 133.333333; % COW
	2422	 0.5	 0.4	 9999.0	 -9999.0	 1.028639	 0.960469	 1	 9999.0	 -9999.0; % COW
	2426	 15.96	 5.35	 9999.0	 -9999.0	 1.077784	 25.249242	 1	 9999.0	 -9999.0; % COW
	2434	 157.2	 25.5	 78.09426	 -32.3759	 1.022955	 238.882194	 1	 180.0	 0.0; % NG
	2435	 34.5	 6.4	 69.00791	 -69.9001	 1.060818	 52.632903	 1	 209.8182	 0.0; % COW
	2440	 19.81	 5.69	 9999.0	 -9999.0	 1.002973	 30.916459	 1	 9999.0	 -9999.0; % NUC
	2451	 0.2	 4.97	 9999.0	 -9999.0	 1.083674	 7.461034	 1	 9999.0	 -9999.0; % COW
	2458	 1118.3	 189.9	 665.7662	 -242.998	 1.064579	 1701.463495	 1	 1480.0	 133.333332; % COW
	2465	 77.6	 8.4	 70.15367	 -58.105	 1.073773	 117.079973	 1	 196.71715	 0.0; % NG
	2471	 148.8	 27.6	 69.22198	 -30.3499	 1.0334	 227.007048	 1	 160.0	 0.0; % COW
	2474	 0.13	 1.0	 9999.0	 -9999.0	 1.07923	 1.512622	 1	 9999.0	 -9999.0; % COW
	2475	 65.1	 15.9	 57.40889	 -17.323	 1.030636	 100.520371	 1	 120.0	 0.0; % NG
	2478	 1.01	 0.78	 9999.0	 -9999.0	 1.073441	 1.91419	 1	 9999.0	 -9999.0; % COW
	2479	 -2.05	 1.55	 9999.0	 -9999.0	 0.991722	 3.855029	 1	 9999.0	 -9999.0; % COW
	2481	 204.3	 11.1	 137.0248	 -46.7535	 1.017318	 306.901979	 1	 300.0	 0.0; % NG
	2487	 69.2	 4.2	 35.584	 -14.2628	 1.054136	 103.991009	 1	 80.0	 0.0; % NG
	2488	 9.82	 3.4	 9999.0	 -9999.0	 0.996493	 15.587909	 1	 9999.0	 -9999.0; % NG
	2490	 11.77	 3.81	 9999.0	 -9999.0	 1.019444	 18.556946	 1	 9999.0	 -9999.0; % COW
	2495	 0.63	 1.17	 9999.0	 -9999.0	 1.006417	 1.993251	 1	 9999.0	 -9999.0; % COW
	2500	 872.2	 142.1	 748.514	 -231.559	 1.081947	 1325.549627	 1	 1600.0	 466.666665; % COW
	2505	 576.3	 76.2	 416.6955	 -134.5	 1.088579	 871.973791	 1	 900.0	 300.0; % COW
	2510	 93.59	 36.62	 9999.0	 -9999.0	 1.056239	 150.748974	 1	 9999.0	 -9999.0; % NG
	2514	 -6.65	 4.21	 9999.0	 -9999.0	 1.03873	 11.805924	 1	 9999.0	 -9999.0; % COW
	2520	 28.13	 0.81	 9999.0	 -9999.0	 1.095266	 42.212489	 1	 9999.0	 -9999.0; % NUC
	2524	 1221.2	 333.8	 934.8061	 -291.472	 1.102737	 1898.997559	 1	 2000.0	 666.666666; % COW
	2533	 179.0	 15.5	 88.32609	 -36.3317	 1.078545	 269.504754	 1	 200.0	 0.0; % COW
	2535	 66.8	 14.0	 77.91347	 -21.6558	 1.074091	 102.376951	 1	 160.0	 0.0; % NG
	2536	 1049.2	 89.2	 525.344	 -209.845	 1.083868	 1579.477407	 1	 1200.0	 400.0; % COW
	2550	 1250.4	 258.8	 926.2575	 -297.735	 1.0915	 1915.352344	 1	 2000.0	 666.666666; % COW
	2551	 71.8	 -1.2	 34.79788	 -14.9432	 1.024867	 107.715041	 1	 80.0	 0.0; % NG
	2555	 86.4	 17.8	 54.6213	 -19.1096	 1.053318	 132.321767	 1	 120.0	 0.0; % NG
	2566	 831.6	 171.0	 551.0249	 -184.738	 1.084184	 1273.498728	 1	 1200.0	 399.999999; % COW
	2567	 5.66	 3.06	 9999.0	 -9999.0	 0.969603	 9.651332	 1	 9999.0	 -9999.0; % COW
	2570	 29.2	 3.6	 28.38039	 -8.37922	 1.005	 44.131621	 1	 60.0	 0.0; % PEL
	2572	 80.7	 21.3	 55.98089	 -18.7627	 1.059773	 125.195467	 1	 120.0	 0.0; % NG
	2573	 31.6	 6.1	 18.18763	 -6.74162	 1.040364	 48.275071	 1	 40.0	 0.0; % NG
	2579	 0.87	 0.84	 9999.0	 -9999.0	 1.044584	 1.814008	 1	 9999.0	 -9999.0; % COW
	2583	 138.6	 2.4	 91.19925	 -31.3544	 1.096818	 207.931166	 1	 200.0	 0.0; % NG
	2584	 126.0	 3.6	 72.02056	 -27.4713	 1.024	 189.077127	 1	 160.0	 0.0; % NG
	2585	 12.33	 2.65	 9999.0	 -9999.0	 1.085298	 18.917337	 1	 9999.0	 -9999.0; % NUC
	2593	 47.6	 12.0	 37.93587	 -11.8917	 1.061909	 73.63396	 1	 80.0	 0.0; % NG
	2594	 1.51	 0.66	 9999.0	 -9999.0	 1.054352	 2.471907	 1	 9999.0	 -9999.0; % COW
	2598	 115.2	 19.8	 110.2864	 -93.1338	 1.072591	 175.333767	 1	 311.38048	 0.0; % NG
	2602	 28.28	 19.72	 9999.0	 -9999.0	 1.043873	 51.714919	 1	 9999.0	 -9999.0; % COW
	2603	 4.5	 0.7	 0.7	 0.7	 1.065682	 6.831179	 1	 4.5	 4.5; % PEL
	2604	 0.58	 1.0	 9999.0	 -9999.0	 1.010387	 1.734042	 1	 9999.0	 -9999.0; % COW
	2608	 52.5	 9.1	 72.95267	 -68.7068	 1.058773	 79.924245	 1	 214.85716	 0.0; % NG
	2611	 17.88	 8.45	 9999.0	 -9999.0	 0.959599	 29.664255	 1	 9999.0	 -9999.0; % COW
	2615	 60.9	 25.8	 57.68599	 -17.019	 1.068864	 99.209438	 1	 120.0	 0.0; % NG
	2625	 3.6	 0.3	 0.3	 0.3	 1.044318	 5.418718	 1	 3.6	 3.6; % NG
	2626	 99.6	 2.5	 94.67771	 -27.8706	 1.094545	 149.447056	 1	 200.0	 66.666667; % NG
	2630	 0.51	 20.69	 9999.0	 -9999.0	 1.061894	 31.044427	 1	 9999.0	 -9999.0; % COW
	2631	 20.9	 5.4	 19.18509	 -5.71506	 1.085	 32.379507	 1	 40.0	 0.0; % NG
	2649	 658.5	 174.0	 563.9284	 -170.684	 1.066553	 1021.651145	 1	 1200.0	 399.999999; % NG
	2652	 962.1	 151.2	 536.8406	 -198.88	 1.062342	 1460.862814	 1	 1200.0	 399.999999; % COW
	2659	 53.2	 6.8	 37.24111	 -12.5371	 1.060455	 80.449239	 1	 80.0	 0.0; % NG
	2663	 3.4	 0.5	 0.5	 0.5	 1.080136	 5.154852	 1	 3.4	 3.4; % PEL
	2671	 330.6	 151.6	 283.4205	 -84.4476	 1.064316	 545.552536	 1	 600.0	 200.0; % NG
	2676	 4.3	 0.2	 0.2	 0.2	 1.014409	 6.456973	 1	 4.3	 4.3; % NG
	2677	 23.78	 15.53	 9999.0	 -9999.0	 1.031212	 42.602886	 1	 9999.0	 -9999.0; % COW
	2678	 137.0	 59.22	 9999.0	 -9999.0	 1.037439	 223.877241	 1	 9999.0	 -9999.0; % COW
	2685	 362.8	 -4.0	 172.5338	 -72.7462	 1.088658	 544.233075	 1	 400.0	 133.333332; % NG
	2688	 0.45	 0.03	 9999.0	 -9999.0	 1.010038	 0.676498	 1	 9999.0	 -9999.0; % COW
	2694	 29.96	 21.31	 9999.0	 -9999.0	 1.061073	 55.14857	 1	 9999.0	 -9999.0; % NG
	2697	 21.79	 7.69	 9999.0	 -9999.0	 1.081031	 34.660719	 1	 9999.0	 -9999.0; % COW
	2701	 10.48	 5.51	 9999.0	 -9999.0	 1.045299	 17.76031	 1	 9999.0	 -9999.0; % COW
	2702	 930.1	 134.6	 432.4675	 -180.67	 1.081632	 1409.683345	 1	 1000.0	 333.333333; % COW
	2704	 30.2	 4.7	 18.34657	 -6.58203	 1.063636	 45.845311	 1	 40.0	 0.0; % NG
	2710	 79.4	 15.0	 34.04062	 -15.7819	 0.992818	 121.206683	 1	 80.0	 0.0; % NG
	2712	 0.47	 0.8	 9999.0	 -9999.0	 0.966927	 1.39177	 1	 9999.0	 -9999.0; % COW
	2713	 183.6	 32.3	 184.4563	 -132.672	 1.092182	 279.629331	 1	 493.34672	 0.0; % NG
	2715	 296.8	 7.2	 139.6427	 -59.7518	 1.098455	 445.330978	 1	 320.0	 0.0; % NG
	2717	 87.0	 18.9	 55.22231	 -19.4824	 1.052026	 133.543897	 1	 120.0	 0.0; % PEL
	2720	 200.1	 50.2	 189.579	 -55.3286	 1.102526	 309.451309	 1	 400.0	 133.333333; % NG
	2725	 2528.4	 452.4	 1434.053	 -527.42	 1.083553	 3852.831779	 1	 3200.0	 1066.666664; % COW
	2728	 61.37	 21.83	 9999.0	 -9999.0	 1.037701	 97.705466	 1	 9999.0	 -9999.0; % NUC
	2729	 516.6	 134.0	 370.5762	 -119.771	 1.054955	 800.544196	 1	 800.0	 266.666666; % COW
	2735	 43.9	 6.8	 47.71976	 -13.5005	 1.057067	 66.635295	 1	 100.0	 33.333333; % NG
	2744	 162.5	 12.0	 89.61202	 -34.8173	 1.039091	 244.413712	 1	 200.0	 0.0; % NG
	2754	 855.7	 157.7	 441.8502	 -171.271	 1.079816	 1305.165317	 1	 1000.0	 333.333333; % COW
	2755	 49.6	 7.0	 37.49499	 -12.2378	 1.005545	 75.137274	 1	 80.0	 0.0; % NG
	2760	 676.2	 205.2	 564.6201	 -170.921	 1.055658	 1059.974212	 1	 1200.0	 399.999999; % COW
	2763	 292.2	 63.3	 127.9105	 -56.335	 1.035045	 448.466713	 1	 300.0	 0.0; % NG
	2764	 37.1	 4.9	 17.42935	 -7.48901	 1.085773	 56.133279	 1	 40.0	 0.0; % NG
	2774	 0.54	 0.77	 9999.0	 -9999.0	 1.08369	 1.410718	 1	 9999.0	 -9999.0; % COW
	2776	 29.7	 8.7	 22.35191	 -16.7674	 1.034455	 46.422031	 1	 60.4264	 0.0; % PEL
	2779	 392.3	 -5.5	 167.7199	 -77.1137	 1.032045	 588.507829	 1	 400.0	 133.333333; % NG
	2781	 17.8	 3.68	 9999.0	 -9999.0	 1.105203	 27.264636	 1	 9999.0	 -9999.0; % COW
	2782	 14.85	 4.99	 9999.0	 -9999.0	 0.967787	 23.498954	 1	 9999.0	 -9999.0; % COW
	2799	 340.5	 56.5	 228.1885	 -78.0551	 1.059636	 517.733643	 1	 500.0	 166.666665; % NG
	2804	 7.63	 1.97	 9999.0	 -9999.0	 1.075195	 11.820324	 1	 9999.0	 -9999.0; % COW
	2805	 344.07	 126.7	 188.93	 -56.3231	 1.050273	 549.984885	 1	 525.57	 258.903333; % COW
	2809	 203.4	 19.2	 106.961	 -42.4946	 1.073227	 306.456277	 1	 240.0	 0.0; % NG
	2811	 47.0	 21.6	 38.05564	 -11.7985	 1.030455	 77.588723	 1	 80.0	 0.0; % NG
	2829	 0.19	 73.31	 9999.0	 -9999.0	 1.080657	 109.965369	 1	 9999.0	 -9999.0; % NUC
	2832	 16.1	 0.7	 22.39079	 -20.9936	 1.093184	 24.172815	 1	 65.79592	 0.0; % NG
	2833	 38.6	 5.1	 17.33017	 -7.61288	 1.071636	 58.403189	 1	 40.0	 0.0; % NG
	2840	 5.44	 2.16	 9999.0	 -9999.0	 1.036673	 8.779704	 1	 9999.0	 -9999.0; % NG
	2845	 2.32	 1.28	 9999.0	 -9999.0	 1.050103	 3.974519	 1	 9999.0	 -9999.0; % COW
	2846	 581.4	 -33.0	 250.267	 -116.974	 1.070526	 873.503669	 1	 600.0	 199.999998; % COW
	2849	 357.4	 40.8	 278.1559	 -88.4691	 1.070632	 539.581921	 1	 600.0	 200.0; % COW
	2851	 14.9	 4.6	 9999.0	 -9999.0	 0.992533	 23.390864	 1	 9999.0	 -9999.0; % COW
	2852	 141.6	 32.4	 113.9748	 -35.5577	 1.089773	 217.889238	 1	 240.0	 0.0; % NG
	2853	 142.0	 9.6	 70.25158	 -29.3318	 0.983864	 213.486206	 1	 160.0	 0.0; % COW
	2863	 233.4	 12.1	 187.3535	 -57.7612	 1.104579	 350.570153	 1	 400.0	 133.333333; % COW
	2866	 9.0	 1.5	 1.5	 1.5	 1.041864	 13.686216	 1	 9.0	 9.0; % NG
	2868	 94.5	 24.9	 54.68458	 -20.1297	 1.073273	 146.588148	 1	 120.0	 0.0; % NG
	2872	 9.0	 0.6	 0.6	 0.6	 1.079773	 13.529967	 1	 9.0	 9.0; % NG
	2873	 181.3	 13.4	 138.8055	 -44.4952	 1.061267	 272.69179	 1	 300.0	 100.0; % NG
	2876	 0.49	 0.66	 9999.0	 -9999.0	 1.005569	 1.233015	 1	 9999.0	 -9999.0; % COW
	2878	 33.9	 7.6	 67.92443	 -69.0188	 1.0335	 52.112211	 1	 206.86296	 0.0; % NG
	2880	 11.89	 3.6	 9999.0	 -9999.0	 1.07408	 18.634571	 1	 9999.0	 -9999.0; % COW
	2884	 -2.83	 2.15	 9999.0	 -9999.0	 0.983142	 5.331102	 1	 9999.0	 -9999.0; % COW
	2896	 98.7	 5.7	 53.70363	 -20.9803	 1.076455	 148.296679	 1	 120.0	 0.0; % NG
	2902	 77.1	 3.1	 44.68199	 -16.5811	 1.007818	 115.743445	 1	 100.0	 0.0; % NG
	2910	 144.0	 33.6	 113.5482	 -35.8641	 0.983182	 221.802074	 1	 240.0	 0.0; % NG
	2916	 416.7	 90.9	 243.6108	 -88.463	 1.077342	 639.749033	 1	 540.0	 0.0; % COW
	2927	 57.8	 8.0	 36.79117	 -13.0042	 1.054318	 87.52651	 1	 80.0	 0.0; % NG
	2928	 304.7	 55.4	 180.5489	 -64.6315	 1.057045	 464.543122	 1	 400.0	 133.333333; % NG
	2934	 360.0	 35.2	 173.9584	 -71.5641	 1.088158	 542.575193	 1	 400.0	 133.333332; % NG
	2936	 323.2	 -0.4	 177.6058	 -67.6604	 1.098211	 484.800371	 1	 400.0	 133.333332; % NG
	2939	 387.1	 11.9	 178.4736	 -79.1125	 1.020864	 580.924302	 1	 420.0	 0.0; % NG
	2940	 69.4	 17.4	 56.13718	 -17.5304	 1.0705	 107.322039	 1	 120.0	 0.0; % NG
	2941	 9.78	 2.97	 9999.0	 -9999.0	 1.029379	 15.331534	 1	 9999.0	 -9999.0; % COW
	2942	 359.3	 32.4	 173.8463	 -71.3061	 1.026591	 541.136824	 1	 400.0	 133.333333; % NG
	2945	 5.06	 1.84	 9999.0	 -9999.0	 1.092885	 8.076243	 1	 9999.0	 -9999.0; % COW
	2946	 68.4	 6.0	 62.23372	 -51.372	 1.087545	 102.99398	 1	 174.2386	 0.0; % NG
	2957	 428.0	 111.2	 378.6379	 -111.908	 1.065364	 663.314586	 1	 800.0	 266.666666; % COW
	2967	 39.6	 15.6	 38.64547	 -11.2044	 1.056273	 63.842932	 1	 80.0	 0.0; % NG
	2968	 37.8	 8.7	 17.35786	 -7.56344	 1.069263	 58.182407	 1	 45.0	 0.0; % PEL
	2980	 113.4	 15.0	 52.30851	 -22.5164	 1.071091	 171.581642	 1	 120.0	 0.0; % NG
	2985	 130.2	 25.8	 81.96635	 -28.662	 1.058895	 199.097413	 1	 180.0	 0.0; % NG
	2986	 654.8	 86.4	 356.436	 -134.086	 1.086684	 990.713379	 1	 800.0	 266.666666; % COW
	2988	 0.57	 0.91	 9999.0	 -9999.0	 1.015739	 1.610668	 1	 9999.0	 -9999.0; % COW
	2990	 176.7	 23.1	 76.53817	 -34.1961	 1.097053	 267.305303	 1	 180.0	 0.0; % NG
	2991	 327.0	 30.0	 229.0024	 -77.0209	 1.042136	 492.559895	 1	 500.0	 166.666665; % NG
	2997	 228.6	 42.0	 103.5849	 -45.8927	 1.036267	 348.63937	 1	 240.0	 0.0; % NG
	3002	 861.3	 120.9	 439.1991	 -173.427	 1.046091	 1304.615892	 1	 1000.0	 333.333333; % COW
	3006	 29.8	 3.8	 22.58182	 -16.939	 1.0	 45.061957	 1	 61.06122	 0.0; % PEL
	3010	 0.2	 1.64	 9999.0	 -9999.0	 1.068652	 2.478225	 1	 9999.0	 -9999.0; % COW
	3017	 52.6	 7.3	 46.86475	 -14.2632	 0.942133	 79.656214	 1	 100.0	 33.333333; % NG
	3018	 44.0	 7.6	 38.13373	 -11.6413	 1.059273	 66.97731	 1	 80.0	 0.0; % NG
	3020	 660.4	 180.9	 564.4374	 -170.467	 1.073273	 1027.092587	 1	 1200.0	 399.999999; % NG
	3024	 114.6	 11.8	 93.36139	 -29.109	 1.030364	 172.808854	 1	 200.0	 0.0; % NG
	3026	 10.59	 5.25	 9999.0	 -9999.0	 1.03285	 17.729886	 1	 9999.0	 -9999.0; % COW
	3027	 738.4	 101.8	 345.7083	 -144.761	 1.082318	 1118.076496	 1	 800.0	 266.666666; % COW
	3028	 75.0	 1.4	 34.41229	 -15.3417	 1.025909	 112.519598	 1	 80.0	 0.0; % NG
	3029	 -600.0	 325.55	 99999.0	 -99999.0	 1.040526	 1023.943995	 1	 630.0	 -630.0; % COW
	3033	 91.8	 20.7	 55.00357	 -19.8098	 1.003182	 141.157332	 1	 120.0	 0.0; % PEL
	3038	 56.8	 10.8	 37.10117	 -12.7605	 1.074632	 86.726467	 1	 80.0	 0.0; % COW
	3041	 136.8	 12.8	 91.47759	 -31.1124	 1.087237	 206.096288	 1	 200.0	 0.0; % NG
	3045	 44.2	 9.0	 38.20483	 -11.6107	 1.081773	 67.660476	 1	 80.0	 0.0; % NG
	3054	 59.2	 7.8	 36.83316	 -13.0254	 1.055591	 89.567461	 1	 80.0	 0.0; % NG
	3056	 44.5	 1.9	 47.19351	 -41.4382	 1.074	 66.810815	 1	 135.27273	 0.0; % NG
	3060	 57.81	 20.84	 9999.0	 -9999.0	 1.086521	 92.177431	 1	 9999.0	 -9999.0; % COW
	3063	 61.8	 11.2	 36.3129	 -13.4715	 1.036818	 94.210031	 1	 80.0	 0.0; % NG
	3067	 347.7	 66.6	 175.6632	 -69.5685	 1.004682	 531.031461	 1	 400.0	 133.333333; % NG
	3078	 0.2	 1.64	 9999.0	 -9999.0	 1.068652	 2.478225	 1	 9999.0	 -9999.0; % COW
	3079	 78.6	 21.3	 56.34953	 -18.438	 1.018318	 122.152415	 1	 120.0	 0.0; % NG
	3080	 94.2	 22.5	 54.58719	 -20.1874	 1.044682	 145.274748	 1	 120.0	 0.0; % COW
	3083	 24.87	 3.71	 9999.0	 -9999.0	 1.038648	 37.717798	 1	 9999.0	 -9999.0; % NG
	3086	 249.3	 -6.3	 131.7502	 -52.0409	 1.074053	 374.069385	 1	 300.0	 0.0; % NG
	3088	 0.75	 0.93	 9999.0	 -9999.0	 0.978189	 1.792108	 1	 9999.0	 -9999.0; % COW
	3092	 66.13	 26.79	 9999.0	 -9999.0	 1.063538	 107.025615	 1	 9999.0	 -9999.0; % NG
	3093	 0.76	 0.86	 9999.0	 -9999.0	 1.038064	 1.72154	 1	 9999.0	 -9999.0; % COW
	3099	 55.8	 8.3	 25.57268	 -11.2551	 0.994091	 84.620875	 1	 60.0	 0.0; % PEL
	3104	 171.3	 3.6	 76.42851	 -34.1246	 1.003318	 257.006736	 1	 180.0	 0.0; % COW
	3110	 53.7	 -2.4	 58.19449	 -16.4966	 1.096545	 80.630407	 1	 120.0	 0.0; % NG
	3117	 127.6	 12.0	 92.2584	 -30.2648	 1.047318	 192.244532	 1	 200.0	 0.0; % NG
	3118	 -39.05	 11.82	 9999.0	 -9999.0	 1.07932	 61.199539	 1	 9999.0	 -9999.0; % COW
	3122	 835.5	 195.6	 550.9653	 -184.892	 1.052864	 1287.136016	 1	 1200.0	 399.999999; % COW
	3124	 52.6	 13.2	 37.39729	 -12.4151	 1.055182	 81.346481	 1	 80.0	 0.0; % NG
	3126	 159.2	 8.0	 89.44973	 -33.2807	 1.0775	 239.101317	 1	 200.0	 66.666666; % NG
	3130	 7.63	 4.3	 9999.0	 -9999.0	 1.044212	 13.137371	 1	 9999.0	 -9999.0; % COW
	3131	 13.97	 6.85	 9999.0	 -9999.0	 1.074294	 23.338544	 1	 9999.0	 -9999.0; % COW
	3137	 0.49	 -0.1	 9999.0	 -9999.0	 0.934331	 0.75015	 1	 9999.0	 -9999.0; % COW
	3161	 239.6	 -14.4	 185.188	 -59.5457	 1.075727	 360.048497	 1	 400.0	 133.333332; % NG
	3173	 102.6	 19.5	 53.75122	 -21.0757	 1.058682	 156.654947	 1	 120.0	 0.0; % NG
	3187	 109.8	 2.6	 51.57644	 -22.1262	 1.055727	 164.746168	 1	 120.0	 0.0; % NG
	3188	 96.9	 35.1	 54.08884	 -20.6392	 1.075658	 154.591866	 1	 120.0	 0.0; % NG
	3191	 522.8	 5.8	 366.737	 -122.452	 1.099364	 784.248258	 1	 800.0	 266.666666; % COW
	3192	 3.24	 1.18	 9999.0	 -9999.0	 1.046462	 5.172282	 1	 9999.0	 -9999.0; % COW
	3193	 829.8	 73.2	 387.8762	 -163.395	 1.078842	 1249.533565	 1	 900.0	 300.0; % COW
	3194	 0.64	 3.53	 9999.0	 -9999.0	 1.094331	 5.381322	 1	 9999.0	 -9999.0; % COW
	3195	 38.4	 12.8	 38.53735	 -11.2184	 1.027682	 60.715731	 1	 80.0	 0.0; % NG
	3198	 845.0	 -12.0	 433.8317	 -177.9	 1.038667	 1267.627804	 1	 1000.0	 333.33333; % COW
	3215	 0.48	 -0.1	 9999.0	 -9999.0	 1.024741	 0.735459	 1	 9999.0	 -9999.0; % PEL
	3226	 140.0	 16.0	 91.05973	 -31.4976	 1.091455	 211.366979	 1	 200.0	 66.666666; % NG
	3229	 341.1	 51.3	 157.1492	 -67.4015	 1.065273	 517.404122	 1	 360.0	 0.0; % COW
	3230	 350.0	 63.8	 175.5053	 -69.7598	 1.018318	 533.651094	 1	 400.0	 133.333333; % COW
	3243	 35.6	 15.6	 38.82578	 -10.9681	 1.057682	 58.301973	 1	 80.0	 0.0; % NG
	3247	 298.9	 20.0	 124.1502	 -59.2122	 1.0415	 449.352559	 1	 300.0	 100.0; % NG
	3248	 233.6	 27.6	 100.9133	 -46.4341	 1.020227	 352.837243	 1	 240.0	 0.0; % NG
	3254	 38.7	 12.99	 9999.0	 -9999.0	 1.070314	 61.232897	 1	 9999.0	 -9999.0; % COW
	3256	 1.88	 1.85	 9999.0	 -9999.0	 1.051337	 3.95639	 1	 9999.0	 -9999.0; % COW
	3257	 539.0	 133.0	 261.6953	 -107.358	 1.076136	 832.749962	 1	 600.0	 0.0; % COW
	3259	 31.2	 2.8	 52.83077	 -52.0446	 1.087053	 46.988084	 1	 158.88325	 0.0; % NG
	3260	 36.3	 5.8	 17.701	 -7.25467	 1.069474	 55.140661	 1	 40.0	 0.0; % PEL
	3261	 26.6	 5.1	 19.79709	 -15.1203	 1.0525	 40.626746	 1	 53.9798	 0.0; % NG
	3262	 50.8	 3.2	 37.43079	 -12.3168	 1.024136	 76.351031	 1	 80.0	 0.0; % NG
	3274	 43.6	 15.2	 38.11837	 -11.6405	 1.015545	 69.260378	 1	 80.0	 0.0; % NG
	3280	 158.7	 16.8	 78.60296	 -32.0414	 1.075	 239.380121	 1	 180.0	 0.0; % NG
	3282	 16.9	 7.26	 9999.0	 -9999.0	 1.033934	 27.590118	 1	 9999.0	 -9999.0; % COW
	3284	 28.13	 0.82	 9999.0	 -9999.0	 1.09526	 42.212924	 1	 9999.0	 -9999.0; % NUC
	3286	 92.4	 22.2	 54.59248	 -20.1214	 1.051455	 142.544204	 1	 120.0	 0.0; % COW
	3290	 113.97	 50.37	 9999.0	 -9999.0	 1.041342	 186.906849	 1	 9999.0	 -9999.0; % COW
	3292	 65.8	 13.4	 36.22158	 -13.6796	 1.012	 100.725866	 1	 80.0	 0.0; % NG
	3295	 261.0	 14.0	 130.0067	 -54.0425	 1.0555	 392.062814	 1	 300.0	 0.0; % NG
	3301	 79.6	 20.4	 76.85015	 -22.6417	 1.017182	 123.258752	 1	 160.0	 0.0; % NG
	3306	 412.0	 -9.0	 217.4353	 -88.2017	 1.098045	 618.147434	 1	 500.0	 166.666665; % COW
	3314	 16.4	 3.1	 22.35149	 -21.217	 1.054091	 25.035625	 1	 66.09044	 0.0; % NG
	3322	 0.61	 1.34	 9999.0	 -9999.0	 1.053869	 2.208467	 1	 9999.0	 -9999.0; % NUC
	3325	 112.2	 43.2	 116.0739	 -33.3221	 1.070591	 180.343921	 1	 240.0	 0.0; % NG
	3328	 1097.4	 514.2	 943.644	 -282.012	 1.064474	 1817.841825	 1	 2000.0	 666.666666; % COW
	3329	 861.2	 106.9	 441.0395	 -172.049	 1.082816	 1301.714009	 1	 1000.0	 333.333333; % NUC
	3331	 0.2	 0.96	 9999.0	 -9999.0	 1.063021	 1.470918	 1	 9999.0	 -9999.0; % COW
	3340	 556.8	 30.6	 257.6069	 -110.427	 1.036227	 836.46031	 1	 600.0	 199.999998; % COW
	3341	 6.15	 2.24	 9999.0	 -9999.0	 1.071885	 9.817852	 1	 9999.0	 -9999.0; % COW
	3343	 74.2	 25.27	 9999.0	 -9999.0	 1.093923	 117.577545	 1	 9999.0	 -9999.0; % COW
	3345	 0.62	 1.41	 9999.0	 -9999.0	 1.056492	 2.310438	 1	 9999.0	 -9999.0; % COW
	3346	 14.96	 4.49	 9999.0	 -9999.0	 1.009926	 23.42891	 1	 9999.0	 -9999.0; % COW
	3352	 9.88	 3.96	 9999.0	 -9999.0	 0.928433	 15.966089	 1	 9999.0	 -9999.0; % COW
	3356	 5.2	 0.5	 0.5	 0.5	 1.071727	 7.835975	 1	 5.2	 5.2; % NG
	3358	 239.6	 65.0	 133.8361	 -49.8906	 1.076067	 372.3904	 1	 300.0	 100.0; % NG
	3359	 387.8	 27.3	 180.1052	 -77.8448	 1.009909	 583.139599	 1	 420.0	 0.0; % NG
	3361	 662.8	 13.6	 354.58	 -135.702	 1.084737	 994.409272	 1	 800.0	 266.666666; % NG
	3362	 32.71	 13.76	 9999.0	 -9999.0	 1.058124	 53.229539	 1	 9999.0	 -9999.0; % PEL
	3363	 62.0	 12.2	 36.33525	 -13.4711	 1.073636	 94.783385	 1	 80.0	 0.0; % NG
	3365	 4.86	 2.12	 9999.0	 -9999.0	 0.982218	 7.953396	 1	 9999.0	 -9999.0; % COW
	3375	 40.4	 5.6	 38.3637	 -11.3757	 1.0198	 61.179408	 1	 80.0	 0.0; % NG
	3376	 0.19	 0.87	 9999.0	 -9999.0	 1.066214	 1.335758	 1	 9999.0	 -9999.0; % NUC
	3384	 28.6	 5.8	 18.39755	 -6.48899	 1.002727	 43.77328	 1	 40.0	 0.0; % PEL
	3387	 1146.3	 206.1	 514.1476	 -221.73	 1.050895	 1747.0209	 1	 1200.0	 399.999999; % COW
	3388	 94.9	 21.4	 42.93563	 -18.4696	 1.031955	 145.924407	 1	 100.0	 0.0; % NG
	3396	 24.87	 3.7	 9999.0	 -9999.0	 1.04408	 37.715587	 1	 9999.0	 -9999.0; % NUC
	3401	 5.67	 2.84	 9999.0	 -9999.0	 1.080953	 9.512236	 1	 9999.0	 -9999.0; % COW
	3403	 34.4	 7.4	 38.89954	 -10.8975	 1.067545	 52.780394	 1	 80.0	 0.0; % COW
	3405	 854.7	 204.0	 548.5682	 -187.155	 1.080816	 1318.062291	 1	 1200.0	 399.999999; % PEL
	3407	 29.9	 3.7	 28.37993	 -8.40395	 1.025067	 45.19209	 1	 60.0	 0.0; % NG
	3408	 26.5	 7.25	 9999.0	 -9999.0	 1.071874	 41.210777	 1	 9999.0	 -9999.0; % COW
	3410	 44.8	 20.0	 38.05757	 -11.7222	 1.037364	 73.592391	 1	 80.0	 0.0; % NG
	3414	 239.2	 105.6	 148.0244	 -51.7016	 1.000136	 392.209128	 1	 320.0	 0.0; % NG
	3417	 572.4	 125.4	 255.7925	 -112.326	 1.048421	 878.962781	 1	 600.0	 199.999998; % COW
	3422	 147.6	 5.8	 90.31483	 -32.2665	 1.0155	 221.570869	 1	 200.0	 0.0; % NG
	3425	 146.08	 63.89	 9999.0	 -9999.0	 1.039631	 239.16087	 1	 9999.0	 -9999.0; % NUC
	3431	 162.4	 35.6	 110.3415	 -37.1203	 1.053636	 249.384282	 1	 240.0	 0.0; % NG
	3437	 8.03	 7.84	 9999.0	 -9999.0	 1.015158	 16.833883	 1	 9999.0	 -9999.0; % NG
	3444	 35.5	 5.5	 17.76234	 -7.17904	 1.007545	 53.885295	 1	 40.0	 0.0; % NG
	3447	 6.03	 3.15	 9999.0	 -9999.0	 0.992894	 10.204786	 1	 9999.0	 -9999.0; % COW
	3451	 90.6	 5.7	 54.70099	 -19.9681	 1.0126	 136.168691	 1	 120.0	 0.0; % COW
	3452	 190.8	 8.4	 108.0619	 -41.254	 1.071955	 286.477224	 1	 240.0	 0.0; % NG
	3453	 13.2	 6.15	 9999.0	 -9999.0	 1.050529	 21.843549	 1	 9999.0	 -9999.0; % COW
	3457	 68.3	 9.9	 35.41076	 -14.3663	 1.019947	 103.52065	 1	 80.0	 0.0; % NG
	3465	 615.0	 151.2	 467.0212	 -146.118	 1.103974	 949.970784	 1	 1000.0	 333.333333; % COW
	3466	 563.5	 156.1	 313.012	 -116.735	 1.081364	 877.082542	 1	 700.0	 233.333331; % NUC
	3467	 89.6	 -12.2	 94.80645	 -27.3595	 1.043	 135.640149	 1	 200.0	 66.666666; % NG
	3470	 1.6	 1.01	 9999.0	 -9999.0	 1.054809	 2.838173	 1	 9999.0	 -9999.0; % NUC
	3478	 397.6	 5.6	 165.7633	 -79.1699	 1.0305	 596.459152	 1	 400.0	 133.333332; % COW
	3481	 837.3	 80.1	 388.1704	 -163.4	 1.088395	 1261.683964	 1	 900.0	 300.0; % COW
	3495	 21.4	 4.4	 36.28851	 -35.4239	 1.079818	 32.771482	 1	 108.33335	 0.0; % COW
	3496	 143.4	 -9.3	 79.52042	 -30.8462	 1.075727	 215.551879	 1	 180.0	 0.0; % NG
	3502	 17.91	 7.9	 9999.0	 -9999.0	 1.066946	 29.362403	 1	 9999.0	 -9999.0; % NG
	3504	 239.6	 -14.4	 185.188	 -59.5457	 1.075727	 360.048497	 1	 400.0	 133.333332; % NG
	3505	 31.6	 3.6	 28.22675	 -8.55108	 1.0124	 47.706603	 1	 60.0	 0.0; % NG
	3507	 287.0	 14.1	 182.7313	 -62.5427	 1.094182	 431.019225	 1	 400.0	 133.333333; % NG
	3509	 38.73	 15.32	 9999.0	 -9999.0	 1.077512	 62.47487	 1	 9999.0	 -9999.0; % COW
	3515	 0.58	 2.28	 9999.0	 -9999.0	 1.038027	 3.528923	 1	 9999.0	 -9999.0; % COW
	3520	 9.24	 3.54	 9999.0	 -9999.0	 1.041649	 14.842362	 1	 9999.0	 -9999.0; % COW
	3522	 8.43	 7.98	 9999.0	 -9999.0	 1.065098	 17.411976	 1	 9999.0	 -9999.0; % COW
	3523	 855.6	 157.5	 440.6871	 -172.142	 1.081368	 1304.963456	 1	 1000.0	 333.333333; % COW
	3528	 77.0	 13.4	 34.27487	 -15.5221	 1.047227	 117.235916	 1	 80.0	 0.0; % NG
	3531	 139.6	 32.8	 71.01919	 -28.6777	 1.062867	 215.102301	 1	 160.0	 0.0; % NG
	3532	 28.13	 0.82	 9999.0	 -9999.0	 1.095247	 42.212924	 1	 9999.0	 -9999.0; % COW
	3540	 70.2	 19.2	 56.83658	 -17.8426	 1.057273	 109.16744	 1	 120.0	 0.0; % NG
	3552	 99.6	 22.2	 54.18915	 -20.6545	 1.040182	 153.066162	 1	 120.0	 0.0; % COW
	3559	 10.0	 2.0	 2.0	 2.0	 0.950818	 15.297059	 1	 10.0	 10.0; % NG
	3561	 362.0	 57.8	 173.8408	 -71.3995	 1.060158	 549.878068	 1	 400.0	 133.333333; % NG
	3567	 45.4	 16.2	 38.02338	 -11.766	 1.075045	 72.305601	 1	 80.0	 0.0; % NG
	3569	 11.8	 5.47	 9999.0	 -9999.0	 1.07292	 19.50928	 1	 9999.0	 -9999.0; % NG
	3571	 349.3	 59.5	 175.5273	 -69.7258	 1.050316	 531.497098	 1	 400.0	 133.333333; % NG
	3573	 571.2	 127.2	 256.1129	 -112.058	 1.061184	 877.787491	 1	 600.0	 199.999998; % NG
	3581	 47.2	 14.0	 38.01499	 -11.8286	 1.013909	 73.848764	 1	 80.0	 0.0; % COW
	3589	 57.4	 6.8	 25.38834	 -11.4507	 1.0215	 86.702076	 1	 60.0	 0.0; % NG
	3590	 723.0	 -7.0	 450.57	 -161.535	 1.048909	 1084.550829	 1	 1000.0	 333.33333; % NUC
	3597	 50.6	 4.4	 26.31069	 -10.5231	 1.074727	 76.186416	 1	 60.0	 0.0; % COW
	3598	 124.0	 15.0	 94.11957	 -30.35	 1.085273	 187.355945	 1	 200.0	 0.0; % NG
	3600	 63.3	 6.4	 126.1635	 -127.559	 1.048045	 95.434074	 1	 382.43214	 0.0; % NG
	3602	 66.09	 31.27	 9999.0	 -9999.0	 1.059995	 109.671451	 1	 9999.0	 -9999.0; % COW
	3607	 79.2	 6.6	 55.30057	 -18.398	 1.074636	 119.211786	 1	 120.0	 0.0; % NG
	3610	 3.21	 1.7	 9999.0	 -9999.0	 1.075322	 5.448553	 1	 9999.0	 -9999.0; % COW
	3611	 334.8	 36.4	 177.0911	 -68.4099	 1.054868	 505.159381	 1	 400.0	 133.333332; % NG
	3616	 0.18	 2.27	 9999.0	 -9999.0	 1.083103	 3.415688	 1	 9999.0	 -9999.0; % COW
	3619	 84.0	 19.2	 55.6678	 -19.087	 1.063682	 129.249526	 1	 120.0	 0.0; % NG
	3621	 -2.51	 1.64	 9999.0	 -9999.0	 1.081274	 4.497424	 1	 9999.0	 -9999.0; % COW
	3622	 0.18	 1.42	 9999.0	 -9999.0	 1.067558	 2.147044	 1	 9999.0	 -9999.0; % COW
	3628	 229.9	 70.7	 134.9794	 -48.7516	 1.0436	 360.7882	 1	 300.0	 100.0; % COW
	3631	 0.47	 -0.1	 9999.0	 -9999.0	 0.991963	 0.720781	 1	 9999.0	 -9999.0; % COW
	3632	 44.6	 5.8	 38.05465	 -11.7155	 1.039364	 67.463323	 1	 80.0	 0.0; % NG
	3635	 69.21	 20.71	 37.62842	 -12.2185	 1.067682	 108.363225	 1	 97.81	 17.81; % NG
	3640	 27.7	 5.4	 18.61941	 -6.31	 1.083955	 42.332169	 1	 40.0	 0.0; % NG
	3645	 9.97	 4.55	 9999.0	 -9999.0	 1.032109	 16.438755	 1	 9999.0	 -9999.0; % COW
	3648	 10.92	 4.41	 9999.0	 -9999.0	 1.032834	 17.665294	 1	 9999.0	 -9999.0; % COW
	3649	 0.18	 1.0	 9999.0	 -9999.0	 1.06448	 1.524106	 1	 9999.0	 -9999.0; % COW
	3651	 89.4	 12.9	 54.88151	 -19.8023	 1.061727	 135.488865	 1	 120.0	 0.0; % NG
	3654	 46.0	 6.6	 37.87363	 -11.8723	 1.020364	 69.706599	 1	 80.0	 0.0; % NG
	3658	 109.5	 3.0	 52.24768	 -22.4385	 1.067909	 164.311632	 1	 120.0	 0.0; % COW
	3663	 0.18	 1.0	 9999.0	 -9999.0	 1.043276	 1.524106	 1	 9999.0	 -9999.0; % COW
	3666	 89.5	 40.0	 97.07457	 -27.4377	 1.081342	 147.047824	 1	 200.0	 0.0; % NG
	3668	 401.0	 51.0	 223.0745	 -83.7009	 1.090553	 606.345199	 1	 500.0	 166.666665; % COW
	3670	 30.0	 8.1	 18.44	 -6.50996	 1.030273	 46.611399	 1	 40.0	 0.0; % NG
	3686	 323.1	 63.9	 178.6809	 -66.5659	 1.060105	 494.037291	 1	 400.0	 133.333333; % NG
	3690	 66.03	 12.38	 9999.0	 -9999.0	 1.092336	 100.770814	 1	 9999.0	 -9999.0; % COW
	3691	 68.2	 7.2	 35.734	 -14.119	 1.0845	 102.868508	 1	 80.0	 0.0; % NG
	3695	 46.2	 8.4	 38.05318	 -11.7714	 1.075227	 70.436141	 1	 80.0	 0.0; % NG
	3701	 17.55	 1.7	 9999.0	 -9999.0	 1.092661	 26.448216	 1	 9999.0	 -9999.0; % COW
	3706	 -3.59	 1.83	 9999.0	 -9999.0	 1.025679	 6.044274	 1	 9999.0	 -9999.0; % COW
	3711	 79.6	 2.8	 55.21395	 -18.4759	 1.085591	 119.473847	 1	 120.0	 0.0; % NG
	3712	 162.8	 33.0	 88.50638	 -34.0826	 1.025864	 249.16639	 1	 200.0	 66.666666; % NG
	3719	 502.0	 86.0	 264.9409	 -103.736	 1.064455	 763.969895	 1	 600.0	 0.0; % NUC
	3720	 188.0	 21.4	 85.82804	 -36.9183	 1.009818	 283.821088	 1	 200.0	 0.0; % COW
	3727	 391.0	 40.5	 223.9141	 -82.7537	 1.022909	 589.637866	 1	 500.0	 166.666665; % NG
	3748	 41.0	 7.4	 38.3743	 -11.404	 1.070909	 62.49368	 1	 80.0	 0.0; % NG
	3750	 0.54	 1.0	 9999.0	 -9999.0	 1.054954	 1.704729	 1	 9999.0	 -9999.0; % PEL
	3752	 216.0	 19.5	 134.1368	 -49.1225	 0.951818	 325.317633	 1	 300.0	 0.0; % NG
	3754	 1.68	 0.97	 9999.0	 -9999.0	 1.029351	 2.909884	 1	 9999.0	 -9999.0; % NG
	3755	 59.6	 13.2	 36.88517	 -13.0037	 1.060789	 91.566369	 1	 80.0	 0.0; % NG
	3758	 67.5	 19.2	 57.03059	 -17.6274	 1.062773	 105.266341	 1	 120.0	 0.0; % NG
	3759	 0.02	 0.51	 9999.0	 -9999.0	 1.040337	 0.765588	 1	 9999.0	 -9999.0; % COW
	3761	 269.1	 82.2	 184.1854	 -60.9595	 0.996727	 422.061859	 1	 400.0	 133.333333; % NG
	3770	 0.62	 0.0	 9999.0	 -9999.0	 1.040945	 0.93	 1	 9999.0	 -9999.0; % COW
	3774	 0.12	 2.27	 9999.0	 -9999.0	 1.042791	 3.409754	 1	 9999.0	 -9999.0; % COW
	3777	 13.26	 7.13	 9999.0	 -9999.0	 1.025867	 22.583072	 1	 9999.0	 -9999.0; % COW
	3792	 219.0	 69.3	 188.0693	 -56.8225	 1.055273	 344.554571	 1	 400.0	 133.333333; % NG
	3801	 26.2	 5.6	 18.58363	 -6.27517	 0.966545	 40.187685	 1	 40.0	 0.0; % COW
	3803	 1530.2	 61.6	 904.6709	 -321.606	 1.101868	 2297.159082	 1	 2000.0	 666.666666; % NUC
	3806	 514.6	 41.2	 264.003	 -103.612	 1.096211	 774.36997	 1	 600.0	 200.0; % COW
	3807	 95.1	 10.8	 54.59263	 -20.2121	 1.007364	 143.566927	 1	 120.0	 0.0; % NG
	3810	 740.0	 71.2	 344.9026	 -146.059	 1.063474	 1115.126109	 1	 800.0	 266.666664; % COW
	3811	 40.6	 8.6	 38.27121	 -11.4298	 0.985	 62.251265	 1	 80.0	 0.0; % PEL
	3817	 4.65	 1.88	 9999.0	 -9999.0	 1.030601	 7.523498	 1	 9999.0	 -9999.0; % COW
	3820	 767.4	 192.3	 396.3844	 -154.993	 1.082763	 1186.690614	 1	 900.0	 300.0; % COW
	3822	 621.7	 162.0	 465.4215	 -147.305	 1.047368	 963.690045	 1	 1000.0	 333.333333; % COW
	3823	 3.2	 1.05	 9999.0	 -9999.0	 1.092148	 5.051794	 1	 9999.0	 -9999.0; % COW
	3825	 260.1	 5.8	 131.2471	 -52.4515	 0.993211	 390.246989	 1	 300.0	 100.0; % NG
	3829	 4.3	 0.4	 0.4	 0.4	 1.080318	 6.477847	 1	 4.3	 4.3; % PEL
	3832	 491.0	 120.2	 373.4631	 -118.655	 1.089	 758.248205	 1	 800.0	 200.0; % COW
	3835	 139.6	 33.6	 71.60573	 -28.236	 1.046867	 215.379943	 1	 160.0	 0.0; % NG
	3836	 16.0	 6.9	 19.54586	 -5.36425	 1.089227	 26.136612	 1	 40.0	 0.0; % NG
	3840	 0.17	 8.06	 9999.0	 -9999.0	 1.045861	 12.092689	 1	 9999.0	 -9999.0; % COW
	3845	 0.66	 2.79	 9999.0	 -9999.0	 1.027489	 4.300503	 1	 9999.0	 -9999.0; % COW
	3847	 20.56	 3.88	 9999.0	 -9999.0	 1.07619	 31.384359	 1	 9999.0	 -9999.0; % NUC
	3849	 9.87	 3.76	 9999.0	 -9999.0	 0.963793	 15.842905	 1	 9999.0	 -9999.0; % COW
	3850	 46.2	 5.5	 47.62189	 -13.6344	 1.078267	 69.789344	 1	 100.0	 33.333333; % COW
	3853	 2641.24	 435.57	 99999.0	 -99999.0	 1.083974	 4015.371392	 1	 4188.9475	 1333.333332; % COW
	3863	 2.68	 3.06	 9999.0	 -9999.0	 1.048641	 6.101516	 1	 9999.0	 -9999.0; % COW
	3865	 641.0	 88.8	 354.4813	 -135.04	 0.997658	 970.682487	 1	 800.0	 266.666666; % COW
	3877	 103.78	 29.33	 9999.0	 -9999.0	 1.054759	 161.767453	 1	 9999.0	 -9999.0; % COW
	3879	 28.0	 1.5	 18.41111	 -6.45366	 1.0184	 42.060225	 1	 40.0	 0.0; % NG
	3883	 11.81	 4.02	 9999.0	 -9999.0	 0.988349	 18.713154	 1	 9999.0	 -9999.0; % COW
	3892	 29.88	 5.97	 9999.0	 -9999.0	 1.054952	 45.705847	 1	 9999.0	 -9999.0; % COW
	3896	 525.0	 27.6	 261.5961	 -106.385	 1.034591	 788.587478	 1	 600.0	 199.999998; % COW
	3903	 301.09	 38.39	 9999.0	 -9999.0	 0.969689	 455.291341	 1	 9999.0	 -9999.0; % PEL
	3908	 251.3	 33.6	 196.0804	 -61.8802	 1.084409	 380.304434	 1	 420.0	 0.0; % COW
	3911	 0.18	 1.0	 9999.0	 -9999.0	 1.076143	 1.524106	 1	 9999.0	 -9999.0; % COW
	3912	 33.5	 4.8	 18.02218	 -6.92517	 1.086974	 50.7632	 1	 40.0	 0.0; % NG
	3934	 158.8	 26.1	 141.7507	 -41.9698	 1.045273	 241.395863	 1	 300.0	 100.0; % COW
	3935	 212.8	 66.4	 149.9819	 -49.4706	 1.069342	 334.378229	 1	 320.0	 0.0; % NG
	3942	 1176.0	 173.2	 723.4602	 -256.992	 1.092763	 1783.028895	 1	 1600.0	 533.33333; % COW
	3943	 60.2	 7.6	 36.73438	 -13.1213	 1.054591	 91.016757	 1	 80.0	 0.0; % NG
	3945	 152.4	 6.6	 79.098	 -31.4618	 1.014227	 228.81427	 1	 180.0	 0.0; % COW
	3946	 73.3	 8.9	 45.09404	 -16.1662	 1.095447	 110.757505	 1	 100.0	 0.0; % NG
	3949	 490.5	 320.7	 576.779	 -158.19	 1.044921	 879.0547	 1	 1200.0	 399.999999; % COW
	3950	 39.9	 2.9	 16.93089	 -7.96917	 1.066318	 60.007874	 1	 40.0	 0.0; % NG
	3961	 167.0	 7.8	 87.36773	 -35.065	 1.055909	 250.773085	 1	 200.0	 0.0; % NG
	3965	 0.73	 1.93	 9999.0	 -9999.0	 1.026367	 3.095166	 1	 9999.0	 -9999.0; % COW
	3984	 59.2	 11.0	 36.93053	 -12.951	 1.029	 90.319931	 1	 80.0	 0.0; % NG
	3985	 273.6	 2.7	 129.2863	 -54.3776	 1.043667	 410.419983	 1	 300.0	 100.0; % NG
	3988	 67.31	 44.04	 9999.0	 -9999.0	 1.068963	 120.655936	 1	 9999.0	 -9999.0; % COW
	4000	 152.4	 11.1	 142.0	 -41.8689	 1.099526	 229.205546	 1	 300.0	 99.999999; % NG
	4002	 40.8	 13.8	 38.48228	 -11.3333	 1.076864	 64.605959	 1	 80.0	 0.0; % PEL
	4003	 147.6	 29.5	 142.8157	 -41.016	 1.077053	 225.778702	 1	 300.0	 100.0; % NG
	4005	 236.0	 30.0	 134.3927	 -49.9888	 1.093526	 356.848707	 1	 300.0	 0.0; % NG
	4006	 31.9	 9.6	 18.09992	 -6.81448	 1.022818	 49.969816	 1	 40.0	 0.0; % NG
	4007	 358.2	 56.5	 174.6007	 -70.7064	 1.097789	 543.942876	 1	 400.0	 133.333333; % NG
	4016	 5.15	 16.03	 9999.0	 -9999.0	 1.066048	 25.255448	 1	 9999.0	 -9999.0; % COW
	4025	 861.3	 108.3	 441.0395	 -172.049	 1.082684	 1302.123191	 1	 1000.0	 333.333333; % COW
	4031	 11.0	 125.78	 9999.0	 -9999.0	 1.042198	 189.390124	 1	 9999.0	 -9999.0; % COW
	4033	 14.7	 2.7	 20.48971	 -19.2362	 1.049818	 22.418854	 1	 60.24488	 0.0; % PEL
	4044	 90.6	 10.0	 94.73242	 -27.4281	 0.973067	 136.725309	 1	 200.0	 66.666666; % COW
	4046	 20.3	 2.0	 34.61421	 -33.9213	 1.086053	 30.597426	 1	 103.5533	 0.0; % NG
	4049	 253.0	 76.2	 269.0087	 -234.65	 1.053342	 396.339173	 1	 772.5381	 85.837567; % COW
	4051	 289.2	 65.6	 182.8731	 -62.5172	 1.082211	 444.820188	 1	 400.0	 133.333333; % COW
	4062	 50.1	 46.5	 58.4114	 -16.2632	 1.047	 102.530898	 1	 120.0	 0.0; % COW
	4073	 0.2	 1.64	 9999.0	 -9999.0	 1.068652	 2.478225	 1	 9999.0	 -9999.0; % COW
	4074	 410.5	 55.5	 220.6235	 -85.8069	 1.100421	 621.352255	 1	 500.0	 166.666665; % COW
	4076	 861.3	 121.3	 439.1991	 -173.427	 1.046091	 1304.699431	 1	 1000.0	 333.333333; % COW
	4078	 35.2	 14.0	 38.85147	 -10.9486	 1.051318	 56.822883	 1	 80.0	 0.0; % NG
	4082	 39.6	 4.9	 16.90316	 -7.98099	 1.001	 59.853007	 1	 40.0	 0.0; % NG
	4094	 156.8	 7.4	 89.57813	 -33.1114	 1.103553	 235.46178	 1	 200.0	 0.0; % NG
	4098	 115.0	 14.4	 51.15334	 -22.6177	 1.053091	 173.847088	 1	 120.0	 0.0; % COW
	4102	 47.8	 15.0	 37.85738	 -11.9536	 1.073364	 75.147455	 1	 80.0	 0.0; % NG
	4104	 6.39	 3.43	 9999.0	 -9999.0	 1.015363	 10.878568	 1	 9999.0	 -9999.0; % COW
	4111	 364.8	 49.2	 173.0676	 -72.3924	 1.048682	 552.154218	 1	 400.0	 133.333332; % NG
	4117	 47.5	 7.7	 26.83413	 -10.0356	 1.0565	 72.180087	 1	 60.0	 0.0; % PEL
	4120	 9.78	 3.5	 9999.0	 -9999.0	 1.082712	 15.581123	 1	 9999.0	 -9999.0; % COW
	4123	 1935.6	 328.2	 1074.337	 -397.656	 1.079289	 2944.841396	 1	 2400.0	 799.999998; % COW
	4128	 14.82	 5.03	 9999.0	 -9999.0	 1.017432	 23.475518	 1	 9999.0	 -9999.0; % COW
	4129	 15.88	 4.9	 9999.0	 -9999.0	 1.030702	 24.928195	 1	 9999.0	 -9999.0; % COW
	4152	 9.87	 3.77	 9999.0	 -9999.0	 0.966331	 15.848251	 1	 9999.0	 -9999.0; % COW
	4153	 318.0	 -11.0	 122.6399	 -61.6555	 1.083955	 477.285292	 1	 325.0	 0.0; % NG
	4155	 47.2	 8.2	 37.94159	 -11.874	 1.082409	 71.86049	 1	 80.0	 0.0; % NG
	4161	 31.26	 13.2	 9999.0	 -9999.0	 1.039896	 50.899038	 1	 9999.0	 -9999.0; % COW
	4168	 59.13	 22.68	 9999.0	 -9999.0	 1.092728	 94.995597	 1	 9999.0	 -9999.0; % COW
	4172	 127.0	 56.2	 92.96222	 -29.8058	 1.075	 208.318842	 1	 200.0	 66.666666; % NG
	4175	 0.64	 1.32	 9999.0	 -9999.0	 1.028661	 2.200454	 1	 9999.0	 -9999.0; % COW
	4180	 1.73	 1.71	 9999.0	 -9999.0	 1.045696	 3.648733	 1	 9999.0	 -9999.0; % COW
	4181	 23.31	 10.08	 9999.0	 -9999.0	 1.076509	 38.094168	 1	 9999.0	 -9999.0; % COW
	4188	 466.8	 142.8	 375.6952	 -114.931	 1.086526	 732.230619	 1	 800.0	 266.666666; % COW
	4202	 115.2	 20.6	 93.85476	 -28.8521	 1.101947	 175.541021	 1	 200.0	 0.0; % NG
	4206	 68.0	 14.4	 35.62251	 -14.1944	 1.054	 104.261978	 1	 80.0	 0.0; % PEL
	4214	 44.4	 11.8	 38.2839	 -11.575	 1.094263	 68.9119	 1	 80.0	 0.0; % NG
	4222	 78.4	 15.2	 45.00697	 -16.3986	 1.070105	 119.789816	 1	 100.0	 0.0; % NG
	4231	 170.0	 30.5	 140.9785	 -43.3118	 1.085864	 259.071539	 1	 300.0	 0.0; % NG
	4235	 21.7	 6.2	 19.14344	 -5.7673	 1.059682	 33.852511	 1	 40.0	 0.0; % PEL
	4236	 1597.2	 112.8	 897.5751	 -328.796	 1.090237	 2401.767324	 1	 2000.0	 666.666666; % COW
	4237	 88.2	 7.2	 55.07343	 -19.6265	 1.048864	 132.740084	 1	 120.0	 0.0; % NG
	4240	 491.0	 -45.5	 198.8395	 -105.442	 1.018455	 739.655536	 1	 500.0	 166.666665; % NG
	4243	 450.5	 -47.5	 214.7051	 -91.5765	 1.088079	 679.495861	 1	 500.0	 166.666665; % NG
	4249	 763.6	 22.4	 343.2496	 -147.429	 1.098237	 1145.892717	 1	 800.0	 266.666666; % COW
	4262	 541.8	 65.7	 417.981	 -132.474	 1.086447	 818.653402	 1	 900.0	 300.0; % NUC
	4265	 -29.38	 14.09	 9999.0	 -9999.0	 1.047338	 48.875895	 1	 9999.0	 -9999.0; % COW
	4267	 38.4	 12.2	 38.53424	 -11.2199	 1.027636	 60.437157	 1	 80.0	 0.0; % NG
	4273	 93.2	 5.0	 98.40225	 -86.291	 1.090737	 140.001036	 1	 281.84922	 0.0; % NG
	4280	 79.5	 9.3	 56.02602	 -18.6845	 0.968182	 120.063171	 1	 120.0	 0.0; % NG
	4282	 2.7	 1.16	 9999.0	 -9999.0	 1.058228	 4.407959	 1	 9999.0	 -9999.0; % COW
	4291	 2.91	 0.6	 9999.0	 -9999.0	 1.057064	 4.456818	 1	 9999.0	 -9999.0; % COW
	4297	 7.81	 2.71	 9999.0	 -9999.0	 0.962984	 12.40022	 1	 9999.0	 -9999.0; % NG
	4309	 4.11	 1.58	 9999.0	 -9999.0	 1.078886	 6.604856	 1	 9999.0	 -9999.0; % COW
	4310	 50.0	 6.6	 37.44187	 -12.2776	 0.992	 75.650578	 1	 80.0	 0.0; % NG
	4311	 0.15	 0.9	 9999.0	 -9999.0	 1.070183	 1.368622	 1	 9999.0	 -9999.0; % NG
	4312	 5.92	 2.38	 9999.0	 -9999.0	 0.979616	 9.570752	 1	 9999.0	 -9999.0; % NUC
	4314	 0.65	 1.97	 9999.0	 -9999.0	 1.010753	 3.111696	 1	 9999.0	 -9999.0; % COW
	4325	 17.96	 15.71	 9999.0	 -9999.0	 0.907012	 35.792078	 1	 9999.0	 -9999.0; % COW
	4327	 570.6	 126.6	 257.4896	 -110.952	 1.043368	 876.713648	 1	 600.0	 199.999998; % COW
	4335	 16.84	 7.96	 9999.0	 -9999.0	 1.068366	 27.939778	 1	 9999.0	 -9999.0; % COW
	4339	 165.5	 10.0	 89.53827	 -34.9773	 1.0615	 248.702759	 1	 200.0	 0.0; % NG
	4340	 16.0	 3.6	 22.15173	 -20.9025	 1.064636	 24.6	 1	 65.29948	 0.0; % NG
	4343	 805.5	 156.6	 389.8258	 -161.157	 1.103711	 1230.872078	 1	 900.0	 300.0; % COW
	4349	 861.3	 120.1	 439.1991	 -173.427	 1.046182	 1304.449625	 1	 1000.0	 333.333333; % NG
	4354	 418.0	 103.6	 379.5125	 -111.07	 1.024545	 645.970711	 1	 800.0	 266.666666; % COW
	4371	 188.1	 67.3	 190.2855	 -54.5208	 1.060364	 299.665689	 1	 400.0	 133.333333; % COW
	4381	 42.0	 12.2	 38.37408	 -11.4354	 1.076364	 65.60404	 1	 80.0	 0.0; % NG
	4383	 855.6	 157.8	 440.6871	 -172.142	 1.081342	 1305.044999	 1	 1000.0	 333.333333; % NG
	4387	 10.3	 1.8	 1.8	 1.8	 1.066409	 15.684148	 1	 10.3	 10.3; % NG
	4388	 728.4	 107.1	 558.524	 -176.387	 1.099237	 1104.347401	 1	 1200.0	 399.999999; % COW
	4395	 6.1	 1.77	 9999.0	 -9999.0	 1.066339	 9.527409	 1	 9999.0	 -9999.0; % COW
	4400	 24.9	 3.98	 9999.0	 -9999.0	 1.036552	 37.824111	 1	 9999.0	 -9999.0; % COW
	4405	 5.01	 1.81	 9999.0	 -9999.0	 1.080177	 7.990397	 1	 9999.0	 -9999.0; % COW
	4406	 6.8	 0.7	 0.7	 0.7	 1.080053	 10.253902	 1	 6.8	 6.8; % NG
	4407	 399.8	 32.6	 377.4793	 -111.422	 0.923591	 601.690369	 1	 800.0	 266.666666; % COW
	4408	 38.8	 2.8	 27.53551	 -9.24479	 1.023933	 58.35135	 1	 60.0	 0.0; % NG
	4409	 239.6	 64.6	 133.8361	 -49.8906	 1.0762	 372.233757	 1	 300.0	 100.0; % NG
	4410	 173.6	 63.4	 192.0998	 -53.1536	 1.062789	 277.222239	 1	 400.0	 133.333333; % NG
	4411	 219.0	 19.0	 187.3059	 -57.2401	 1.021136	 329.733984	 1	 400.0	 133.333333; % NG
	4413	 88.8	 33.6	 76.52478	 -23.1868	 1.067091	 142.416291	 1	 160.0	 0.0; % NG
	4425	 17.89	 7.56	 9999.0	 -9999.0	 0.982253	 29.132676	 1	 9999.0	 -9999.0; % NUC
	4427	 28.21	 6.0	 9999.0	 -9999.0	 1.054868	 43.261521	 1	 9999.0	 -9999.0; % NUC
	4433	 87.7	 28.2	 43.87105	 -17.5297	 1.078545	 138.183546	 1	 100.0	 0.0; % NG
	4436	 0.58	 53.03	 9999.0	 -9999.0	 1.056306	 79.549758	 1	 9999.0	 -9999.0; % COW
	4442	 95.6	 20.4	 75.61747	 -23.9643	 1.071818	 146.62851	 1	 160.0	 0.0; % NG
	4451	 357.0	 50.0	 176.3036	 -72.865	 1.084818	 540.726595	 1	 400.0	 0.0; % NG
	4456	 50.8	 15.2	 37.58176	 -12.232	 1.043409	 79.537915	 1	 80.0	 0.0; % NG
	4464	 0.44	 0.0	 9999.0	 -9999.0	 1.085075	 0.66	 1	 9999.0	 -9999.0; % COW
	4471	 38.75	 16.63	 9999.0	 -9999.0	 1.060948	 63.25163	 1	 9999.0	 -9999.0; % COW
	4474	 54.8	 9.0	 37.26511	 -12.5747	 1.099818	 83.3012	 1	 80.0	 0.0; % NG
	4479	 6.43	 1.13	 9999.0	 -9999.0	 1.094008	 9.792806	 1	 9999.0	 -9999.0; % COW
	4485	 20.2	 2.5	 34.39271	 -33.6434	 1.072579	 30.531173	 1	 102.7919	 0.0; % NG
	4492	 1201.0	 193.2	 933.8733	 -291.319	 1.080737	 1824.660596	 1	 2000.0	 666.666666; % COW
	4498	 28.0	 7.6	 18.63635	 -6.30424	 0.983182	 43.519651	 1	 40.0	 0.0; % NG
	4499	 385.5	 13.5	 224.402	 -82.2158	 1.087605	 578.604463	 1	 500.0	 166.666665; % COW
	4503	 60.0	 2.4	 57.62968	 -16.9993	 1.058727	 90.071971	 1	 120.0	 0.0; % COW
	4506	 54.8	 15.6	 37.22543	 -12.6066	 1.059182	 85.465783	 1	 80.0	 0.0; % NG
	4508	 93.6	 18.6	 54.45642	 -20.2598	 1.054591	 143.145276	 1	 120.0	 0.0; % NG
	4510	 962.8	 85.6	 533.3919	 -201.124	 1.088895	 1449.896617	 1	 1200.0	 400.0; % COW
	4519	 375.2	 32.2	 182.2005	 -75.8345	 1.045955	 564.868772	 1	 420.0	 0.0; % NG
	4521	 453.4	 124.6	 375.7286	 -114.446	 1.092211	 705.313845	 1	 800.0	 266.666666; % COW
	4525	 0.42	 0.0	 9999.0	 -9999.0	 1.060616	 0.63	 1	 9999.0	 -9999.0; % COW
	4530	 246.0	 -5.5	 132.4556	 -51.7136	 1.093263	 369.092214	 1	 300.0	 0.0; % COW
	4535	 22.8	 16.4	 9999.0	 -9999.0	 1.042295	 42.128375	 1	 9999.0	 -9999.0; % COW
	4536	 14.77	 4.59	 9999.0	 -9999.0	 1.016203	 23.200156	 1	 9999.0	 -9999.0; % NUC
	4538	 4.89	 2.4	 9999.0	 -9999.0	 0.978572	 8.170815	 1	 9999.0	 -9999.0; % COW
	4542	 0.12	 1.74	 9999.0	 -9999.0	 1.040962	 2.6162	 1	 9999.0	 -9999.0; % COW
	4543	 360.4	 35.6	 173.7644	 -71.7238	 1.074816	 543.231001	 1	 400.0	 133.333332; % COW
	4545	 130.8	 15.2	 71.89431	 -27.7171	 0.996273	 197.520328	 1	 160.0	 0.0; % NG
	4551	 25.08	 8.59	 9999.0	 -9999.0	 1.076083	 39.765407	 1	 9999.0	 -9999.0; % COW
	4552	 54.3	 10.0	 74.73169	 -70.4102	 1.065591	 82.819699	 1	 220.1212	 0.0; % NG
	4553	 406.0	 38.5	 220.8797	 -85.4495	 1.097553	 611.732019	 1	 500.0	 166.666665; % COW
	4566	 49.4	 6.8	 37.72001	 -12.0877	 1.060455	 74.79873	 1	 80.0	 0.0; % PEL
	4567	 35.2	 11.6	 38.87417	 -10.9304	 1.045136	 55.593165	 1	 80.0	 0.0; % NG
	4571	 7.5	 1.5	 1.5	 1.5	 1.026136	 11.472794	 1	 7.5	 7.5; % PEL
	4573	 119.8	 32.0	 93.57975	 -29.1811	 1.063	 186.000242	 1	 200.0	 66.666666; % NG
	4574	 21.83	 4.73	 9999.0	 -9999.0	 1.037937	 33.504836	 1	 9999.0	 -9999.0; % COW
	4580	 75.2	 14.0	 35.0585	 -14.8524	 1.014	 114.738137	 1	 80.0	 0.0; % COW
	4586	 179.5	 33.0	 88.65206	 -36.0981	 1.053318	 273.762328	 1	 200.0	 0.0; % COW
	4595	 104.8	 14.8	 74.54863	 -24.9693	 1.033409	 158.759819	 1	 160.0	 0.0; % NG
	4602	 130.2	 25.8	 81.96635	 -28.662	 1.058868	 199.097413	 1	 180.0	 0.0; % NG
	4603	 13.3	 1.1	 14.22468	 -12.4344	 1.095816	 20.018117	 1	 40.68366	 0.0; % NG
	4608	 1008.3	 184.5	 532.9598	 -203.194	 1.103421	 1537.561565	 1	 1200.0	 399.999999; % COW
	4610	 542.0	 33.0	 258.9085	 -109.582	 1.041632	 814.505525	 1	 600.0	 0.0; % NUC
	4612	 19.07	 6.06	 9999.0	 -9999.0	 1.080718	 30.014565	 1	 9999.0	 -9999.0; % COW
	4617	 55.7	 6.6	 25.91258	 -10.9885	 1.061864	 84.134491	 1	 60.0	 0.0; % PEL
	4619	 47.8	 20.6	 37.88687	 -11.9287	 1.069	 78.074964	 1	 80.0	 0.0; % NG
	4626	 242.4	 18.6	 101.3244	 -48.1175	 1.070682	 364.66885	 1	 249.06	 0.0; % NG
	4628	 14.81	 0.52	 9999.0	 -9999.0	 1.06504	 22.228689	 1	 9999.0	 -9999.0; % COW
	4629	 2.72	 111.15	 9999.0	 -9999.0	 1.059732	 166.774914	 1	 9999.0	 -9999.0; % NUC
	4631	 348.0	 19.2	 151.8106	 -69.2526	 1.090684	 522.793879	 1	 360.0	 0.0; % COW
	4632	 416.4	 42.9	 221.6174	 -84.9588	 1.103658	 627.90611	 1	 500.0	 166.666667; % COW
	4636	 2.27	 1.81	 9999.0	 -9999.0	 1.085077	 4.354911	 1	 9999.0	 -9999.0; % NUC
	4637	 21.1	 6.2	 6.2	 6.2	 1.086467	 32.988066	 1	 21.1	 21.1; % PEL
	4646	 55.83	 31.99	 9999.0	 -9999.0	 1.076205	 96.518316	 1	 9999.0	 -9999.0; % COW
	4648	 42.2	 10.6	 38.2824	 -11.4991	 1.068545	 65.266377	 1	 80.0	 0.0; % NG
	4652	 0.03	 0.52	 9999.0	 -9999.0	 0.99876	 0.781297	 1	 9999.0	 -9999.0; % COW
	4656	 78.0	 15.9	 56.34794	 -18.4204	 1.079727	 119.406124	 1	 120.0	 0.0; % NG
	4657	 1.33	 0.62	 9999.0	 -9999.0	 1.048658	 2.201119	 1	 9999.0	 -9999.0; % COW
	4658	 20.01	 7.01	 9999.0	 -9999.0	 0.956255	 31.803545	 1	 9999.0	 -9999.0; % COW
	4670	 308.8	 42.8	 179.8595	 -65.5608	 1.090316	 467.627929	 1	 400.0	 133.333332; % COW
	4676	 1713.6	 180.4	 882.8552	 -343.242	 1.082895	 2584.604519	 1	 2000.0	 666.666666; % NUC
	4677	 422.6	 143.8	 450.4023	 -391.11	 1.042136	 669.593683	 1	 1290.5178	 143.390867; % COW
	4680	 58.43	 21.16	 9999.0	 -9999.0	 1.069794	 93.215201	 1	 9999.0	 -9999.0; % COW
	4684	 50.6	 17.2	 37.75053	 -12.114	 1.069409	 80.165142	 1	 80.0	 0.0; % NG
	4686	 28.3	 4.2	 28.42471	 -8.31984	 0.968333	 42.914945	 1	 60.0	 0.0; % PEL
	4696	 629.3	 65.1	 301.8902	 -127.188	 1.094105	 948.987421	 1	 700.0	 233.333331; % COW
	4703	 19.2	 5.0	 32.8857	 -32.2851	 1.047	 29.760544	 1	 98.4694	 0.0; % NG
	4711	 9.2	 5.23	 9999.0	 -9999.0	 1.051405	 15.874005	 1	 9999.0	 -9999.0; % COW
	4722	 143.4	 -9.3	 79.52042	 -30.8462	 1.075727	 215.551879	 1	 180.0	 0.0; % NG
	4723	 49.8	 2.0	 37.47262	 -12.2604	 1.041091	 74.760217	 1	 80.0	 0.0; % NG
	4737	 63.91	 24.65	 9999.0	 -9999.0	 1.030177	 102.748474	 1	 9999.0	 -9999.0; % COW
	4738	 12.39	 9.73	 9999.0	 -9999.0	 1.069389	 23.630833	 1	 9999.0	 -9999.0; % COW
	4751	 254.4	 28.8	 145.2776	 -54.1518	 1.086636	 384.037498	 1	 320.0	 0.0; % NG
	4752	 249.6	 48.8	 145.5332	 -53.8084	 1.104553	 381.488663	 1	 320.0	 0.0; % NG
	4756	 129.0	 22.8	 91.9066	 -30.5371	 1.021818	 196.499084	 1	 200.0	 66.666666; % NG
	4761	 403.7	 39.6	 193.5558	 -80.8261	 1.086227	 608.456377	 1	 440.0	 0.0; % NG
	4762	 106.8	 32.8	 75.02463	 -24.7419	 1.066364	 167.584844	 1	 160.0	 0.0; % NG
	4764	 -1000.0	 268.95	 99999.0	 -99999.0	 1.05	 1553.30349	 1	 1050.0	 -1050.0; % COW
	4771	 4.88	 2.79	 9999.0	 -9999.0	 0.944964	 8.431881	 1	 9999.0	 -9999.0; % NG
	4773	 139.6	 28.8	 71.43607	 -28.3603	 0.988545	 213.809728	 1	 160.0	 0.0; % COW
	4781	 17.8	 3.58	 9999.0	 -9999.0	 1.039671	 27.234664	 1	 9999.0	 -9999.0; % NUC
	4783	 418.2	 41.5	 221.3348	 -85.2247	 1.102816	 630.381117	 1	 500.0	 166.666667; % COW
	4793	 40.7	 6.9	 47.9121	 -13.2946	 1.053533	 61.921119	 1	 100.0	 33.333333; % NG
	4795	 -6.2	 4.16	 9999.0	 -9999.0	 1.021892	 11.199446	 1	 9999.0	 -9999.0; % COW
	4797	 119.4	 14.7	 51.30161	 -23.4931	 1.073909	 180.452244	 1	 120.0	 0.0; % NG
	4799	 5.3	 0.7	 0.7	 0.7	 1.063773	 8.01904	 1	 5.3	 5.3; % NG
	4803	 151.0	 20.5	 91.72492	 -32.914	 1.0435	 228.577804	 1	 200.0	 0.0; % NG
	4807	 292.2	 24.6	 159.6655	 -61.422	 1.030273	 439.850543	 1	 360.0	 0.0; % COW
	4813	 152.3	 64.6	 542.7318	 -582.679	 1.056658	 248.151189	 1	 1689.1358	 51.185933; % COW
	4815	 102.6	 16.2	 94.65528	 -27.9451	 1.067455	 155.806611	 1	 200.0	 0.0; % COW
	4819	 256.0	 56.9	 185.6771	 -59.5635	 1.072773	 393.370846	 1	 400.0	 133.333333; % NG
	4820	 0.47	 -0.1	 9999.0	 -9999.0	 0.997323	 0.720781	 1	 9999.0	 -9999.0; % COW
	4823	 44.9	 6.9	 132.5755	 -139.968	 1.087	 68.140627	 1	 409.09095	 0.0; % COW
	4824	 89.74	 38.63	 9999.0	 -9999.0	 1.049752	 146.551954	 1	 9999.0	 -9999.0; % COW
	4835	 9.86	 3.08	 9999.0	 -9999.0	 0.95776	 15.494789	 1	 9999.0	 -9999.0; % COW
	4836	 41.0	 6.6	 38.41524	 -11.3816	 1.047364	 62.291733	 1	 80.0	 0.0; % NG
	4842	 20.9	 4.4	 35.24747	 -34.5986	 1.060455	 32.037205	 1	 105.52765	 0.0; % COW
	4852	 61.8	 12.2	 36.37445	 -13.4287	 1.052182	 94.489047	 1	 80.0	 0.0; % NG
	4859	 10.8	 0.9	 11.36311	 -10.0847	 1.052136	 16.256153	 1	 32.74371	 0.0; % NG
	4873	 30.7	 -0.5	 18.13765	 -6.74603	 1.095182	 46.056107	 1	 40.0	 0.0; % NG
	4874	 200.0	 24.7	 137.6496	 -45.9109	 1.092636	 302.27918	 1	 300.0	 100.0; % NG
	4875	 42.0	 14.0	 38.34252	 -11.4514	 1.058909	 66.407831	 1	 80.0	 0.0; % NG
	4880	 3.12	 3.05	 9999.0	 -9999.0	 1.022265	 6.544694	 1	 9999.0	 -9999.0; % COW
	4884	 1250.6	 308.4	 926.4741	 -297.626	 1.101474	 1932.097195	 1	 2000.0	 666.666666; % COW
	4891	 126.55	 54.72	 9999.0	 -9999.0	 0.990794	 206.810679	 1	 9999.0	 -9999.0; % PEL
	4901	 55.2	 16.2	 36.81412	 -12.8885	 0.976364	 86.29212	 1	 80.0	 0.0; % COW
	4902	 333.2	 39.6	 177.2869	 -68.2141	 1.054289	 503.317395	 1	 400.0	 133.333332; % NG
	4903	 35.28	 8.32	 9999.0	 -9999.0	 1.076242	 54.371654	 1	 9999.0	 -9999.0; % COW
	4904	 91.8	 7.4	 42.68333	 -18.5732	 1.094237	 138.146661	 1	 100.0	 0.0; % NG
	4906	 439.0	 110.5	 219.4251	 -87.6007	 1.021316	 679.039993	 1	 500.0	 166.666665; % NG
	4912	 220.4	 12.8	 102.6016	 -44.6926	 1.060864	 331.157062	 1	 240.0	 0.0; % NG
	4914	 359.1	 50.9	 174.7512	 -70.6137	 1.092763	 544.03414	 1	 400.0	 133.333333; % NG
	4921	 18.62	 6.66	 9999.0	 -9999.0	 1.047569	 29.662856	 1	 9999.0	 -9999.0; % COW
	4925	 181.6	 13.2	 108.2667	 -39.2001	 1.092737	 273.118656	 1	 240.0	 0.0; % COW
	4928	 292.5	 63.9	 127.1233	 -56.9614	 1.039955	 449.097745	 1	 300.0	 0.0; % NG
	4931	 4.86	 2.12	 9999.0	 -9999.0	 0.981264	 7.953396	 1	 9999.0	 -9999.0; % NUC
	4936	 24.79	 11.15	 9999.0	 -9999.0	 1.081788	 40.773151	 1	 9999.0	 -9999.0; % COW
	4937	 0.17	 0.84	 9999.0	 -9999.0	 1.042938	 1.285545	 1	 9999.0	 -9999.0; % NUC
	4939	 865.8	 185.7	 382.8671	 -169.372	 1.050579	 1328.236347	 1	 900.0	 199.999998; % COW
	4942	 0.47	 2.15	 9999.0	 -9999.0	 0.951174	 3.301159	 1	 9999.0	 -9999.0; % COW
	4947	 20.99	 4.25	 9999.0	 -9999.0	 0.988442	 32.123914	 1	 9999.0	 -9999.0; % NUC
	4951	 40.0	 10.6	 38.49277	 -11.2965	 1.061273	 62.071008	 1	 80.0	 0.0; % NG
	4954	 15.89	 6.42	 9999.0	 -9999.0	 0.995489	 25.706889	 1	 9999.0	 -9999.0; % COW
	4955	 43.4	 11.2	 38.26298	 -11.5479	 1.067632	 67.232804	 1	 80.0	 0.0; % NG
	4956	 102.68	 29.02	 9999.0	 -9999.0	 1.054592	 160.053183	 1	 9999.0	 -9999.0; % NUC
	4959	 18.5	 3.7	 31.08572	 -30.7638	 1.021727	 28.299558	 1	 93.46735	 0.0; % NG
	4961	 38.8	 18.07	 9999.0	 -9999.0	 1.012138	 64.202189	 1	 9999.0	 -9999.0; % NUC
	4964	 519.6	 75.0	 263.395	 -104.856	 1.041263	 787.477371	 1	 600.0	 199.999998; % COW
	4971	 204.4	 54.2	 188.3489	 -56.1134	 1.018737	 317.195917	 1	 400.0	 133.333333; % COW
	4973	 1368.6	 246.4	 920.3133	 -305.642	 1.100684	 2085.905695	 1	 2000.0	 666.666666; % COW
	4977	 861.3	 107.4	 441.0395	 -172.049	 1.082763	 1301.955457	 1	 1000.0	 333.333333; % NUC
	4978	 265.8	 12.3	 129.2974	 -54.4309	 1.031727	 399.126662	 1	 300.0	 99.999999; % NG
	4979	 51.8	 13.8	 37.49169	 -12.3251	 1.035545	 80.410074	 1	 80.0	 0.0; % NG
	4981	 3424.8	 452.0	 1765.358	 -686.674	 1.079816	 5181.747566	 1	 4000.0	 1333.333332; % COW
	4986	 -195.74	 32.87	 9999.0	 -9999.0	 1.063786	 297.721036	 1	 9999.0	 -9999.0; % NG
	4995	 47.2	 13.4	 37.97503	 -11.8597	 1.021909	 73.597894	 1	 80.0	 0.0; % NG
	4996	 72.11	 25.53	 9999.0	 -9999.0	 1.093887	 114.743951	 1	 9999.0	 -9999.0; % COW
	5003	 148.8	 11.2	 69.66893	 -30.0037	 1.038318	 223.831365	 1	 160.0	 0.0; % NG
	5004	 260.0	 64.6	 185.0586	 -60.0879	 1.042773	 401.857699	 1	 400.0	 133.333333; % NG
	5015	 3.17	 2.25	 9999.0	 -9999.0	 1.078794	 5.831008	 1	 9999.0	 -9999.0; % COW
	5016	 8.71	 19.54	 9999.0	 -9999.0	 1.070866	 32.090035	 1	 9999.0	 -9999.0; % COW
	5020	 59.0	 20.2	 36.944	 -12.9418	 1.021364	 93.543252	 1	 80.0	 0.0; % NG
	5023	 173.0	 25.5	 88.87103	 -35.7095	 1.084273	 262.303855	 1	 200.0	 0.0; % NG
	5026	 0.53	 0.91	 9999.0	 -9999.0	 1.069062	 1.579636	 1	 9999.0	 -9999.0; % COW
	5034	 21.5	 6.2	 19.15591	 -5.7534	 1.079182	 33.564155	 1	 40.0	 0.0; % COW
	5036	 0.94	 6.39	 9999.0	 -9999.0	 0.994643	 9.688154	 1	 9999.0	 -9999.0; % NG
	5044	 571.8	 124.2	 255.9258	 -112.203	 1.049026	 877.699823	 1	 600.0	 199.999998; % COW
	5052	 57.6	 9.0	 36.80262	 -12.9898	 1.072818	 87.448328	 1	 80.0	 0.0; % NG
	5060	 79.6	 2.8	 55.21395	 -18.4759	 1.085591	 119.473847	 1	 120.0	 0.0; % NG
	5071	 0.19	 14.8	 9999.0	 -9999.0	 1.050954	 22.201829	 1	 9999.0	 -9999.0; % COW
	5080	 37.1	 5.3	 17.51672	 -7.42136	 1.078455	 56.214989	 1	 40.0	 0.0; % NG
	5090	 7.02	 3.47	 9999.0	 -9999.0	 1.042074	 11.746188	 1	 9999.0	 -9999.0; % NG
	5092	 33.7	 -2.8	 17.99491	 -6.95173	 1.101816	 50.724181	 1	 40.0	 0.0; % NG
	5098	 136.5	 33.9	 80.7264	 -29.7409	 1.05	 210.969868	 1	 180.0	 0.0; % NG
	5106	 9.84	 4.46	 9999.0	 -9999.0	 0.948178	 16.20536	 1	 9999.0	 -9999.0; % NUC
	5110	 0.47	 0.83	 9999.0	 -9999.0	 0.9545	 1.430752	 1	 9999.0	 -9999.0; % COW
	5115	 -1.38	 1.15	 9999.0	 -9999.0	 1.050197	 2.694536	 1	 9999.0	 -9999.0; % COW
	5118	 108.57	 27.54	 9999.0	 -9999.0	 1.04324	 168.012699	 1	 9999.0	 -9999.0; % COW
	5123	 104.6	 17.4	 52.51436	 -21.2352	 1.004818	 159.056028	 1	 120.0	 0.0; % NG
	5130	 7.51	 2.52	 9999.0	 -9999.0	 1.011642	 11.882282	 1	 9999.0	 -9999.0; % COW
	5131	 5.65	 3.71	 9999.0	 -9999.0	 0.998327	 10.13878	 1	 9999.0	 -9999.0; % COW
	5132	 0.21	 1.04	 9999.0	 -9999.0	 1.055681	 1.591485	 1	 9999.0	 -9999.0; % NUC
	5133	 234.4	 66.2	 187.0576	 -57.9599	 1.054409	 365.353322	 1	 400.0	 133.333333; % NG
	5135	 229.8	 49.2	 103.1765	 -46.2511	 1.038053	 352.511744	 1	 240.0	 0.0; % NG
	5141	 128.0	 21.2	 72.7078	 -27.0531	 1.081	 194.615621	 1	 160.0	 0.0; % NG
	5144	 241.8	 58.2	 164.82	 -56.0667	 1.049227	 373.058414	 1	 360.0	 0.0; % NG
	5145	 76.2	 1.8	 34.46826	 -15.3437	 1.013182	 114.331885	 1	 80.0	 0.0; % COW
	5146	 16.6	 3.7	 22.96798	 -21.7009	 1.036545	 25.511027	 1	 67.75512	 0.0; % PEL
	5153	 107.8	 7.0	 52.13783	 -21.6313	 1.068591	 162.04055	 1	 120.0	 0.0; % NG
	5155	 41.8	 2.4	 27.24957	 -9.54503	 1.0404	 62.803264	 1	 60.0	 0.0; % COW
	5166	 654.8	 86.8	 356.5338	 -134.014	 1.087632	 990.792047	 1	 800.0	 266.666666; % COW
	5178	 33.4	 2.3	 28.17304	 -8.65299	 1.09675	 50.218647	 1	 60.0	 0.0; % COW
	5181	 837.0	 135.3	 550.6898	 -185.152	 1.088605	 1271.797528	 1	 1200.0	 399.999999; % COW
	5184	 7.43	 3.65	 9999.0	 -9999.0	 1.075474	 12.417192	 1	 9999.0	 -9999.0; % COW
	5186	 74.8	 14.6	 55.4801	 -18.128	 1.048318	 114.317322	 1	 120.0	 0.0; % NG
	5187	 10.0	 3.41	 9999.0	 -9999.0	 1.048313	 15.84813	 1	 9999.0	 -9999.0; % NUC
	5189	 84.5	 5.1	 44.00077	 -17.3317	 1.098289	 126.980648	 1	 100.0	 0.0; % NG
	5194	 122.7	 22.8	 82.65072	 -27.9427	 1.075636	 187.200541	 1	 180.0	 0.0; % COW
	5198	 19.0	 4.2	 31.98434	 -31.5355	 1.064318	 29.188011	 1	 95.9799	 0.0; % COW
	5204	 130.56	 56.18	 9999.0	 -9999.0	 1.037352	 213.201169	 1	 9999.0	 -9999.0; % NUC
	5206	 20.5	 8.06	 9999.0	 -9999.0	 1.08384	 33.041347	 1	 9999.0	 -9999.0; % COW
	5208	 45.6	 9.2	 38.00595	 -11.7795	 0.979545	 69.77822	 1	 80.0	 0.0; % PEL
	5213	 84.5	 15.4	 35.6861	 -16.4299	 1.079682	 128.837776	 1	 85.13568	 28.37856; % PEL
	5220	 302.1	 28.5	 123.764	 -59.9473	 1.024727	 455.162043	 1	 306.0	 102.0; % NG
	5226	 448.4	 41.0	 376.646	 -113.744	 1.098447	 675.405811	 1	 800.0	 266.666666; % COW
	5238	 38.01	 22.73	 9999.0	 -9999.0	 1.084502	 66.431764	 1	 9999.0	 -9999.0; % COW
	5247	 1652.7	 291.3	 779.2916	 -324.794	 1.067816	 2517.263237	 1	 1800.0	 599.999997; % COW
	5251	 31.7	 4.6	 23.3014	 -17.979	 1.004273	 48.048023	 1	 63.8392	 0.0; % NG
	5252	 106.8	 31.6	 114.6652	 -32.5647	 1.039818	 167.065257	 1	 240.0	 0.0; % NG
	5272	 354.4	 -28.4	 169.1888	 -75.03	 0.994227	 533.304153	 1	 400.0	 133.333332; % NG
	5273	 34.7	 5.0	 17.41918	 -7.41332	 0.99	 52.58757	 1	 40.0	 0.0; % NG
	5274	 292.5	 66.3	 126.9759	 -57.0775	 1.025818	 449.879834	 1	 300.0	 0.0; % NG
	5276	 371.8	 82.5	 196.9838	 -77.174	 1.053727	 571.264696	 1	 440.0	 146.666663; % NG
	5282	 22.6	 5.2	 45.82579	 -46.3016	 1.065364	 34.785773	 1	 138.85716	 0.0; % NG
	5283	 257.4	 19.5	 185.2292	 -59.899	 1.103763	 387.206369	 1	 400.0	 133.333333; % NG
	5284	 405.5	 53.0	 220.7483	 -85.5432	 1.082474	 613.423437	 1	 500.0	 166.666665; % NG
	5285	 935.4	 153.3	 539.2236	 -196.321	 1.089868	 1421.818066	 1	 1200.0	 399.999999; % COW
	5286	 171.0	 3.9	 76.50068	 -34.0491	 1.002682	 256.566702	 1	 180.0	 0.0; % COW
	5288	 13.2	 1.0	 13.93053	 -12.2653	 1.081591	 19.856737	 1	 39.97989	 0.0; % NG
	5291	 3.7	 0.2	 0.2	 0.2	 1.086947	 5.558102	 1	 3.7	 3.7; % NG
	5296	 33.21	 16.58	 9999.0	 -9999.0	 1.042389	 55.678103	 1	 9999.0	 -9999.0; % NG
	5298	 101.4	 16.0	 53.01273	 -20.7603	 1.042909	 153.98185	 1	 120.0	 0.0; % COW
	5302	 696.8	 92.8	 351.2482	 -139.878	 1.089227	 1054.428604	 1	 800.0	 0.0; % COW
	5310	 453.4	 125.8	 376.3911	 -114.065	 1.092368	 705.792958	 1	 800.0	 266.666666; % COW
	5311	 411.6	 30.0	 214.1296	 -84.9969	 1.087409	 619.037769	 1	 480.0	 159.999996; % COW
	5314	 0.7	 2.28	 9999.0	 -9999.0	 0.996478	 3.577555	 1	 9999.0	 -9999.0; % NUC
	5317	 68.2	 7.2	 35.734	 -14.119	 1.084553	 102.868508	 1	 80.0	 0.0; % NG
	5318	 625.2	 120.4	 358.2046	 -131.844	 1.054955	 955.031518	 1	 800.0	 266.666666; % COW
	5322	 514.8	 97.6	 369.7199	 -120.262	 1.087263	 785.955342	 1	 800.0	 266.666666; % COW
	5328	 56.0	 8.2	 46.52619	 -14.5939	 0.9792	 84.89576	 1	 100.0	 33.333333; % NG
	5335	 60.0	 13.4	 36.71858	 -13.1328	 1.067909	 92.217189	 1	 80.0	 0.0; % NG
	5336	 106.8	 17.4	 52.96332	 -21.8053	 1.097763	 162.312199	 1	 120.0	 0.0; % NG
	5337	 1056.6	 131.1	 526.7683	 -209.308	 1.104658	 1597.053297	 1	 1200.0	 399.999999; % COW
	5339	 107.8	 7.0	 52.11096	 -21.6518	 1.067136	 162.04055	 1	 120.0	 0.0; % NG
	5347	 182.6	 43.4	 86.2963	 -36.3924	 1.045455	 281.53014	 1	 200.0	 0.0; % NG
	5349	 55.6	 19.4	 37.31919	 -12.5723	 1.0245	 88.331025	 1	 80.0	 0.0; % PEL
	5367	 57.59	 30.52	 9999.0	 -9999.0	 1.075388	 97.765928	 1	 9999.0	 -9999.0; % COW
	5369	 1.25	 4.59	 9999.0	 -9999.0	 1.052776	 7.135745	 1	 9999.0	 -9999.0; % COW
	5371	 16.2	 7.6	 19.48889	 -5.3929	 1.007818	 26.8412	 1	 40.0	 0.0; % NG
	5379	 160.4	 11.2	 68.32973	 -31.4162	 1.039955	 241.18582	 1	 164.92	 0.0; % NG
	5387	 39.5	 3.3	 17.21198	 -7.73312	 1.055636	 59.456413	 1	 40.0	 0.0; % NG
	5388	 51.2	 10.6	 37.52717	 -12.2824	 1.087711	 78.42863	 1	 80.0	 0.0; % NG
	5402	 47.8	 2.4	 37.77729	 -11.9912	 1.031818	 71.79032	 1	 80.0	 0.0; % NG
	5404	 0.44	 0.0	 9999.0	 -9999.0	 1.069805	 0.66	 1	 9999.0	 -9999.0; % COW
	5411	 52.6	 8.0	 37.04554	 -12.6281	 0.986545	 79.80733	 1	 80.0	 0.0; % NG
	5417	 151.8	 37.2	 172.4674	 -48.3432	 1.060182	 234.437476	 1	 360.0	 0.0; % COW
	5418	 1221.2	 350.0	 934.545	 -291.637	 1.100526	 1905.548803	 1	 2000.0	 666.666666; % COW
	5420	 102.8	 15.6	 75.26134	 -24.4359	 1.094273	 155.965381	 1	 160.0	 0.0; % NG
	5422	 60.4	 9.2	 35.89595	 -13.7154	 0.966818	 91.644967	 1	 80.0	 0.0; % NG
	5424	 310.7	 10.3	 179.909	 -65.2683	 0.979763	 466.306021	 1	 400.0	 133.333333; % COW
	5427	 269.1	 29.7	 129.7179	 -54.2207	 1.077533	 406.101003	 1	 300.0	 0.0; % NG
	5430	 55.2	 9.4	 37.27217	 -12.591	 1.087026	 83.991964	 1	 80.0	 0.0; % COW
	5432	 598.6	 131.4	 362.2147	 -128.135	 1.086553	 919.278424	 1	 800.0	 266.666666; % COW
	5433	 1698.2	 244.4	 884.3854	 -341.633	 1.089921	 2573.544802	 1	 2000.0	 666.666666; % NUC
	5434	 25.82	 6.52	 9999.0	 -9999.0	 1.081318	 39.945729	 1	 9999.0	 -9999.0; % COW
	5435	 492.0	 134.2	 373.5819	 -117.057	 1.076947	 764.961234	 1	 800.0	 266.666666; % COW
	5438	 1096.0	 48.0	 517.5506	 -217.251	 1.055318	 1645.575887	 1	 1200.0	 400.0; % COW
	5441	 30.2	 4.1	 60.5129	 -61.0826	 1.069182	 45.715561	 1	 183.2727	 0.0; % NG
	5446	 617.7	 204.3	 411.6599	 -139.212	 1.086447	 975.913165	 1	 900.0	 300.0; % COW
	5452	 4.24	 11.53	 9999.0	 -9999.0	 1.09119	 18.427334	 1	 9999.0	 -9999.0; % COW
	5458	 0.26	 2.05	 9999.0	 -9999.0	 1.017958	 3.099633	 1	 9999.0	 -9999.0; % NUC
	5468	 0.16	 1.92	 9999.0	 -9999.0	 1.066762	 2.889983	 1	 9999.0	 -9999.0; % COW
	5475	 72.9	 22.2	 56.85985	 -17.9276	 1.018091	 114.307972	 1	 120.0	 0.0; % COW
	5478	 820.2	 119.4	 390.3955	 -161.157	 1.052289	 1243.267831	 1	 900.0	 300.0; % COW
	5486	 0.2	 0.98	 9999.0	 -9999.0	 1.078087	 1.5003	 1	 9999.0	 -9999.0; % COW
	5487	 697.2	 165.6	 351.6586	 -138.952	 1.049727	 1074.895437	 1	 800.0	 266.666666; % COW
	5503	 0.51	 0.64	 9999.0	 -9999.0	 1.000917	 1.227528	 1	 9999.0	 -9999.0; % NUC
	5510	 14.58	 5.96	 9999.0	 -9999.0	 1.058392	 23.62669	 1	 9999.0	 -9999.0; % COW
	5524	 74.8	 11.0	 34.67426	 -15.1397	 1.066053	 113.406746	 1	 80.0	 0.0; % COW
	5526	 60.4	 7.6	 36.58297	 -13.2341	 1.0825	 91.314402	 1	 80.0	 0.0; % PEL
	5528	 776.7	 95.7	 395.5863	 -155.881	 1.094658	 1173.860343	 1	 900.0	 300.0; % PEL
	5536	 382.19	 126.6	 185.6273	 -59.5527	 1.044636	 603.918621	 1	 527.29	 260.623333; % NG
	5539	 164.5	 18.8	 141.3924	 -42.3685	 1.040364	 248.356201	 1	 300.0	 100.0; % NG
	5540	 14.28	 5.51	 9999.0	 -9999.0	 1.056517	 22.959238	 1	 9999.0	 -9999.0; % NG
	5541	 84.9	 20.4	 55.72582	 -19.0656	 0.978091	 130.97474	 1	 120.0	 0.0; % NG
	5545	 114.95	 52.9	 9999.0	 -9999.0	 1.020195	 189.807279	 1	 9999.0	 -9999.0; % PEL
	5547	 11.38	 3.43	 9999.0	 -9999.0	 1.070914	 17.828514	 1	 9999.0	 -9999.0; % COW
	5553	 0.14	 2.32	 9999.0	 -9999.0	 1.07896	 3.48633	 1	 9999.0	 -9999.0; % COW
	5554	 29.95	 10.04	 9999.0	 -9999.0	 1.063956	 47.382056	 1	 9999.0	 -9999.0; % COW
	5555	 58.6	 17.4	 36.73408	 -13.0721	 1.047909	 91.693075	 1	 80.0	 0.0; % NG
	5561	 356.0	 -1.2	 173.4863	 -71.8009	 1.088763	 534.003034	 1	 400.0	 133.333332; % COW
	5562	 49.4	 11.2	 37.68306	 -12.1168	 1.032727	 75.98059	 1	 80.0	 0.0; % NG
	5563	 602.4	 102.6	 415.2591	 -136.327	 1.099467	 916.612334	 1	 900.0	 300.0; % COW
	5569	 40.1	 2.3	 16.9082	 -7.99332	 1.048091	 60.248859	 1	 41.16	 0.0; % NG
	5573	 9.9	 1.7	 1.7	 1.7	 0.985818	 15.067349	 1	 9.9	 9.9; % NG
	5574	 206.4	 9.2	 104.7581	 -42.5984	 1.038773	 309.907406	 1	 240.0	 0.0; % NG
	5582	 95.0	 18.3	 249.649	 -261.817	 1.069816	 145.119787	 1	 769.93936	 32.080807; % COW
	5595	 21.82	 8.63	 9999.0	 -9999.0	 1.074803	 35.196959	 1	 9999.0	 -9999.0; % NUC
	5597	 26.3	 3.1	 19.85663	 -14.9319	 1.087545	 39.723104	 1	 53.7551	 0.0; % NG
	5598	 39.0	 10.0	 38.47819	 -11.2711	 1.028591	 60.392466	 1	 80.0	 0.0; % NG
	5601	 6.3	 3.18	 9999.0	 -9999.0	 0.984977	 10.585622	 1	 9999.0	 -9999.0; % COW
	5606	 70.2	 8.8	 35.42857	 -14.4123	 1.047364	 106.124125	 1	 80.0	 0.0; % NG
	5608	 55.8	 16.2	 57.93207	 -16.6968	 1.038909	 87.156067	 1	 120.0	 0.0; % COW
	5616	 64.68	 21.72	 9999.0	 -9999.0	 1.086483	 102.344207	 1	 9999.0	 -9999.0; % NUC
	5617	 2.91	 0.63	 9999.0	 -9999.0	 1.057064	 4.466122	 1	 9999.0	 -9999.0; % COW
	5624	 24.44	 9.58	 9999.0	 -9999.0	 1.070872	 39.375786	 1	 9999.0	 -9999.0; % NUC
	5626	 310.4	 43.2	 178.9671	 -66.249	 1.0855	 470.087651	 1	 400.0	 133.333332; % COW
	5629	 767.5	 36.0	 447.1289	 -164.561	 1.068591	 1152.515754	 1	 1000.0	 333.333333; % NUC
	5631	 7.62	 2.52	 9999.0	 -9999.0	 1.072851	 12.038825	 1	 9999.0	 -9999.0; % NUC
	5632	 411.8	 5.2	 274.1207	 -93.0109	 1.099211	 617.749245	 1	 600.0	 200.0; % NG
	5646	 11.79	 22.64	 9999.0	 -9999.0	 1.063403	 38.288913	 1	 9999.0	 -9999.0; % COW
	5656	 879.6	 244.8	 545.677	 -189.968	 1.086474	 1369.544523	 1	 1200.0	 399.999999; % COW
	5661	 5.3	 0.5	 0.5	 0.5	 1.071364	 7.985299	 1	 5.3	 5.3; % NG
	5664	 81.3	 10.5	 55.51535	 -19.0839	 1.015364	 122.96286	 1	 120.0	 0.0; % PEL
	5665	 2.29	 2.48	 9999.0	 -9999.0	 1.053974	 5.063361	 1	 9999.0	 -9999.0; % COW
	5670	 0.6	 1.58	 9999.0	 -9999.0	 1.082017	 2.535133	 1	 9999.0	 -9999.0; % COW
	5671	 333.2	 40.4	 177.2869	 -68.2141	 1.054079	 503.460425	 1	 400.0	 133.333332; % COW
	5673	 10.77	 5.53	 9999.0	 -9999.0	 1.048972	 18.16015	 1	 9999.0	 -9999.0; % COW
	5687	 14.81	 4.65	 9999.0	 -9999.0	 0.99851	 23.284262	 1	 9999.0	 -9999.0; % COW
	5689	 153.93	 44.76	 9999.0	 -9999.0	 1.079629	 240.45848	 1	 9999.0	 -9999.0; % NUC
	5697	 44.6	 8.8	 38.09102	 -11.6929	 0.979455	 68.189809	 1	 80.0	 0.0; % NG
	5698	 117.9	 2.4	 51.24997	 -23.4864	 1.037955	 176.886637	 1	 120.0	 0.0; % COW
	5699	 0.28	 5.54	 9999.0	 -9999.0	 1.07943	 8.320607	 1	 9999.0	 -9999.0; % COW
	5701	 91.9	 7.4	 42.68333	 -18.5732	 1.094237	 138.296177	 1	 100.0	 0.0; % PEL
	5707	 55.5	 24.3	 58.11852	 -16.5976	 1.042182	 90.879948	 1	 120.0	 0.0; % NG
	5715	 0.57	 1.0	 9999.0	 -9999.0	 1.04657	 1.726565	 1	 9999.0	 -9999.0; % NUC
	5734	 0.2	 1.64	 9999.0	 -9999.0	 1.068652	 2.478225	 1	 9999.0	 -9999.0; % COW
	5740	 223.4	 -1.7	 134.0765	 -49.1543	 1.027533	 335.109702	 1	 300.0	 100.0; % NG
	5742	 48.8	 8.8	 37.75939	 -12.0502	 1.089773	 74.380643	 1	 80.0	 0.0; % NG
	5743	 96.0	 3.0	 96.55635	 -27.9482	 1.096	 144.070295	 1	 200.0	 0.0; % COW
	5745	 66.6	 18.2	 56.24379	 -17.3592	 1.014727	 103.563024	 1	 120.0	 0.0; % NG
	5746	 -92.76	 46.04	 9999.0	 -9999.0	 1.043413	 155.33584	 1	 9999.0	 -9999.0; % COW
	5749	 29.5	 4.8	 21.92169	 -16.8577	 0.998	 44.831936	 1	 59.9797	 0.0; % NG
	5762	 43.8	 16.8	 38.28945	 -11.556	 1.063409	 70.367109	 1	 80.0	 0.0; % NG
	5769	 49.8	 33.8	 37.69186	 -12.1244	 0.954182	 90.280563	 1	 80.0	 0.0; % NG
	5774	 0.48	 0.0	 9999.0	 -9999.0	 0.977652	 0.72	 1	 9999.0	 -9999.0; % COW
	5777	 188.9	 51.5	 139.0741	 -44.6174	 1.098447	 293.69165	 1	 300.0	 100.0; % COW
	5779	 114.0	 8.4	 51.11374	 -23.4556	 1.008409	 171.463582	 1	 120.0	 0.0; % NG
	5783	 124.0	 28.0	 72.49993	 -27.059	 1.011955	 190.682983	 1	 160.0	 0.0; % NG
	5784	 318.4	 -1.2	 176.6996	 -68.1513	 1.079342	 477.603392	 1	 400.0	 0.0; % NG
	5785	 18.69	 7.9	 9999.0	 -9999.0	 1.065535	 30.436552	 1	 9999.0	 -9999.0; % COW
	5786	 223.2	 32.0	 148.6542	 -50.7336	 1.072273	 338.223358	 1	 320.0	 0.0; % NG
	5791	 22.18	 7.71	 9999.0	 -9999.0	 1.075959	 35.22275	 1	 9999.0	 -9999.0; % COW
	5794	 0.6	 0.89	 9999.0	 -9999.0	 0.99733	 1.610039	 1	 9999.0	 -9999.0; % COW
	5798	 18.68	 4.52	 9999.0	 -9999.0	 1.064842	 28.828611	 1	 9999.0	 -9999.0; % COW
	5813	 4.88	 2.77	 9999.0	 -9999.0	 0.938651	 8.417032	 1	 9999.0	 -9999.0; % COW
	5816	 958.2	 223.5	 537.0295	 -198.633	 1.066684	 1475.880704	 1	 1200.0	 399.999999; % NG
	5817	 191.2	 2.6	 83.57609	 -38.7814	 0.996409	 286.826516	 1	 200.0	 66.666666; % NG
	5821	 1156.8	 244.2	 507.5835	 -228.203	 1.068842	 1773.441493	 1	 1200.0	 399.999996; % COW
	5824	 0.47	 0.84	 9999.0	 -9999.0	 0.952368	 1.443823	 1	 9999.0	 -9999.0; % COW
	5826	 0.18	 2.28	 9999.0	 -9999.0	 1.083153	 3.430641	 1	 9999.0	 -9999.0; % NUC
	5831	 171.0	 28.0	 88.83223	 -35.6876	 1.074727	 259.915852	 1	 200.0	 0.0; % NG
	5834	 291.2	 16.0	 180.9344	 -64.1998	 1.033591	 437.458844	 1	 400.0	 0.0; % COW
	5836	 837.3	 281.1	 551.3255	 -184.728	 1.062955	 1324.839283	 1	 1200.0	 399.999999; % COW
	5838	 5.2	 0.8	 0.8	 0.8	 1.038864	 7.891768	 1	 5.2	 5.2; % PEL
	5850	 31.9	 17.4	 18.35941	 -6.62741	 0.943909	 54.505344	 1	 40.0	 0.0; % COW
	5859	 1.5	 41.98	 9999.0	 -9999.0	 1.074241	 63.010185	 1	 9999.0	 -9999.0; % COW
	5860	 91.2	 1.4	 43.08973	 -18.2391	 1.089263	 136.816117	 1	 100.0	 0.0; % NG
	5861	 77.4	 12.9	 86.16914	 -24.2529	 1.024533	 117.701455	 1	 180.0	 0.0; % NG
	5864	 9.88	 3.96	 9999.0	 -9999.0	 0.973755	 15.966089	 1	 9999.0	 -9999.0; % COW
	5867	 22.2	 5.79	 9999.0	 -9999.0	 1.094112	 34.413939	 1	 9999.0	 -9999.0; % COW
	5873	 872.4	 135.6	 438.7154	 -174.146	 1.073318	 1324.313226	 1	 1000.0	 333.333333; % COW
	5878	 0.21	 1.04	 9999.0	 -9999.0	 1.055674	 1.591485	 1	 9999.0	 -9999.0; % NUC
	5881	 90.0	 21.3	 55.3415	 -19.5146	 1.023182	 138.729242	 1	 120.0	 0.0; % COW
	5882	 1170.9	 48.0	 508.021	 -227.301	 1.089921	 1757.825168	 1	 1200.0	 399.999999; % NG
	5886	 0.12	 1.74	 9999.0	 -9999.0	 1.041142	 2.6162	 1	 9999.0	 -9999.0; % NUC
	5889	 304.8	 15.3	 180.0197	 -65.0036	 1.032237	 457.775646	 1	 400.0	 133.333333; % NG
	5894	 701.6	 100.0	 348.8315	 -141.855	 1.071789	 1063.036105	 1	 800.0	 266.666664; % COW
	5898	 49.6	 13.8	 37.5588	 -12.1921	 1.024091	 77.225967	 1	 80.0	 0.0; % NG
	5902	 0.04	 1.34	 9999.0	 -9999.0	 1.059239	 2.010895	 1	 9999.0	 -9999.0; % COW
	5909	 0.18	 1.0	 9999.0	 -9999.0	 1.086417	 1.524106	 1	 9999.0	 -9999.0; % COW
	5911	 228.2	 42.0	 126.7283	 -47.8284	 1.087182	 348.049264	 1	 280.0	 0.0; % NG
	5912	 14.73	 9.85	 9999.0	 -9999.0	 0.980909	 26.579873	 1	 9999.0	 -9999.0; % COW
	5913	 0.19	 1.94	 9999.0	 -9999.0	 1.068152	 2.923923	 1	 9999.0	 -9999.0; % NUC
	5925	 15.91	 6.0	 9999.0	 -9999.0	 1.040241	 25.505651	 1	 9999.0	 -9999.0; % COW
	5926	 0.65	 2.03	 9999.0	 -9999.0	 1.007427	 3.197288	 1	 9999.0	 -9999.0; % COW
	5941	 49.2	 12.6	 37.57981	 -12.1648	 1.053545	 76.181691	 1	 80.0	 0.0; % NG
	5943	 37.81	 21.64	 9999.0	 -9999.0	 1.018516	 65.347095	 1	 9999.0	 -9999.0; % COW
	5957	 26.78	 23.26	 9999.0	 -9999.0	 1.080647	 53.206588	 1	 9999.0	 -9999.0; % COW
	5971	 22.27	 8.9	 9999.0	 -9999.0	 1.095569	 35.973831	 1	 9999.0	 -9999.0; % NUC
	5976	 219.0	 68.3	 188.4472	 -56.6116	 1.057273	 344.105002	 1	 400.0	 133.333333; % NG
	5979	 606.6	 104.1	 414.3165	 -137.058	 1.059909	 923.201404	 1	 900.0	 300.0; % COW
	5986	 14.12	 6.04	 9999.0	 -9999.0	 1.019773	 23.036406	 1	 9999.0	 -9999.0; % COW
	5993	 43.7	 5.8	 47.5639	 -13.5606	 1.013	 66.124825	 1	 100.0	 33.333333; % PEL
	5997	 3.71	 2.15	 9999.0	 -9999.0	 1.050203	 6.43194	 1	 9999.0	 -9999.0; % NUC
	6004	 290.7	 84.3	 125.5963	 -58.1225	 1.070318	 454.014543	 1	 300.0	 0.0; % NG
	6006	 37.33	 11.88	 9999.0	 -9999.0	 1.081926	 58.762168	 1	 9999.0	 -9999.0; % NUC
	6008	 31.9	 11.7	 18.32016	 -6.65635	 1.010636	 50.966901	 1	 40.0	 0.0; % COW
	6009	 99.5	 5.4	 42.14038	 -19.2346	 1.024545	 149.469637	 1	 100.0	 33.333333; % NG
	6011	 0.44	 0.0	 9999.0	 -9999.0	 1.096201	 0.66	 1	 9999.0	 -9999.0; % COW
	6014	 2027.7	 155.4	 1378.193	 -459.093	 1.100184	 3050.469146	 1	 3000.0	 999.999999; % COW
	6020	 11.13	 3.06	 9999.0	 -9999.0	 1.061794	 17.314477	 1	 9999.0	 -9999.0; % COW
	6022	 37.8	 13.6	 38.53067	 -11.1889	 1.005364	 60.258194	 1	 80.0	 0.0; % NG
	6027	 19.84	 6.04	 9999.0	 -9999.0	 0.992868	 31.108539	 1	 9999.0	 -9999.0; % COW
	6028	 26.03	 0.84	 9999.0	 -9999.0	 1.095255	 39.065325	 1	 9999.0	 -9999.0; % COW
	6032	 9.32	 10.58	 9999.0	 -9999.0	 1.062421	 21.149404	 1	 9999.0	 -9999.0; % COW
	6034	 773.6	 56.0	 337.0381	 -153.263	 1.072091	 1163.436358	 1	 800.0	 266.666664; % COW
	6036	 249.0	 19.0	 131.8789	 -52.2396	 1.081364	 374.585771	 1	 300.0	 0.0; % NG
	6041	 79.9	 23.4	 44.49301	 -16.8156	 0.993273	 124.884076	 1	 100.0	 0.0; % NG
	6042	 0.2	 1.64	 9999.0	 -9999.0	 1.068652	 2.478225	 1	 9999.0	 -9999.0; % COW
	6057	 33.2	 9.3	 28.15462	 -8.65873	 1.060182	 51.716946	 1	 60.0	 0.0; % NG
	6058	 21.3	 1.7	 36.22044	 -35.5049	 1.096211	 32.051599	 1	 108.37565	 0.0; % NG
	6066	 9.9	 5.32	 9999.0	 -9999.0	 0.943281	 16.858318	 1	 9999.0	 -9999.0; % COW
	6069	 20.1	 4.5	 9999.0	 -9999.0	 1.08393	 30.896359	 1	 9999.0	 -9999.0; % COW
	6079	 989.7	 34.2	 533.9777	 -201.865	 1.105368	 1485.436095	 1	 1200.0	 399.999999; % COW
	6084	 218.82	 93.95	 9999.0	 -9999.0	 1.054613	 357.204127	 1	 9999.0	 -9999.0; % COW
	6091	 32.8	 0.7	 18.02568	 -6.89546	 1.045409	 49.211203	 1	 40.0	 0.0; % COW
	6107	 14.86	 5.19	 9999.0	 -9999.0	 0.959147	 23.610386	 1	 9999.0	 -9999.0; % COW
	6108	 662.2	 106.1	 311.5164	 -132.093	 1.087909	 1005.968992	 1	 720.0	 0.0; % COW
	6110	 670.8	 42.9	 405.8782	 -144.96	 1.079105	 1008.255604	 1	 900.0	 300.0; % COW
	6112	 4.91	 2.53	 9999.0	 -9999.0	 1.026168	 8.285243	 1	 9999.0	 -9999.0; % NG
	6113	 59.4	 19.2	 36.92949	 -12.9664	 1.057182	 93.638934	 1	 80.0	 0.0; % NG
	6117	 4.38	 2.61	 9999.0	 -9999.0	 1.075038	 7.648014	 1	 9999.0	 -9999.0; % COW
	6124	 68.2	 12.6	 35.86946	 -14.0181	 1.070632	 104.031245	 1	 80.0	 0.0; % COW
	6127	 32.2	 9.4	 28.24344	 -8.57106	 1.060727	 50.316001	 1	 60.0	 0.0; % NG
	6132	 -8.62	 5.68	 9999.0	 -9999.0	 1.017453	 15.48468	 1	 9999.0	 -9999.0; % COW
	6135	 9.9	 1.6	 1.6	 1.6	 0.988455	 15.042689	 1	 9.9	 9.9; % PEL
	6149	 276.8	 53.2	 183.4019	 -62.0244	 1.068079	 422.799101	 1	 400.0	 133.333332; % NG
	6151	 14.5	 5.6	 10.67677	 -8.06034	 1.077474	 23.315714	 1	 29.18592	 4.86432; % PEL
	6155	 6.77	 2.13	 9999.0	 -9999.0	 1.032778	 10.645753	 1	 9999.0	 -9999.0; % COW
	6162	 32.6	 1.8	 28.21062	 -8.60515	 1.092773	 48.974483	 1	 60.0	 0.0; % NG
	6166	 949.7	 181.4	 429.6092	 -183.481	 1.086974	 1450.3038	 1	 1000.0	 333.333333; % COW
	6168	 6.84	 0.61	 9999.0	 -9999.0	 1.063195	 10.30072	 1	 9999.0	 -9999.0; % NUC
	6173	 7.81	 2.67	 9999.0	 -9999.0	 0.986089	 12.380681	 1	 9999.0	 -9999.0; % COW
	6174	 4.56	 2.13	 9999.0	 -9999.0	 1.052874	 7.549412	 1	 9999.0	 -9999.0; % COW
	6175	 74.8	 27.2	 77.143	 -22.4628	 1.072818	 119.387939	 1	 160.0	 0.0; % NG
	6176	 0.16	 29.24	 9999.0	 -9999.0	 0.9765	 43.860657	 1	 9999.0	 -9999.0; % COW
	6179	 114.4	 -12.8	 93.15287	 -29.2258	 1.079868	 172.670785	 1	 200.0	 0.0; % NG
	6183	 76.0	 24.8	 77.35327	 -22.2595	 1.075455	 119.915971	 1	 160.0	 0.0; % NG
	6187	 15.9	 2.0	 11.98894	 -9.05853	 1.078273	 24.037939	 1	 32.53062	 0.0; % PEL
	6188	 251.0	 -6.0	 131.8117	 -52.3576	 1.093237	 376.607554	 1	 300.0	 0.0; % NG
	6195	 150.2	 13.83	 9999.0	 -9999.0	 0.923923	 226.253055	 1	 9999.0	 -9999.0; % COW
	6197	 69.6	 7.6	 35.62461	 -14.2456	 1.058864	 105.020569	 1	 80.0	 0.0; % NG
	6198	 0.12	 1.74	 9999.0	 -9999.0	 1.041152	 2.6162	 1	 9999.0	 -9999.0; % COW
	6201	 0.15	 1.93	 9999.0	 -9999.0	 1.029304	 2.90373	 1	 9999.0	 -9999.0; % COW
	6204	 578.0	 107.0	 255.2267	 -112.308	 1.082267	 881.730826	 1	 600.0	 200.0; % COW
	6205	 10.76	 4.0	 9999.0	 -9999.0	 1.040728	 17.219164	 1	 9999.0	 -9999.0; % NUC
	6208	 89.7	 24.9	 54.68224	 -19.958	 0.973091	 139.637835	 1	 120.0	 0.0; % NG
	6210	 102.9	 17.1	 53.23502	 -21.4697	 1.052455	 156.466754	 1	 120.0	 0.0; % NG
	6212	 298.0	 108.0	 181.6255	 -63.956	 1.036579	 475.450313	 1	 400.0	 0.0; % NG
	6215	 27.5	 3.9	 18.55563	 -6.34345	 1.015	 41.662753	 1	 40.0	 0.0; % NG
	6220	 2463.6	 632.4	 1865.83	 -585.945	 1.086447	 3815.209446	 1	 4000.0	 1333.333332; % COW
	6224	 42.0	 14.0	 38.34252	 -11.4514	 1.058864	 66.407831	 1	 80.0	 0.0; % NG
	6227	 64.6	 16.0	 36.07788	 -13.7451	 1.054789	 99.827902	 1	 80.0	 0.0; % PEL
	6236	 362.8	 -3.6	 172.4173	 -72.8485	 1.0875	 544.226791	 1	 400.0	 133.333332; % NG
	6239	 19.8	 2.5	 33.56642	 -32.9514	 1.093026	 29.935806	 1	 100.50505	 0.0; % NG
	6246	 0.12	 1.31	 9999.0	 -9999.0	 1.040622	 1.973227	 1	 9999.0	 -9999.0; % COW
	6250	 242.0	 56.0	 189.3052	 -59.8709	 1.086045	 372.59227	 1	 400.0	 133.33333; % NG
	6251	 12.49	 5.83	 9999.0	 -9999.0	 1.081051	 20.675475	 1	 9999.0	 -9999.0; % COW
	6252	 21.09	 9.94	 9999.0	 -9999.0	 1.076	 34.97258	 1	 9999.0	 -9999.0; % NUC
	6260	 420.5	 10.0	 218.8106	 -87.4814	 1.100105	 630.928334	 1	 500.0	 166.666665; % NG
	6261	 37.84	 19.23	 9999.0	 -9999.0	 1.000005	 63.668922	 1	 9999.0	 -9999.0; % COW
	6266	 735.3	 87.4	 327.0448	 -146.461	 1.088263	 1110.714145	 1	 760.0	 0.0; % COW
	6269	 116.8	 32.0	 104.7978	 -87.0942	 1.052026	 181.656379	 1	 295.83335	 0.0; % NG
	6273	 173.4	 0.4	 87.27873	 -35.3472	 1.096447	 260.100692	 1	 200.0	 0.0; % NG
	6279	 37.34	 13.33	 9999.0	 -9999.0	 1.050657	 59.472011	 1	 9999.0	 -9999.0; % COW
	6282	 131.2	 22.4	 56.01159	 -25.3869	 1.0475	 199.64769	 1	 132.8384	 44.279467; % NG
	6283	 10.36	 4.66	 9999.0	 -9999.0	 1.039853	 17.03971	 1	 9999.0	 -9999.0; % COW
	6286	 98.4	 22.9	 72.87702	 -55.0102	 1.076684	 151.544325	 1	 199.23232	 33.205387; % COW
	6289	 33.7	 3.2	 28.11731	 -8.69483	 1.058267	 50.777382	 1	 60.0	 0.0; % NG
	6291	 826.2	 24.6	 388.7	 -162.642	 1.032045	 1239.849225	 1	 900.0	 300.0; % COW
	6292	 354.36	 101.97	 188.1474	 -56.9601	 1.084727	 553.109396	 1	 530.46	 263.793333; % COW
	6300	 227.5	 42.0	 126.0931	 -48.2881	 1.0795	 347.01666	 1	 280.0	 0.0; % NG
	6301	 319.2	 91.2	 179.3856	 -66.228	 1.010227	 497.959516	 1	 400.0	 0.0; % NG
	6308	 0.67	 3.48	 9999.0	 -9999.0	 1.016274	 5.315865	 1	 9999.0	 -9999.0; % COW
	6317	 269.0	 31.4	 184.5344	 -60.7314	 1.047273	 406.239658	 1	 400.0	 133.333333; % NG
	6319	 39.8	 10.4	 38.53143	 -11.2704	 1.086045	 61.704538	 1	 80.0	 0.0; % NG
	6322	 12.25	 5.0	 9999.0	 -9999.0	 1.085918	 19.846678	 1	 9999.0	 -9999.0; % COW
	6330	 76.5	 18.3	 56.21861	 -18.444	 1.053818	 117.987563	 1	 120.0	 0.0; % PEL
	6339	 24.68	 9.24	 9999.0	 -9999.0	 0.99434	 39.529483	 1	 9999.0	 -9999.0; % COW
	6341	 157.6	 23.4	 89.69457	 -33.0531	 1.084474	 238.991569	 1	 200.0	 0.0; % COW
	6347	 1872.8	 207.4	 862.0493	 -363.971	 1.101579	 2826.373622	 1	 2000.0	 666.666666; % COW
	6356	 862.0	 92.0	 401.302	 -186.614	 1.073182	 1300.343416	 1	 960.0	 0.0; % NUC
	6371	 36.2	 3.6	 17.58638	 -7.3383	 0.999818	 54.567848	 1	 40.0	 0.0; % PEL
	6372	 363.0	 41.0	 175.5077	 -73.6979	 1.078864	 547.962134	 1	 400.0	 0.0; % COW
	6373	 438.5	 108.0	 219.3174	 -87.6839	 1.030868	 677.406128	 1	 500.0	 166.666665; % PEL
	6374	 1154.4	 6.8	 507.7266	 -226.726	 1.091553	 1731.630041	 1	 1200.0	 400.0; % NUC
	6377	 199.6	 63.0	 190.4426	 -54.8494	 1.044091	 313.959567	 1	 400.0	 133.333333; % NG
	6380	 65.8	 8.2	 36.16321	 -13.7172	 1.072864	 99.463461	 1	 80.0	 0.0; % NG
	6386	 4.02	 1.8	 9999.0	 -9999.0	 1.019	 6.606883	 1	 9999.0	 -9999.0; % COW
	6393	 55.5	 27.0	 58.1769	 -16.5599	 1.055409	 92.578683	 1	 120.0	 0.0; % NG
	6400	 490.8	 108.0	 267.3579	 -100.985	 1.052421	 753.813266	 1	 600.0	 199.999998; % NG
	6402	 50.4	 17.4	 37.59435	 -12.2008	 1.014636	 79.97856	 1	 80.0	 0.0; % NG
	6406	 423.2	 37.5	 220.6567	 -85.886	 1.102368	 637.2873	 1	 500.0	 166.666667; % COW
	6408	 199.5	 13.8	 136.871	 -46.6784	 1.037545	 299.965085	 1	 300.0	 99.999999; % NG
	6412	 2.01	 1.08	 9999.0	 -9999.0	 1.043125	 3.422663	 1	 9999.0	 -9999.0; % COW
	6418	 12.8	 0.6	 13.40967	 -11.8881	 1.0245	 19.221082	 1	 38.62311	 0.0; % COW
	6426	 292.8	 65.1	 126.9295	 -57.1241	 1.036591	 449.924619	 1	 300.0	 0.0; % COW
	6430	 41.8	 12.6	 38.34582	 -11.4419	 1.058342	 65.48664	 1	 80.0	 0.0; % NG
	6434	 119.2	 34.0	 93.13635	 -29.4212	 1.094605	 185.931278	 1	 200.0	 0.0; % NG
	6444	 234.2	 11.2	 133.0191	 -50.2862	 1.02	 351.701479	 1	 300.0	 100.0; % NG
	6447	 325.5	 69.7	 177.4357	 -67.5455	 1.007727	 499.3183	 1	 400.0	 133.333333; % NG
	6453	 94.5	 18.3	 54.37656	 -20.3491	 1.077368	 144.383396	 1	 120.0	 0.0; % NG
	6454	 89.2	 12.4	 95.05883	 -83.3387	 1.074864	 135.086639	 1	 272.28426	 0.0; % NG
	6469	 19.75	 1.37	 9999.0	 -9999.0	 1.072578	 29.696189	 1	 9999.0	 -9999.0; % COW
	6474	 1120.4	 43.2	 516.035	 -219.174	 1.087026	 1681.848804	 1	 1200.0	 400.0; % NUC
	6480	 6.24	 3.42	 9999.0	 -9999.0	 1.039663	 10.673636	 1	 9999.0	 -9999.0; % COW
	6488	 35.7	 8.8	 17.6075	 -7.30711	 1.075	 55.152901	 1	 40.0	 0.0; % PEL
	6490	 8.01	 3.24	 9999.0	 -9999.0	 0.955879	 12.960703	 1	 9999.0	 -9999.0; % COW
	6492	 861.3	 108.2	 441.0395	 -172.049	 1.082711	 1302.104486	 1	 1000.0	 333.333333; % COW
	6497	 18.6	 6.72	 9999.0	 -9999.0	 1.052168	 29.66507	 1	 9999.0	 -9999.0; % NG
	6499	 89.4	 16.5	 55.10733	 -19.653	 0.963182	 136.364851	 1	 120.0	 0.0; % NG
	6502	 56.4	 3.0	 37.06226	 -12.7731	 1.104553	 84.719596	 1	 80.0	 0.0; % COW
	6506	 73.19	 26.77	 9999.0	 -9999.0	 1.042571	 116.898119	 1	 9999.0	 -9999.0; % COW
	6514	 1250.6	 310.6	 926.4741	 -297.626	 1.101368	 1932.889966	 1	 2000.0	 666.666666; % COW
	6516	 14.87	 5.46	 9999.0	 -9999.0	 0.967222	 23.761084	 1	 9999.0	 -9999.0; % NUC
	6529	 199.0	 35.5	 86.17981	 -38.6108	 0.983636	 303.212487	 1	 200.0	 0.0; % NG
	6533	 241.32	 48.72	 9999.0	 -9999.0	 1.02852	 369.283369	 1	 9999.0	 -9999.0; % COW
	6535	 119.2	 34.8	 93.13635	 -29.4212	 1.094263	 186.264006	 1	 200.0	 0.0; % NG
	6537	 7.3	 1.1	 1.1	 1.1	 1.080091	 11.073617	 1	 7.3	 7.3; % NG
	6540	 67.0	 11.6	 70.22175	 -62.0219	 1.062947	 101.995147	 1	 202.70352	 0.0; % COW
	6541	 359.1	 51.2	 174.7512	 -70.6137	 1.092711	 544.097475	 1	 400.0	 133.333333; % COW
	6552	 528.0	 88.6	 370.3469	 -120.319	 1.103895	 803.073104	 1	 800.0	 266.666666; % COW
	6554	 0.18	 1.0	 9999.0	 -9999.0	 1.065416	 1.524106	 1	 9999.0	 -9999.0; % COW
	6572	 39.6	 8.0	 17.25551	 -7.70147	 1.044455	 60.6	 1	 40.0	 0.0; % NG
	6578	 29.75	 15.08	 9999.0	 -9999.0	 1.018513	 50.030541	 1	 9999.0	 -9999.0; % COW
	6579	 21.3	 1.3	 35.76807	 -35.2298	 1.076553	 32.009452	 1	 107.28645	 0.0; % COW
	6582	 32.0	 13.7	 13.73162	 -6.27692	 1.058333	 52.214007	 1	 32.70408	 10.90136; % NG
	6588	 168.0	 28.0	 89.83811	 -34.8411	 1.055947	 255.476026	 1	 200.0	 0.0; % NG
	6591	 766.8	 155.7	 394.8591	 -156.123	 1.104158	 1173.671863	 1	 900.0	 300.0; % NUC
	6595	 0.33	 0.0	 9999.0	 -9999.0	 1.079255	 0.495	 1	 9999.0	 -9999.0; % COW
	6598	 354.7	 14.4	 174.0095	 -71.0502	 1.087318	 532.488275	 1	 400.0	 133.333333; % COW
	6599	 34.1	 10.0	 14.78255	 -6.64399	 1.075667	 53.304057	 1	 34.91837	 11.639457; % COW
	6601	 2464.4	 367.6	 1862.294	 -588.165	 1.102974	 3737.498297	 1	 4000.0	 1333.333332; % COW
	6611	 50.0	 10.6	 37.71116	 -12.1241	 1.086591	 76.666877	 1	 80.0	 0.0; % COW
	6616	 119.69	 27.08	 9999.0	 -9999.0	 1.05427	 184.072813	 1	 9999.0	 -9999.0; % COW
	6620	 858.9	 29.7	 384.3376	 -167.039	 1.086105	 1289.12002	 1	 900.0	 300.0; % COW
	6625	 9.86	 2.8	 9999.0	 -9999.0	 0.953641	 15.374788	 1	 9999.0	 -9999.0; % NUC
	6643	 94.0	 32.4	 76.10756	 -23.6156	 1.059227	 149.140739	 1	 160.0	 0.0; % NG
	6644	 53.0	 19.4	 37.45443	 -12.3922	 1.019289	 84.65849	 1	 80.0	 0.0; % COW
	6645	 62.8	 2.4	 36.2567	 -13.554	 1.054727	 94.268765	 1	 80.0	 0.0; % NG
	6646	 399.0	 41.0	 167.1121	 -77.8096	 1.102079	 601.651477	 1	 401.01	 133.67; % NG
	6647	 32.1	 6.5	 18.11857	 -6.80864	 1.079273	 49.127233	 1	 40.0	 0.0; % NG
	6664	 1.73	 0.76	 9999.0	 -9999.0	 1.035572	 2.834365	 1	 9999.0	 -9999.0; % COW
	6672	 116.8	 9.2	 51.00006	 -22.788	 1.092395	 175.742653	 1	 120.0	 0.0; % COW
	6684	 0.2	 0.83	 9999.0	 -9999.0	 1.063236	 1.280635	 1	 9999.0	 -9999.0; % COW
	6686	 80.4	 21.9	 56.1777	 -18.6229	 1.020818	 124.99393	 1	 120.0	 0.0; % COW
	6688	 27.03	 11.14	 9999.0	 -9999.0	 1.049818	 43.853405	 1	 9999.0	 -9999.0; % COW
	6691	 100.6	 19.7	 42.53724	 -19.539	 1.017773	 153.766097	 1	 101.397	 33.799; % NG
	6700	 32.3	 13.7	 34.07797	 -29.8701	 1.067636	 52.627987	 1	 98.09091	 10.89899; % NG
	6708	 242.4	 71.7	 134.0057	 -50.1547	 1.014955	 379.172734	 1	 300.0	 0.0; % NG
	6714	 0.2	 1.0	 9999.0	 -9999.0	 1.072349	 1.529706	 1	 9999.0	 -9999.0; % COW
	6731	 0.2	 1.0	 9999.0	 -9999.0	 1.087526	 1.529706	 1	 9999.0	 -9999.0; % COW
	6733	 856.4	 304.8	 752.6096	 -226.418	 1.0855	 1363.535478	 1	 1600.0	 533.333332; % NG
	6736	 735.6	 40.5	 399.876	 -151.376	 1.039182	 1105.071094	 1	 900.0	 300.0; % COW
	6737	 49.6	 17.4	 37.64625	 -12.1398	 1.041909	 78.845228	 1	 80.0	 0.0; % NG
	6745	 9.78	 2.96	 9999.0	 -9999.0	 1.027532	 15.327182	 1	 9999.0	 -9999.0; % COW
	6750	 13.3	 2.7	 14.28313	 -12.5521	 1.043773	 20.35694	 1	 40.95918	 0.0; % NG
	6752	 0.06	 1.72	 9999.0	 -9999.0	 1.009791	 2.581569	 1	 9999.0	 -9999.0; % NG
	6768	 37.9	 4.0	 27.69362	 -9.11151	 1.0432	 57.165746	 1	 60.0	 0.0; % PEL
	6769	 41.47	 18.47	 75.85474	 -77.0613	 1.030409	 68.095734	 1	 233.84236	 3.37; % COW
	6770	 11.14	 3.38	 9999.0	 -9999.0	 1.068287	 17.462216	 1	 9999.0	 -9999.0; % COW
	6774	 18.95	 6.93	 9999.0	 -9999.0	 1.049596	 30.266097	 1	 9999.0	 -9999.0; % COW
	6776	 2.43	 3.34	 9999.0	 -9999.0	 1.071462	 6.195654	 1	 9999.0	 -9999.0; % NUC
	6777	 76.5	 9.9	 56.26624	 -18.4124	 1.022636	 115.706893	 1	 120.0	 0.0; % NG
	6783	 0.18	 3.54	 9999.0	 -9999.0	 1.048135	 5.31686	 1	 9999.0	 -9999.0; % NUC
	6792	 196.4	 -20.4	 83.00204	 -39.4157	 1.085289	 296.184942	 1	 200.0	 0.0; % NG
	6796	 6.79	 1.44	 9999.0	 -9999.0	 1.057061	 10.411524	 1	 9999.0	 -9999.0; % COW
	6797	 189.2	 59.4	 214.2317	 -59.7698	 1.061091	 297.45798	 1	 440.0	 146.666663; % COW
	6800	 148.4	 7.8	 90.3117	 -32.2944	 0.986636	 222.907268	 1	 200.0	 66.666666; % NG
	6805	 5.2	 0.4	 0.4	 0.4	 1.055091	 7.823043	 1	 5.2	 5.2; % PEL
	6809	 717.9	 30.9	 402.1496	 -149.167	 1.085053	 1077.847042	 1	 900.0	 300.0; % COW
	6819	 14.89	 4.46	 9999.0	 -9999.0	 0.966052	 23.31541	 1	 9999.0	 -9999.0; % COW
	6820	 22.93	 9.6	 9999.0	 -9999.0	 1.077045	 37.287746	 1	 9999.0	 -9999.0; % COW
	6821	 702.4	 113.6	 350.3641	 -140.731	 1.032711	 1067.290551	 1	 800.0	 266.666664; % COW
	6823	 508.0	 144.0	 371.1129	 -119.669	 1.040974	 792.022727	 1	 800.0	 266.666664; % COW
	6826	 8.66	 6.01	 9999.0	 -9999.0	 1.050629	 15.811715	 1	 9999.0	 -9999.0; % COW
	6841	 9.08	 3.86	 9999.0	 -9999.0	 1.065664	 14.799611	 1	 9999.0	 -9999.0; % COW
	6844	 14.0	 3.62	 9999.0	 -9999.0	 0.957659	 21.690664	 1	 9999.0	 -9999.0; % NG
	6849	 5.91	 2.55	 9999.0	 -9999.0	 1.007689	 9.654991	 1	 9999.0	 -9999.0; % COW
	6851	 125.92	 53.57	 9999.0	 -9999.0	 1.044003	 205.262224	 1	 9999.0	 -9999.0; % NUC
	6858	 0.03	 1.09	 9999.0	 -9999.0	 1.06807	 1.635619	 1	 9999.0	 -9999.0; % COW
	6866	 100.8	 9.9	 53.40224	 -21.2625	 1.0385	 151.927491	 1	 120.0	 0.0; % NG
	6882	 18.27	 12.99	 9999.0	 -9999.0	 1.06958	 33.625872	 1	 9999.0	 -9999.0; % COW
	6903	 179.2	 44.1	 131.8909	 -42.6196	 1.062273	 276.81991	 1	 280.0	 0.0; % COW
	6911	 375.8	 79.2	 276.9884	 -89.8843	 1.097184	 576.082572	 1	 600.0	 200.0; % COW
	6914	 115.8	 12.0	 51.08731	 -22.6943	 1.067895	 174.630152	 1	 120.0	 0.0; % NG
	6919	 147.69	 58.76	 9999.0	 -9999.0	 1.077468	 238.424864	 1	 9999.0	 -9999.0; % COW
	6921	 289.4	 77.0	 180.6115	 -64.062	 1.016591	 449.202694	 1	 400.0	 133.333333; % NG
	6922	 243.0	 54.5	 133.775	 -50.0428	 1.099	 373.554966	 1	 300.0	 100.0; % NG
	6924	 43.4	 4.8	 45.84971	 -40.5002	 1.014045	 65.496946	 1	 131.81817	 0.0; % NG
	6932	 37.4	 7.7	 27.79209	 -9.02801	 1.044773	 57.276631	 1	 60.0	 0.0; % PEL
	6934	 769.2	 68.3	 378.2056	 -162.352	 1.0195	 1158.33952	 1	 880.0	 199.999998; % COW
	6946	 101.8	 19.6	 108.4714	 -95.1824	 1.027864	 155.504502	 1	 312.3366	 34.704067; % NG
	6947	 378.0	 77.2	 172.4099	 -72.9867	 1.078921	 578.704277	 1	 400.0	 133.333333; % NG
	6948	 102.8	 8.4	 74.7031	 -24.7791	 1.031091	 154.71393	 1	 160.0	 0.0; % NG
	6950	 168.6	 1.2	 76.75097	 -33.7898	 1.054727	 252.906406	 1	 180.0	 0.0; % NG
	6951	 0.21	 2.37	 9999.0	 -9999.0	 1.066194	 3.568928	 1	 9999.0	 -9999.0; % NUC
	6956	 1.39	 39.72	 9999.0	 -9999.0	 1.067664	 59.616471	 1	 9999.0	 -9999.0; % PEL
	6958	 32.2	 3.9	 28.04922	 -8.67368	 0.940267	 48.65298	 1	 60.0	 0.0; % NG
	6959	 285.1	 16.5	 182.9465	 -62.3341	 1.094227	 428.365597	 1	 400.0	 133.333333; % NG
	6964	 46.6	 9.6	 38.03439	 -11.8053	 1.089579	 71.36785	 1	 80.0	 0.0; % COW
	6967	 22.2	 5.79	 9999.0	 -9999.0	 1.09413	 34.413939	 1	 9999.0	 -9999.0; % COW
	6968	 367.0	 62.0	 176.1811	 -73.3057	 1.063409	 558.300322	 1	 400.0	 0.0; % NG
	6973	 50.0	 35.0	 37.99934	 -11.9442	 0.975909	 91.549167	 1	 80.0	 0.0; % NG
	6979	 14.96	 4.7	 9999.0	 -9999.0	 1.070785	 23.521397	 1	 9999.0	 -9999.0; % COW
	6982	 228.2	 42.0	 126.7283	 -47.8284	 1.087182	 348.049264	 1	 280.0	 0.0; % COW
	6992	 37.4	 9.6	 38.67011	 -11.1061	 0.997045	 57.91865	 1	 80.0	 0.0; % NG
	7002	 348.0	 11.6	 173.9112	 -71.2165	 1.053864	 522.289919	 1	 400.0	 133.333332; % NG
	7019	 60.0	 14.8	 36.89859	 -13.0017	 1.073818	 92.697573	 1	 80.0	 0.0; % NG
	7023	 24.99	 4.94	 9999.0	 -9999.0	 0.980864	 38.210382	 1	 9999.0	 -9999.0; % NUC
	7024	 20.4	 2.5	 19.09781	 -5.74242	 0.982867	 30.828923	 1	 40.0	 0.0; % NG
	7025	 229.6	 -18.4	 97.38247	 -49.104	 1.018455	 345.504153	 1	 240.0	 0.0; % NG
	7034	 6.3	 0.7	 0.7	 0.7	 1.089737	 9.508154	 1	 6.3	 6.3; % NG
	7035	 0.58	 -0.1	 9999.0	 -9999.0	 0.986835	 0.882836	 1	 9999.0	 -9999.0; % COW
	7037	 382.8	 37.4	 195.3043	 -78.8309	 1.102	 576.934008	 1	 440.0	 0.0; % NG
	7038	 1425.1	 173.8	 700.1584	 -281.594	 1.105763	 2153.488336	 1	 1600.0	 399.999999; % COW
	7040	 106.8	 2.1	 52.74746	 -21.9661	 1.033864	 160.230966	 1	 120.0	 0.0; % NG
	7054	 1221.2	 335.2	 934.725	 -291.521	 1.102158	 1899.552337	 1	 2000.0	 666.666666; % COW
	7057	 345.2	 95.8	 281.917	 -85.8167	 1.0968	 537.370012	 1	 600.0	 200.0; % COW
	7062	 212.4	 41.4	 105.8524	 -43.6262	 1.078	 324.595702	 1	 240.0	 0.0; % NG
	7072	 47.6	 2.4	 37.77729	 -11.9912	 1.031909	 71.490699	 1	 80.0	 0.0; % NG
	7074	 86.1	 12.9	 55.01944	 -19.5943	 0.996273	 130.59152	 1	 120.0	 0.0; % PEL
	7081	 1250.4	 259.6	 926.3492	 -297.678	 1.092	 1915.595918	 1	 2000.0	 666.666666; % COW
	7091	 25.6	 2.1	 18.89849	 -14.4403	 1.064682	 38.528983	 1	 51.53768	 0.0; % NG
	7103	 17.17	 7.1	 9999.0	 -9999.0	 1.068978	 27.870101	 1	 9999.0	 -9999.0; % COW
	7105	 208.8	 40.2	 106.7723	 -42.8119	 1.039591	 318.951924	 1	 240.0	 0.0; % NG
	7107	 133.8	 18.6	 81.41106	 -29.1694	 1.075227	 202.629958	 1	 180.0	 0.0; % NG
	7108	 14.9	 1.1	 1.1	 1.1	 0.995	 22.410823	 1	 14.9	 14.9; % NG
	7111	 9.78	 3.66	 9999.0	 -9999.0	 0.976402	 15.66362	 1	 9999.0	 -9999.0; % NUC
	7114	 165.0	 27.5	 90.08493	 -34.5619	 1.072474	 250.913954	 1	 200.0	 0.0; % NG
	7115	 390.4	 94.4	 170.1382	 -75.4637	 1.049818	 602.476489	 1	 400.0	 0.0; % NG
	7123	 3.53	 4.62	 9999.0	 -9999.0	 1.059798	 8.721349	 1	 9999.0	 -9999.0; % COW
	7125	 321.3	 -2.0	 175.2932	 -68.9541	 0.943909	 481.959337	 1	 400.0	 133.333333; % NG
	7131	 397.0	 64.6	 380.358	 -109.911	 1.091763	 603.332297	 1	 800.0	 266.666666; % COW
	7144	 34.25	 8.56	 9999.0	 -9999.0	 1.064234	 52.955228	 1	 9999.0	 -9999.0; % COW
	7148	 1.56	 0.81	 9999.0	 -9999.0	 1.038913	 2.636631	 1	 9999.0	 -9999.0; % COW
	7151	 436.0	 105.5	 217.1751	 -89.2166	 1.047868	 672.873734	 1	 500.0	 166.666665; % NG
	7158	 9.88	 3.18	 9999.0	 -9999.0	 0.986899	 15.568728	 1	 9999.0	 -9999.0; % NG
	7160	 26.3	 5.2	 18.76393	 -6.16613	 1.064273	 40.21371	 1	 40.0	 0.0; % COW
	7165	 216.8	 29.6	 149.2959	 -50.0868	 1.093273	 328.217001	 1	 320.0	 0.0; % COW
	7180	 1368.6	 256.4	 920.408	 -305.58	 1.100789	 2088.615707	 1	 2000.0	 666.666666; % COW
	7182	 0.18	 1.31	 9999.0	 -9999.0	 1.043032	 1.983463	 1	 9999.0	 -9999.0; % COW
	7194	 1403.6	 134.0	 698.0721	 -282.166	 1.083474	 2114.972851	 1	 1600.0	 533.333332; % COW
	7196	 0.67	 2.78	 9999.0	 -9999.0	 1.039859	 4.289397	 1	 9999.0	 -9999.0; % COW
	7198	 14.91	 5.0	 9999.0	 -9999.0	 0.999118	 23.589049	 1	 9999.0	 -9999.0; % COW
	7199	 207.9	 -30.3	 136.0283	 -47.5511	 1.073026	 315.14461	 1	 300.0	 0.0; % NG
	7205	 411.8	 5.8	 274.1207	 -93.0109	 1.099132	 617.761265	 1	 600.0	 200.0; % COW
	7216	 313.0	 106.8	 282.7794	 -84.1676	 1.056132	 496.078915	 1	 600.0	 200.0; % COW
	7223	 419.0	 124.4	 274.1952	 -93.2181	 1.086026	 655.615596	 1	 600.0	 200.0; % COW
	7239	 1890.8	 51.7	 1487.057	 -470.652	 1.104789	 2837.260024	 1	 3200.0	 1066.666665; % NG
	7243	 127.52	 54.47	 9999.0	 -9999.0	 1.04406	 207.999388	 1	 9999.0	 -9999.0; % COW
	7245	 3.55	 1.43	 9999.0	 -9999.0	 1.07169	 5.740788	 1	 9999.0	 -9999.0; % NG
	7254	 811.8	 128.7	 391.5692	 -160.947	 1.076053	 1232.907779	 1	 900.0	 299.999997; % NG
	7281	 0.08	 1.57	 9999.0	 -9999.0	 1.024771	 2.358055	 1	 9999.0	 -9999.0; % COW
	7291	 33.2	 9.4	 28.20379	 -8.63105	 1.059864	 51.757608	 1	 60.0	 0.0; % NG
	7297	 96.8	 28.4	 75.67197	 -23.9621	 1.066182	 151.32019	 1	 160.0	 0.0; % NG
	7298	 337.6	 123.8	 281.6325	 -85.708	 1.072727	 539.375055	 1	 600.0	 200.0; % COW
	7299	 10.7	 2.3	 2.3	 2.3	 1.003909	 16.416607	 1	 10.7	 10.7; % NG
	7316	 399.4	 50.2	 276.9394	 -90.7452	 1.099842	 603.81363	 1	 600.0	 200.0; % COW
	7317	 10.2	 1.4	 10.72726	 -9.53466	 1.003182	 15.443445	 1	 30.93468	 0.0; % PEL
	7331	 0.67	 3.26	 9999.0	 -9999.0	 1.016359	 4.992206	 1	 9999.0	 -9999.0; % COW
	7334	 392.7	 4.9	 177.2228	 -80.2727	 1.026682	 589.095854	 1	 420.0	 0.0; % NG
	7341	 8.15	 3.57	 9999.0	 -9999.0	 0.981917	 13.34641	 1	 9999.0	 -9999.0; % COW
	7342	 49.6	 20.2	 37.66225	 -12.1378	 1.043636	 80.333368	 1	 80.0	 0.0; % NG
	7346	 76.3	 25.5	 151.599	 -153.823	 1.069409	 120.672553	 1	 461.30652	 0.0; % COW
	7352	 992.0	 211.68	 99999.0	 -99999.0	 1.052974	 1521.50023	 1	 1041.6	 0.0; % COW
	7358	 1036.4	 119.6	 525.0919	 -210.367	 1.068816	 1564.917097	 1	 1200.0	 399.999998; % NG
	7360	 75.8	 14.2	 34.53229	 -15.2813	 1.021818	 115.677915	 1	 80.0	 0.0; % NG
	7362	 57.4	 19.0	 36.82699	 -12.9573	 1.018818	 90.694322	 1	 80.0	 0.0; % PEL
	7372	 56.8	 19.0	 36.87177	 -12.9125	 1.018773	 89.840358	 1	 80.0	 0.0; % PEL
	7381	 1.07	 0.72	 9999.0	 -9999.0	 1.048327	 1.934535	 1	 9999.0	 -9999.0; % COW
	7385	 0.84	 0.96	 9999.0	 -9999.0	 1.024915	 1.913426	 1	 9999.0	 -9999.0; % COW
	7391	 178.0	 26.4	 87.42633	 -35.3852	 1.092421	 269.920655	 1	 200.0	 66.666666; % NG
	7392	 314.0	 52.4	 179.34	 -66.1002	 1.068658	 477.513309	 1	 400.0	 133.333332; % COW
	7393	 153.0	 19.0	 91.66575	 -33.0104	 1.091182	 231.262837	 1	 200.0	 0.0; % NG
	7394	 700.7	 51.8	 291.7106	 -137.405	 1.086079	 1053.918115	 1	 709.87	 236.623331; % COW
	7405	 12.15	 0.84	 9999.0	 -9999.0	 1.094034	 18.268504	 1	 9999.0	 -9999.0; % COW
	7419	 116.8	 31.8	 104.1908	 -86.7384	 1.052053	 181.577339	 1	 294.34675	 0.0; % NG
	7421	 441.0	 123.0	 219.0976	 -87.9121	 1.029	 686.74777	 1	 500.0	 166.666665; % COW
	7428	 0.18	 1.0	 9999.0	 -9999.0	 1.065427	 1.524106	 1	 9999.0	 -9999.0; % COW
	7429	 15.25	 6.42	 9999.0	 -9999.0	 1.046293	 24.819398	 1	 9999.0	 -9999.0; % COW
	7434	 0.02	 -0.1	 9999.0	 -9999.0	 0.951192	 0.152971	 1	 9999.0	 -9999.0; % NG
	7438	 50.9	 4.5	 70.1748	 -66.4543	 1.020364	 76.647798	 1	 207.26904	 0.0; % NG
	7441	 1329.2	 61.6	 709.4384	 -271.313	 1.086553	 1995.939929	 1	 1600.0	 533.333332; % COW
	7443	 49.8	 15.8	 37.47627	 -12.2563	 0.976364	 78.369509	 1	 80.0	 0.0; % NG
	7446	 103.8	 4.2	 52.21295	 -21.4456	 1.075773	 155.827405	 1	 120.0	 0.0; % NG
	7452	 4.78	 1.71	 9999.0	 -9999.0	 0.995385	 7.614993	 1	 9999.0	 -9999.0; % COW
	7453	 66.8	 12.6	 35.75759	 -14.053	 1.023316	 101.966906	 1	 80.0	 0.0; % COW
	7454	 401.0	 131.8	 276.8136	 -90.8809	 1.089237	 633.156805	 1	 600.0	 200.0; % NUC
	7456	 17.0	 7.2	 19.49097	 -5.42359	 1.071136	 27.692779	 1	 40.0	 0.0; % NG
	7469	 21.2	 1.6	 36.33778	 -35.5854	 1.097921	 31.890437	 1	 108.67345	 0.0; % NG
	7471	 396.9	 40.6	 177.815	 -79.9253	 1.034909	 598.456709	 1	 420.0	 0.0; % NG
	7477	 253.8	 35.4	 164.2984	 -56.8499	 1.085237	 384.385354	 1	 360.0	 0.0; % NG
	7481	 323.6	 30.4	 178.0869	 -67.3184	 1.059789	 487.537199	 1	 400.0	 133.333332; % NG
	7482	 0.57	 1.0	 9999.0	 -9999.0	 1.046427	 1.726565	 1	 9999.0	 -9999.0; % COW
	7484	 0.24	 23.15	 9999.0	 -9999.0	 1.082251	 34.726866	 1	 9999.0	 -9999.0; % COW
	7493	 203.4	 12.0	 106.8417	 -42.5638	 1.090553	 305.630512	 1	 240.0	 0.0; % NG
	7495	 25.0	 9.3	 18.94217	 -6.00423	 1.015636	 40.010655	 1	 40.0	 0.0; % NG
	7504	 97.2	 2.7	 53.87593	 -20.8004	 1.025867	 145.856239	 1	 120.0	 0.0; % COW
	7510	 0.12	 1.31	 9999.0	 -9999.0	 1.041081	 1.973227	 1	 9999.0	 -9999.0; % COW
	7515	 29.84	 2.96	 9999.0	 -9999.0	 1.056507	 44.979675	 1	 9999.0	 -9999.0; % COW
	7529	 411.8	 5.4	 274.1207	 -93.0109	 1.099184	 617.753106	 1	 600.0	 200.0; % COW
	7534	 34.7	 4.4	 17.7956	 -7.1323	 1.073455	 52.466775	 1	 40.0	 0.0; % PEL
	7535	 1702.2	 355.8	 1096.325	 -374.644	 1.087079	 2608.481662	 1	 2400.0	 799.999998; % COW
	7536	 9.75	 2.74	 9999.0	 -9999.0	 1.032678	 15.191535	 1	 9999.0	 -9999.0; % COW
	7550	 116.36	 49.54	 9999.0	 -9999.0	 1.037295	 189.700258	 1	 9999.0	 -9999.0; % NUC
	7555	 20.88	 16.63	 9999.0	 -9999.0	 1.060754	 40.039923	 1	 9999.0	 -9999.0; % COW
	7556	 0.21	 405.11	 9999.0	 -9999.0	 1.076169	 607.665082	 1	 9999.0	 -9999.0; % COW
	7558	 2.3	 3.34	 9999.0	 -9999.0	 1.018404	 6.082976	 1	 9999.0	 -9999.0; % COW
	7560	 124.8	 36.4	 72.47199	 -27.1094	 1.041467	 195.0	 1	 160.0	 0.0; % NG
	7566	 2.09	 1.43	 9999.0	 -9999.0	 1.043683	 3.798585	 1	 9999.0	 -9999.0; % COW
	7569	 4.96	 3.41	 9999.0	 -9999.0	 1.02724	 9.028667	 1	 9999.0	 -9999.0; % COW
	7579	 407.0	 20.9	 192.7011	 -81.5855	 1.072818	 611.304402	 1	 440.0	 0.0; % NG
	7586	 242.0	 43.0	 185.6584	 -59.0841	 1.101632	 368.685842	 1	 400.0	 133.333333; % NG
	7590	 459.2	 58.4	 203.2176	 -91.523	 1.053316	 694.34804	 1	 480.0	 0.0; % NG
	7592	 224.1	 26.7	 136.0398	 -48.1043	 0.982818	 338.527436	 1	 300.0	 99.999999; % COW
	7593	 33.8	 2.7	 17.78071	 -7.11316	 1.074136	 50.861503	 1	 40.0	 0.0; % NG
	7598	 331.0	 -23.0	 225.3638	 -79.4871	 0.994318	 497.697197	 1	 500.0	 166.666665; % NG
	7601	 114.27	 29.09	 9999.0	 -9999.0	 1.04305	 176.871952	 1	 9999.0	 -9999.0; % COW
	7607	 0.67	 1.84	 9999.0	 -9999.0	 1.056173	 2.937282	 1	 9999.0	 -9999.0; % COW
	7610	 80.2	 5.6	 34.16326	 -15.7098	 1.060909	 120.59291	 1	 82.32	 0.0; % NG
	7613	 443.0	 134.8	 377.6349	 -112.991	 1.076711	 694.582673	 1	 800.0	 266.666666; % COW
	7625	 379.2	 21.2	 171.0144	 -74.4335	 1.095579	 569.688231	 1	 400.0	 133.333332; % NG
	7626	 0.24	 25.61	 9999.0	 -9999.0	 1.091001	 38.416687	 1	 9999.0	 -9999.0; % COW
	7627	 425.0	 2.5	 218.0701	 -88.1844	 1.099211	 637.511029	 1	 500.0	 166.666665; % COW
	7638	 50.0	 17.6	 37.60763	 -12.1862	 1.044237	 79.510754	 1	 80.0	 0.0; % NG
	7643	 0.19	 17.71	 9999.0	 -9999.0	 1.053252	 26.566529	 1	 9999.0	 -9999.0; % COW
	7644	 375.6	 116.0	 380.548	 -109.053	 1.093026	 589.657155	 1	 800.0	 266.666666; % COW
	7657	 68.32	 25.75	 9999.0	 -9999.0	 1.04043	 109.517309	 1	 9999.0	 -9999.0; % NUC
	7659	 57.2	 18.2	 37.15246	 -12.732	 1.033364	 90.038492	 1	 80.0	 0.0; % COW
	7664	 13.82	 4.26	 9999.0	 -9999.0	 1.041729	 21.69251	 1	 9999.0	 -9999.0; % COW
	7666	 517.1	 75.8	 474.4186	 -138.493	 1.092553	 783.939164	 1	 1000.0	 333.333333; % COW
	7669	 0.59	 0.86	 9999.0	 -9999.0	 1.033407	 1.564393	 1	 9999.0	 -9999.0; % COW
	7671	 194.6	 34.0	 84.6123	 -38.076	 1.027909	 296.321801	 1	 200.0	 66.666666; % NG
	7679	 164.5	 17.0	 90.21334	 -34.4517	 1.0795	 248.06413	 1	 200.0	 0.0; % NG
	7680	 648.4	 135.4	 356.6585	 -133.716	 1.065447	 993.579574	 1	 800.0	 266.666666; % COW
	7687	 79.5	 26.7	 55.64274	 -18.9316	 0.998636	 125.795727	 1	 120.0	 0.0; % NG
	7689	 0.17	 1.82	 9999.0	 -9999.0	 1.082959	 2.741883	 1	 9999.0	 -9999.0; % PEL
	7692	 78.8	 11.0	 34.15589	 -15.6732	 1.060684	 119.346093	 1	 80.0	 0.0; % NG
	7693	 6.61	 3.62	 9999.0	 -9999.0	 1.051092	 11.304518	 1	 9999.0	 -9999.0; % COW
	7696	 0.19	 1.0	 9999.0	 -9999.0	 1.063342	 1.526835	 1	 9999.0	 -9999.0; % NUC
	7699	 8.03	 3.48	 9999.0	 -9999.0	 1.085263	 13.127468	 1	 9999.0	 -9999.0; % NUC
	7703	 -184.68	 51.55	 9999.0	 -9999.0	 1.060776	 287.60952	 1	 9999.0	 -9999.0; % NG
	7704	 14.89	 4.43	 9999.0	 -9999.0	 0.998578	 23.302537	 1	 9999.0	 -9999.0; % COW
	7710	 0.59	 2.63	 9999.0	 -9999.0	 1.011318	 4.04305	 1	 9999.0	 -9999.0; % COW
	7713	 8.02	 15.14	 9999.0	 -9999.0	 1.058578	 25.699514	 1	 9999.0	 -9999.0; % NUC
	7720	 134.0	 13.0	 93.02833	 -31.4293	 1.073909	 201.94368	 1	 200.0	 0.0; % NG
	7726	 8.3	 1.1	 1.1	 1.1	 1.062682	 12.558861	 1	 8.3	 8.3; % NG
	7734	 194.8	 1.8	 83.35362	 -39.0826	 1.037318	 292.212474	 1	 200.0	 66.666666; % COW
	7735	 -2.3	 299.03	 99999.0	 -99999.0	 1.097605	 448.558268	 1	 -2.3	 -2.3; % SYNC
	7740	 25.66	 10.66	 9999.0	 -9999.0	 1.067722	 41.679254	 1	 9999.0	 -9999.0; % COW
	7755	 2486.5	 237.3	 1851.265	 -596.857	 1.102263	 3746.696607	 1	 4000.0	 1266.666665; % COW
	7765	 114.6	 12.0	 51.91257	 -22.8621	 1.050591	 172.839839	 1	 120.0	 0.0; % NG
	7766	 0.19	 0.92	 9999.0	 -9999.0	 1.081016	 1.409122	 1	 9999.0	 -9999.0; % COW
	7770	 296.8	 51.6	 181.2367	 -64.1896	 1.068079	 451.878081	 1	 400.0	 133.333332; % NG
	7773	 4.92	 3.44	 9999.0	 -9999.0	 0.99403	 9.004999	 1	 9999.0	 -9999.0; % COW
	7785	 48.4	 7.0	 37.74531	 -12.0404	 1.012091	 73.355368	 1	 80.0	 0.0; % COW
	7790	 354.8	 97.8	 278.8385	 -87.9664	 1.070867	 552.048666	 1	 600.0	 200.0; % COW
	7800	 205.2	 38.4	 106.8707	 -42.6208	 1.050133	 313.143098	 1	 240.0	 0.0; % NG
	7802	 427.0	 141.6	 273.94	 -93.6538	 1.061184	 674.799237	 1	 600.0	 200.0; % NG
	7805	 285.0	 34.0	 233.6468	 -72.5884	 1.084263	 430.531358	 1	 500.0	 166.666665; % COW
	7807	 289.7	 70.0	 224.7033	 -70.313	 1.071227	 447.055592	 1	 480.0	 133.333333; % NG
	7808	 55.8	 6.3	 46.83548	 -14.4116	 1.0848	 84.231778	 1	 100.0	 33.333333; % NG
	7818	 70.45	 35.14	 9999.0	 -9999.0	 1.048247	 118.091277	 1	 9999.0	 -9999.0; % COW
	7819	 100.8	 0.9	 52.65974	 -21.8056	 0.955	 151.206027	 1	 120.0	 0.0; % NG
	7820	 157.2	 34.4	 110.42	 -36.8838	 1.076632	 241.379784	 1	 240.0	 0.0; % NG
	7822	 20.3	 2.2	 34.47588	 -33.719	 1.087632	 30.628296	 1	 103.0303	 0.0; % NG
	7827	 298.2	 -10.8	 124.56	 -59.1927	 1.101579	 447.593264	 1	 300.0	 99.999999; % NG
	7837	 264.3	 15.9	 131.333	 -52.8395	 1.104947	 397.166747	 1	 300.0	 0.0; % NG
	7842	 24.78	 9.83	 9999.0	 -9999.0	 0.975256	 39.987797	 1	 9999.0	 -9999.0; % COW
	7847	 13.91	 5.49	 9999.0	 -9999.0	 1.061374	 22.431305	 1	 9999.0	 -9999.0; % NUC
	7856	 0.12	 1.74	 9999.0	 -9999.0	 1.041657	 2.6162	 1	 9999.0	 -9999.0; % COW
	7857	 461.0	 -40.5	 207.95	 -97.1517	 1.055789	 694.16339	 1	 500.0	 166.666665; % COW
	7864	 53.8	 12.6	 37.40093	 -12.4562	 1.050455	 82.883653	 1	 80.0	 0.0; % NG
	7869	 47.0	 12.8	 38.01728	 -11.8298	 1.078409	 73.067708	 1	 80.0	 0.0; % PEL
	7870	 75.4	 13.6	 34.92256	 -14.9646	 1.026955	 114.925063	 1	 80.0	 0.0; % NG
	7874	 106.52	 23.19	 54.32125	 -20.3883	 1.073818	 163.522612	 1	 132.02	 12.02; % NG
	7876	 61.97	 26.49	 9999.0	 -9999.0	 1.033702	 101.091554	 1	 9999.0	 -9999.0; % COW
	7878	 0.15	 152.82	 9999.0	 -9999.0	 1.041474	 229.23011	 1	 9999.0	 -9999.0; % NUC
	7882	 10.16	 5.44	 9999.0	 -9999.0	 1.033472	 17.287082	 1	 9999.0	 -9999.0; % COW
	7884	 62.2	 4.8	 36.39263	 -13.4382	 1.100605	 93.577401	 1	 80.0	 0.0; % COW
	7892	 142.8	 60.6	 173.2019	 -47.6709	 1.049227	 232.6896	 1	 360.0	 0.0; % NG
	7902	 0.96	 16.26	 9999.0	 -9999.0	 0.99443	 24.432472	 1	 9999.0	 -9999.0; % COW
	7910	 1232.6	 301.6	 932.6775	 -293.145	 1.086	 1903.443451	 1	 2000.0	 666.666666; % COW
	7918	 33.0	 3.3	 34.95247	 -30.7993	 1.0615	 49.746884	 1	 100.36365	 0.0; % NG
	7925	 417.8	 371.0	 379.6843	 -111.007	 1.065867	 838.120003	 1	 800.0	 266.666666; % NG
	7941	 23.09	 46.44	 9999.0	 -9999.0	 1.069492	 77.795237	 1	 9999.0	 -9999.0; % COW
	7946	 738.2	 98.6	 346.4941	 -144.145	 1.089318	 1117.133698	 1	 800.0	 266.666666; % COW
	7949	 0.26	 2.35	 9999.0	 -9999.0	 0.952927	 3.546509	 1	 9999.0	 -9999.0; % COW
	7950	 386.0	 42.0	 168.924	 -76.2989	 1.074316	 582.417376	 1	 400.0	 133.333332; % COW
	7952	 330.4	 59.4	 178.0439	 -67.2532	 1.000364	 503.545599	 1	 400.0	 133.333333; % NG
	7957	 21.7	 2.6	 19.07478	 -5.80385	 1.025733	 32.782808	 1	 40.0	 0.0; % PEL
	7974	 4.4	 2.45	 9999.0	 -9999.0	 1.069628	 7.554179	 1	 9999.0	 -9999.0; % COW
	7979	 166.2	 23.4	 111.7	 -37.8503	 1.094409	 251.758813	 1	 240.0	 0.0; % COW
	7986	 -31.21	 13.87	 9999.0	 -9999.0	 1.042342	 51.229798	 1	 9999.0	 -9999.0; % COW
	7990	 69.0	 11.0	 35.84041	 -14.0654	 1.078864	 104.806965	 1	 80.0	 0.0; % PEL
	7991	 23.3	 9.39	 9999.0	 -9999.0	 1.074093	 37.681424	 1	 9999.0	 -9999.0; % COW
	7998	 0.49	 -0.1	 9999.0	 -9999.0	 0.935847	 0.75015	 1	 9999.0	 -9999.0; % COW
	8000	 82.0	 15.6	 76.87015	 -22.7457	 1.080636	 125.20607	 1	 160.0	 0.0; % NG
	8001	 9.78	 2.41	 9999.0	 -9999.0	 1.05607	 15.108843	 1	 9999.0	 -9999.0; % COW
	8002	 118.8	 21.2	 92.95259	 -29.5106	 1.045818	 181.015137	 1	 200.0	 66.666666; % COW
	8004	 229.98	 97.55	 192.7245	 -52.4967	 1.080474	 374.720304	 1	 467.78	 201.113333; % COW
	8032	 76.9	 6.1	 44.89052	 -16.4296	 1.094263	 115.712337	 1	 100.0	 0.0; % NG
	8037	 0.57	 1.0	 9999.0	 -9999.0	 1.044737	 1.726565	 1	 9999.0	 -9999.0; % COW
	8039	 250.2	 19.2	 163.9089	 -56.9781	 1.068682	 376.403414	 1	 360.0	 0.0; % NG
	8050	 334.4	 81.8	 384.3012	 -105.833	 1.095868	 516.389243	 1	 800.0	 266.666666; % COW
	8052	 192.8	 16.0	 106.621	 -40.7537	 1.059636	 290.194142	 1	 240.0	 0.0; % NG
	8053	 1232.6	 306.8	 932.6775	 -293.145	 1.085789	 1905.312376	 1	 2000.0	 666.666666; % COW
	8056	 443.8	 124.4	 272.7733	 -95.0191	 1.095	 691.35812	 1	 600.0	 200.0; % COW
	8063	 0.16	 1.44	 9999.0	 -9999.0	 1.069696	 2.173292	 1	 9999.0	 -9999.0; % PEL
	8070	 8.15	 5.23	 9999.0	 -9999.0	 1.081905	 14.525655	 1	 9999.0	 -9999.0; % COW
	8075	 299.8	 42.7	 179.7341	 -65.0445	 1.093	 454.238365	 1	 400.0	 133.333333; % COW
	8076	 0.2	 1.0	 9999.0	 -9999.0	 1.064532	 1.529706	 1	 9999.0	 -9999.0; % COW
	8077	 75.0	 26.1	 56.50421	 -18.2121	 1.060545	 119.117474	 1	 120.0	 0.0; % NG
	8083	 17.0	 2.3	 28.99114	 -28.4124	 1.071053	 25.732324	 1	 86.7347	 0.0; % NG
	8092	 50.4	 10.2	 37.19023	 -12.4552	 0.956818	 77.132678	 1	 80.0	 0.0; % PEL
	8097	 6.01	 2.92	 9999.0	 -9999.0	 1.053731	 10.022705	 1	 9999.0	 -9999.0; % NG
	8098	 38.8	 4.5	 17.26669	 -7.66826	 1.014909	 58.590123	 1	 40.0	 0.0; % NG
	8102	 21.72	 8.34	 9999.0	 -9999.0	 1.074792	 34.899234	 1	 9999.0	 -9999.0; % COW
	8105	 37.2	 6.0	 38.63549	 -11.1152	 1.0132	 56.521146	 1	 80.0	 0.0; % NG
	8108	 0.56	 0.0	 9999.0	 -9999.0	 1.08598	 0.84	 1	 9999.0	 -9999.0; % NG
	8111	 10.07	 3.91	 9999.0	 -9999.0	 0.98531	 16.20368	 1	 9999.0	 -9999.0; % PEL
	8114	 2.35	 2.06	 9999.0	 -9999.0	 1.000447	 4.687614	 1	 9999.0	 -9999.0; % COW
	8120	 88.4	 -4.6	 42.89557	 -18.294	 1.096545	 132.779404	 1	 100.0	 0.0; % NG
	8121	 758.4	 88.8	 339.054	 -151.205	 1.087868	 1145.371555	 1	 800.0	 266.666664; % COW
	8125	 44.4	 17.2	 38.23025	 -11.6107	 1.051227	 71.422685	 1	 80.0	 0.0; % NG
	8131	 498.4	 114.6	 266.1681	 -101.497	 1.099658	 767.108447	 1	 600.0	 200.0; % COW
	8136	 38.9	 5.1	 53.52049	 -50.3809	 1.081545	 58.849342	 1	 157.57576	 0.0; % NG
	8139	 0.59	 2.43	 9999.0	 -9999.0	 1.071689	 3.7509	 1	 9999.0	 -9999.0; % NUC
	8141	 203.1	 9.9	 136.9636	 -46.7499	 1.104632	 305.011713	 1	 300.0	 0.0; % COW
	8146	 203.0	 69.2	 189.1979	 -55.6225	 1.050409	 321.705906	 1	 400.0	 133.333333; % COW
	8147	 25.3	 5.2	 18.69955	 -6.16757	 0.982545	 38.74329	 1	 40.0	 0.0; % NG
	8148	 1899.0	 90.0	 858.9986	 -367.117	 1.096921	 2851.697258	 1	 2000.0	 666.666666; % COW
	8151	 110.0	 42.0	 95.64927	 -28.9496	 1.061364	 176.618232	 1	 200.0	 0.0; % NG
	8153	 627.8	 78.0	 359.9627	 -130.661	 1.059364	 948.940404	 1	 800.0	 266.666666; % COW
	8156	 19.3	 3.3	 32.65772	 -32.1828	 1.044682	 29.370138	 1	 97.9798	 0.0; % NG
	8162	 23.0	 1.2	 31.68029	 -29.9156	 1.094211	 34.546925	 1	 93.72588	 0.0; % NG
	8165	 8.49	 17.09	 9999.0	 -9999.0	 1.054081	 28.624001	 1	 9999.0	 -9999.0; % NUC
	8167	 33.2	 8.6	 38.98063	 -10.818	 1.077091	 51.443659	 1	 80.0	 0.0; % NG
	8169	 78.2	 13.2	 107.5901	 -101.48	 1.071605	 118.959363	 1	 317.09088	 0.0; % NG
	8172	 341.2	 43.6	 175.2955	 -69.9556	 1.066579	 515.961626	 1	 400.0	 133.333332; % NG
	8173	 418.0	 40.0	 220.4901	 -86.144	 1.052227	 629.864271	 1	 500.0	 166.666665; % COW
	8174	 1.58	 0.66	 9999.0	 -9999.0	 1.069094	 2.568463	 1	 9999.0	 -9999.0; % COW
	8185	 31.2	 9.8	 28.36122	 -8.46913	 1.057409	 49.054358	 1	 60.0	 0.0; % PEL
	8187	 4.89	 2.33	 9999.0	 -9999.0	 0.993061	 8.1251	 1	 9999.0	 -9999.0; % NUC
	8193	 2.22	 1.67	 9999.0	 -9999.0	 1.06336	 4.167004	 1	 9999.0	 -9999.0; % COW
	8198	 458.0	 130.8	 376.2517	 -114.309	 1.085211	 714.467242	 1	 800.0	 266.666666; % COW
	8204	 59.6	 5.0	 36.3536	 -13.361	 1.011273	 89.714046	 1	 80.0	 0.0; % NG
	8205	 19.83	 13.51	 9999.0	 -9999.0	 1.024332	 35.992155	 1	 9999.0	 -9999.0; % COW
	8206	 22.37	 8.9	 9999.0	 -9999.0	 1.122614	 36.113163	 1	 9999.0	 -9999.0; % COW
	8208	 5.2	 0.8	 0.8	 0.8	 1.050818	 7.891768	 1	 5.2	 5.2; % NG
	8209	 72.99	 26.65	 9999.0	 -9999.0	 1.04259	 116.554562	 1	 9999.0	 -9999.0; % NUC
	8212	 34.1	 3.3	 17.82291	 -7.08859	 1.064364	 51.388958	 1	 40.0	 0.0; % NG
	8215	 340.4	 24.8	 176.1399	 -69.3011	 1.095079	 511.953318	 1	 400.0	 0.0; % NG
	8216	 238.0	 20.6	 186.9582	 -58.1393	 1.005474	 358.334774	 1	 400.0	 133.333333; % NG
	8217	 144.0	 15.5	 92.44556	 -32.1609	 1.082909	 217.247698	 1	 200.0	 0.0; % COW
	8222	 334.3	 59.6	 177.8749	 -67.5089	 1.082184	 509.356911	 1	 400.0	 133.333333; % NG
	8223	 10.9	 1.1	 11.60485	 -10.232	 1.033909	 16.433046	 1	 33.33672	 0.0; % NG
	8224	 9.87	 5.63	 9999.0	 -9999.0	 1.013411	 17.044238	 1	 9999.0	 -9999.0; % COW
	8226	 46.7	 5.5	 47.34312	 -13.7808	 0.952933	 70.534141	 1	 100.0	 33.333333; % COW
	8228	 73.6	 11.8	 34.79433	 -15.0072	 1.040684	 111.809883	 1	 80.0	 0.0; % PEL
	8230	 41.57	 23.4	 9999.0	 -9999.0	 1.077674	 71.555266	 1	 9999.0	 -9999.0; % NUC
	8233	 2.37	 1.59	 9999.0	 -9999.0	 1.04416	 4.280917	 1	 9999.0	 -9999.0; % COW
	8234	 369.6	 70.4	 198.075	 -76.3385	 1.093636	 564.36754	 1	 440.0	 146.666663; % COW
	8256	 40.1	 2.0	 17.03131	 -7.89505	 1.055409	 60.224767	 1	 41.16	 0.0; % NG
	8258	 84.5	 4.9	 44.00077	 -17.3317	 1.098421	 126.962928	 1	 100.0	 0.0; % NG
	8259	 839.6	 150.1	 442.9899	 -169.918	 1.052447	 1279.367376	 1	 1000.0	 333.333333; % NUC
	8261	 99.4	 -12.7	 40.58133	 -20.483	 1.100091	 150.31205	 1	 100.0	 33.333333; % NG
	8264	 25.2	 4.7	 18.64871	 -14.1561	 1.058727	 38.451821	 1	 50.69346	 0.0; % NG
	8266	 376.5	 42.8	 172.5303	 -72.8475	 1.095105	 568.38737	 1	 400.0	 133.333333; % COW
	8269	 123.4	 1.0	 49.65318	 -24.0691	 1.060455	 185.106078	 1	 125.78	 0.0; % NG
	8273	 0.22	 3.34	 9999.0	 -9999.0	 1.068143	 5.020857	 1	 9999.0	 -9999.0; % COW
	8279	 39.7	 7.0	 17.27831	 -7.68619	 1.041182	 60.468608	 1	 40.0	 0.0; % NG
	8283	 10.29	 8.53	 9999.0	 -9999.0	 1.050377	 20.048722	 1	 9999.0	 -9999.0; % COW
	8285	 663.0	 17.6	 355.138	 -135.291	 1.089921	 994.850346	 1	 800.0	 266.666666; % COW
	8290	 296.1	 133.0	 335.959	 -93.2291	 1.041591	 486.897805	 1	 700.0	 233.333331; % COW
	8292	 121.2	 24.8	 73.18618	 -26.4808	 1.052273	 185.566915	 1	 160.0	 0.0; % NG
	8302	 860.8	 118.3	 439.3782	 -173.285	 1.079368	 1303.336466	 1	 1000.0	 333.333333; % COW
	8309	 5.41	 1.08	 9999.0	 -9999.0	 1.087296	 8.275121	 1	 9999.0	 -9999.0; % COW
	8312	 368.0	 61.0	 175.9554	 -73.5101	 1.062091	 559.532171	 1	 400.0	 0.0; % NG
	8318	 119.1	 20.4	 82.75521	 -27.7465	 1.093316	 181.25171	 1	 180.0	 0.0; % NG
	8319	 299.2	 47.0	 126.7997	 -57.0953	 1.054273	 454.303522	 1	 301.01	 100.336667; % NG
	8320	 -59.54	 18.83	 9999.0	 -9999.0	 1.081298	 93.669932	 1	 9999.0	 -9999.0; % COW
	8325	 158.4	 96.3	 175.0039	 -49.1586	 1.048053	 278.063954	 1	 360.0	 0.0; % NG
	8330	 0.68	 2.44	 9999.0	 -9999.0	 1.002513	 3.799474	 1	 9999.0	 -9999.0; % COW
	8331	 72.0	 22.4	 77.68714	 -21.9685	 1.094545	 113.105968	 1	 160.0	 0.0; % NG
	8332	 5.58	 1.65	 9999.0	 -9999.0	 1.05987	 8.72826	 1	 9999.0	 -9999.0; % NG
	8337	 47.1	 6.3	 26.85162	 -10.0095	 1.054455	 71.279205	 1	 60.0	 0.0; % NG
	8344	 65.8	 21.4	 36.14994	 -13.7259	 1.026364	 103.788728	 1	 80.0	 0.0; % NG
	8345	 1.11	 1.56	 9999.0	 -9999.0	 1.019769	 2.871903	 1	 9999.0	 -9999.0; % COW
	8346	 46.4	 6.8	 34.6463	 -26.4201	 1.050545	 70.343443	 1	 95.0204	 0.0; % NG
	8349	 292.5	 64.8	 126.9042	 -57.1442	 1.036136	 449.387809	 1	 300.0	 0.0; % COW
	8357	 4.78	 1.72	 9999.0	 -9999.0	 0.988967	 7.620059	 1	 9999.0	 -9999.0; % COW
	8363	 28.3	 1.0	 18.19123	 -6.61422	 0.926182	 42.476493	 1	 40.0	 0.0; % COW
	8369	 5.15	 2.04	 9999.0	 -9999.0	 1.084862	 8.308985	 1	 9999.0	 -9999.0; % COW
	8376	 289.1	 44.3	 127.957	 -55.878	 1.006409	 438.711665	 1	 300.0	 100.0; % NG
	8377	 13.62	 5.62	 9999.0	 -9999.0	 1.076407	 22.1009	 1	 9999.0	 -9999.0; % COW
	8380	 123.89	 52.61	 9999.0	 -9999.0	 1.057568	 201.896569	 1	 9999.0	 -9999.0; % COW
	8381	 359.0	 89.0	 176.3275	 -72.9451	 1.083789	 554.801316	 1	 400.0	 0.0; % NG
	8384	 829.8	 157.8	 552.0842	 -183.993	 1.104105	 1267.006306	 1	 1200.0	 399.999999; % COW
	8385	 419.0	 124.2	 274.1952	 -93.2181	 1.086053	 655.530274	 1	 600.0	 200.0; % NG
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.000000	  18.130646	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.899131	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.714975	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.564137	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.311448	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.442461	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.497507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.747879	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  42.608525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.425028	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.169166	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.096008	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.502744	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  27.300737	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.332069	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.315452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.089004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.964515	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.504296	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.752850	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  26.258554	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.404643	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.164513	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.909421	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.619126	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.907284	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.308174	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.218636	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.831525	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.866181	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.289072	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.294626	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.114366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.188996	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.997956	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  20.199133	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.960916	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.879456	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.075190	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.774221	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.822136	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.496713	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.459789	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.778074	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.497525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.821946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.652106	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.781025	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.355020	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.329335	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.857966	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.432193	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.372311	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  55.929965	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.193859	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.048246	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.244934	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 107.279795	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   7.333091	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  10.543214	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.069247	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   7.613053	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  28.945646	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.103443	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.752858	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.436780	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.591305	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.648792	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.252807	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.916947	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.428880	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.662181	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.283271	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.362241	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.181341	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 100.673745	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.732707	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.314392	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.603616	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.709033	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.818857	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.491283	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.704611	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.404721	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.091379	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.181733	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.314382	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.576426	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.465543	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.788936	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.584229	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.322202	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.263223	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.568688	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.525744	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.000590	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.127710	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.996032	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.238071	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.224556	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.042403	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.226613	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.446039	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.086407	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.419020	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.446315	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.689615	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.917116	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.657884	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.173151	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.108451	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.530806	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.532813	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.816016	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  98.850429	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.127373	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.726959	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.224455	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.622934	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.653828	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.539002	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  38.612077	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.344935	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.583814	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.445641	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.110435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.480638	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  45.310011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.516269	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.303315	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.417375	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.051325	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.768645	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.600583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.708150	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.165534	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.483065	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.409557	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.911011	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  22.856992	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 117.207234	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  11.716451	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.514516	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.515337	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.270179	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.508910	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   2.881460	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.436772	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.792470	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.635119	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.422240	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.021825	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.272833	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.882109	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.783414	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.079474	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.861316	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.575138	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.269500	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.529946	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.812025	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.632180	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.051403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.679125	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.014491	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.026515	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.439785	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.748961	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.097731	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.789745	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.819745	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.582986	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.921308	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.304414	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.072454	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  45.713051	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.558019	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 115.436487	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.990617	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.137478	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.499529	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.499699	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.345038	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  41.194918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.999022	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.952791	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.033657	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.364788	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.403688	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.847029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.289916	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.765848	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   4.825237	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.837778	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.283237	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.489572	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.187205	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.403189	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.489589	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.163436	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.312195	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.423347	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.115711	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.734390	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.213095	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.574364	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.683382	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.959305	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.407482	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.390496	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.888617	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.274658	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.467205	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.609418	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.223277	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.534397	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.863372	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.024994	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.826404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.129560	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.313377	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.641453	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  34.360531	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.532690	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.134542	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.755274	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.687176	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.190588	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.219281	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.803729	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.795212	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.177233	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.219263	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.883116	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.528826	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  22.297233	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.203746	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.864222	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.798529	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.817449	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.236566	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.063106	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.652088	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  28.744768	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.878130	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.178095	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.071098	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.512099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.243167	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.170358	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.910098	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.459995	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 113.442501	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.063894	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.036875	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.978089	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.844250	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.106393	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  97.677622	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.320529	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.150106	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.185362	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.501805	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.160384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.904377	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.498196	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.958310	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.173199	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.884818	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.826466	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.859666	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.758936	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.313399	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.753560	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.975616	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.414728	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.973407	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.872306	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.838264	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.146951	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.102475	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.444353	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.767864	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.082129	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  29.309986	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.194267	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.803736	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.081092	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 101.610338	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.349813	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.177533	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.421705	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 110.240764	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.858198	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.824442	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  19.839816	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.167531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.370587	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.941861	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.526562	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.622399	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.114941	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.878169	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.241968	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.261042	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.263937	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.810764	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.620382	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 107.526929	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.913019	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.440048	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   7.147531	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  42.231159	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.220565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.672905	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.854982	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.951822	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.492634	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.716841	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.532297	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.288480	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.559848	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.148750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.308476	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.933622	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.735184	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.423081	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 109.830875	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.467966	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.244845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.277504	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  22.803947	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.440635	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.132211	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.024745	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  32.493732	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.104083	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  40.027489	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.736181	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.989075	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.841428	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.781491	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.497571	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.162464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.640079	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.576876	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 115.965884	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.317728	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.925437	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.844531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.219542	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.246234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.428125	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.228984	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.201865	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.896840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.099775	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.769974	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.231080	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.002587	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.049665	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.419863	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.566414	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 107.918480	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.277628	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.758676	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.407892	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  19.152947	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.265084	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.897720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.560107	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.753571	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.536463	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.763273	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.943575	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.373515	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.402247	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 102.562999	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.430090	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   2.832849	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 105.269667	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.115074	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.158009	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.045075	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.532249	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.333433	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.428953	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.588484	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.642396	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.522900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.109684	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.742579	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.637204	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.068099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   4.248836	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.856031	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.284999	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.221824	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  34.048633	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.258387	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 107.539691	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.673206	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.622121	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.997419	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.990713	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.676561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.350918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.316730	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  29.271045	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.473747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.670553	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.610114	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.706507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.885748	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.184801	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.269642	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.371325	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.983832	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.881458	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.518267	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.263591	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.427370	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.951093	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.060015	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.154442	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.488207	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.099637	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.080754	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.299391	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   6.861542	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   6.875282	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  24.074830	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.865534	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.061628	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.005610	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.741911	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.257756	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  28.957240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.509264	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.661498	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.503509	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.145526	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.958968	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.549094	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.539130	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.952303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.412505	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.932471	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.001940	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.694840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.924491	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.990044	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.083827	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   1.214755	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.134442	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.527745	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.608450	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.020736	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.941040	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.837638	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.794123	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.582477	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.887033	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.319139	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.729740	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.413422	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.037350	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.262725	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   7.235665	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   7.819287	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  37.643193	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.177742	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.125103	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.728079	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.278181	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.950215	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.255259	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.447615	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.873099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.953932	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.909097	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.910938	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  41.365026	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.021550	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.145358	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.009576	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.450889	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.727109	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.590911	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.149668	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  40.935477	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 113.292178	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.049148	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.856434	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.087352	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.340658	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.794621	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.524070	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  29.482439	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.476605	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.657783	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.712655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.413040	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.815637	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   7.870715	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  21.965393	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.189607	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.339125	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.401759	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.307609	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.892695	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.953208	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.829326	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.403551	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.096618	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.360930	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.511950	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  98.519911	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.432955	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.265704	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.887259	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.689404	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.051424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.971307	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.305771	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.577555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.791980	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.783694	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   6.022062	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.694329	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.245442	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.425275	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.955473	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.903741	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.850916	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.476607	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.171921	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.007786	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.086719	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.125918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.297459	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.511575	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  26.179302	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.001930	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.860583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.236200	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.764890	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.350685	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.089863	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.897212	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.183326	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.395210	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.432539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.389061	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.868274	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.611622	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.695054	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.835389	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.308373	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.131587	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  25.023203	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.549072	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.235074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.377988	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.002515	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.930647	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.226377	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.767394	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.487330	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.165645	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.890422	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.704545	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.062009	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.049983	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.370120	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.312233	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  29.250226	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.936890	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.214676	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.736574	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  95.948668	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.864463	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.888471	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.205162	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.112278	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.076922	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.663965	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.823446	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.881018	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.931318	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.085666	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.811301	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.088044	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.379871	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.269359	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.095343	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.365074	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.537719	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.118795	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.478139	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.190560	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.180374	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.341144	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.691409	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.761223	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.826574	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.733262	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.406608	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.332106	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.321232	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.062572	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.422535	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  21.496440	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.554339	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.158375	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.228261	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.264748	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.210378	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.210282	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.651667	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.896330	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 116.074793	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.871141	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.577597	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.023465	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.027304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.837368	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.724056	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.896242	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.994470	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.058813	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  27.775327	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.288044	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.664003	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.416850	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.436044	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.978614	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.857861	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.579795	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.808325	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.483584	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.668351	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.861450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.803520	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.266254	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.803152	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.378206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.195606	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.213020	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.662775	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.348638	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.326483	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.460694	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.534844	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.793764	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.928541	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.291236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.019794	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.741367	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.348787	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.263032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.271157	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.339527	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.323112	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.679196	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  93.847694	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.416759	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.971848	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.868721	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.478315	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.776349	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.891103	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.041025	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.217178	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 103.077154	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.380545	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.600092	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.330589	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.464901	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.047302	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.765651	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.471777	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.926067	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.972868	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  94.849392	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   8.056413	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.382445	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.616498	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.686735	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.965417	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.173308	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.147072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.222071	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.244223	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.478918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.835993	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.639855	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.149476	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.441767	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.542305	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.884136	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 130.905926	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.476249	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.914874	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.669751	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.913104	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.022656	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.669860	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.859759	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.988948	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.196644	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.502769	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.606296	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.250134	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.096964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.952461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.926216	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.584224	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.315887	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.196420	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.917400	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.664819	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 122.483481	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.974304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.778411	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.446371	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.660900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.028570	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.243124	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.994368	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.254681	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.654503	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.160609	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.015588	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.779134	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.215909	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.906146	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.989448	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.004881	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.345048	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  25.420408	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.818795	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.071821	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.578420	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.176930	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.541832	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.032035	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.367455	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  47.818494	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.022266	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.713998	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  29.700206	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.009622	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.030947	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.669784	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.534940	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.338049	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.843994	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.811023	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.832937	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.759241	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.023058	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.282079	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.499053	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.442952	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.241527	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.675939	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  98.823509	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.201194	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.338774	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.426692	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  21.736322	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.347897	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 104.329657	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.103500	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.429276	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.960340	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.715635	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.306063	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.341754	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.660347	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  36.441946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.747313	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.067381	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.573743	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.645817	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.584279	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.882923	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.773497	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.469807	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.225287	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  22.997187	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.830828	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  24.887142	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.440838	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.991572	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.913916	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.568925	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.075937	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.424523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.229971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.143251	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.875713	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.976736	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.559227	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.774952	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.232111	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.683051	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.926085	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.809002	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.285631	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.198266	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.074072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.840293	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.355708	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.422530	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.913394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.157665	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.022896	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.899023	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  20.407129	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.971557	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.102912	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.150906	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.493036	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.039500	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.087539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.620606	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.221583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.182018	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.140118	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.492300	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.969667	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.115276	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.655533	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.412159	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.580806	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.176018	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.083591	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.125431	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.805501	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.965503	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.146861	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.978696	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.118279	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.772857	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.637399	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.405862	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.534820	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.124138	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.579071	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.071963	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.490087	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.536044	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.821980	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  32.398202	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.694552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.535408	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.663810	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.751377	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.286249	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.131769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.965530	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.466533	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.436639	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.632603	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.453582	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.334048	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.163169	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.205309	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.684715	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  24.703147	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.110315	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.844892	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 109.217087	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  10.759942	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.769656	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.812380	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.991697	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.886196	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.357977	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.638140	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.538412	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.090642	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.201631	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.160210	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.718406	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  30.195428	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.923804	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.218201	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.073816	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.037624	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.988017	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.977410	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.401480	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.653653	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.636455	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 105.545679	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.839742	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.596417	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.163572	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.925718	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.299627	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.158501	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.406707	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.752672	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.705634	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.346691	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.338940	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.687070	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.753605	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.034497	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.567516	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.560242	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.931399	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.600229	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.459155	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.907102	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.598834	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.424888	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.225814	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.189680	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.241374	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 110.819104	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.924603	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.753782	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.421989	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.636044	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.461485	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.537150	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.127129	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.151201	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.595984	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.229344	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.179386	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.101685	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  56.068773	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.697721	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.297693	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.065476	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.172212	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.021439	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.460928	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.519990	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.015208	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.354133	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.290745	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.497530	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.694561	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.024464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.433083	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.018418	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.363515	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.472400	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.771025	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.952295	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.735089	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.198818	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.816812	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.221812	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.234000	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.025479	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.131513	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.023061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.995088	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.017399	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  32.620886	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.817806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.810889	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.079064	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.079906	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.121773	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.446634	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.439763	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.095925	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.122990	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.291322	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  26.013801	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.201904	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.921939	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.523374	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.824739	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.857104	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.110754	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.842395	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.658386	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.830430	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.096371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.979029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.836516	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.866618	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.423330	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.622856	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.633236	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.621877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.170809	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.366397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.069917	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.711304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.537924	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.347641	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.873438	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   8.162338	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  51.974376	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.580506	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.739355	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.650414	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.872465	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.705934	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.733531	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.701663	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.381744	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.740335	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.709427	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.737712	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   1.783149	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.227172	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.232718	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.554063	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.874802	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.852415	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.709287	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.722675	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.225740	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.971882	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.885102	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  23.675578	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.080577	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.165354	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.298061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.477238	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.096212	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.617101	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 100.439556	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.327312	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.860209	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.818370	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.568311	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.415781	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.850218	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.198247	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.141860	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.408897	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.200099	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.236832	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  25.443122	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 101.430939	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.702590	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.709764	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.381114	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.528512	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  19.371982	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.674616	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.839453	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	 120.674920	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.653306	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.654624	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.969896	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.131873	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.269357	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.072279	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.869599	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.015573	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  18.975344	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.629894	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.516479	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  96.818334	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.815762	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.271022	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.458929	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.198878	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.846335	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.885647	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.390556	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.159818	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.916374	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.918905	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.432036	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.755068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.336150	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.024568	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.363260	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.716407	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  23.690824	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.745837	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.099928	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.868236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.745519	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.714520	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.295667	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.544092	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.111504	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.627587	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.219022	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.450277	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.442076	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.765173	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.775484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.376961	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.952324	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.663286	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.141122	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.692005	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.872376	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.599910	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.670130	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 109.590010	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.786453	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.219922	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.676537	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.970879	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.056498	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.367406	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.259626	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.987023	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.951749	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  55.357259	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.916124	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  20.898506	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.390122	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  38.712002	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.798159	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.520324	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  56.843956	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.204447	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.700404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.176493	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  32.564947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.235995	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  23.366406	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.257934	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.064543	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.752608	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  37.204827	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.968730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.960616	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.575288	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.493722	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.436956	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.261992	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  63.914533	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.699596	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.347732	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.724384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.613417	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.856038	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.677970	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.715873	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.213063	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.709802	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.205631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.607374	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.464183	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.527386	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.312072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.411135	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.077385	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  25.919974	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.972494	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.191712	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.319393	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.117198	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.214755	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.453519	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  46.282766	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.886877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.541820	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.384218	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.174969	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.590709	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.362970	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.731137	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.233571	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.039212	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.373223	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.820661	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.727816	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.514135	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  34.044417	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.044586	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.373546	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.645738	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  29.233075	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 107.522069	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.361604	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.708934	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.789382	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.654853	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.763009	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.413797	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.393080	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.404923	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.444538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.245619	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.128915	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.909562	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.853185	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.391359	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.577725	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.138770	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.157781	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.144892	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.094332	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.917996	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.811198	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.774540	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.909325	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.557054	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  32.518239	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.075618	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.031301	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.882140	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.547147	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.112381	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.216523	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.769707	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.380988	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.963129	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.900365	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.895103	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.678489	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.680633	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.514807	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.035143	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.835746	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.764853	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.358999	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.176594	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.261577	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.319999	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.705439	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.435185	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.935495	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.483111	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.030752	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.493062	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  18.548412	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.810136	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.785731	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.823586	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.250145	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.974319	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.621113	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  27.895698	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.515721	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.231174	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.410630	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.056124	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.496907	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  14.633014	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.088270	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 113.631071	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.705599	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  13.013928	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.758386	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.359488	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.373502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.675515	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.152157	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.955079	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.323317	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.547676	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.184761	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.090997	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.122137	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.189082	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.108815	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.357326	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.051788	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.983518	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  54.011646	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.661051	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.937331	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.806432	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.979423	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   5.895393	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  19.810463	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.571461	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  33.254597	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.755706	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   6.811806	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  54.249724	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.580866	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.462374	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.443259	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  89.077112	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.045563	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.082105	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.408819	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.722556	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.288182	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.423480	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  32.398882	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.817530	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.264629	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 113.996478	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.165657	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.985837	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  31.399848	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.516951	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.937957	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.472942	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.460860	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.394340	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.121565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.158550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.199679	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.523850	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.002550	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.834021	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.828251	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.725699	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.222980	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.404547	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.274696	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.005833	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.883224	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   2.354157	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.685357	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.544133	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.248727	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.266339	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.200729	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  37.869730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.641317	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.332289	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 105.509103	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.212862	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.361113	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.891029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.645826	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.057158	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.652742	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.938321	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.309656	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  38.302592	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.872977	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.485352	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  22.145641	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.735224	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.361175	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.179537	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.783722	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.949349	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.007895	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.646756	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  31.854731	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.474678	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.654900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.679856	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.673979	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.028468	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  17.931335	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.252402	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.890799	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.675832	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   8.452350	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  22.394916	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.184560	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  50.415278	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.795010	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.992811	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.201349	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.420454	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.846802	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.225256	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.195496	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.532741	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.367021	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.007255	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.764580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.103728	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.972005	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.188155	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.461974	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.602141	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.210886	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.004362	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.483400	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.877363	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.998876	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.176157	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.431905	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.162199	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.885535	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.073746	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.974192	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.202727	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 103.947551	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.000075	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.276275	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.025724	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.757458	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.733937	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.224864	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  29.444835	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.921311	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.530651	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.702437	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.166019	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.693254	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.324355	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.986903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.584710	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.551171	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.549761	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.494158	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.929847	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.986779	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  41.722825	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.772371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.668637	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.362853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.586927	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.311220	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.249612	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.659856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.031877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.227530	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.558619	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.172112	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.722337	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  39.675737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.247947	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.962685	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.596144	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.501924	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.794038	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.446617	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.656181	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.996266	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.529708	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.170381	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.716513	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   2.836241	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.230760	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.664821	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.870531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.827849	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.318996	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.479863	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.330522	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.298406	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.546035	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.592129	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	 106.462935	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.052054	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  98.558203	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   6.534084	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  10.969705	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.846699	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.430246	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.700956	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.881798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.803856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.148031	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  60.442236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.404631	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.518222	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.791016	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.736853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.744264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.549660	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.729036	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.874849	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.474986	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.509100	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.400768	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  22.890471	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 115.200071	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.362632	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.544066	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.311504	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.498786	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.824518	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.244748	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.529171	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.401353	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  40.846314	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.364484	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.027473	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.684563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.776343	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.890976	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.068453	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.280738	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.425504	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.802082	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.907754	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.044782	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.856146	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.970781	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  35.720499	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.876336	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.805843	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.758096	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.221163	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.693394	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.337276	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   5.096663	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  27.051287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.612915	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.729509	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.613296	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.317405	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.339226	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.751880	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.959901	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.847855	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.866933	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.420801	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.409992	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.711296	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.966968	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.330776	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.524297	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.781616	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.124938	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.290003	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.907945	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.535982	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.728515	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.149520	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.164581	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.358251	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.350334	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  40.267290	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.369236	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  35.868628	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.194311	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.991101	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.019287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.536701	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.077701	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.411235	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.806450	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.938129	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.152381	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.421521	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.508691	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.867554	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.604152	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.276111	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  18.848113	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.291441	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.733717	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.681099	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.632970	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  55.941932	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.926182	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.921802	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.330181	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.550142	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.291981	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.066466	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.267571	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.381643	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.177081	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.727664	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.598968	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	 114.043041	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.773398	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.190050	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.865939	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.344623	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.174749	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.033627	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.951736	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.359974	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.369525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.855989	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.280784	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.396143	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  13.614803	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.124259	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.436431	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.342119	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.788032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.271543	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.626263	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.402796	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.074834	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.786179	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.814619	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.453013	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.513344	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.368308	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.009820	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.856272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.519297	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.369580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.998781	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  30.042517	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.895002	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.730169	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.861791	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.256965	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.701859	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.893569	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.278940	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.673184	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.696779	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.523698	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.459918	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.171123	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.494570	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.452509	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.148978	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.810180	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.979989	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.211189	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.024723	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.548122	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.761788	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.306642	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.503548	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.177318	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.750018	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.914110	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.653271	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.215008	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.859187	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  92.669665	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  11.517440	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  57.357725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.860646	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.072850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.327080	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.324889	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.481273	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.883106	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.217559	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.460956	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.722257	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.978309	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.602865	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.652990	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.669333	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.123042	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.389808	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.667900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.692939	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.927402	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.214681	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.990179	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.764369	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.256663	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.974196	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.472074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.199133	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.176286	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.088151	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  53.004844	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.790361	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.680963	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.313808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.281941	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.523836	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.998403	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.563253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.838527	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.511853	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.292697	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.417274	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.186365	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 113.273054	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.042138	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.466992	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.971495	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  36.751272	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.994377	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.121298	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.413433	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.695899	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.844195	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.317958	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.281009	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.844943	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.274075	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.998218	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.470525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.539198	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.746362	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.443141	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.794779	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.742546	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.089183	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.955961	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.864846	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.436015	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.544754	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.518764	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  16.466728	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   2.068001	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.347530	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.895232	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.445029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.735532	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.432034	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.195132	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.023309	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  54.253905	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.369304	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.109002	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   6.847246	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  29.100400	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.099606	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.093316	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.750169	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  34.713946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.509913	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.851582	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  18.055666	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.266369	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.880200	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.378290	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.608037	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.993465	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.052223	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.099140	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.968031	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.144265	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.654186	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.012553	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.254831	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.576364	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.975826	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.364226	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.703297	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.526198	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.311407	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.130923	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.800619	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  17.636855	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.892698	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.113651	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.396551	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.292400	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.680035	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.612643	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.642172	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  35.929635	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.577246	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.439438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.895234	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.881205	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.130347	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.852253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.756300	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.654668	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.082238	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.065518	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.263957	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  90.869630	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.644269	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.513846	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.444740	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 110.633221	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.524694	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.795197	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.867249	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.612265	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.683640	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.349366	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.224019	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.211131	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  55.193318	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.021050	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.413303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.935940	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.539638	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.784560	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.284186	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.950734	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.909446	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.602843	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.899785	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.736096	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.510601	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.669248	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.977510	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.393623	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.445967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.175479	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.690593	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.784753	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.123577	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.540208	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.546755	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.271947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.832938	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  27.288092	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.259962	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.029218	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.930803	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.140268	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.486026	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.319334	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.381242	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.941888	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  27.510712	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.815841	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.990984	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.965590	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.081190	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 122.089271	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   7.219181	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  24.837079	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.555669	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.516219	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.238086	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.442039	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.424068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.518824	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  33.858501	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.842993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.282275	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.641640	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.946970	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.654737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.443086	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.827743	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 117.859944	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   8.045180	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  25.382256	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.219082	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.700889	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.935720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.242650	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  21.552987	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.252092	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.976996	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.552397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.738680	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.595488	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.857100	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.223029	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.581031	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.030285	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.515215	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.714190	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.149403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.522142	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.282272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.795209	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.993073	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.785239	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.560234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.364101	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.145365	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.931048	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.489733	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  58.955024	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.768238	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.927005	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.559120	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.624829	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.110618	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.995008	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.755434	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.481532	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.420364	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.334201	   0.000000; % NG
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	4679	 2816	 0.0006	 0.00616	 0.19426	 837.866207	 837.866207	 837.866207	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 7951	 0.0005	 0.0074	 0.16192	 939.310725	 939.310725	 939.310725	 0.0	 0.0	 1	 -30.0	 30.0;
	1976	 2843	 0.00107	 0.00626	 0.0176	 489.131391	 489.131391	 489.131391	 0.0	 0.0	 1	 -30.0	 30.0;
	1976	 2940	 0.000841	 0.0055	 0.00899	 488.494654	 488.494654	 488.494654	 0.0	 0.0	 1	 -30.0	 30.0;
	3197	 645	 0.00143	 0.01563	 0.4664	 1660.159233	 1660.159233	 1660.159233	 0.0	 0.0	 1	 -30.0	 30.0;
	3197	 4123	 0.00146	 0.01692	 0.38774	 1742.65082	 1742.65082	 1742.65082	 0.0	 0.0	 1	 -30.0	 30.0;
	384	 4925	 7e-05	 0.00057	 0.01238	 1713.388168	 1713.388168	 1713.388168	 0.0	 0.0	 1	 -30.0	 30.0;
	384	 4276	 6e-05	 0.00056	 0.01238	 1530.306379	 1530.306379	 1530.306379	 0.0	 0.0	 1	 -30.0	 30.0;
	5407	 6736	 0.003349	 0.01656	 0.02751	 231.433719	 231.433719	 231.433719	 0.0	 0.0	 1	 -30.0	 30.0;
	5407	 2899	 0.003409	 0.016211	 0.02803	 286.353101	 286.353101	 286.353101	 0.0	 0.0	 1	 -30.0	 30.0;
	4077	 6736	 0.003479	 0.01586	 0.02855	 235.506394	 235.506394	 235.506394	 0.0	 0.0	 1	 -30.0	 30.0;
	4077	 2899	 0.003099	 0.017969	 0.02543	 282.911066	 282.911066	 282.911066	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 8352	 0.00127	 0.01842	 0.46004	 830.576213	 830.576213	 830.576213	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 756	 0.00126	 0.01847	 0.48802	 1552.792417	 1552.792417	 1552.792417	 0.0	 0.0	 1	 -30.0	 30.0;
	1510	 105	 0.0013	 0.01808	 0.46926	 1220.321038	 1220.321038	 1220.321038	 0.0	 0.0	 1	 -30.0	 30.0;
	1510	 3134	 0.00131	 0.01765	 0.50568	 1757.022165	 1757.022165	 1757.022165	 0.0	 0.0	 1	 -30.0	 30.0;
	4625	 1654	 0.00065	 0.01311	 4.8838	 2817.518821	 2817.518821	 2817.518821	 0.0	 0.0	 1	 -30.0	 30.0;
	4625	 5805	 0.00067	 0.00974	 5.004478	 2634.653227	 2634.653227	 2634.653227	 0.0	 0.0	 1	 -30.0	 30.0;
	4733	 7105	 0.00236	 0.01418	 0.02922	 566.739703	 566.739703	 566.739703	 0.0	 0.0	 1	 -30.0	 30.0;
	4733	 7048	 0.002169	 0.015909	 0.02764	 524.512373	 524.512373	 524.512373	 0.0	 0.0	 1	 -30.0	 30.0;
	319	 1163	 0.00027	 0.00254	 0.08831	 1378.411759	 1378.411759	 1378.411759	 0.0	 0.0	 1	 -30.0	 30.0;
	319	 6912	 0.00027	 0.00259	 0.08492	 1131.566217	 1131.566217	 1131.566217	 0.0	 0.0	 1	 -30.0	 30.0;
	2367	 1163	 0.00033	 0.00302	 0.10365	 1462.494165	 1462.494165	 1462.494165	 0.0	 0.0	 1	 -30.0	 30.0;
	2367	 818	 0.00029	 0.00312	 0.08619	 1630.685305	 1630.685305	 1630.685305	 0.0	 0.0	 1	 -30.0	 30.0;
	1685	 5933	 0.000289	 0.00137	 0.22216	 544.409342	 544.409342	 544.409342	 0.0	 0.0	 1	 -30.0	 30.0;
	1685	 6917	 0.000219	 0.00263	 0.28226	 281.672649	 281.672649	 281.672649	 0.0	 0.0	 1	 -30.0	 30.0;
	1946	 5933	 0.000289	 0.001341	 0.22651	 465.512314	 465.512314	 465.512314	 0.0	 0.0	 1	 -30.0	 30.0;
	1946	 7971	 0.000229	 0.00257	 0.2878	 289.387031	 289.387031	 289.387031	 0.0	 0.0	 1	 -30.0	 30.0;
	5998	 5933	 0.000841	 0.00689	 0.00957	 522.453554	 522.453554	 522.453554	 0.0	 0.0	 1	 -30.0	 30.0;
	5998	 1505	 0.000979	 0.00586	 0.01124	 503.907031	 503.907031	 503.907031	 0.0	 0.0	 1	 -30.0	 30.0;
	5239	 5933	 0.00014	 0.0012	 0.0041	 268.472275	 268.472275	 268.472275	 0.0	 0.0	 1	 -30.0	 30.0;
	5239	 7112	 0.000211	 0.001539	 0.00302	 280.884255	 280.884255	 280.884255	 0.0	 0.0	 1	 -30.0	 30.0;
	4742	 5933	 0.000401	 0.004901	 0.01141	 292.571856	 292.571856	 292.571856	 0.0	 0.0	 1	 -30.0	 30.0;
	4742	 7112	 0.000219	 0.00151	 0.00617	 544.34342	 544.34342	 544.34342	 0.0	 0.0	 1	 -30.0	 30.0;
	7323	 5933	 0.000729	 0.004539	 0.00827	 509.486382	 509.486382	 509.486382	 0.0	 0.0	 1	 -30.0	 30.0;
	7323	 2501	 0.00062	 0.00482	 0.00701	 512.761136	 512.761136	 512.761136	 0.0	 0.0	 1	 -30.0	 30.0;
	2700	 5509	 0.00052	 0.00407	 0.12738	 1486.455841	 1486.455841	 1486.455841	 0.0	 0.0	 1	 -30.0	 30.0;
	2700	 3130	 0.00034	 0.00502	 0.10364	 1862.363105	 1862.363105	 1862.363105	 0.0	 0.0	 1	 -30.0	 30.0;
	6860	 5509	 0.00065	 0.00698	 0.21868	 1729.127868	 1729.127868	 1729.127868	 0.0	 0.0	 1	 -30.0	 30.0;
	6860	 8006	 0.00059	 0.00806	 0.19224	 1708.378765	 1708.378765	 1708.378765	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 8045	 0.00063	 0.00464	 0.01791	 502.488759	 502.488759	 502.488759	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 4620	 0.000599	 0.005099	 0.00753	 540.018489	 540.018489	 540.018489	 0.0	 0.0	 1	 -30.0	 30.0;
	4509	 4351	 0.00064	 0.00307	 0.00977	 328.235579	 328.235579	 328.235579	 0.0	 0.0	 1	 -30.0	 30.0;
	4509	 6956	 0.000659	 0.003	 0.00994	 279.764726	 279.764726	 279.764726	 0.0	 0.0	 1	 -30.0	 30.0;
	7816	 6146	 0.00053	 0.00528	 0.13049	 1106.540923	 1106.540923	 1106.540923	 0.0	 0.0	 1	 -30.0	 30.0;
	7816	 7429	 0.00056	 0.0053	 0.13554	 1298.465351	 1298.465351	 1298.465351	 0.0	 0.0	 1	 -30.0	 30.0;
	2826	 4351	 0.0018	 0.007919	 0.0274	 283.888462	 283.888462	 283.888462	 0.0	 0.0	 1	 -30.0	 30.0;
	2826	 6489	 0.001651	 0.00862	 0.02553	 282.802085	 282.802085	 282.802085	 0.0	 0.0	 1	 -30.0	 30.0;
	4932	 6146	 0.00045	 0.00545	 0.10855	 1383.103261	 1383.103261	 1383.103261	 0.0	 0.0	 1	 -30.0	 30.0;
	4932	 818	 0.00052	 0.00476	 0.12312	 1549.818105	 1549.818105	 1549.818105	 0.0	 0.0	 1	 -30.0	 30.0;
	2075	 6238	 0.01286	 0.037421	 0.00426	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2075	 5131	 0.032397	 0.123	 0.01071	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	428	 6238	 0.032851	 0.069727	 0.00686	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	428	 7299	 0.059942	 0.112802	 0.01253	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7184	 6775	 0.00011	 0.00109	 0.0275	 1117.523303	 1117.523303	 1117.523303	 0.0	 0.0	 1	 -30.0	 30.0;
	7184	 8079	 0.00011	 0.00107	 0.02724	 1195.989466	 1195.989466	 1195.989466	 0.0	 0.0	 1	 -30.0	 30.0;
	5649	 6968	 0.000461	 0.00395	 0.00707	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	5649	 1374	 0.000599	 0.003789	 0.00905	 609.489453	 609.489453	 609.489453	 0.0	 0.0	 1	 -30.0	 30.0;
	6457	 5956	 0.00173	 0.01542	 0.41037	 991.605046	 991.605046	 991.605046	 0.0	 0.0	 1	 -30.0	 30.0;
	6457	 3958	 0.00166	 0.02083	 0.38623	 1139.939574	 1139.939574	 1139.939574	 0.0	 0.0	 1	 -30.0	 30.0;
	3151	 8031	 0.006314	 0.018488	 0.0014	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3151	 1823	 0.015727	 0.037669	 0.00402	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6856	 6402	 0.00374	 0.02095	 0.02838	 813.890259	 813.890259	 813.890259	 0.0	 0.0	 1	 -30.0	 30.0;
	6856	 3936	 0.00511	 0.019461	 0.03356	 805.730048	 805.730048	 805.730048	 0.0	 0.0	 1	 -30.0	 30.0;
	975	 2598	 0.011281	 0.050771	 0.08633	 470.645455	 470.645455	 470.645455	 0.0	 0.0	 1	 -30.0	 30.0;
	975	 2345	 0.0115	 0.049719	 0.088	 449.934942	 449.934942	 449.934942	 0.0	 0.0	 1	 -30.0	 30.0;
	3594	 2598	 0.011719	 0.048659	 0.08965	 452.083309	 452.083309	 452.083309	 0.0	 0.0	 1	 -30.0	 30.0;
	3594	 2345	 0.01193	 0.047599	 0.09132	 454.348277	 454.348277	 454.348277	 0.0	 0.0	 1	 -30.0	 30.0;
	117	 2691	 0.00064	 0.00715	 0.21543	 1506.892967	 1506.892967	 1506.892967	 0.0	 0.0	 1	 -30.0	 30.0;
	117	 4000	 0.00089	 0.00712	 0.21232	 1309.97954	 1309.97954	 1309.97954	 0.0	 0.0	 1	 -30.0	 30.0;
	4587	 628	 0.00048	 0.00555	 0.12144	 1001.310558	 1001.310558	 1001.310558	 0.0	 0.0	 1	 -30.0	 30.0;
	4587	 7131	 0.00047	 0.00566	 0.11886	 1106.93978	 1106.93978	 1106.93978	 0.0	 0.0	 1	 -30.0	 30.0;
	6245	 628	 0.00046	 0.00524	 0.11627	 1061.994032	 1061.994032	 1061.994032	 0.0	 0.0	 1	 -30.0	 30.0;
	6245	 7131	 0.00052	 0.00514	 0.13178	 1066.333408	 1066.333408	 1066.333408	 0.0	 0.0	 1	 -30.0	 30.0;
	1324	 4099	 0.00438	 0.010686	 0.00092	 72.65579	 72.65579	 72.65579	 0.0	 0.0	 1	 -30.0	 30.0;
	1324	 6038	 0.031347	 0.062653	 0.00639	 72.65579	 72.65579	 72.65579	 0.0	 0.0	 1	 -30.0	 30.0;
	5891	 4499	 0.00029	 0.00298	 0.08127	 1628.17106	 1628.17106	 1628.17106	 0.0	 0.0	 1	 -30.0	 30.0;
	5891	 5519	 0.0003	 0.00291	 0.08283	 1543.318584	 1543.318584	 1543.318584	 0.0	 0.0	 1	 -30.0	 30.0;
	1258	 8182	 0.00155	 0.01529	 0.48969	 1213.99791	 1213.99791	 1213.99791	 0.0	 0.0	 1	 -30.0	 30.0;
	1258	 2862	 0.00148	 0.0152	 0.35671	 1311.675668	 1311.675668	 1311.675668	 0.0	 0.0	 1	 -30.0	 30.0;
	7887	 7378	 0.000169	 0.00096	 0.00546	 322.117283	 322.117283	 322.117283	 0.0	 0.0	 1	 -30.0	 30.0;
	7887	 5621	 0.000182	 0.000942	 0.00558	 322.117283	 322.117283	 322.117283	 0.0	 0.0	 1	 -30.0	 30.0;
	5142	 381	 0.00016	 0.00184	 0.05863	 2676.565133	 2676.565133	 2676.565133	 0.0	 0.0	 1	 -30.0	 30.0;
	5142	 6559	 0.00022	 0.00287	 0.072	 2676.565133	 2676.565133	 2676.565133	 0.0	 0.0	 1	 -30.0	 30.0;
	3506	 5894	 0.00015	 0.00187	 0.05744	 2521.340125	 2521.340125	 2521.340125	 0.0	 0.0	 1	 -30.0	 30.0;
	3506	 4345	 0.00022	 0.00266	 0.07043	 2521.340125	 2521.340125	 2521.340125	 0.0	 0.0	 1	 -30.0	 30.0;
	610	 8066	 0.00138	 0.0174	 0.4384	 1321.989996	 1321.989996	 1321.989996	 0.0	 0.0	 1	 -30.0	 30.0;
	610	 2834	 0.00272	 0.0288	 0.87792	 1111.997888	 1111.997888	 1111.997888	 0.0	 0.0	 1	 -30.0	 30.0;
	7365	 4709	 0.00065	 0.01024	 0.22418	 1854.816421	 1854.816421	 1854.816421	 0.0	 0.0	 1	 -30.0	 30.0;
	7365	 5452	 0.00073	 0.01004	 0.25405	 1897.315059	 1897.315059	 1897.315059	 0.0	 0.0	 1	 -30.0	 30.0;
	8112	 4709	 0.00075	 0.00983	 0.25905	 1927.105571	 1927.105571	 1927.105571	 0.0	 0.0	 1	 -30.0	 30.0;
	8112	 5452	 0.00076	 0.00963	 0.26401	 1937.405419	 1937.405419	 1937.405419	 0.0	 0.0	 1	 -30.0	 30.0;
	6482	 6695	 0.00042	 0.02666	 0.0	 1205.779883	 1205.779883	 1205.779883	 0.0	 0.0	 1	 -30.0	 30.0;
	3646	 8036	 0.00029	 0.0026	 0.11024	 2185.862183	 2185.862183	 2185.862183	 0.0	 0.0	 1	 -30.0	 30.0;
	3646	 5247	 0.00022	 0.00303	 0.09849	 1209.378149	 1209.378149	 1209.378149	 0.0	 0.0	 1	 -30.0	 30.0;
	6344	 3424	 0.001	 0.006159	 0.01409	 267.888504	 267.888504	 267.888504	 0.0	 0.0	 1	 -30.0	 30.0;
	6344	 8264	 0.00113	 0.00657	 0.01345	 543.343542	 543.343542	 543.343542	 0.0	 0.0	 1	 -30.0	 30.0;
	1102	 7486	 0.0013	 0.01277	 0.3118	 1318.151494	 1318.151494	 1318.151494	 0.0	 0.0	 1	 -30.0	 30.0;
	1102	 6646	 0.00163	 0.01808	 0.39172	 1409.439648	 1409.439648	 1409.439648	 0.0	 0.0	 1	 -30.0	 30.0;
	7841	 95	 0.00047	 0.00406	 0.10714	 1325.914719	 1325.914719	 1325.914719	 0.0	 0.0	 1	 -30.0	 30.0;
	7841	 5337	 0.00235	 0.02343	 0.53841	 1334.222916	 1334.222916	 1334.222916	 0.0	 0.0	 1	 -30.0	 30.0;
	86	 5816	 0.00036	 0.00445	 0.18766	 1579.188698	 1579.188698	 1579.188698	 0.0	 0.0	 1	 -30.0	 30.0;
	86	 1498	 0.00017	 0.0025	 0.0	 1911.928614	 1911.928614	 1911.928614	 0.0	 0.0	 1	 -30.0	 30.0;
	3987	 5816	 0.00036	 0.00436	 0.19134	 1593.219106	 1593.219106	 1593.219106	 0.0	 0.0	 1	 -30.0	 30.0;
	3987	 3164	 0.00017	 0.00255	 0.0	 1817.450265	 1817.450265	 1817.450265	 0.0	 0.0	 1	 -30.0	 30.0;
	1725	 2919	 0.00096	 0.00995	 0.22139	 1380.469227	 1380.469227	 1380.469227	 0.0	 0.0	 1	 -30.0	 30.0;
	1725	 6159	 0.00152	 0.01949	 0.37613	 1402.562332	 1402.562332	 1402.562332	 0.0	 0.0	 1	 -30.0	 30.0;
	4828	 2919	 0.00094	 0.01014	 0.21687	 1268.953249	 1268.953249	 1268.953249	 0.0	 0.0	 1	 -30.0	 30.0;
	4828	 6159	 0.00149	 0.01986	 0.36829	 1430.785061	 1430.785061	 1430.785061	 0.0	 0.0	 1	 -30.0	 30.0;
	2614	 2919	 0.00107	 0.01243	 0.24707	 1178.384486	 1178.384486	 1178.384486	 0.0	 0.0	 1	 -30.0	 30.0;
	2614	 2342	 0.00102	 0.01034	 0.24764	 1234.992513	 1234.992513	 1234.992513	 0.0	 0.0	 1	 -30.0	 30.0;
	3381	 4411	 0.0047	 0.02061	 0.03819	 447.966813	 447.966813	 447.966813	 0.0	 0.0	 1	 -30.0	 30.0;
	3381	 3355	 0.00739	 0.040531	 0.05525	 404.795239	 404.795239	 404.795239	 0.0	 0.0	 1	 -30.0	 30.0;
	5504	 7837	 0.00049	 0.00611	 0.19795	 1947.280741	 1947.280741	 1947.280741	 0.0	 0.0	 1	 -30.0	 30.0;
	5504	 6646	 0.00035	 0.00431	 0.0827	 1567.792982	 1567.792982	 1567.792982	 0.0	 0.0	 1	 -30.0	 30.0;
	4882	 937	 0.00261	 0.01344	 0.0252	 437.660522	 437.660522	 437.660522	 0.0	 0.0	 1	 -30.0	 30.0;
	4882	 3204	 0.003521	 0.019591	 0.03391	 429.711413	 429.711413	 429.711413	 0.0	 0.0	 1	 -30.0	 30.0;
	6232	 3117	 0.0025	 0.01419	 0.03183	 372.206218	 372.206218	 372.206218	 0.0	 0.0	 1	 -30.0	 30.0;
	6232	 4589	 0.00287	 0.0237	 0.04153	 385.660754	 385.660754	 385.660754	 0.0	 0.0	 1	 -30.0	 30.0;
	6070	 6116	 0.00088	 0.00956	 0.22766	 1569.533866	 1569.533866	 1569.533866	 0.0	 0.0	 1	 -30.0	 30.0;
	6070	 261	 0.00095	 0.00877	 0.19307	 1400.706925	 1400.706925	 1400.706925	 0.0	 0.0	 1	 -30.0	 30.0;
	1875	 682	 0.00332	 0.020651	 0.02957	 470.772726	 470.772726	 470.772726	 0.0	 0.0	 1	 -30.0	 30.0;
	1875	 2772	 0.003969	 0.018781	 0.03027	 471.867867	 471.867867	 471.867867	 0.0	 0.0	 1	 -30.0	 30.0;
	2622	 2483	 0.002849	 0.014909	 0.02173	 445.358899	 445.358899	 445.358899	 0.0	 0.0	 1	 -30.0	 30.0;
	2622	 1435	 0.00439	 0.02451	 0.0346	 451.864585	 451.864585	 451.864585	 0.0	 0.0	 1	 -30.0	 30.0;
	1389	 7878	 0.0002	 0.0018	 0.07654	 2095.832469	 2095.832469	 2095.832469	 0.0	 0.0	 1	 -30.0	 30.0;
	1389	 7605	 0.00025	 0.00261	 0.06775	 2102.649232	 2102.649232	 2102.649232	 0.0	 0.0	 1	 -30.0	 30.0;
	6681	 7878	 0.0002	 0.00176	 0.07802	 2134.423496	 2134.423496	 2134.423496	 0.0	 0.0	 1	 -30.0	 30.0;
	6681	 123	 0.00025	 0.00255	 0.06908	 1937.405419	 1937.405419	 1937.405419	 0.0	 0.0	 1	 -30.0	 30.0;
	928	 5603	 0.012488	 0.047413	 0.00424	 67.329076	 67.329076	 67.329076	 0.0	 0.0	 1	 -30.0	 30.0;
	928	 6509	 0.010479	 0.027711	 0.00207	 85.815012	 85.815012	 85.815012	 0.0	 0.0	 1	 -30.0	 30.0;
	2363	 6761	 0.00044	 0.00428	 0.12975	 1833.265656	 1833.265656	 1833.265656	 0.0	 0.0	 1	 -30.0	 30.0;
	2363	 1217	 0.00036	 0.00475	 0.10092	 1994.391899	 1994.391899	 1994.391899	 0.0	 0.0	 1	 -30.0	 30.0;
	4306	 4764	 0.00058	 0.00534	 0.13981	 1877.338659	 1877.338659	 1877.338659	 0.0	 0.0	 1	 -30.0	 30.0;
	4306	 2861	 0.00054	 0.00589	 0.13209	 1858.837238	 1858.837238	 1858.837238	 0.0	 0.0	 1	 -30.0	 30.0;
	2670	 1301	 0.00206	 0.02057	 0.51797	 1174.669063	 1174.669063	 1174.669063	 0.0	 0.0	 1	 -30.0	 30.0;
	2670	 1406	 0.00077	 0.00872	 0.20069	 961.484786	 961.484786	 961.484786	 0.0	 0.0	 1	 -30.0	 30.0;
	3435	 8333	 0.00161	 0.01963	 0.40525	 1358.870415	 1358.870415	 1358.870415	 0.0	 0.0	 1	 -30.0	 30.0;
	3435	 1406	 0.00075	 0.00888	 0.19651	 1403.075054	 1403.075054	 1403.075054	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 6583	 0.00016	 0.00152	 0.04776	 1657.359338	 1657.359338	 1657.359338	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 4971	 0.00019	 0.00163	 0.04733	 1717.031849	 1717.031849	 1717.031849	 0.0	 0.0	 1	 -30.0	 30.0;
	4966	 6583	 0.00015	 0.0016	 0.04863	 1564.938458	 1564.938458	 1564.938458	 0.0	 0.0	 1	 -30.0	 30.0;
	4966	 4971	 0.00015	 0.00183	 0.03978	 1665.435198	 1665.435198	 1665.435198	 0.0	 0.0	 1	 -30.0	 30.0;
	3318	 2990	 0.00121	 0.01426	 0.55448	 1444.733197	 1444.733197	 1444.733197	 0.0	 0.0	 1	 -30.0	 30.0;
	3318	 5013	 0.00116	 0.01456	 0.60295	 1466.368867	 1466.368867	 1466.368867	 0.0	 0.0	 1	 -30.0	 30.0;
	407	 128	 0.00068	 0.00727	 0.22697	 1800.689729	 1800.689729	 1800.689729	 0.0	 0.0	 1	 -30.0	 30.0;
	407	 1459	 0.0007	 0.00734	 0.22711	 1898.674199	 1898.674199	 1898.674199	 0.0	 0.0	 1	 -30.0	 30.0;
	7167	 128	 0.00076	 0.00712	 0.25723	 1607.734593	 1607.734593	 1607.734593	 0.0	 0.0	 1	 -30.0	 30.0;
	7167	 1459	 0.0008	 0.00719	 0.25739	 1927.514958	 1927.514958	 1927.514958	 0.0	 0.0	 1	 -30.0	 30.0;
	1919	 1442	 0.0002	 0.0022	 0.062275	 1244.209656	 1244.209656	 1244.209656	 0.0	 0.0	 1	 -30.0	 30.0;
	1919	 6722	 0.0002	 0.0022	 0.062275	 1261.682342	 1261.682342	 1261.682342	 0.0	 0.0	 1	 -30.0	 30.0;
	245	 1869	 0.000205	 0.00215	 0.06346	 1418.856877	 1418.856877	 1418.856877	 0.0	 0.0	 1	 -30.0	 30.0;
	245	 6722	 0.000205	 0.00215	 0.06346	 1453.656134	 1453.656134	 1453.656134	 0.0	 0.0	 1	 -30.0	 30.0;
	5385	 7644	 0.00053	 0.00589	 0.16224	 1317.582827	 1317.582827	 1317.582827	 0.0	 0.0	 1	 -30.0	 30.0;
	5385	 740	 0.00046	 0.00675	 0.14064	 1137.865651	 1137.865651	 1137.865651	 0.0	 0.0	 1	 -30.0	 30.0;
	7742	 7644	 0.00054	 0.00577	 0.1653	 1330.820129	 1330.820129	 1330.820129	 0.0	 0.0	 1	 -30.0	 30.0;
	7742	 740	 0.00045	 0.00625	 0.13758	 1096.470122	 1096.470122	 1096.470122	 0.0	 0.0	 1	 -30.0	 30.0;
	1508	 1408	 0.00275	 0.02752	 0.56046	 1411.808435	 1411.808435	 1411.808435	 0.0	 0.0	 1	 -30.0	 30.0;
	1508	 6962	 0.00184	 0.01515	 0.34348	 1346.975799	 1346.975799	 1346.975799	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 3779	 0.00438	 0.02432	 0.03353	 333.346238	 333.346238	 333.346238	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 543	 0.0043	 0.01949	 0.03241	 339.998629	 339.998629	 339.998629	 0.0	 0.0	 1	 -30.0	 30.0;
	7591	 6347	 0.00033	 0.00269	 0.0779	 1242.212082	 1242.212082	 1242.212082	 0.0	 0.0	 1	 -30.0	 30.0;
	7591	 4460	 0.00243	 0.01904	 0.5944	 1144.881184	 1144.881184	 1144.881184	 0.0	 0.0	 1	 -30.0	 30.0;
	853	 6347	 0.00034	 0.00263	 0.07939	 1144.715981	 1144.715981	 1144.715981	 0.0	 0.0	 1	 -30.0	 30.0;
	853	 4460	 0.00248	 0.01864	 0.60583	 1111.114611	 1111.114611	 1111.114611	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 5616	 0.00122	 0.01249	 0.30518	 1013.272967	 1013.272967	 1013.272967	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 3694	 0.00106	 0.01031	 0.38362	 1081.291191	 1081.291191	 1081.291191	 0.0	 0.0	 1	 -30.0	 30.0;
	3009	 5616	 0.00119	 0.01273	 0.29895	 999.643389	 999.643389	 999.643389	 0.0	 0.0	 1	 -30.0	 30.0;
	3009	 3694	 0.00108	 0.01009	 0.39072	 1111.156735	 1111.156735	 1111.156735	 0.0	 0.0	 1	 -30.0	 30.0;
	1257	 4008	 0.001039	 0.013711	 0.03649	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1257	 4677	 0.00114	 0.011409	 0.04302	 265.692506	 265.692506	 265.692506	 0.0	 0.0	 1	 -30.0	 30.0;
	7122	 5332	 0.001021	 0.013969	 0.03573	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7122	 4677	 0.001169	 0.011159	 0.04381	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7257	 7434	 0.0	 0.000271	 0.0	 116.419016	 116.419016	 116.419016	 0.0	 0.0	 1	 -30.0	 30.0;
	2111	 7434	 0.0	 0.000271	 0.0	 107.991376	 107.991376	 107.991376	 0.0	 0.0	 1	 -30.0	 30.0;
	763	 136	 0.009372	 0.035702	 0.00318	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	763	 3273	 0.029157	 0.103686	 0.0096	 62.300153	 62.300153	 62.300153	 0.0	 0.0	 1	 -30.0	 30.0;
	479	 5017	 0.00065	 0.00673	 0.27895	 1520.735794	 1520.735794	 1520.735794	 0.0	 0.0	 1	 -30.0	 30.0;
	479	 3793	 0.00066	 0.00658	 0.28412	 1707.555383	 1707.555383	 1707.555383	 0.0	 0.0	 1	 -30.0	 30.0;
	3208	 2254	 0.000969	 0.006021	 0.02439	 569.472221	 569.472221	 569.472221	 0.0	 0.0	 1	 -30.0	 30.0;
	3208	 3796	 0.00099	 0.005901	 0.02496	 392.38364	 392.38364	 392.38364	 0.0	 0.0	 1	 -30.0	 30.0;
	1057	 7795	 0.00088	 0.006599	 0.0224	 301.459494	 301.459494	 301.459494	 0.0	 0.0	 1	 -30.0	 30.0;
	1057	 4838	 0.00086	 0.006729	 0.02201	 497.991593	 497.991593	 497.991593	 0.0	 0.0	 1	 -30.0	 30.0;
	7881	 2979	 9e-05	 0.00077	 0.02844	 1730.488983	 1730.488983	 1730.488983	 0.0	 0.0	 1	 -30.0	 30.0;
	7881	 3848	 9e-05	 0.00078	 0.02787	 1594.328797	 1594.328797	 1594.328797	 0.0	 0.0	 1	 -30.0	 30.0;
	4477	 2979	 8e-05	 0.00082	 0.02558	 1504.127297	 1504.127297	 1504.127297	 0.0	 0.0	 1	 -30.0	 30.0;
	4477	 6912	 8e-05	 0.00076	 0.02572	 1261.729073	 1261.729073	 1261.729073	 0.0	 0.0	 1	 -30.0	 30.0;
	6130	 5017	 9e-05	 0.00074	 0.02909	 1625.280995	 1625.280995	 1625.280995	 0.0	 0.0	 1	 -30.0	 30.0;
	6130	 3848	 9e-05	 0.00073	 0.02972	 1271.969685	 1271.969685	 1271.969685	 0.0	 0.0	 1	 -30.0	 30.0;
	3722	 2254	 0.00062	 0.003781	 0.00889	 259.689045	 259.689045	 259.689045	 0.0	 0.0	 1	 -30.0	 30.0;
	3722	 709	 0.000599	 0.0035	 0.00876	 564.635157	 564.635157	 564.635157	 0.0	 0.0	 1	 -30.0	 30.0;
	6233	 7795	 0.00064	 0.00274	 0.00858	 380.223535	 380.223535	 380.223535	 0.0	 0.0	 1	 -30.0	 30.0;
	6233	 1226	 0.000651	 0.00268	 0.0087	 613.291582	 613.291582	 613.291582	 0.0	 0.0	 1	 -30.0	 30.0;
	6180	 1246	 0.00055	 0.00685	 0.14191	 1806.74827	 1806.74827	 1806.74827	 0.0	 0.0	 1	 -30.0	 30.0;
	6180	 337	 0.00061	 0.00639	 0.15911	 1857.406357	 1857.406357	 1857.406357	 0.0	 0.0	 1	 -30.0	 30.0;
	5463	 5017	 0.00042	 0.00523	 0.10137	 1525.086359	 1525.086359	 1525.086359	 0.0	 0.0	 1	 -30.0	 30.0;
	5463	 7554	 0.00045	 0.00605	 0.10902	 1499.506879	 1499.506879	 1499.506879	 0.0	 0.0	 1	 -30.0	 30.0;
	5167	 2979	 0.0003	 0.00228	 0.06581	 1478.004819	 1478.004819	 1478.004819	 0.0	 0.0	 1	 -30.0	 30.0;
	5167	 8079	 0.00026	 0.00264	 0.05674	 1225.587789	 1225.587789	 1225.587789	 0.0	 0.0	 1	 -30.0	 30.0;
	3047	 8376	 0.00536	 0.03568	 0.04968	 567.016727	 567.016727	 567.016727	 0.0	 0.0	 1	 -30.0	 30.0;
	3047	 5704	 0.006091	 0.03549	 0.05313	 585.517143	 585.517143	 585.517143	 0.0	 0.0	 1	 -30.0	 30.0;
	4976	 8376	 0.006419	 0.033271	 0.05979	 608.629421	 608.629421	 608.629421	 0.0	 0.0	 1	 -30.0	 30.0;
	4976	 1347	 0.005789	 0.035901	 0.0553	 621.061978	 621.061978	 621.061978	 0.0	 0.0	 1	 -30.0	 30.0;
	6318	 1672	 0.0	 0.000146	 0.0	 341.060619	 341.060619	 341.060619	 0.0	 0.0	 1	 -30.0	 30.0;
	6318	 7052	 0.0	 0.000146	 0.0	 340.650227	 340.650227	 340.650227	 0.0	 0.0	 1	 -30.0	 30.0;
	7219	 8376	 0.008401	 0.04011	 0.05941	 424.979901	 424.979901	 424.979901	 0.0	 0.0	 1	 -30.0	 30.0;
	7219	 2909	 0.007831	 0.041531	 0.05618	 436.344752	 436.344752	 436.344752	 0.0	 0.0	 1	 -30.0	 30.0;
	6850	 604	 0.00575	 0.046461	 0.0553	 576.885572	 576.885572	 576.885572	 0.0	 0.0	 1	 -30.0	 30.0;
	6850	 1109	 0.006711	 0.04426	 0.0558	 609.453635	 609.453635	 609.453635	 0.0	 0.0	 1	 -30.0	 30.0;
	3289	 7920	 0.00036	 0.00485	 0.12447	 2133.01565	 2133.01565	 2133.01565	 0.0	 0.0	 1	 -30.0	 30.0;
	3289	 5668	 0.00042	 0.00415	 0.1458	 2180.834352	 2180.834352	 2180.834352	 0.0	 0.0	 1	 -30.0	 30.0;
	6376	 1531	 9e-05	 0.00069	 0.42124	 1343.485474	 1343.485474	 1343.485474	 0.0	 0.0	 1	 -30.0	 30.0;
	6376	 6726	 4e-05	 0.00036	 0.43761	 1442.888978	 1442.888978	 1442.888978	 0.0	 0.0	 1	 -30.0	 30.0;
	925	 2266	 0.00055	 0.00569	 0.13419	 1343.846156	 1343.846156	 1343.846156	 0.0	 0.0	 1	 -30.0	 30.0;
	925	 7758	 0.0007	 0.00767	 0.1666	 1214.180225	 1214.180225	 1214.180225	 0.0	 0.0	 1	 -30.0	 30.0;
	5516	 3537	 0.0013	 0.01299	 0.31812	 1209.507152	 1209.507152	 1209.507152	 0.0	 0.0	 1	 -30.0	 30.0;
	2664	 7544	 0.00092	 0.01031	 0.37753	 1646.176214	 1646.176214	 1646.176214	 0.0	 0.0	 1	 -30.0	 30.0;
	999	 3537	 0.00158	 0.01496	 0.49876	 1458.814285	 1458.814285	 1458.814285	 0.0	 0.0	 1	 -30.0	 30.0;
	999	 1031	 0.00123	 0.01309	 0.36164	 1924.446526	 1924.446526	 1924.446526	 0.0	 0.0	 1	 -30.0	 30.0;
	3688	 6021	 0.000599	 0.00274	 0.15573	 544.88718	 544.88718	 544.88718	 0.0	 0.0	 1	 -30.0	 30.0;
	3688	 6634	 0.0005	 0.00405	 0.195	 351.46484	 351.46484	 351.46484	 0.0	 0.0	 1	 -30.0	 30.0;
	2307	 7101	 0.003349	 0.02445	 0.039	 571.116838	 571.116838	 571.116838	 0.0	 0.0	 1	 -30.0	 30.0;
	2307	 4505	 0.003281	 0.02493	 0.03821	 569.773251	 569.773251	 569.773251	 0.0	 0.0	 1	 -30.0	 30.0;
	3626	 3296	 0.00087	 0.01097	 0.2087	 1269.101998	 1269.101998	 1269.101998	 0.0	 0.0	 1	 -30.0	 30.0;
	3626	 8149	 0.00161	 0.01464	 0.36978	 1353.055401	 1353.055401	 1353.055401	 0.0	 0.0	 1	 -30.0	 30.0;
	6352	 3062	 0.0	 0.00046	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 3351	 0.00118	 0.01223	 0.24339	 1017.700539	 1017.700539	 1017.700539	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 6086	 0.00045	 0.00364	 0.12321	 1273.751376	 1273.751376	 1273.751376	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 1783	 0.00714	 0.03393	 0.05753	 357.797911	 357.797911	 357.797911	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 6966	 0.00655	 0.036849	 0.05109	 341.786521	 341.786521	 341.786521	 0.0	 0.0	 1	 -30.0	 30.0;
	4572	 7216	 0.00088	 0.00722	 0.2163	 1820.746427	 1820.746427	 1820.746427	 0.0	 0.0	 1	 -30.0	 30.0;
	4572	 5848	 0.00071	 0.00835	 0.18603	 1933.174642	 1933.174642	 1933.174642	 0.0	 0.0	 1	 -30.0	 30.0;
	5963	 7216	 0.00084	 0.00705	 0.28116	 1846.578649	 1846.578649	 1846.578649	 0.0	 0.0	 1	 -30.0	 30.0;
	5963	 7613	 0.00102	 0.00799	 0.25557	 1642.661536	 1642.661536	 1642.661536	 0.0	 0.0	 1	 -30.0	 30.0;
	5795	 5080	 0.003781	 0.029969	 0.04141	 544.659692	 544.659692	 544.659692	 0.0	 0.0	 1	 -30.0	 30.0;
	5795	 7381	 0.00386	 0.02969	 0.03574	 542.174477	 542.174477	 542.174477	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 7637	 0.00076	 0.00463	 0.00841	 586.97695	 586.97695	 586.97695	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 2616	 0.000711	 0.004841	 0.0079	 586.847392	 586.847392	 586.847392	 0.0	 0.0	 1	 -30.0	 30.0;
	4734	 8334	 0.00631	 0.034469	 0.05046	 402.417098	 402.417098	 402.417098	 0.0	 0.0	 1	 -30.0	 30.0;
	4734	 6716	 0.006169	 0.03512	 0.04938	 424.509302	 424.509302	 424.509302	 0.0	 0.0	 1	 -30.0	 30.0;
	2808	 4693	 0.002961	 0.017651	 0.03977	 622.602187	 622.602187	 622.602187	 0.0	 0.0	 1	 -30.0	 30.0;
	2808	 2616	 0.00299	 0.02462	 0.033	 604.767467	 604.767467	 604.767467	 0.0	 0.0	 1	 -30.0	 30.0;
	230	 8334	 0.002789	 0.011659	 0.04297	 496.342022	 496.342022	 496.342022	 0.0	 0.0	 1	 -30.0	 30.0;
	230	 6094	 0.00249	 0.013211	 0.0383	 492.616866	 492.616866	 492.616866	 0.0	 0.0	 1	 -30.0	 30.0;
	3808	 8334	 0.002669	 0.016031	 0.04088	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	3808	 4274	 0.00261	 0.014841	 0.03996	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	5363	 8334	 0.00074	 0.004599	 0.00929	 386.547841	 386.547841	 386.547841	 0.0	 0.0	 1	 -30.0	 30.0;
	5363	 1801	 0.000719	 0.00468	 0.00865	 438.262964	 438.262964	 438.262964	 0.0	 0.0	 1	 -30.0	 30.0;
	1838	 4269	 3.5e-05	 0.000355	 0.003435	 1270.815238	 1270.815238	 1270.815238	 0.0	 0.0	 1	 -30.0	 30.0;
	1838	 4388	 3.5e-05	 0.000355	 0.003435	 1270.385447	 1270.385447	 1270.385447	 0.0	 0.0	 1	 -30.0	 30.0;
	1305	 224	 0.00511	 0.02949	 0.03885	 432.507948	 432.507948	 432.507948	 0.0	 0.0	 1	 -30.0	 30.0;
	1305	 5205	 0.007719	 0.044271	 0.05873	 412.076365	 412.076365	 412.076365	 0.0	 0.0	 1	 -30.0	 30.0;
	2665	 224	 0.004281	 0.022469	 0.03267	 384.422718	 384.422718	 384.422718	 0.0	 0.0	 1	 -30.0	 30.0;
	2665	 2822	 0.005961	 0.03382	 0.04539	 463.516368	 463.516368	 463.516368	 0.0	 0.0	 1	 -30.0	 30.0;
	4452	 5868	 0.00073	 0.01034	 0.34561	 1687.444714	 1687.444714	 1687.444714	 0.0	 0.0	 1	 -30.0	 30.0;
	4452	 950	 0.00076	 0.00889	 0.43866	 1867.312613	 1867.312613	 1867.312613	 0.0	 0.0	 1	 -30.0	 30.0;
	2357	 2369	 0.005159	 0.025789	 0.03929	 413.516738	 413.516738	 413.516738	 0.0	 0.0	 1	 -30.0	 30.0;
	2357	 8238	 0.00549	 0.027711	 0.03804	 363.919879	 363.919879	 363.919879	 0.0	 0.0	 1	 -30.0	 30.0;
	1932	 2369	 0.00614	 0.01764	 0.04668	 401.137528	 401.137528	 401.137528	 0.0	 0.0	 1	 -30.0	 30.0;
	1932	 2910	 0.003229	 0.01788	 0.02558	 354.248419	 354.248419	 354.248419	 0.0	 0.0	 1	 -30.0	 30.0;
	7596	 4361	 0.00053	 0.00587	 0.17659	 1807.65919	 1807.65919	 1807.65919	 0.0	 0.0	 1	 -30.0	 30.0;
	7596	 5050	 0.00055	 0.00666	 0.18184	 1743.415624	 1743.415624	 1743.415624	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 6032	 0.00326	 0.01388	 0.05107	 224.967281	 224.967281	 224.967281	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 3702	 0.003081	 0.01488	 0.04795	 236.602678	 236.602678	 236.602678	 0.0	 0.0	 1	 -30.0	 30.0;
	3097	 1566	 0.00051	 0.00614	 0.17963	 2097.54176	 2097.54176	 2097.54176	 0.0	 0.0	 1	 -30.0	 30.0;
	3097	 5668	 0.00043	 0.00406	 0.1485	 2188.612715	 2188.612715	 2188.612715	 0.0	 0.0	 1	 -30.0	 30.0;
	7283	 5379	 0.00761	 0.046031	 0.05785	 443.171284	 443.171284	 443.171284	 0.0	 0.0	 1	 -30.0	 30.0;
	7283	 8213	 0.00351	 0.01632	 0.02771	 429.333791	 429.333791	 429.333791	 0.0	 0.0	 1	 -30.0	 30.0;
	4579	 1468	 0.00031	 0.00495	 0.12257	 1769.368293	 1769.368293	 1769.368293	 0.0	 0.0	 1	 -30.0	 30.0;
	4579	 8286	 0.00043	 0.00485	 0.1425	 1958.398706	 1958.398706	 1958.398706	 0.0	 0.0	 1	 -30.0	 30.0;
	7939	 131	 0.00426	 0.027099	 0.04049	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	7939	 5339	 0.00437	 0.024969	 0.04258	 599.835522	 599.835522	 599.835522	 0.0	 0.0	 1	 -30.0	 30.0;
	5514	 7165	 0.005	 0.03932	 0.05477	 432.956826	 432.956826	 432.956826	 0.0	 0.0	 1	 -30.0	 30.0;
	5514	 6776	 0.006039	 0.036789	 0.02852	 463.000425	 463.000425	 463.000425	 0.0	 0.0	 1	 -30.0	 30.0;
	7494	 8277	 0.0009	 0.00893	 0.21405	 1228.69637	 1228.69637	 1228.69637	 0.0	 0.0	 1	 -30.0	 30.0;
	7494	 6631	 0.00286	 0.02156	 0.27942	 1072.608489	 1072.608489	 1072.608489	 0.0	 0.0	 1	 -30.0	 30.0;
	615	 131	 0.00418	 0.022729	 0.03947	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	615	 5153	 0.00405	 0.02231	 0.03933	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	6609	 4394	 0.00013	 0.00675	 0.15658	 1666.221064	 1666.221064	 1666.221064	 0.0	 0.0	 1	 -30.0	 30.0;
	6609	 1134	 0.00013	 0.00688	 0.15324	 1709.39302	 1709.39302	 1709.39302	 0.0	 0.0	 1	 -30.0	 30.0;
	8280	 3714	 0.00078	 0.01201	 0.33298	 2019.315175	 2019.315175	 2019.315175	 0.0	 0.0	 1	 -30.0	 30.0;
	8280	 5922	 0.00075	 0.01254	 0.31987	 1789.714589	 1789.714589	 1789.714589	 0.0	 0.0	 1	 -30.0	 30.0;
	2116	 4701	 0.00071	 0.00722	 0.28953	 2172.335282	 2172.335282	 2172.335282	 0.0	 0.0	 1	 -30.0	 30.0;
	2116	 3949	 0.00084	 0.0074	 0.28098	 1906.494028	 1906.494028	 1906.494028	 0.0	 0.0	 1	 -30.0	 30.0;
	3771	 7373	 0.00105	 0.0081	 0.20937	 1077.708063	 1077.708063	 1077.708063	 0.0	 0.0	 1	 -30.0	 30.0;
	3771	 7141	 0.00203	 0.01565	 0.40346	 1151.522872	 1151.522872	 1151.522872	 0.0	 0.0	 1	 -30.0	 30.0;
	7705	 1446	 0.00035	 0.00581	 0.14223	 1901.672864	 1901.672864	 1901.672864	 0.0	 0.0	 1	 -30.0	 30.0;
	7705	 2387	 0.00045	 0.00534	 0.176	 2061.707188	 2061.707188	 2061.707188	 0.0	 0.0	 1	 -30.0	 30.0;
	6670	 6829	 8.1e-05	 0.001331	 0.03287	 280.915882	 280.915882	 280.915882	 0.0	 0.0	 1	 -30.0	 30.0;
	6670	 5712	 0.00025	 0.001591	 0.0426	 347.458087	 347.458087	 347.458087	 0.0	 0.0	 1	 -30.0	 30.0;
	6310	 2081	 0.00401	 0.026219	 0.04089	 420.669069	 420.669069	 420.669069	 0.0	 0.0	 1	 -30.0	 30.0;
	6310	 6776	 0.004669	 0.027521	 0.04056	 423.104367	 423.104367	 423.104367	 0.0	 0.0	 1	 -30.0	 30.0;
	279	 7780	 0.00115	 0.01265	 0.25963	 1093.690631	 1093.690631	 1093.690631	 0.0	 0.0	 1	 -30.0	 30.0;
	279	 1237	 0.00112	 0.0129	 0.25734	 1094.594311	 1094.594311	 1094.594311	 0.0	 0.0	 1	 -30.0	 30.0;
	7043	 5306	 0.00123	 0.01589	 0.35725	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7043	 7141	 0.00054	 0.00484	 0.15614	 1196.363312	 1196.363312	 1196.363312	 0.0	 0.0	 1	 -30.0	 30.0;
	3440	 7407	 0.00401	 0.03961	 0.10773	 316.917597	 316.917597	 316.917597	 0.0	 0.0	 1	 -30.0	 30.0;
	3440	 3540	 0.002909	 0.01981	 0.03145	 519.73704	 519.73704	 519.73704	 0.0	 0.0	 1	 -30.0	 30.0;
	909	 5574	 0.002211	 0.014419	 0.01811	 439.349722	 439.349722	 439.349722	 0.0	 0.0	 1	 -30.0	 30.0;
	909	 2899	 0.002169	 0.013349	 0.01773	 473.003018	 473.003018	 473.003018	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 7780	 0.00055	 0.00508	 0.12874	 1224.321452	 1224.321452	 1224.321452	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 810	 0.00046	 0.00595	 0.10852	 1456.206578	 1456.206578	 1456.206578	 0.0	 0.0	 1	 -30.0	 30.0;
	6015	 6770	 0.00201	 0.00988	 0.01587	 568.869398	 568.869398	 568.869398	 0.0	 0.0	 1	 -30.0	 30.0;
	6015	 2003	 0.003401	 0.019099	 0.03377	 573.588717	 573.588717	 573.588717	 0.0	 0.0	 1	 -30.0	 30.0;
	1805	 616	 0.00028	 0.00308	 0.11808	 1692.512695	 1692.512695	 1692.512695	 0.0	 0.0	 1	 -30.0	 30.0;
	1805	 5150	 0.00038	 0.00307	 0.13025	 1860.949994	 1860.949994	 1860.949994	 0.0	 0.0	 1	 -30.0	 30.0;
	2211	 3833	 0.00044	 0.00577	 0.09831	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2211	 2178	 0.00102	 0.01295	 0.24007	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5086	 1507	 0.00085	 0.01005	 0.21741	 1713.667236	 1713.667236	 1713.667236	 0.0	 0.0	 1	 -30.0	 30.0;
	5086	 4989	 0.00073	 0.0097	 0.20189	 1850.713989	 1850.713989	 1850.713989	 0.0	 0.0	 1	 -30.0	 30.0;
	6937	 1724	 0.00139	 0.0126	 0.35664	 1350.379902	 1350.379902	 1350.379902	 0.0	 0.0	 1	 -30.0	 30.0;
	6937	 4994	 0.00117	 0.01389	 0.31297	 1225.142202	 1225.142202	 1225.142202	 0.0	 0.0	 1	 -30.0	 30.0;
	5962	 1372	 0.00076	 0.00908	 0.18213	 1391.072496	 1391.072496	 1391.072496	 0.0	 0.0	 1	 -30.0	 30.0;
	5962	 7764	 0.00137	 0.01338	 0.30919	 1315.007372	 1315.007372	 1315.007372	 0.0	 0.0	 1	 -30.0	 30.0;
	2987	 2345	 0.006	 0.0402	 0.05688	 448.698812	 448.698812	 448.698812	 0.0	 0.0	 1	 -30.0	 30.0;
	2987	 625	 0.005719	 0.03906	 0.05652	 450.172337	 450.172337	 450.172337	 0.0	 0.0	 1	 -30.0	 30.0;
	2067	 1724	 0.0007	 0.01065	 0.26892	 887.038783	 887.038783	 887.038783	 0.0	 0.0	 1	 -30.0	 30.0;
	2067	 2085	 0.00066	 0.01062	 0.25535	 869.052059	 869.052059	 869.052059	 0.0	 0.0	 1	 -30.0	 30.0;
	3724	 2862	 0.00153	 0.01695	 0.36722	 1153.591529	 1153.591529	 1153.591529	 0.0	 0.0	 1	 -30.0	 30.0;
	3724	 5534	 0.00083	 0.00925	 0.19859	 1320.384038	 1320.384038	 1320.384038	 0.0	 0.0	 1	 -30.0	 30.0;
	5500	 4806	 0.00033	 0.00101	 1.61324	 855.017043	 855.017043	 855.017043	 0.0	 0.0	 1	 -30.0	 30.0;
	7226	 4806	 0.00028	 0.00104	 1.58996	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	956	 547	 0.00139	 0.0125	 0.30823	 1314.895481	 1314.895481	 1314.895481	 0.0	 0.0	 1	 -30.0	 30.0;
	956	 7563	 0.00119	 0.01236	 0.26778	 1147.899595	 1147.899595	 1147.899595	 0.0	 0.0	 1	 -30.0	 30.0;
	2147	 7915	 0.010099	 0.05513	 0.07809	 392.132146	 392.132146	 392.132146	 0.0	 0.0	 1	 -30.0	 30.0;
	2147	 543	 0.00464	 0.027021	 0.03615	 378.772873	 378.772873	 378.772873	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 3513	 0.002211	 0.012031	 0.03387	 605.873659	 605.873659	 605.873659	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 3702	 0.002479	 0.0115	 0.03858	 587.716189	 587.716189	 587.716189	 0.0	 0.0	 1	 -30.0	 30.0;
	5024	 7777	 0.030281	 0.058314	 0.00629	 109.200884	 109.200884	 109.200884	 0.0	 0.0	 1	 -30.0	 30.0;
	5024	 7005	 0.028174	 0.054256	 0.00584	 121.431865	 121.431865	 121.431865	 0.0	 0.0	 1	 -30.0	 30.0;
	2337	 7777	 0.01114	 0.026231	 0.00232	 89.412897	 89.412897	 89.412897	 0.0	 0.0	 1	 -30.0	 30.0;
	2337	 1984	 0.018157	 0.045248	 0.00384	 87.812101	 87.812101	 87.812101	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 318	 0.00369	 0.017159	 0.02813	 342.439643	 342.439643	 342.439643	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 4376	 0.004909	 0.03018	 0.03738	 314.563082	 314.563082	 314.563082	 0.0	 0.0	 1	 -30.0	 30.0;
	7838	 6604	 0.00408	 0.0056	 0.09831	 1264.821199	 1264.821199	 1264.821199	 0.0	 0.0	 1	 -30.0	 30.0;
	7838	 6962	 0.00301	 0.00925	 0.21504	 1303.952592	 1303.952592	 1303.952592	 0.0	 0.0	 1	 -30.0	 30.0;
	4250	 318	 0.001599	 0.00489	 0.00882	 242.108487	 242.108487	 242.108487	 0.0	 0.0	 1	 -30.0	 30.0;
	4250	 5608	 0.00031	 0.00175	 0.00444	 405.194199	 405.194199	 405.194199	 0.0	 0.0	 1	 -30.0	 30.0;
	5583	 318	 0.00163	 0.004789	 0.00899	 504.683613	 504.683613	 504.683613	 0.0	 0.0	 1	 -30.0	 30.0;
	5583	 5608	 0.00031	 0.001789	 0.00435	 401.800176	 401.800176	 401.800176	 0.0	 0.0	 1	 -30.0	 30.0;
	2770	 2942	 0.00988	 0.063229	 0.07517	 401.905728	 401.905728	 401.905728	 0.0	 0.0	 1	 -30.0	 30.0;
	2770	 1435	 0.00114	 0.00638	 0.00903	 418.532896	 418.532896	 418.532896	 0.0	 0.0	 1	 -30.0	 30.0;
	617	 6424	 0.00065	 0.00755	 0.15871	 1102.256834	 1102.256834	 1102.256834	 0.0	 0.0	 1	 -30.0	 30.0;
	617	 6266	 0.00052	 0.00503	 0.13206	 998.491576	 998.491576	 998.491576	 0.0	 0.0	 1	 -30.0	 30.0;
	512	 6424	 0.00063	 0.0077	 0.15547	 1108.218622	 1108.218622	 1108.218622	 0.0	 0.0	 1	 -30.0	 30.0;
	512	 6266	 0.00053	 0.00493	 0.1346	 938.817091	 938.817091	 938.817091	 0.0	 0.0	 1	 -30.0	 30.0;
	2154	 3036	 0.00055	 0.00683	 0.26639	 1647.375416	 1647.375416	 1647.375416	 0.0	 0.0	 1	 -30.0	 30.0;
	2154	 7489	 0.00118	 0.01134	 0.3066	 1386.452735	 1386.452735	 1386.452735	 0.0	 0.0	 1	 -30.0	 30.0;
	5880	 3036	 0.00056	 0.00668	 0.27133	 1961.100532	 1961.100532	 1961.100532	 0.0	 0.0	 1	 -30.0	 30.0;
	5880	 7489	 0.0012	 0.0111	 0.3125	 1355.471577	 1355.471577	 1355.471577	 0.0	 0.0	 1	 -30.0	 30.0;
	6019	 8075	 0.0098	 0.01047	 0.23401	 1029.973608	 1029.973608	 1029.973608	 0.0	 0.0	 1	 -30.0	 30.0;
	6019	 2919	 0.00134	 0.01215	 0.30439	 1091.397534	 1091.397534	 1091.397534	 0.0	 0.0	 1	 -30.0	 30.0;
	5888	 8075	 0.00092	 0.01198	 0.21894	 1297.590631	 1297.590631	 1297.590631	 0.0	 0.0	 1	 -30.0	 30.0;
	5888	 2342	 0.00057	 0.00616	 0.13745	 1285.877014	 1285.877014	 1285.877014	 0.0	 0.0	 1	 -30.0	 30.0;
	7508	 6758	 0.00108	 0.01773	 0.44114	 1578.037543	 1578.037543	 1578.037543	 0.0	 0.0	 1	 -30.0	 30.0;
	7508	 3393	 0.00064	 0.01047	 0.28743	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	323	 8217	 0.002211	 0.013341	 0.02565	 571.922761	 571.922761	 571.922761	 0.0	 0.0	 1	 -30.0	 30.0;
	323	 85	 0.001901	 0.014229	 0.02177	 601.141765	 601.141765	 601.141765	 0.0	 0.0	 1	 -30.0	 30.0;
	6185	 673	 0.00193	 0.011771	 0.01584	 413.796049	 413.796049	 413.796049	 0.0	 0.0	 1	 -30.0	 30.0;
	6185	 7701	 0.00251	 0.014909	 0.01965	 455.503243	 455.503243	 455.503243	 0.0	 0.0	 1	 -30.0	 30.0;
	4582	 554	 6e-05	 0.00084	 0.02052	 1452.690584	 1452.690584	 1452.690584	 0.0	 0.0	 1	 -30.0	 30.0;
	4582	 1134	 6e-05	 0.00092	 0.01978	 1452.876191	 1452.876191	 1452.876191	 0.0	 0.0	 1	 -30.0	 30.0;
	7639	 5356	 0.00138	 0.010349	 0.01637	 537.048957	 537.048957	 537.048957	 0.0	 0.0	 1	 -30.0	 30.0;
	7639	 6767	 0.00156	 0.009151	 0.01696	 544.635686	 544.635686	 544.635686	 0.0	 0.0	 1	 -30.0	 30.0;
	5726	 5356	 0.001349	 0.010539	 0.01603	 561.397746	 561.397746	 561.397746	 0.0	 0.0	 1	 -30.0	 30.0;
	5726	 6767	 0.001591	 0.00895	 0.01728	 524.851509	 524.851509	 524.851509	 0.0	 0.0	 1	 -30.0	 30.0;
	5307	 3759	 0.0	 0.000271	 0.0	 146.658804	 146.658804	 146.658804	 0.0	 0.0	 1	 -30.0	 30.0;
	3973	 4103	 0.00057	 0.0071	 0.1846	 1638.803289	 1638.803289	 1638.803289	 0.0	 0.0	 1	 -30.0	 30.0;
	3973	 5668	 0.00057	 0.00697	 0.1885	 1619.644347	 1619.644347	 1619.644347	 0.0	 0.0	 1	 -30.0	 30.0;
	7642	 3752	 0.000969	 0.00743	 0.02614	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	7642	 4407	 0.00099	 0.007271	 0.02662	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 3752	 0.00088	 0.00824	 0.02372	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 4407	 0.00086	 0.008401	 0.02323	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	566	 3450	 0.00293	 0.01664	 0.02232	 409.423105	 409.423105	 409.423105	 0.0	 0.0	 1	 -30.0	 30.0;
	566	 7238	 0.008719	 0.05249	 0.06623	 386.602331	 386.602331	 386.602331	 0.0	 0.0	 1	 -30.0	 30.0;
	3004	 1573	 0.00057	 0.00627	 0.05878	 874.696604	 874.696604	 874.696604	 0.0	 0.0	 1	 -30.0	 30.0;
	3004	 7141	 0.00088	 0.00878	 0.09612	 800.412513	 800.412513	 800.412513	 0.0	 0.0	 1	 -30.0	 30.0;
	8211	 200	 0.00033	 0.00421	 0.05828	 1914.542902	 1914.542902	 1914.542902	 0.0	 0.0	 1	 -30.0	 30.0;
	8211	 7820	 0.00084	 0.00353	 0.06713	 2086.529104	 2086.529104	 2086.529104	 0.0	 0.0	 1	 -30.0	 30.0;
	382	 6827	 0.0001	 0.00119	 0.0375	 1810.691422	 1810.691422	 1810.691422	 0.0	 0.0	 1	 -30.0	 30.0;
	382	 5150	 0.0001	 0.0013	 0.01685	 1632.077355	 1632.077355	 1632.077355	 0.0	 0.0	 1	 -30.0	 30.0;
	4365	 7781	 9e-05	 0.00121	 0.03588	 1523.925989	 1523.925989	 1523.925989	 0.0	 0.0	 1	 -30.0	 30.0;
	4365	 3949	 0.0001	 0.00134	 0.0165	 1271.10747	 1271.10747	 1271.10747	 0.0	 0.0	 1	 -30.0	 30.0;
	5975	 2751	 0.00063	 0.01067	 0.22597	 1543.184316	 1543.184316	 1543.184316	 0.0	 0.0	 1	 -30.0	 30.0;
	5975	 2196	 0.00073	 0.00959	 0.25241	 1532.537607	 1532.537607	 1532.537607	 0.0	 0.0	 1	 -30.0	 30.0;
	6597	 3539	 0.002021	 0.030271	 0.08068	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6597	 4629	 0.00218	 0.02786	 0.08704	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4478	 2751	 0.00086	 0.00781	 0.24161	 1580.393824	 1580.393824	 1580.393824	 0.0	 0.0	 1	 -30.0	 30.0;
	4478	 3894	 0.00092	 0.00666	 0.27844	 1519.169327	 1519.169327	 1519.169327	 0.0	 0.0	 1	 -30.0	 30.0;
	5085	 3539	 0.003969	 0.0272	 0.13136	 221.966503	 221.966503	 221.966503	 0.0	 0.0	 1	 -30.0	 30.0;
	5085	 5405	 0.00311	 0.029729	 0.12083	 227.430776	 227.430776	 227.430776	 0.0	 0.0	 1	 -30.0	 30.0;
	4739	 2751	 0.00055	 0.00837	 0.18311	 1313.253982	 1313.253982	 1313.253982	 0.0	 0.0	 1	 -30.0	 30.0;
	4739	 8381	 0.00053	 0.0084	 0.18127	 1419.70527	 1419.70527	 1419.70527	 0.0	 0.0	 1	 -30.0	 30.0;
	4890	 2751	 0.00053	 0.00853	 0.17922	 1320.162232	 1320.162232	 1320.162232	 0.0	 0.0	 1	 -30.0	 30.0;
	4890	 8381	 0.00052	 0.00778	 0.17733	 1437.724245	 1437.724245	 1437.724245	 0.0	 0.0	 1	 -30.0	 30.0;
	7003	 3539	 0.0017	 0.008159	 0.02643	 567.770065	 567.770065	 567.770065	 0.0	 0.0	 1	 -30.0	 30.0;
	7003	 7115	 0.001729	 0.00799	 0.0269	 267.699884	 267.699884	 267.699884	 0.0	 0.0	 1	 -30.0	 30.0;
	2064	 3539	 0.00176	 0.00781	 0.02742	 595.212228	 595.212228	 595.212228	 0.0	 0.0	 1	 -30.0	 30.0;
	2064	 7115	 0.00157	 0.008849	 0.02441	 263.180617	 263.180617	 263.180617	 0.0	 0.0	 1	 -30.0	 30.0;
	713	 3539	 0.000219	 0.002229	 0.0078	 258.815295	 258.815295	 258.815295	 0.0	 0.0	 1	 -30.0	 30.0;
	713	 4677	 0.000229	 0.00218	 0.00795	 221.922682	 221.922682	 221.922682	 0.0	 0.0	 1	 -30.0	 30.0;
	1782	 3539	 0.000229	 0.00213	 0.0081	 219.596364	 219.596364	 219.596364	 0.0	 0.0	 1	 -30.0	 30.0;
	1782	 4677	 0.000211	 0.002419	 0.00721	 219.560164	 219.560164	 219.560164	 0.0	 0.0	 1	 -30.0	 30.0;
	4034	 3539	 0.00019	 0.00255	 0.00636	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4034	 4677	 0.000211	 0.0025	 0.0072	 252.769156	 252.769156	 252.769156	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 3539	 0.0	 0.000103	 0.0	 496.099673	 496.099673	 496.099673	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 1981	 0.0	 0.000103	 0.0	 496.051661	 496.051661	 496.051661	 0.0	 0.0	 1	 -30.0	 30.0;
	1768	 7249	 0.00067	 0.01058	 0.45838	 1340.176807	 1340.176807	 1340.176807	 0.0	 0.0	 1	 -30.0	 30.0;
	1768	 6761	 0.00065	 0.01078	 0.44866	 1185.131482	 1185.131482	 1185.131482	 0.0	 0.0	 1	 -30.0	 30.0;
	3374	 240	 0.009281	 0.05299	 0.07436	 343.244423	 343.244423	 343.244423	 0.0	 0.0	 1	 -30.0	 30.0;
	3374	 6966	 0.009419	 0.057219	 0.07358	 338.387164	 338.387164	 338.387164	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 2173	 0.00055	 0.00505	 0.03957	 285.353604	 285.353604	 285.353604	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 5712	 9.9e-05	 0.00164	 0.00403	 283.417483	 283.417483	 283.417483	 0.0	 0.0	 1	 -30.0	 30.0;
	6972	 7249	 0.00064	 0.00998	 0.43888	 1170.50213	 1170.50213	 1170.50213	 0.0	 0.0	 1	 -30.0	 30.0;
	6972	 2152	 0.00216	 0.02943	 0.53664	 1025.632258	 1025.632258	 1025.632258	 0.0	 0.0	 1	 -30.0	 30.0;
	4520	 1962	 0.00039	 0.00474	 0.16913	 1856.255201	 1856.255201	 1856.255201	 0.0	 0.0	 1	 -30.0	 30.0;
	4520	 1596	 0.00045	 0.00467	 0.16216	 1461.533223	 1461.533223	 1461.533223	 0.0	 0.0	 1	 -30.0	 30.0;
	6984	 1962	 0.00052	 0.00567	 0.21225	 1672.482982	 1672.482982	 1672.482982	 0.0	 0.0	 1	 -30.0	 30.0;
	6984	 1541	 0.00054	 0.00667	 0.18021	 1344.167348	 1344.167348	 1344.167348	 0.0	 0.0	 1	 -30.0	 30.0;
	4066	 4023	 0.008909	 0.042349	 0.07091	 365.827421	 365.827421	 365.827421	 0.0	 0.0	 1	 -30.0	 30.0;
	4066	 7546	 0.00713	 0.03293	 0.05806	 322.540388	 322.540388	 322.540388	 0.0	 0.0	 1	 -30.0	 30.0;
	8064	 1301	 0.0021	 0.02015	 0.52812	 1448.826414	 1448.826414	 1448.826414	 0.0	 0.0	 1	 -30.0	 30.0;
	8064	 8333	 0.00177	 0.02084	 0.45884	 1458.341712	 1458.341712	 1458.341712	 0.0	 0.0	 1	 -30.0	 30.0;
	2260	 6700	 0.001461	 0.00781	 0.01124	 267.602716	 267.602716	 267.602716	 0.0	 0.0	 1	 -30.0	 30.0;
	2260	 5362	 0.001651	 0.007651	 0.01275	 313.916057	 313.916057	 313.916057	 0.0	 0.0	 1	 -30.0	 30.0;
	7868	 6700	 0.00168	 0.0075	 0.01299	 281.573576	 281.573576	 281.573576	 0.0	 0.0	 1	 -30.0	 30.0;
	7868	 5362	 0.001719	 0.007341	 0.01325	 369.814741	 369.814741	 369.814741	 0.0	 0.0	 1	 -30.0	 30.0;
	7196	 6317	 0.00626	 0.020771	 0.03716	 396.862896	 396.862896	 396.862896	 0.0	 0.0	 1	 -30.0	 30.0;
	7196	 6317	 0.00638	 0.02032	 0.03785	 408.637378	 408.637378	 408.637378	 0.0	 0.0	 1	 -30.0	 30.0;
	4211	 5728	 0.047983	 0.076364	 0.00627	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4211	 1428	 0.010868	 0.039083	 0.00351	 99.38272	 99.38272	 99.38272	 0.0	 0.0	 1	 -30.0	 30.0;
	4968	 3154	 0.021851	 0.032364	 0.00251	 61.937011	 61.937011	 61.937011	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 3154	 0.075008	 0.121636	 0.01102	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3154	 4704	 0.049273	 0.084942	 0.00708	 69.341216	 69.341216	 69.341216	 0.0	 0.0	 1	 -30.0	 30.0;
	6485	 6469	 0.058521	 0.110017	 0.00836	 58.277205	 58.277205	 58.277205	 0.0	 0.0	 1	 -30.0	 30.0;
	6818	 6009	 0.012992	 0.052719	 0.00484	 69.288441	 69.288441	 69.288441	 0.0	 0.0	 1	 -30.0	 30.0;
	6009	 6818	 0.012727	 0.053752	 0.00474	 80.213369	 80.213369	 80.213369	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 2244	 0.013341	 0.054169	 0.07854	 338.181396	 338.181396	 338.181396	 0.0	 0.0	 1	 -30.0	 30.0;
	4411	 4839	 0.014961	 0.083521	 0.12171	 419.841425	 419.841425	 419.841425	 0.0	 0.0	 1	 -30.0	 30.0;
	6477	 1503	 0.023653	 0.033603	 0.00338	 76.065246	 76.065246	 76.065246	 0.0	 0.0	 1	 -30.0	 30.0;
	6477	 1503	 0.024099	 0.032876	 0.00345	 63.301174	 63.301174	 63.301174	 0.0	 0.0	 1	 -30.0	 30.0;
	1503	 6818	 0.024934	 0.109579	 0.00929	 71.459289	 71.459289	 71.459289	 0.0	 0.0	 1	 -30.0	 30.0;
	1503	 6818	 0.024397	 0.111653	 0.00909	 90.671699	 90.671699	 90.671699	 0.0	 0.0	 1	 -30.0	 30.0;
	1503	 5466	 0.03414	 0.051058	 0.00503	 71.674774	 71.674774	 71.674774	 0.0	 0.0	 1	 -30.0	 30.0;
	5728	 4968	 0.018893	 0.029083	 0.0027	 61.170146	 61.170146	 61.170146	 0.0	 0.0	 1	 -30.0	 30.0;
	2244	 5134	 0.000581	 0.003081	 0.00591	 489.163399	 489.163399	 489.163399	 0.0	 0.0	 1	 -30.0	 30.0;
	2244	 5134	 0.0005	 0.002789	 0.00559	 496.193031	 496.193031	 496.193031	 0.0	 0.0	 1	 -30.0	 30.0;
	2244	 5901	 0.009281	 0.03489	 0.05529	 383.028833	 383.028833	 383.028833	 0.0	 0.0	 1	 -30.0	 30.0;
	5436	 2244	 0.006081	 0.034	 0.04918	 451.724359	 451.724359	 451.724359	 0.0	 0.0	 1	 -30.0	 30.0;
	5436	 2244	 0.00595	 0.034651	 0.04816	 419.472568	 419.472568	 419.472568	 0.0	 0.0	 1	 -30.0	 30.0;
	1550	 6477	 0.05019	 0.076339	 0.00593	 74.536087	 74.536087	 74.536087	 0.0	 0.0	 1	 -30.0	 30.0;
	6477	 3463	 0.05724	 0.101868	 0.00818	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7486	 6630	 0.0013	 0.01496	 0.32143	 934.259857	 934.259857	 934.259857	 0.0	 0.0	 1	 -30.0	 30.0;
	1408	 7486	 0.00108	 0.01115	 0.23482	 1419.038535	 1419.038535	 1419.038535	 0.0	 0.0	 1	 -30.0	 30.0;
	7486	 95	 0.00223	 0.02267	 0.51652	 1352.091827	 1352.091827	 1352.091827	 0.0	 0.0	 1	 -30.0	 30.0;
	7196	 5901	 0.008229	 0.03325	 0.04859	 400.38038	 400.38038	 400.38038	 0.0	 0.0	 1	 -30.0	 30.0;
	7196	 5423	 0.018159	 0.06526	 0.1092	 427.747475	 427.747475	 427.747475	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 8322	 0.02257	 0.034777	 0.00266	 60.636483	 60.636483	 60.636483	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 2392	 0.032339	 0.103017	 0.0099	 94.752948	 94.752948	 94.752948	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 2392	 0.031678	 0.105041	 0.0097	 95.596595	 95.596595	 95.596595	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 754	 0.028331	 0.050182	 0.0043	 72.070114	 72.070114	 72.070114	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 5728	 0.047314	 0.063678	 0.00716	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4411	 6533	 0.0045	 0.02618	 0.03665	 425.528614	 425.528614	 425.528614	 0.0	 0.0	 1	 -30.0	 30.0;
	4411	 5436	 0.01913	 0.10681	 0.15565	 390.058846	 390.058846	 390.058846	 0.0	 0.0	 1	 -30.0	 30.0;
	7521	 6485	 0.059273	 0.08086	 0.00848	 82.159016	 82.159016	 82.159016	 0.0	 0.0	 1	 -30.0	 30.0;
	7241	 3784	 0.008041	 0.014298	 0.00115	 59.253839	 59.253839	 59.253839	 0.0	 0.0	 1	 -30.0	 30.0;
	4224	 7241	 0.047802	 0.073562	 0.00683	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3386	 1550	 0.049636	 0.058818	 0.00593	 69.60357	 69.60357	 69.60357	 0.0	 0.0	 1	 -30.0	 30.0;
	8322	 1428	 0.04738	 0.075992	 0.00599	 58.910893	 58.910893	 58.910893	 0.0	 0.0	 1	 -30.0	 30.0;
	5466	 8007	 0.035603	 0.045331	 0.00524	 70.79264	 70.79264	 70.79264	 0.0	 0.0	 1	 -30.0	 30.0;
	2626	 4704	 0.024529	 0.031678	 0.00356	 74.794821	 74.794821	 74.794821	 0.0	 0.0	 1	 -30.0	 30.0;
	8072	 2626	 0.036851	 0.047521	 0.00535	 71.423661	 71.423661	 71.423661	 0.0	 0.0	 1	 -30.0	 30.0;
	5759	 7559	 0.004058	 0.011041	 0.00123	 79.96721	 79.96721	 79.96721	 0.0	 0.0	 1	 -30.0	 30.0;
	4207	 5759	 0.012818	 0.022554	 0.00188	 62.586132	 62.586132	 62.586132	 0.0	 0.0	 1	 -30.0	 30.0;
	4138	 1506	 0.079256	 0.118479	 0.01163	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4207	 4138	 0.012554	 0.022967	 0.00184	 72.881563	 72.881563	 72.881563	 0.0	 0.0	 1	 -30.0	 30.0;
	7559	 7347	 0.007917	 0.029628	 0.0024	 72.776202	 72.776202	 72.776202	 0.0	 0.0	 1	 -30.0	 30.0;
	7559	 7347	 0.007744	 0.027438	 0.00235	 67.41767	 67.41767	 67.41767	 0.0	 0.0	 1	 -30.0	 30.0;
	1408	 2264	 0.00039	 0.00461	 0.09592	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6533	 248	 0.014039	 0.071669	 0.1423	 449.407567	 449.407567	 449.407567	 0.0	 0.0	 1	 -30.0	 30.0;
	6533	 248	 0.01251	 0.081219	 0.12677	 488.900474	 488.900474	 488.900474	 0.0	 0.0	 1	 -30.0	 30.0;
	248	 5423	 0.0045	 0.016831	 0.01788	 344.542664	 344.542664	 344.542664	 0.0	 0.0	 1	 -30.0	 30.0;
	5436	 248	 0.00261	 0.009401	 0.01039	 392.462517	 392.462517	 392.462517	 0.0	 0.0	 1	 -30.0	 30.0;
	6534	 2392	 0.08024	 0.135628	 0.01173	 72.226536	 72.226536	 72.226536	 0.0	 0.0	 1	 -30.0	 30.0;
	3941	 6534	 0.043587	 0.057314	 0.00386	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6533	 70	 0.00326	 0.01895	 0.02654	 493.152243	 493.152243	 493.152243	 0.0	 0.0	 1	 -30.0	 30.0;
	673	 70	 0.005409	 0.02675	 0.04408	 400.963388	 400.963388	 400.963388	 0.0	 0.0	 1	 -30.0	 30.0;
	3784	 3071	 0.083537	 0.116554	 0.01217	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2305	 3071	 0.012463	 0.054793	 0.00464	 137.445922	 137.445922	 137.445922	 0.0	 0.0	 1	 -30.0	 30.0;
	754	 8007	 0.044992	 0.07586	 0.00662	 66.346726	 66.346726	 66.346726	 0.0	 0.0	 1	 -30.0	 30.0;
	6490	 1506	 0.032777	 0.050628	 0.00421	 60.572467	 60.572467	 60.572467	 0.0	 0.0	 1	 -30.0	 30.0;
	3463	 4224	 0.060314	 0.092818	 0.00863	 57.988178	 57.988178	 57.988178	 0.0	 0.0	 1	 -30.0	 30.0;
	8072	 7521	 0.02462	 0.034967	 0.00352	 65.810968	 65.810968	 65.810968	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 3386	 0.026603	 0.03038	 0.00317	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 4658	 0.01595	 0.022281	 0.00194	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6490	 4658	 0.018083	 0.021843	 0.0022	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	70	 5436	 0.0132	 0.06293	 0.10683	 401.089897	 401.089897	 401.089897	 0.0	 0.0	 1	 -30.0	 30.0;
	70	 5436	 0.01345	 0.06162	 0.10888	 417.45414	 417.45414	 417.45414	 0.0	 0.0	 1	 -30.0	 30.0;
	4207	 3386	 0.010612	 0.023017	 0.00241	 68.076508	 68.076508	 68.076508	 0.0	 0.0	 1	 -30.0	 30.0;
	904	 6848	 0.01601	 0.06706	 0.12503	 431.471869	 431.471869	 431.471869	 0.0	 0.0	 1	 -30.0	 30.0;
	904	 5080	 0.00362	 0.01457	 0.02827	 471.790895	 471.790895	 471.790895	 0.0	 0.0	 1	 -30.0	 30.0;
	7346	 4342	 0.010281	 0.04007	 0.08012	 436.585195	 436.585195	 436.585195	 0.0	 0.0	 1	 -30.0	 30.0;
	7346	 8334	 0.01549	 0.06756	 0.12161	 391.990014	 391.990014	 391.990014	 0.0	 0.0	 1	 -30.0	 30.0;
	1660	 4709	 0.00073	 0.01141	 0.26279	 1904.736689	 1904.736689	 1904.736689	 0.0	 0.0	 1	 -30.0	 30.0;
	1660	 7249	 0.00108	 0.01698	 0.39106	 1492.382746	 1492.382746	 1492.382746	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 466	 0.0022	 0.027409	 0.07783	 387.495515	 387.495515	 387.495515	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 466	 0.002151	 0.02794	 0.07621	 397.599468	 397.599468	 397.599468	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 6893	 0.00445	 0.02582	 0.06201	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 240	 0.005099	 0.02426	 0.07118	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 1576	 0.019539	 0.100021	 0.15273	 307.813141	 307.813141	 307.813141	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 1576	 0.01914	 0.101979	 0.14962	 288.610448	 288.610448	 288.610448	 0.0	 0.0	 1	 -30.0	 30.0;
	4709	 2006	 0.00158	 0.02551	 0.55935	 1535.2368	 1535.2368	 1535.2368	 0.0	 0.0	 1	 -30.0	 30.0;
	4709	 4254	 0.00021	 0.00296	 0.07527	 1393.599246	 1393.599246	 1393.599246	 0.0	 0.0	 1	 -30.0	 30.0;
	4709	 5129	 0.00157	 0.02091	 0.55027	 1606.183922	 1606.183922	 1606.183922	 0.0	 0.0	 1	 -30.0	 30.0;
	1240	 4254	 0.00162	 0.02163	 0.57081	 1504.222733	 1504.222733	 1504.222733	 0.0	 0.0	 1	 -30.0	 30.0;
	6931	 4342	 0.008521	 0.03463	 0.06921	 360.914528	 360.914528	 360.914528	 0.0	 0.0	 1	 -30.0	 30.0;
	6931	 8334	 0.00463	 0.078531	 0.18354	 247.567045	 247.567045	 247.567045	 0.0	 0.0	 1	 -30.0	 30.0;
	6931	 8334	 0.004531	 0.072711	 0.17955	 224.315683	 224.315683	 224.315683	 0.0	 0.0	 1	 -30.0	 30.0;
	6931	 99	 0.00575	 0.02876	 0.047	 390.045129	 390.045129	 390.045129	 0.0	 0.0	 1	 -30.0	 30.0;
	6931	 2868	 0.00411	 0.01826	 0.03166	 446.15339	 446.15339	 446.15339	 0.0	 0.0	 1	 -30.0	 30.0;
	6931	 1576	 0.008091	 0.03594	 0.06232	 397.810952	 397.810952	 397.810952	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 1850	 0.011031	 0.060581	 0.08626	 434.235634	 434.235634	 434.235634	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 5445	 0.01326	 0.07163	 0.10328	 428.06451	 428.06451	 428.06451	 0.0	 0.0	 1	 -30.0	 30.0;
	4612	 1672	 0.007031	 0.069341	 0.24929	 229.457969	 229.457969	 229.457969	 0.0	 0.0	 1	 -30.0	 30.0;
	4612	 5080	 0.00238	 0.031081	 0.08439	 237.061464	 237.061464	 237.061464	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 8334	 0.010831	 0.057479	 0.08699	 461.511277	 461.511277	 461.511277	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 99	 0.001849	 0.01024	 0.01488	 397.874206	 397.874206	 397.874206	 0.0	 0.0	 1	 -30.0	 30.0;
	6848	 6133	 0.017581	 0.07664	 0.13729	 504.656559	 504.656559	 504.656559	 0.0	 0.0	 1	 -30.0	 30.0;
	6848	 6133	 0.017909	 0.07501	 0.13988	 500.978653	 500.978653	 500.978653	 0.0	 0.0	 1	 -30.0	 30.0;
	6848	 5445	 0.01312	 0.05724	 0.1025	 399.633519	 399.633519	 399.633519	 0.0	 0.0	 1	 -30.0	 30.0;
	6848	 5445	 0.01337	 0.056021	 0.10444	 403.813651	 403.813651	 403.813651	 0.0	 0.0	 1	 -30.0	 30.0;
	6848	 500	 0.007961	 0.0347	 0.06213	 421.980266	 421.980266	 421.980266	 0.0	 0.0	 1	 -30.0	 30.0;
	4619	 8334	 0.01181	 0.044729	 0.09514	 392.866813	 392.866813	 392.866813	 0.0	 0.0	 1	 -30.0	 30.0;
	4619	 109	 0.00457	 0.018729	 0.03678	 314.688067	 314.688067	 314.688067	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 7457	 0.0012	 0.0141	 0.42013	 1310.534385	 1310.534385	 1310.534385	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 7457	 0.00107	 0.01598	 0.3743	 1297.304323	 1297.304323	 1297.304323	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 2662	 0.00046	 0.00666	 0.28083	 900.703243	 900.703243	 900.703243	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 2511	 0.001	 0.0181	 0.60041	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1043	 3367	 9.1e-05	 0.00139	 0.00362	 217.283003	 217.283003	 217.283003	 0.0	 0.0	 1	 -30.0	 30.0;
	1043	 3367	 0.00013	 0.00089	 0.00677	 250.361293	 250.361293	 250.361293	 0.0	 0.0	 1	 -30.0	 30.0;
	6893	 240	 0.000281	 0.001289	 0.00395	 575.360986	 575.360986	 575.360986	 0.0	 0.0	 1	 -30.0	 30.0;
	6313	 3188	 0.00119	 0.01964	 0.42295	 1120.877385	 1120.877385	 1120.877385	 0.0	 0.0	 1	 -30.0	 30.0;
	6313	 3188	 0.00117	 0.02001	 0.41395	 1189.858526	 1189.858526	 1189.858526	 0.0	 0.0	 1	 -30.0	 30.0;
	1672	 3832	 0.00238	 0.032341	 0.08398	 275.255367	 275.255367	 275.255367	 0.0	 0.0	 1	 -30.0	 30.0;
	1672	 3832	 0.002331	 0.02994	 0.08215	 348.489211	 348.489211	 348.489211	 0.0	 0.0	 1	 -30.0	 30.0;
	1672	 4405	 0.005479	 0.07155	 0.19422	 292.212144	 292.212144	 292.212144	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 240	 0.008091	 0.036841	 0.0648	 391.645544	 391.645544	 391.645544	 0.0	 0.0	 1	 -30.0	 30.0;
	5080	 4405	 0.003081	 0.03707	 0.109	 247.542277	 247.542277	 247.542277	 0.0	 0.0	 1	 -30.0	 30.0;
	5080	 500	 0.01086	 0.05936	 0.08485	 442.525783	 442.525783	 442.525783	 0.0	 0.0	 1	 -30.0	 30.0;
	2662	 869	 0.00063	 0.00975	 0.38002	 848.036393	 848.036393	 848.036393	 0.0	 0.0	 1	 -30.0	 30.0;
	8334	 7806	 0.00143	 0.025771	 0.09611	 273.521965	 273.521965	 273.521965	 0.0	 0.0	 1	 -30.0	 30.0;
	8334	 7806	 0.001401	 0.026271	 0.0941	 269.916459	 269.916459	 269.916459	 0.0	 0.0	 1	 -30.0	 30.0;
	8334	 109	 0.00631	 0.03037	 0.0508	 408.417511	 408.417511	 408.417511	 0.0	 0.0	 1	 -30.0	 30.0;
	1850	 5445	 0.00325	 0.01388	 0.02498	 414.445741	 414.445741	 414.445741	 0.0	 0.0	 1	 -30.0	 30.0;
	7806	 3367	 0.015461	 0.0828	 0.11986	 423.340237	 423.340237	 423.340237	 0.0	 0.0	 1	 -30.0	 30.0;
	7806	 3367	 0.017521	 0.08114	 0.13584	 425.536616	 425.536616	 425.536616	 0.0	 0.0	 1	 -30.0	 30.0;
	5129	 7249	 0.00036	 0.00554	 0.1258	 1545.824931	 1545.824931	 1545.824931	 0.0	 0.0	 1	 -30.0	 30.0;
	2511	 7249	 0.0018	 0.02089	 0.63352	 1651.144809	 1651.144809	 1651.144809	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 7249	 0.00183	 0.02045	 0.6457	 1639.237687	 1639.237687	 1639.237687	 0.0	 0.0	 1	 -30.0	 30.0;
	3188	 413	 0.00052	 0.01489	 0.36998	 934.470474	 934.470474	 934.470474	 0.0	 0.0	 1	 -30.0	 30.0;
	3188	 413	 0.00051	 0.01518	 0.36228	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5303	 5445	 0.020669	 0.110081	 0.16146	 363.832618	 363.832618	 363.832618	 0.0	 0.0	 1	 -30.0	 30.0;
	5303	 5445	 0.02024	 0.1122	 0.1581	 371.156803	 371.156803	 371.156803	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 240	 0.01089	 0.05145	 0.08506	 595.18746	 595.18746	 595.18746	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 240	 0.01111	 0.050401	 0.08673	 565.213974	 565.213974	 565.213974	 0.0	 0.0	 1	 -30.0	 30.0;
	2868	 1576	 0.00493	 0.026719	 0.03795	 249.659397	 249.659397	 249.659397	 0.0	 0.0	 1	 -30.0	 30.0;
	3539	 6700	 0.005169	 0.067461	 0.18294	 246.435704	 246.435704	 246.435704	 0.0	 0.0	 1	 -30.0	 30.0;
	3539	 6700	 0.00506	 0.068729	 0.17905	 245.365331	 245.365331	 245.365331	 0.0	 0.0	 1	 -30.0	 30.0;
	1742	 6238	 0.011397	 0.04438	 0.00394	 64.529493	 64.529493	 64.529493	 0.0	 0.0	 1	 -30.0	 30.0;
	1762	 7624	 0.022504	 0.082851	 0.00776	 74.8053	 74.8053	 74.8053	 0.0	 0.0	 1	 -30.0	 30.0;
	1762	 3587	 0.015793	 0.061587	 0.00526	 69.202133	 69.202133	 69.202133	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 2369	 0.012659	 0.05405	 0.10094	 391.549138	 391.549138	 391.549138	 0.0	 0.0	 1	 -30.0	 30.0;
	661	 3652	 0.016149	 0.057248	 0.00549	 65.114216	 65.114216	 65.114216	 0.0	 0.0	 1	 -30.0	 30.0;
	136	 3652	 0.038612	 0.122471	 0.01301	 76.924706	 76.924706	 76.924706	 0.0	 0.0	 1	 -30.0	 30.0;
	3652	 6517	 0.044273	 0.108959	 0.00923	 58.120212	 58.120212	 58.120212	 0.0	 0.0	 1	 -30.0	 30.0;
	8031	 5389	 0.038876	 0.139587	 0.01341	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8031	 5807	 0.10805	 0.191992	 0.02242	 75.058889	 75.058889	 75.058889	 0.0	 0.0	 1	 -30.0	 30.0;
	2813	 8031	 0.035802	 0.084231	 0.00743	 79.449742	 79.449742	 79.449742	 0.0	 0.0	 1	 -30.0	 30.0;
	3074	 4700	 0.00614	 0.02205	 0.00212	 137.18776	 137.18776	 137.18776	 0.0	 0.0	 1	 -30.0	 30.0;
	3074	 5560	 0.003587	 0.01395	 0.00124	 61.674086	 61.674086	 61.674086	 0.0	 0.0	 1	 -30.0	 30.0;
	4700	 7047	 0.019554	 0.05981	 0.00675	 96.392611	 96.392611	 96.392611	 0.0	 0.0	 1	 -30.0	 30.0;
	5560	 3012	 0.038066	 0.142281	 0.01313	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2452	 3938	 0.007421	 0.02181	 0.00257	 58.228812	 58.228812	 58.228812	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 7411	 0.007562	 0.021339	 0.00261	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2452	 6885	 0.007388	 0.026537	 0.00255	 85.408049	 85.408049	 85.408049	 0.0	 0.0	 1	 -30.0	 30.0;
	6885	 1526	 0.00724	 0.02705	 0.0025	 58.759806	 58.759806	 58.759806	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 6427	 0.004893	 0.018273	 0.00081	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6427	 5039	 0.004777	 0.018612	 0.00079	 70.148283	 70.148283	 70.148283	 0.0	 0.0	 1	 -30.0	 30.0;
	2452	 5757	 0.015289	 0.041463	 0.00528	 69.577087	 69.577087	 69.577087	 0.0	 0.0	 1	 -30.0	 30.0;
	2452	 5757	 0.01143	 0.042091	 0.00394	 69.377797	 69.377797	 69.377797	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 2452	 0.006793	 0.014182	 0.00141	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5039	 2452	 0.012967	 0.048471	 0.00447	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5571	 5757	 0.009281	 0.029554	 0.0032	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5610	 5757	 0.041248	 0.116479	 0.01423	 78.907316	 78.907316	 78.907316	 0.0	 0.0	 1	 -30.0	 30.0;
	3459	 5757	 0.071479	 0.137678	 0.01483	 78.617717	 78.617717	 78.617717	 0.0	 0.0	 1	 -30.0	 30.0;
	2110	 5757	 0.020612	 0.075893	 0.00711	 57.187399	 57.187399	 57.187399	 0.0	 0.0	 1	 -30.0	 30.0;
	5757	 465	 0.05214	 0.100421	 0.01081	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4336	 5757	 0.047942	 0.179157	 0.01654	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6584	 2275	 0.0016	 0.01402	 0.37663	 1148.984932	 1148.984932	 1148.984932	 0.0	 0.0	 1	 -30.0	 30.0;
	5361	 5571	 0.009149	 0.027992	 0.13951	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7819	 5361	 0.031107	 0.116281	 0.01073	 83.559379	 83.559379	 83.559379	 0.0	 0.0	 1	 -30.0	 30.0;
	7819	 5039	 0.026463	 0.091273	 0.00855	 64.756599	 64.756599	 64.756599	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 7819	 0.023562	 0.075017	 0.00813	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 7819	 0.015702	 0.050017	 0.00542	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3993	 3012	 0.004802	 0.017231	 0.00166	 78.514261	 78.514261	 78.514261	 0.0	 0.0	 1	 -30.0	 30.0;
	3993	 1108	 0.065579	 0.208826	 0.02263	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3993	 3171	 0.049917	 0.112843	 0.01036	 58.159841	 58.159841	 58.159841	 0.0	 0.0	 1	 -30.0	 30.0;
	3993	 120	 0.047793	 0.095603	 0.00988	 67.898747	 67.898747	 67.898747	 0.0	 0.0	 1	 -30.0	 30.0;
	6697	 3012	 0.043421	 0.168942	 0.01498	 83.343514	 83.343514	 83.343514	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 3012	 0.029364	 0.093017	 0.01064	 91.217555	 91.217555	 91.217555	 0.0	 0.0	 1	 -30.0	 30.0;
	2640	 3477	 0.023521	 0.086562	 0.00811	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	884	 3477	 0.017909	 0.058463	 0.00617	 59.859711	 59.859711	 59.859711	 0.0	 0.0	 1	 -30.0	 30.0;
	3420	 483	 0.008198	 0.030248	 0.00279	 64.080995	 64.080995	 64.080995	 0.0	 0.0	 1	 -30.0	 30.0;
	483	 2824	 0.015579	 0.053744	 0.00538	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	483	 5448	 0.030471	 0.09738	 0.01017	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2545	 483	 0.017157	 0.066	 0.00573	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1158	 4099	 0.017628	 0.065868	 0.00608	 72.883468	 72.883468	 72.883468	 0.0	 0.0	 1	 -30.0	 30.0;
	1158	 4705	 0.022686	 0.072273	 0.00782	 86.674663	 86.674663	 86.674663	 0.0	 0.0	 1	 -30.0	 30.0;
	2021	 3921	 0.010322	 0.03719	 0.00344	 61.28046	 61.28046	 61.28046	 0.0	 0.0	 1	 -30.0	 30.0;
	3921	 6831	 0.010802	 0.038281	 0.00368	 71.135586	 71.135586	 71.135586	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 6517	 0.019298	 0.073041	 0.00656	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2920	 4532	 0.011678	 0.035273	 0.00398	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 4099	 0.019719	 0.057256	 0.00672	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	155	 661	 0.026421	 0.086471	 0.009	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7411	 1753	 0.014281	 0.045471	 0.00493	 63.000144	 63.000144	 63.000144	 0.0	 0.0	 1	 -30.0	 30.0;
	884	 6382	 0.004529	 0.013686	 0.00154	 114.101584	 114.101584	 114.101584	 0.0	 0.0	 1	 -30.0	 30.0;
	6382	 6831	 0.014603	 0.058463	 0.00498	 81.179333	 81.179333	 81.179333	 0.0	 0.0	 1	 -30.0	 30.0;
	6098	 5067	 0.007702	 0.020876	 0.00265	 98.486678	 98.486678	 98.486678	 0.0	 0.0	 1	 -30.0	 30.0;
	6098	 3149	 0.010281	 0.03957	 0.00343	 128.306409	 128.306409	 128.306409	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 4607	 0.00686	 0.023661	 0.00236	 72.529472	 72.529472	 72.529472	 0.0	 0.0	 1	 -30.0	 30.0;
	3420	 4613	 0.02457	 0.09557	 0.00847	 73.239561	 73.239561	 73.239561	 0.0	 0.0	 1	 -30.0	 30.0;
	15	 1108	 0.03024	 0.085372	 0.01043	 69.082864	 69.082864	 69.082864	 0.0	 0.0	 1	 -30.0	 30.0;
	15	 6697	 0.04157	 0.14924	 0.01433	 111.668	 111.668	 111.668	 0.0	 0.0	 1	 -30.0	 30.0;
	5472	 15	 0.028132	 0.097008	 0.0097	 61.036968	 61.036968	 61.036968	 0.0	 0.0	 1	 -30.0	 30.0;
	15	 7861	 0.038661	 0.123091	 0.01334	 74.617251	 74.617251	 74.617251	 0.0	 0.0	 1	 -30.0	 30.0;
	1187	 7907	 0.019364	 0.077413	 0.00659	 59.753778	 59.753778	 59.753778	 0.0	 0.0	 1	 -30.0	 30.0;
	7907	 3587	 0.009562	 0.036182	 0.00325	 80.66701	 80.66701	 80.66701	 0.0	 0.0	 1	 -30.0	 30.0;
	6584	 5103	 0.00147	 0.01643	 0.34292	 1442.728382	 1442.728382	 1442.728382	 0.0	 0.0	 1	 -30.0	 30.0;
	636	 5640	 0.005719	 0.016826	 0.00197	 74.640495	 74.640495	 74.640495	 0.0	 0.0	 1	 -30.0	 30.0;
	5640	 8328	 0.007843	 0.027041	 0.0027	 77.078461	 77.078461	 77.078461	 0.0	 0.0	 1	 -30.0	 30.0;
	5640	 1175	 0.016826	 0.045628	 0.00581	 59.369869	 59.369869	 59.369869	 0.0	 0.0	 1	 -30.0	 30.0;
	5640	 2008	 0.02238	 0.062777	 0.00756	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1108	 636	 0.012959	 0.041248	 0.00447	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8328	 3994	 0.004702	 0.017562	 0.00162	 70.942203	 70.942203	 70.942203	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 8328	 0.023331	 0.080446	 0.00816	 72.875847	 72.875847	 72.875847	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 884	 0.00505	 0.018653	 0.00172	 58.805723	 58.805723	 58.805723	 0.0	 0.0	 1	 -30.0	 30.0;
	3967	 1362	 0.008562	 0.025686	 0.00265	 58.152601	 58.152601	 58.152601	 0.0	 0.0	 1	 -30.0	 30.0;
	3172	 2687	 0.026124	 0.083149	 0.00901	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2687	 4336	 0.02038	 0.04605	 0.00422	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7007	 5987	 0.000169	 0.00106	 0.00342	 305.351551	 305.351551	 305.351551	 0.0	 0.0	 1	 -30.0	 30.0;
	874	 7007	 0.00043	 0.003901	 0.00876	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7229	 4212	 0.005298	 0.021	 0.00183	 76.280539	 76.280539	 76.280539	 0.0	 0.0	 1	 -30.0	 30.0;
	4212	 6610	 0.001322	 0.004289	 0.00045	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 1015	 0.005471	 0.016554	 0.00186	 61.963685	 61.963685	 61.963685	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 4440	 0.022198	 0.064653	 0.00753	 74.807777	 74.807777	 74.807777	 0.0	 0.0	 1	 -30.0	 30.0;
	4357	 2503	 0.027653	 0.099256	 0.00954	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2378	 4357	 0.044099	 0.152107	 0.01521	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2722	 2881	 0.017603	 0.047711	 0.0607	 69.096582	 69.096582	 69.096582	 0.0	 0.0	 1	 -30.0	 30.0;
	2722	 3967	 0.024198	 0.06562	 0.00835	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7586	 3296	 0.00165	 0.01428	 0.38483	 1309.662297	 1309.662297	 1309.662297	 0.0	 0.0	 1	 -30.0	 30.0;
	6604	 7586	 0.00131	 0.01467	 0.3032	 1167.85954	 1167.85954	 1167.85954	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 8117	 0.040802	 0.129909	 0.01407	 78.285631	 78.285631	 78.285631	 0.0	 0.0	 1	 -30.0	 30.0;
	856	 2503	 0.005058	 0.019686	 0.00175	 82.329727	 82.329727	 82.329727	 0.0	 0.0	 1	 -30.0	 30.0;
	2503	 1262	 0.075521	 0.145463	 0.01567	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	856	 4726	 0.024033	 0.088488	 0.00829	 74.64964	 74.64964	 74.64964	 0.0	 0.0	 1	 -30.0	 30.0;
	6866	 4489	 0.001599	 0.007401	 0.01272	 439.166817	 439.166817	 439.166817	 0.0	 0.0	 1	 -30.0	 30.0;
	1175	 7624	 0.025289	 0.082934	 0.00861	 92.115121	 92.115121	 92.115121	 0.0	 0.0	 1	 -30.0	 30.0;
	8018	 6697	 0.012421	 0.035058	 0.00429	 100.712969	 100.712969	 100.712969	 0.0	 0.0	 1	 -30.0	 30.0;
	2942	 2483	 0.00855	 0.03774	 0.06864	 470.086834	 470.086834	 470.086834	 0.0	 0.0	 1	 -30.0	 30.0;
	5610	 4735	 0.010686	 0.03019	 0.00369	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3801	 5603	 0.010331	 0.03438	 0.00345	 80.441999	 80.441999	 80.441999	 0.0	 0.0	 1	 -30.0	 30.0;
	5603	 5937	 0.01581	 0.050339	 0.00546	 67.980673	 67.980673	 67.980673	 0.0	 0.0	 1	 -30.0	 30.0;
	7229	 4440	 0.005661	 0.022744	 0.00192	 61.049543	 61.049543	 61.049543	 0.0	 0.0	 1	 -30.0	 30.0;
	5294	 7610	 0.000636	 0.002512	 0.00023	 60.372796	 60.372796	 60.372796	 0.0	 0.0	 1	 -30.0	 30.0;
	3587	 5294	 0.005281	 0.017521	 0.00175	 77.983648	 77.983648	 77.983648	 0.0	 0.0	 1	 -30.0	 30.0;
	5294	 2556	 0.002826	 0.00781	 0.04179	 74.89237	 74.89237	 74.89237	 0.0	 0.0	 1	 -30.0	 30.0;
	1015	 4545	 0.018066	 0.056876	 0.00615	 65.016476	 65.016476	 65.016476	 0.0	 0.0	 1	 -30.0	 30.0;
	4545	 4705	 0.038537	 0.144033	 0.01329	 79.822791	 79.822791	 79.822791	 0.0	 0.0	 1	 -30.0	 30.0;
	4545	 1137	 0.049669	 0.141083	 0.01734	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4545	 6610	 0.058628	 0.17286	 0.02053	 73.927548	 73.927548	 73.927548	 0.0	 0.0	 1	 -30.0	 30.0;
	4545	 5494	 0.00043	 0.001273	 0.00014	 65.511843	 65.511843	 65.511843	 0.0	 0.0	 1	 -30.0	 30.0;
	4545	 6256	 0.025917	 0.093058	 0.00894	 78.440719	 78.440719	 78.440719	 0.0	 0.0	 1	 -30.0	 30.0;
	1583	 3801	 0.02295	 0.065	 0.00766	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5422	 4705	 0.001504	 0.00486	 0.00051	 71.038609	 71.038609	 71.038609	 0.0	 0.0	 1	 -30.0	 30.0;
	5422	 4705	 0.002182	 0.006678	 0.00075	 61.359147	 61.359147	 61.359147	 0.0	 0.0	 1	 -30.0	 30.0;
	3093	 874	 0.002979	 0.02218	 0.06106	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3093	 874	 0.003021	 0.022531	 0.06192	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 3680	 0.020843	 0.058843	 0.00719	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4613	 367	 0.009331	 0.027413	 0.00321	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 6272	 0.009182	 0.024769	 0.00314	 58.225763	 58.225763	 58.225763	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 318	 0.00275	 0.01488	 0.02254	 477.954397	 477.954397	 477.954397	 0.0	 0.0	 1	 -30.0	 30.0;
	6065	 2720	 0.0001	 0.00082	 0.02422	 1172.274607	 1172.274607	 1172.274607	 0.0	 0.0	 1	 -30.0	 30.0;
	5379	 874	 0.01476	 0.08713	 0.1124	 360.433642	 360.433642	 360.433642	 0.0	 0.0	 1	 -30.0	 30.0;
	5379	 4489	 0.00212	 0.011469	 0.0168	 409.642591	 409.642591	 409.642591	 0.0	 0.0	 1	 -30.0	 30.0;
	6610	 5980	 0.013521	 0.049959	 0.00461	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5980	 884	 0.017793	 0.07124	 0.00607	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7809	 2369	 0.01481	 0.086021	 0.1188	 427.409483	 427.409483	 427.409483	 0.0	 0.0	 1	 -30.0	 30.0;
	4489	 7809	 0.01686	 0.07207	 0.13497	 471.902924	 471.902924	 471.902924	 0.0	 0.0	 1	 -30.0	 30.0;
	6831	 5137	 0.012331	 0.034413	 0.00419	 75.05203	 75.05203	 75.05203	 0.0	 0.0	 1	 -30.0	 30.0;
	5215	 5137	 0.000777	 0.00276	 0.00026	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 136	 0.028421	 0.08657	 0.00957	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1753	 4200	 0.023521	 0.081132	 0.00811	 60.678208	 60.678208	 60.678208	 0.0	 0.0	 1	 -30.0	 30.0;
	3251	 2375	 0.000901	 0.005	 0.01242	 446.593504	 446.593504	 446.593504	 0.0	 0.0	 1	 -30.0	 30.0;
	2375	 2817	 0.00263	 0.01551	 0.02542	 430.340147	 430.340147	 430.340147	 0.0	 0.0	 1	 -30.0	 30.0;
	6508	 2892	 0.017463	 0.071669	 0.00662	 76.347604	 76.347604	 76.347604	 0.0	 0.0	 1	 -30.0	 30.0;
	6508	 7988	 0.016826	 0.065512	 0.00581	 81.993068	 81.993068	 81.993068	 0.0	 0.0	 1	 -30.0	 30.0;
	2881	 3510	 0.019587	 0.076612	 0.00654	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1256	 1187	 0.022537	 0.071769	 0.00778	 66.284424	 66.284424	 66.284424	 0.0	 0.0	 1	 -30.0	 30.0;
	2920	 155	 0.013256	 0.04005	 0.0045	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6577	 2930	 0.046397	 0.13586	 0.01564	 67.644586	 67.644586	 67.644586	 0.0	 0.0	 1	 -30.0	 30.0;
	6577	 518	 0.026471	 0.105893	 0.00901	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7759	 6564	 0.025504	 0.08119	 0.00879	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 7759	 0.027603	 0.10738	 0.00952	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6517	 3459	 0.084843	 0.156942	 0.0176	 60.516452	 60.516452	 60.516452	 0.0	 0.0	 1	 -30.0	 30.0;
	4760	 2824	 0.030521	 0.115653	 0.01065	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1526	 7286	 0.004	 0.010851	 0.00138	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7286	 4735	 0.016017	 0.043421	 0.00552	 61.223493	 61.223493	 61.223493	 0.0	 0.0	 1	 -30.0	 30.0;
	4760	 1742	 0.027091	 0.087488	 0.00947	 63.818261	 63.818261	 63.818261	 0.0	 0.0	 1	 -30.0	 30.0;
	6727	 6293	 0.02243	 0.047793	 0.00532	 61.138709	 61.138709	 61.138709	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 6293	 0.016851	 0.051537	 0.00581	 59.512001	 59.512001	 59.512001	 0.0	 0.0	 1	 -30.0	 30.0;
	7610	 7624	 0.01638	 0.053901	 0.00557	 82.018599	 82.018599	 82.018599	 0.0	 0.0	 1	 -30.0	 30.0;
	7610	 7624	 0.012298	 0.045521	 0.00417	 88.183435	 88.183435	 88.183435	 0.0	 0.0	 1	 -30.0	 30.0;
	7624	 6229	 0.025017	 0.048653	 0.00525	 69.526217	 69.526217	 69.526217	 0.0	 0.0	 1	 -30.0	 30.0;
	3149	 8092	 0.00186	 0.007174	 0.00063	 79.67742	 79.67742	 79.67742	 0.0	 0.0	 1	 -30.0	 30.0;
	2698	 8092	 0.001397	 0.005372	 0.00047	 62.076476	 62.076476	 62.076476	 0.0	 0.0	 1	 -30.0	 30.0;
	2008	 3994	 0.010777	 0.043479	 0.00362	 61.967114	 61.967114	 61.967114	 0.0	 0.0	 1	 -30.0	 30.0;
	5788	 2008	 0.016413	 0.047628	 0.00558	 62.20108	 62.20108	 62.20108	 0.0	 0.0	 1	 -30.0	 30.0;
	1319	 5007	 0.004	 0.011281	 0.00138	 60.014798	 60.014798	 60.014798	 0.0	 0.0	 1	 -30.0	 30.0;
	4705	 5007	 0.004041	 0.015099	 0.00139	 79.899192	 79.899192	 79.899192	 0.0	 0.0	 1	 -30.0	 30.0;
	3149	 7655	 0.004636	 0.017579	 0.00158	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7655	 4705	 0.006529	 0.025091	 0.00222	 86.834133	 86.834133	 86.834133	 0.0	 0.0	 1	 -30.0	 30.0;
	5937	 3149	 0.01781	 0.052339	 0.00614	 85.656875	 85.656875	 85.656875	 0.0	 0.0	 1	 -30.0	 30.0;
	1319	 2698	 0.003744	 0.010149	 0.00129	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 4705	 0.006248	 0.023702	 0.00212	 72.839647	 72.839647	 72.839647	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 5807	 0.035107	 0.106207	 0.01201	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 8147	 0.014769	 0.045182	 0.0051	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 3088	 0.004322	 0.012198	 0.00149	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 6256	 0.015678	 0.054083	 0.00541	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	30	 8018	 0.011331	 0.023636	 0.00236	 83.343514	 83.343514	 83.343514	 0.0	 0.0	 1	 -30.0	 30.0;
	874	 5987	 0.000591	 0.002969	 0.00473	 403.533578	 403.533578	 403.533578	 0.0	 0.0	 1	 -30.0	 30.0;
	874	 5987	 0.000281	 0.0025	 0.00587	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4489	 5987	 0.00781	 0.039159	 0.06232	 373.547899	 373.547899	 373.547899	 0.0	 0.0	 1	 -30.0	 30.0;
	5987	 1026	 0.00419	 0.02431	 0.03336	 431.73289	 431.73289	 431.73289	 0.0	 0.0	 1	 -30.0	 30.0;
	318	 5987	 0.014479	 0.06989	 0.11605	 389.805447	 389.805447	 389.805447	 0.0	 0.0	 1	 -30.0	 30.0;
	318	 5987	 0.013419	 0.07594	 0.10737	 402.963526	 402.963526	 402.963526	 0.0	 0.0	 1	 -30.0	 30.0;
	3296	 3664	 0.00208	 0.02183	 0.48327	 1080.924585	 1080.924585	 1080.924585	 0.0	 0.0	 1	 -30.0	 30.0;
	6564	 3459	 0.028083	 0.103397	 0.00968	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5448	 2021	 0.005793	 0.017802	 0.00193	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8117	 8147	 0.016124	 0.049322	 0.00555	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	30	 3171	 0.018471	 0.041802	 0.00384	 67.397474	 67.397474	 67.397474	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 974	 0.031719	 0.066198	 0.00658	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	188	 1583	 0.017554	 0.056124	 0.00587	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 1137	 0.011207	 0.037917	 0.11382	 71.077095	 71.077095	 71.077095	 0.0	 0.0	 1	 -30.0	 30.0;
	2369	 3251	 0.02261	 0.105521	 0.32503	 240.347268	 240.347268	 240.347268	 0.0	 0.0	 1	 -30.0	 30.0;
	3459	 4488	 0.002397	 0.013603	 0.00114	 64.949792	 64.949792	 64.949792	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 465	 0.021901	 0.055818	 0.00454	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3172	 3459	 0.007719	 0.030066	 0.00267	 73.404365	 73.404365	 73.404365	 0.0	 0.0	 1	 -30.0	 30.0;
	3459	 2110	 0.017711	 0.05	 0.00611	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	518	 3459	 0.035322	 0.070802	 0.00733	 73.218984	 73.218984	 73.218984	 0.0	 0.0	 1	 -30.0	 30.0;
	4200	 5472	 0.017281	 0.050777	 0.00596	 68.152718	 68.152718	 68.152718	 0.0	 0.0	 1	 -30.0	 30.0;
	4182	 4760	 0.04324	 0.168223	 0.01492	 72.276644	 72.276644	 72.276644	 0.0	 0.0	 1	 -30.0	 30.0;
	5494	 4182	 0.022678	 0.082017	 0.00788	 81.094168	 81.094168	 81.094168	 0.0	 0.0	 1	 -30.0	 30.0;
	4182	 2545	 0.026	 0.079537	 0.00896	 61.620548	 61.620548	 61.620548	 0.0	 0.0	 1	 -30.0	 30.0;
	4907	 6259	 0.027347	 0.080372	 0.00943	 61.706094	 61.706094	 61.706094	 0.0	 0.0	 1	 -30.0	 30.0;
	4726	 4907	 0.023364	 0.074372	 0.00806	 67.956095	 67.956095	 67.956095	 0.0	 0.0	 1	 -30.0	 30.0;
	7777	 2813	 0.011421	 0.02757	 0.00237	 86.084224	 86.084224	 86.084224	 0.0	 0.0	 1	 -30.0	 30.0;
	4489	 3251	 0.011039	 0.047169	 0.08828	 362.83655	 362.83655	 362.83655	 0.0	 0.0	 1	 -30.0	 30.0;
	1026	 3251	 0.015159	 0.0732	 0.12146	 399.369832	 399.369832	 399.369832	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 3251	 0.00119	 0.005729	 0.00946	 392.050982	 392.050982	 392.050982	 0.0	 0.0	 1	 -30.0	 30.0;
	6980	 3251	 0.00182	 0.060349	 0.09625	 316.709162	 316.709162	 316.709162	 0.0	 0.0	 1	 -30.0	 30.0;
	6610	 3510	 0.00795	 0.032132	 0.00267	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	773	 6610	 0.006372	 0.021934	 0.00202	 73.057799	 73.057799	 73.057799	 0.0	 0.0	 1	 -30.0	 30.0;
	2378	 6610	 0.015992	 0.036041	 0.00977	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6610	 3967	 0.022843	 0.087157	 0.00773	 62.673773	 62.673773	 62.673773	 0.0	 0.0	 1	 -30.0	 30.0;
	6887	 2640	 0.00495	 0.014942	 0.00169	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	974	 6887	 0.000901	 0.00238	 0.0134	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 6887	 0.008942	 0.027339	 0.00301	 58.623581	 58.623581	 58.623581	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 2640	 0.00476	 0.017587	 0.0016	 57.754403	 57.754403	 57.754403	 0.0	 0.0	 1	 -30.0	 30.0;
	6259	 2640	 0.037339	 0.128802	 0.01289	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	974	 4462	 0.00081	 0.00219	 0.01251	 81.155899	 81.155899	 81.155899	 0.0	 0.0	 1	 -30.0	 30.0;
	974	 4043	 0.005132	 0.018438	 0.00177	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3977	 3510	 0.005934	 0.023107	 0.00207	 74.070824	 74.070824	 74.070824	 0.0	 0.0	 1	 -30.0	 30.0;
	3977	 3510	 0.005802	 0.021397	 0.00203	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3977	 205	 0.000463	 0.001421	 0.00675	 71.2419	 71.2419	 71.2419	 0.0	 0.0	 1	 -30.0	 30.0;
	3977	 5525	 0.000909	 0.002521	 0.0069	 74.387668	 74.387668	 74.387668	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 4043	 0.009347	 0.025364	 0.00322	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8326	 4462	 0.00062	 0.002017	 0.00979	 76.910989	 76.910989	 76.910989	 0.0	 0.0	 1	 -30.0	 30.0;
	205	 8326	 0.000917	 0.002364	 0.01364	 58.602242	 58.602242	 58.602242	 0.0	 0.0	 1	 -30.0	 30.0;
	8326	 2378	 0.009248	 0.016446	 0.00193	 72.799637	 72.799637	 72.799637	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 2421	 0.00295	 0.008	 0.00103	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2378	 5525	 0.003339	 0.012612	 0.00118	 73.415987	 73.415987	 73.415987	 0.0	 0.0	 1	 -30.0	 30.0;
	2378	 2421	 0.00319	 0.012504	 0.00112	 65.225102	 65.225102	 65.225102	 0.0	 0.0	 1	 -30.0	 30.0;
	773	 2378	 0.007826	 0.030521	 0.0027	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6445	 3664	 0.00063	 0.00702	 0.14912	 1002.361012	 1002.361012	 1002.361012	 0.0	 0.0	 1	 -30.0	 30.0;
	3664	 5103	 0.00184	 0.02018	 0.42835	 1097.322464	 1097.322464	 1097.322464	 0.0	 0.0	 1	 -30.0	 30.0;
	1321	 5513	 0.003818	 0.010661	 0.0013	 85.476829	 85.476829	 85.476829	 0.0	 0.0	 1	 -30.0	 30.0;
	6831	 1321	 0.008678	 0.025198	 0.00296	 83.875461	 83.875461	 83.875461	 0.0	 0.0	 1	 -30.0	 30.0;
	5215	 1321	 0.008843	 0.024661	 0.003	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	120	 6229	 0.023347	 0.041909	 0.00491	 63.368049	 63.368049	 63.368049	 0.0	 0.0	 1	 -30.0	 30.0;
	7861	 4735	 0.018091	 0.055347	 0.00624	 60.726793	 60.726793	 60.726793	 0.0	 0.0	 1	 -30.0	 30.0;
	6580	 1256	 0.03443	 0.093347	 0.01187	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6580	 7988	 0.041033	 0.111248	 0.01415	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7436	 6998	 0.015843	 0.05686	 0.00546	 62.290055	 62.290055	 62.290055	 0.0	 0.0	 1	 -30.0	 30.0;
	4200	 7436	 0.020397	 0.064959	 0.00704	 79.002579	 79.002579	 79.002579	 0.0	 0.0	 1	 -30.0	 30.0;
	188	 4760	 0.017893	 0.054959	 0.00598	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	884	 5513	 0.029496	 0.09295	 0.01005	 71.399845	 71.399845	 71.399845	 0.0	 0.0	 1	 -30.0	 30.0;
	8375	 7610	 0.011579	 0.046397	 0.00395	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6980	 2942	 0.00099	 0.0042	 0.00784	 397.419231	 397.419231	 397.419231	 0.0	 0.0	 1	 -30.0	 30.0;
	6980	 2942	 0.00076	 0.00449	 0.00607	 395.07005	 395.07005	 395.07005	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 1300	 0.006587	 0.016868	 0.00139	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1300	 5513	 0.016876	 0.064909	 0.00574	 63.011385	 63.011385	 63.011385	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 4613	 0.036612	 0.115372	 0.01248	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2892	 3587	 0.009421	 0.030826	 0.0032	 91.936789	 91.936789	 91.936789	 0.0	 0.0	 1	 -30.0	 30.0;
	8375	 3587	 0.008041	 0.030438	 0.00274	 82.392981	 82.392981	 82.392981	 0.0	 0.0	 1	 -30.0	 30.0;
	4613	 6272	 0.000744	 0.002182	 0.00025	 72.869179	 72.869179	 72.869179	 0.0	 0.0	 1	 -30.0	 30.0;
	6980	 3965	 0.000901	 0.003979	 0.00712	 218.266496	 218.266496	 218.266496	 0.0	 0.0	 1	 -30.0	 30.0;
	6980	 2817	 0.01212	 0.05176	 0.09653	 385.759065	 385.759065	 385.759065	 0.0	 0.0	 1	 -30.0	 30.0;
	6065	 5103	 0.00256	 0.02765	 0.62005	 1327.50488	 1327.50488	 1327.50488	 0.0	 0.0	 1	 -30.0	 30.0;
	2556	 6727	 0.00224	 0.007256	 0.03306	 78.828057	 78.828057	 78.828057	 0.0	 0.0	 1	 -30.0	 30.0;
	8075	 5103	 0.0009	 0.00943	 0.20859	 1327.081013	 1327.081013	 1327.081013	 0.0	 0.0	 1	 -30.0	 30.0;
	2892	 8375	 0.007744	 0.024273	 0.00265	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6727	 8375	 0.006372	 0.017992	 0.0022	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7988	 7047	 0.048554	 0.142669	 0.01675	 83.027813	 83.027813	 83.027813	 0.0	 0.0	 1	 -30.0	 30.0;
	3088	 8147	 0.010802	 0.030488	 0.00373	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5788	 4162	 0.015496	 0.047397	 0.01394	 58.897747	 58.897747	 58.897747	 0.0	 0.0	 1	 -30.0	 30.0;
	6831	 5513	 0.010207	 0.030826	 0.00348	 63.697277	 63.697277	 63.697277	 0.0	 0.0	 1	 -30.0	 30.0;
	5513	 4162	 0.026504	 0.077876	 0.00914	 79.850227	 79.850227	 79.850227	 0.0	 0.0	 1	 -30.0	 30.0;
	2816	 596	 0.00073	 0.00905	 0.18786	 1213.79914	 1213.79914	 1213.79914	 0.0	 0.0	 1	 -30.0	 30.0;
	8195	 4483	 0.00192	 0.02296	 0.54388	 904.693784	 904.693784	 904.693784	 0.0	 0.0	 1	 -30.0	 30.0;
	1659	 5933	 0.01431	 0.05899	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5933	 1313	 0.02607	 0.07168	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5509	 6199	 0.00054	 0.00465	 0.13926	 1612.274056	 1612.274056	 1612.274056	 0.0	 0.0	 1	 -30.0	 30.0;
	5509	 2063	 0.00126	 0.01124	 0.32378	 1613.438375	 1613.438375	 1613.438375	 0.0	 0.0	 1	 -30.0	 30.0;
	5509	 6511	 0.00048	 0.00527	 0.12407	 1550.584884	 1550.584884	 1550.584884	 0.0	 0.0	 1	 -30.0	 30.0;
	5509	 5709	 0.00082	 0.00938	 0.20371	 1605.24141	 1605.24141	 1605.24141	 0.0	 0.0	 1	 -30.0	 30.0;
	1798	 8341	 0.00028	 0.003502	 0.0	 178.878846	 178.878846	 178.878846	 0.0	 0.0	 1	 -30.0	 30.0;
	1798	 3174	 0.691467	 4.414711	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1798	 866	 0.02004	 0.0916	 0.0	 122.174274	 122.174274	 122.174274	 0.0	 0.0	 1	 -30.0	 30.0;
	1798	 207	 0.841911	 4.768444	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1798	 6192	 0.026	 0.08948	 0.0	 110.329385	 110.329385	 110.329385	 0.0	 0.0	 1	 -30.0	 30.0;
	1798	 8139	 0.002631	 0.011889	 0.0	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	1798	 5242	 0.7232	 1.944	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8341	 866	 0.156169	 0.546756	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8341	 6192	 0.168809	 0.580622	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8341	 8139	 0.019222	 0.068209	 0.0	 118.133226	 118.133226	 118.133226	 0.0	 0.0	 1	 -30.0	 30.0;
	7775	 1473	 0.00039	 0.00386	 0.07949	 1445.705327	 1445.705327	 1445.705327	 0.0	 0.0	 1	 -30.0	 30.0;
	7775	 1058	 0.00096	 0.01138	 0.24684	 1478.731449	 1478.731449	 1478.731449	 0.0	 0.0	 1	 -30.0	 30.0;
	7775	 8231	 0.00037	 0.00325	 0.09724	 1441.539052	 1441.539052	 1441.539052	 0.0	 0.0	 1	 -30.0	 30.0;
	7775	 8099	 0.00029	 0.00339	 0.07351	 1587.367234	 1587.367234	 1587.367234	 0.0	 0.0	 1	 -30.0	 30.0;
	3174	 2089	 0.009458	 0.158871	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 4028	 0.0	 0.000222	 0.0	 136.284686	 136.284686	 136.284686	 0.0	 0.0	 1	 -30.0	 30.0;
	6192	 2089	 0.312951	 7.130667	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6862	 2089	 0.247649	 1.075911	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 2089	 0.06056	 0.18612	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7555	 2089	 2.142489	 4.347733	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4687	 2089	 0.07132	 1.068889	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	246	 2089	 0.02268	 0.08652	 0.0	 109.652326	 109.652326	 109.652326	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 2089	 2.007778	 4.494222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4239	 2089	 0.006178	 0.028938	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4091	 2089	 0.027711	 0.260951	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3174	 5074	 0.0	 0.000222	 0.0	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	4172	 3174	 0.00692	 0.337378	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	207	 3174	 0.025991	 0.10048	 0.0	 145.747139	 145.747139	 145.747139	 0.0	 0.0	 1	 -30.0	 30.0;
	6192	 3174	 0.083711	 0.8648	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6862	 3174	 0.447378	 1.862089	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 3174	 0.062169	 0.153191	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7555	 3174	 2.492533	 4.725778	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4687	 3174	 0.020271	 0.08244	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	246	 3174	 0.11416	 1.777556	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5242	 3174	 0.574978	 2.992578	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 3174	 1.887067	 4.964444	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4239	 3174	 0.250778	 0.817422	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4091	 3174	 0.007049	 0.029609	 0.0	 132.075542	 132.075542	 132.075542	 0.0	 0.0	 1	 -30.0	 30.0;
	5074	 4172	 0.003049	 0.020218	 0.00658	 118.157908	 118.157908	 118.157908	 0.0	 0.0	 1	 -30.0	 30.0;
	4028	 4172	 0.002911	 0.020262	 0.00658	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4483	 2601	 4e-05	 0.00041	 0.01232	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4483	 596	 0.00087	 0.01087	 0.21786	 1313.028226	 1313.028226	 1313.028226	 0.0	 0.0	 1	 -30.0	 30.0;
	4483	 945	 4e-05	 0.00046	 0.01098	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4483	 596	 0.00095	 0.00924	 0.25272	 1493.442414	 1493.442414	 1493.442414	 0.0	 0.0	 1	 -30.0	 30.0;
	1659	 4738	 0.528017	 2.636157	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1659	 1313	 0.032031	 0.128659	 0.0	 249.138881	 249.138881	 249.138881	 0.0	 0.0	 1	 -30.0	 30.0;
	1473	 7041	 0.00044	 0.0032	 0.09137	 1654.215874	 1654.215874	 1654.215874	 0.0	 0.0	 1	 -30.0	 30.0;
	1473	 2282	 0.00046	 0.00489	 0.11819	 1742.565257	 1742.565257	 1742.565257	 0.0	 0.0	 1	 -30.0	 30.0;
	8231	 7041	 0.0003	 0.00352	 0.07776	 1581.438355	 1581.438355	 1581.438355	 0.0	 0.0	 1	 -30.0	 30.0;
	8231	 78	 0.00051	 0.00454	 0.13025	 1654.5318	 1654.5318	 1654.5318	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 596	 0.00068	 0.00746	 0.17522	 1625.483714	 1625.483714	 1625.483714	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 7802	 0.00093	 0.01022	 0.2401	 1761.39445	 1761.39445	 1761.39445	 0.0	 0.0	 1	 -30.0	 30.0;
	7802	 1244	 4e-05	 0.0004	 0.00941	 1507.923017	 1507.923017	 1507.923017	 0.0	 0.0	 1	 -30.0	 30.0;
	7802	 8099	 0.00078	 0.00698	 0.20002	 1770.56223	 1770.56223	 1770.56223	 0.0	 0.0	 1	 -30.0	 30.0;
	1058	 1528	 4e-05	 0.00043	 0.0094	 1592.285808	 1592.285808	 1592.285808	 0.0	 0.0	 1	 -30.0	 30.0;
	1058	 6395	 0.00025	 0.00309	 0.06458	 1690.571066	 1690.571066	 1690.571066	 0.0	 0.0	 1	 -30.0	 30.0;
	825	 7041	 0.00047	 0.00538	 0.12192	 1639.197538	 1639.197538	 1639.197538	 0.0	 0.0	 1	 -30.0	 30.0;
	1921	 7041	 0.00046	 0.00548	 0.11938	 1776.186372	 1776.186372	 1776.186372	 0.0	 0.0	 1	 -30.0	 30.0;
	1921	 5443	 0.00016	 0.00173	 0.03322	 1866.420122	 1866.420122	 1866.420122	 0.0	 0.0	 1	 -30.0	 30.0;
	1921	 5709	 0.00166	 0.01471	 0.4064	 1764.38785	 1764.38785	 1764.38785	 0.0	 0.0	 1	 -30.0	 30.0;
	825	 7041	 0.00051	 0.00512	 0.10635	 1809.149308	 1809.149308	 1809.149308	 0.0	 0.0	 1	 -30.0	 30.0;
	6080	 8099	 0.00021	 0.00248	 0.05377	 1534.292313	 1534.292313	 1534.292313	 0.0	 0.0	 1	 -30.0	 30.0;
	207	 4172	 0.004391	 0.021689	 0.0	 288.312154	 288.312154	 288.312154	 0.0	 0.0	 1	 -30.0	 30.0;
	2216	 5709	 0.00024	 0.00289	 0.06298	 1660.048659	 1660.048659	 1660.048659	 0.0	 0.0	 1	 -30.0	 30.0;
	866	 3186	 0.0	 0.000222	 0.0	 337.883968	 337.883968	 337.883968	 0.0	 0.0	 1	 -30.0	 30.0;
	866	 8139	 0.01788	 0.100471	 0.0	 125.356398	 125.356398	 125.356398	 0.0	 0.0	 1	 -30.0	 30.0;
	3186	 2637	 0.006458	 0.039982	 0.01196	 125.741433	 125.741433	 125.741433	 0.0	 0.0	 1	 -30.0	 30.0;
	207	 6192	 0.106151	 0.993333	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	207	 5242	 0.699778	 3.232311	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8139	 6192	 0.257058	 0.43592	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5242	 6192	 0.002769	 0.011449	 0.0	 136.345221	 136.345221	 136.345221	 0.0	 0.0	 1	 -30.0	 30.0;
	596	 7549	 0.00034	 0.00305	 0.08424	 1603.19513	 1603.19513	 1603.19513	 0.0	 0.0	 1	 -30.0	 30.0;
	596	 6395	 0.00123	 0.01255	 0.32089	 1845.213585	 1845.213585	 1845.213585	 0.0	 0.0	 1	 -30.0	 30.0;
	596	 8385	 6e-05	 0.00065	 0.01652	 1445.692822	 1445.692822	 1445.692822	 0.0	 0.0	 1	 -30.0	 30.0;
	596	 7223	 6e-05	 0.00063	 0.01685	 1515.658599	 1515.658599	 1515.658599	 0.0	 0.0	 1	 -30.0	 30.0;
	596	 5656	 6e-05	 0.00055	 0.01526	 1767.880149	 1767.880149	 1767.880149	 0.0	 0.0	 1	 -30.0	 30.0;
	596	 4917	 0.00079	 0.00968	 0.20826	 1374.646315	 1374.646315	 1374.646315	 0.0	 0.0	 1	 -30.0	 30.0;
	596	 6166	 7e-05	 0.00079	 0.0173	 2092.748899	 2092.748899	 2092.748899	 0.0	 0.0	 1	 -30.0	 30.0;
	718	 2981	 0.0	 0.000222	 0.0	 381.428505	 381.428505	 381.428505	 0.0	 0.0	 1	 -30.0	 30.0;
	6862	 718	 2.064178	 7.545333	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6599	 718	 0.153711	 0.482489	 0.0	 115.998647	 115.998647	 115.998647	 0.0	 0.0	 1	 -30.0	 30.0;
	7555	 718	 0.015809	 0.12368	 0.0	 154.358723	 154.358723	 154.358723	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 718	 0.057978	 0.363422	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4239	 718	 0.6932	 2.196889	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4091	 718	 0.560356	 2.395867	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4917	 2062	 0.00024	 0.00213	 0.05875	 775.769622	 775.769622	 775.769622	 0.0	 0.0	 1	 -30.0	 30.0;
	4917	 6930	 0.00093	 0.00884	 0.23566	 1305.993606	 1305.993606	 1305.993606	 0.0	 0.0	 1	 -30.0	 30.0;
	8139	 1975	 0.0	 0.000222	 0.0	 315.913597	 315.913597	 315.913597	 0.0	 0.0	 1	 -30.0	 30.0;
	3328	 5443	 0.00018	 0.00204	 0.0455	 1802.921615	 1802.921615	 1802.921615	 0.0	 0.0	 1	 -30.0	 30.0;
	5229	 5443	 0.00018	 0.00208	 0.04456	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2948	 4637	 0.0	 0.000222	 0.0	 114.164145	 114.164145	 114.164145	 0.0	 0.0	 1	 -30.0	 30.0;
	6862	 2948	 0.02068	 0.093391	 0.0	 173.042528	 173.042528	 173.042528	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 2948	 0.777778	 7.408	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2948	 6599	 0.00884	 0.07292	 0.0	 123.083341	 123.083341	 123.083341	 0.0	 0.0	 1	 -30.0	 30.0;
	246	 2948	 0.131671	 8.295556	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2948	 1469	 0.082462	 0.568222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4637	 1469	 0.0042	 0.02624	 0.01124	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7415	 7413	 0.00031	 0.00317	 0.0695	 1256.437311	 1256.437311	 1256.437311	 0.0	 0.0	 1	 -30.0	 30.0;
	7415	 7041	 0.00043	 0.00498	 0.10234	 1494.859474	 1494.859474	 1494.859474	 0.0	 0.0	 1	 -30.0	 30.0;
	8196	 7041	 0.00042	 0.00508	 0.1002	 1732.63004	 1732.63004	 1732.63004	 0.0	 0.0	 1	 -30.0	 30.0;
	6862	 4032	 0.110671	 0.773067	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6862	 6599	 0.00912	 0.037609	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6862	 7555	 0.098049	 0.598711	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6862	 4687	 0.019031	 1.160356	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6862	 246	 0.024071	 0.915733	 0.0	 104.516189	 104.516189	 104.516189	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 6862	 1.484267	 4.479111	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4239	 6862	 0.011578	 0.063271	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4091	 6862	 0.654889	 1.839111	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6862	 1469	 0.022049	 0.10076	 0.0	 135.609706	 135.609706	 135.609706	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 6599	 0.459867	 2.604711	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 7555	 2.320222	 6.088	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 4687	 0.006369	 0.048089	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 246	 0.006631	 0.0432	 0.0	 145.521106	 145.521106	 145.521106	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 4032	 2.567244	 6.767111	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4239	 4032	 0.309889	 1.214178	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4091	 4032	 0.009191	 0.043289	 0.0	 127.213762	 127.213762	 127.213762	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 1469	 0.691022	 5.239556	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4738	 1313	 0.002669	 0.01718	 0.0	 225.874182	 225.874182	 225.874182	 0.0	 0.0	 1	 -30.0	 30.0;
	7413	 5000	 0.00074	 0.00694	 0.19186	 1260.942549	 1260.942549	 1260.942549	 0.0	 0.0	 1	 -30.0	 30.0;
	7413	 7041	 0.00068	 0.008	 0.1602	 1549.468612	 1549.468612	 1549.468612	 0.0	 0.0	 1	 -30.0	 30.0;
	6599	 3656	 0.0	 0.000222	 0.0	 159.490962	 159.490962	 159.490962	 0.0	 0.0	 1	 -30.0	 30.0;
	7555	 6599	 0.00524	 0.030631	 0.0	 168.883787	 168.883787	 168.883787	 0.0	 0.0	 1	 -30.0	 30.0;
	4687	 6599	 0.33932	 3.814667	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	246	 6599	 0.22696	 2.614933	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 6599	 0.190671	 0.719378	 0.0	 106.727412	 106.727412	 106.727412	 0.0	 0.0	 1	 -30.0	 30.0;
	4239	 6599	 1.050222	 2.105556	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4091	 6599	 1.431644	 4.294578	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1469	 6599	 0.022618	 0.161089	 0.0	 132.945119	 132.945119	 132.945119	 0.0	 0.0	 1	 -30.0	 30.0;
	5000	 1439	 0.00088	 0.00895	 0.22766	 1817.889929	 1817.889929	 1817.889929	 0.0	 0.0	 1	 -30.0	 30.0;
	7555	 1395	 0.0	 0.000222	 0.0	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	4687	 7555	 1.827778	 7.768	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 7555	 0.020849	 0.153382	 0.0	 120.989551	 120.989551	 120.989551	 0.0	 0.0	 1	 -30.0	 30.0;
	4239	 7555	 0.156231	 0.656267	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4091	 7555	 0.176498	 0.891556	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7041	 2063	 0.00067	 0.00777	 0.17154	 1639.085648	 1639.085648	 1639.085648	 0.0	 0.0	 1	 -30.0	 30.0;
	4687	 246	 0.004578	 0.061889	 0.0	 108.460069	 108.460069	 108.460069	 0.0	 0.0	 1	 -30.0	 30.0;
	4687	 2637	 0.01348	 0.05932	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4239	 4687	 0.066391	 2.802622	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4091	 4687	 0.194258	 2.220444	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4687	 1469	 0.008151	 0.072822	 0.0	 119.61387	 119.61387	 119.61387	 0.0	 0.0	 1	 -30.0	 30.0;
	246	 2637	 0.016502	 0.055382	 0.0	 110.780151	 110.780151	 110.780151	 0.0	 0.0	 1	 -30.0	 30.0;
	4239	 246	 0.0806	 4.633778	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4091	 246	 0.831556	 3.729644	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	246	 1469	 0.007951	 0.074151	 0.0	 126.14985	 126.14985	 126.14985	 0.0	 0.0	 1	 -30.0	 30.0;
	1439	 5304	 0.0004	 0.00362	 0.10368	 1616.279735	 1616.279735	 1616.279735	 0.0	 0.0	 1	 -30.0	 30.0;
	6395	 8028	 0.00015	 0.00177	 0.0384	 1581.381093	 1581.381093	 1581.381093	 0.0	 0.0	 1	 -30.0	 30.0;
	5242	 7458	 0.0	 0.000222	 0.0	 136.505782	 136.505782	 136.505782	 0.0	 0.0	 1	 -30.0	 30.0;
	288	 5656	 2e-05	 0.00022	 0.00551	 1701.556737	 1701.556737	 1701.556737	 0.0	 0.0	 1	 -30.0	 30.0;
	4239	 2222	 0.02864	 0.172902	 0.0	 109.491505	 109.491505	 109.491505	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 4091	 0.017591	 0.1404	 0.0	 111.040738	 111.040738	 111.040738	 0.0	 0.0	 1	 -30.0	 30.0;
	4239	 4091	 0.00752	 0.031711	 0.0	 104.584519	 104.584519	 104.584519	 0.0	 0.0	 1	 -30.0	 30.0;
	1469	 7632	 0.0	 0.000222	 0.0	 549.63939	 549.63939	 549.63939	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 2076	 0.032587	 0.058388	 0.00653	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	576	 2076	 0.029752	 0.070686	 0.00591	 73.633949	 73.633949	 73.633949	 0.0	 0.0	 1	 -30.0	 30.0;
	3995	 3650	 0.00699	 0.04244	 0.06863	 488.072068	 488.072068	 488.072068	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 6832	 0.0008	 0.006081	 0.00853	 337.195617	 337.195617	 337.195617	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 5451	 0.004669	 0.041919	 0.11404	 299.841932	 299.841932	 299.841932	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 5451	 0.00476	 0.04106	 0.11627	 305.991717	 305.991717	 305.991717	 0.0	 0.0	 1	 -30.0	 30.0;
	6347	 1864	 0.00146	 0.0163	 0.33408	 1327.949151	 1327.949151	 1327.949151	 0.0	 0.0	 1	 -30.0	 30.0;
	6347	 1864	 0.00098	 0.01485	 0.35427	 1236.69983	 1236.69983	 1236.69983	 0.0	 0.0	 1	 -30.0	 30.0;
	6347	 1864	 0.00143	 0.01661	 0.32712	 1133.387399	 1133.387399	 1133.387399	 0.0	 0.0	 1	 -30.0	 30.0;
	1372	 6347	 0.00209	 0.0241	 0.75637	 1925.568064	 1925.568064	 1925.568064	 0.0	 0.0	 1	 -30.0	 30.0;
	1372	 6347	 0.00273	 0.02677	 0.70404	 1460.853982	 1460.853982	 1460.853982	 0.0	 0.0	 1	 -30.0	 30.0;
	1372	 6347	 0.00279	 0.02623	 0.71784	 1281.88384	 1281.88384	 1281.88384	 0.0	 0.0	 1	 -30.0	 30.0;
	5011	 739	 0.007479	 0.032207	 0.00402	 83.045151	 83.045151	 83.045151	 0.0	 0.0	 1	 -30.0	 30.0;
	5011	 1939	 0.04319	 0.16186	 0.01732	 73.860483	 73.860483	 73.860483	 0.0	 0.0	 1	 -30.0	 30.0;
	1474	 2993	 0.007256	 0.029702	 0.00418	 100.348303	 100.348303	 100.348303	 0.0	 0.0	 1	 -30.0	 30.0;
	2993	 5495	 0.006488	 0.036041	 0.00367	 109.528398	 109.528398	 109.528398	 0.0	 0.0	 1	 -30.0	 30.0;
	3448	 4147	 0.028653	 0.066364	 0.00692	 66.256417	 66.256417	 66.256417	 0.0	 0.0	 1	 -30.0	 30.0;
	6452	 3448	 0.010463	 0.027446	 0.0025	 66.435511	 66.435511	 66.435511	 0.0	 0.0	 1	 -30.0	 30.0;
	1309	 2886	 0.012409	 0.071919	 0.1254	 418.371711	 418.371711	 418.371711	 0.0	 0.0	 1	 -30.0	 30.0;
	1309	 2886	 0.012659	 0.07045	 0.12786	 453.921881	 453.921881	 453.921881	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 8279	 0.003419	 0.02344	 0.03412	 426.544878	 426.544878	 426.544878	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 6737	 0.002469	 0.01486	 0.02003	 329.654614	 329.654614	 329.654614	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 4988	 0.00682	 0.03368	 0.04313	 467.578755	 467.578755	 467.578755	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 833	 0.02036	 0.09743	 0.12263	 341.634482	 341.634482	 341.634482	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 3428	 0.048	 0.080331	 0.00958	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 3108	 0.00262	 0.008083	 0.00087	 77.992983	 77.992983	 77.992983	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 5928	 0.004107	 0.023083	 0.00244	 67.940282	 67.940282	 67.940282	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 7248	 0.003207	 0.015719	 0.00189	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 649	 0.004727	 0.02143	 0.00257	 70.712239	 70.712239	 70.712239	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 3515	 0.004041	 0.012702	 0.00151	 64.123102	 64.123102	 64.123102	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 2317	 0.017802	 0.037777	 0.0043	 61.134898	 61.134898	 61.134898	 0.0	 0.0	 1	 -30.0	 30.0;
	2651	 4924	 0.002934	 0.014273	 0.00164	 71.068712	 71.068712	 71.068712	 0.0	 0.0	 1	 -30.0	 30.0;
	3311	 2651	 0.006231	 0.032174	 0.00338	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5491	 2666	 0.026876	 0.085248	 0.00679	 77.810269	 77.810269	 77.810269	 0.0	 0.0	 1	 -30.0	 30.0;
	5491	 5778	 0.050636	 0.099223	 0.01231	 94.807057	 94.807057	 94.807057	 0.0	 0.0	 1	 -30.0	 30.0;
	889	 3023	 0.045347	 0.092	 0.01084	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5267	 3023	 0.005231	 0.013504	 0.00128	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 7853	 0.024752	 0.057446	 0.00473	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 7197	 0.015083	 0.065182	 0.00823	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 8103	 0.03986	 0.070686	 0.00773	 65.268351	 65.268351	 65.268351	 0.0	 0.0	 1	 -30.0	 30.0;
	4728	 1365	 0.036231	 0.064248	 0.00703	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 4257	 0.004537	 0.022041	 0.00247	 64.711826	 64.711826	 64.711826	 0.0	 0.0	 1	 -30.0	 30.0;
	8267	 6859	 0.052603	 0.157802	 0.01363	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8103	 6859	 0.005562	 0.024083	 0.00249	 71.136158	 71.136158	 71.136158	 0.0	 0.0	 1	 -30.0	 30.0;
	8103	 6859	 0.005446	 0.024554	 0.00244	 58.6815	 58.6815	 58.6815	 0.0	 0.0	 1	 -30.0	 30.0;
	3288	 6859	 0.009107	 0.051661	 0.00535	 72.870703	 72.870703	 72.870703	 0.0	 0.0	 1	 -30.0	 30.0;
	6859	 690	 0.00419	 0.009868	 0.00117	 68.626174	 68.626174	 68.626174	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 6859	 0.024281	 0.13338	 0.01325	 65.972534	 65.972534	 65.972534	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 6859	 0.02376	 0.123496	 0.01296	 69.192607	 69.192607	 69.192607	 0.0	 0.0	 1	 -30.0	 30.0;
	4562	 6859	 0.005331	 0.020752	 0.00196	 61.595208	 61.595208	 61.595208	 0.0	 0.0	 1	 -30.0	 30.0;
	4158	 6411	 0.001107	 0.004603	 0.00063	 59.551821	 59.551821	 59.551821	 0.0	 0.0	 1	 -30.0	 30.0;
	6411	 7095	 0.005628	 0.030702	 0.00301	 65.382666	 65.382666	 65.382666	 0.0	 0.0	 1	 -30.0	 30.0;
	649	 7351	 0.024628	 0.130893	 0.01447	 59.970025	 59.970025	 59.970025	 0.0	 0.0	 1	 -30.0	 30.0;
	649	 7351	 0.024132	 0.133463	 0.01418	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 7351	 0.01419	 0.07062	 0.00827	 76.579093	 76.579093	 76.579093	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 7351	 0.014471	 0.069182	 0.00843	 76.559278	 76.559278	 76.559278	 0.0	 0.0	 1	 -30.0	 30.0;
	6132	 7620	 0.008372	 0.045231	 0.00455	 61.627407	 61.627407	 61.627407	 0.0	 0.0	 1	 -30.0	 30.0;
	6296	 6132	 0.024628	 0.097983	 0.01339	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6132	 6428	 0.002471	 0.009331	 0.00134	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	303	 1714	 0.025702	 0.144587	 0.01399	 67.419004	 67.419004	 67.419004	 0.0	 0.0	 1	 -30.0	 30.0;
	3812	 303	 0.003421	 0.019752	 0.00201	 59.581543	 59.581543	 59.581543	 0.0	 0.0	 1	 -30.0	 30.0;
	3213	 38	 0.004562	 0.017174	 0.00175	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	38	 827	 0.018868	 0.083661	 0.01108	 59.437125	 59.437125	 59.437125	 0.0	 0.0	 1	 -30.0	 30.0;
	38	 4439	 0.01019	 0.027917	 0.00334	 58.634631	 58.634631	 58.634631	 0.0	 0.0	 1	 -30.0	 30.0;
	8011	 3213	 0.019471	 0.064058	 0.00777	 62.815525	 62.815525	 62.815525	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 1533	 0.053446	 0.118207	 0.01283	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1533	 5027	 0.049521	 0.123438	 0.01198	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 4599	 0.00914	 0.042039	 0.05368	 358.472371	 358.472371	 358.472371	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 833	 0.004711	 0.021591	 0.02835	 290.324798	 290.324798	 290.324798	 0.0	 0.0	 1	 -30.0	 30.0;
	1318	 8383	 0.0	 0.000893	 0.0	 75.600173	 75.600173	 75.600173	 0.0	 0.0	 1	 -30.0	 30.0;
	4265	 1318	 0.00405	 0.021132	 0.0022	 64.47767	 64.47767	 64.47767	 0.0	 0.0	 1	 -30.0	 30.0;
	4265	 1318	 0.004587	 0.020711	 0.00249	 76.221477	 76.221477	 76.221477	 0.0	 0.0	 1	 -30.0	 30.0;
	8383	 3350	 0.044182	 0.091041	 0.00842	 93.379258	 93.379258	 93.379258	 0.0	 0.0	 1	 -30.0	 30.0;
	8383	 4126	 0.022653	 0.047421	 0.00551	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8383	 6786	 0.058876	 0.108463	 0.01145	 78.845014	 78.845014	 78.845014	 0.0	 0.0	 1	 -30.0	 30.0;
	412	 3249	 0.013174	 0.026992	 0.0032	 108.170141	 108.170141	 108.170141	 0.0	 0.0	 1	 -30.0	 30.0;
	6652	 412	 0.001273	 0.002818	 0.00031	 104.963214	 104.963214	 104.963214	 0.0	 0.0	 1	 -30.0	 30.0;
	1548	 1474	 0.009471	 0.048769	 0.00511	 116.055614	 116.055614	 116.055614	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 3156	 0.017388	 0.04138	 0.00666	 85.578569	 85.578569	 85.578569	 0.0	 0.0	 1	 -30.0	 30.0;
	3156	 8077	 0.017339	 0.054661	 0.00372	 112.484593	 112.484593	 112.484593	 0.0	 0.0	 1	 -30.0	 30.0;
	4924	 4191	 0.025033	 0.137942	 0.0147	 58.256057	 58.256057	 58.256057	 0.0	 0.0	 1	 -30.0	 30.0;
	4924	 4191	 0.024521	 0.140653	 0.0144	 57.784125	 57.784125	 57.784125	 0.0	 0.0	 1	 -30.0	 30.0;
	4191	 6512	 0.021198	 0.056041	 0.00381	 62.871539	 62.871539	 62.871539	 0.0	 0.0	 1	 -30.0	 30.0;
	4191	 7409	 0.007174	 0.035	 0.00421	 73.7757	 73.7757	 73.7757	 0.0	 0.0	 1	 -30.0	 30.0;
	2428	 4191	 0.010826	 0.029992	 0.00272	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2428	 4191	 0.012876	 0.028058	 0.00323	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2191	 7026	 0.034248	 0.143124	 0.01898	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5475	 7026	 0.015421	 0.066364	 0.00843	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4728	 7853	 0.014512	 0.035901	 0.00349	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 1309	 0.00863	 0.054419	 0.08751	 539.911033	 539.911033	 539.911033	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 1309	 0.008461	 0.055479	 0.08573	 515.908619	 515.908619	 515.908619	 0.0	 0.0	 1	 -30.0	 30.0;
	434	 3897	 0.013256	 0.073248	 0.00724	 74.693842	 74.693842	 74.693842	 0.0	 0.0	 1	 -30.0	 30.0;
	8153	 3897	 0.004033	 0.018174	 0.00221	 93.218645	 93.218645	 93.218645	 0.0	 0.0	 1	 -30.0	 30.0;
	576	 3428	 0.016008	 0.027066	 0.00319	 78.301825	 78.301825	 78.301825	 0.0	 0.0	 1	 -30.0	 30.0;
	4749	 3288	 0.013537	 0.070083	 0.0073	 70.0494	 70.0494	 70.0494	 0.0	 0.0	 1	 -30.0	 30.0;
	7068	 4749	 0.004744	 0.024876	 0.00261	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3108	 2514	 0.014364	 0.037438	 0.00315	 64.491959	 64.491959	 64.491959	 0.0	 0.0	 1	 -30.0	 30.0;
	7541	 2048	 0.010364	 0.020314	 0.0025	 63.511324	 63.511324	 63.511324	 0.0	 0.0	 1	 -30.0	 30.0;
	2048	 3336	 0.007289	 0.018207	 0.00175	 65.363423	 65.363423	 65.363423	 0.0	 0.0	 1	 -30.0	 30.0;
	7577	 1366	 0.011744	 0.052446	 0.00645	 75.682099	 75.682099	 75.682099	 0.0	 0.0	 1	 -30.0	 30.0;
	6759	 7577	 0.015438	 0.062876	 0.00836	 78.015275	 78.015275	 78.015275	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 5956	 0.00157	 0.01612	 0.38916	 1026.095616	 1026.095616	 1026.095616	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 5956	 0.00154	 0.01643	 0.38122	 1052.243763	 1052.243763	 1052.243763	 0.0	 0.0	 1	 -30.0	 30.0;
	3311	 4924	 0.001967	 0.008438	 0.00471	 97.802691	 97.802691	 97.802691	 0.0	 0.0	 1	 -30.0	 30.0;
	4924	 7498	 0.01162	 0.033653	 0.0053	 83.411722	 83.411722	 83.411722	 0.0	 0.0	 1	 -30.0	 30.0;
	1041	 803	 0.006901	 0.04661	 0.0697	 433.127537	 433.127537	 433.127537	 0.0	 0.0	 1	 -30.0	 30.0;
	1041	 803	 0.00782	 0.04568	 0.07899	 448.13257	 448.13257	 448.13257	 0.0	 0.0	 1	 -30.0	 30.0;
	2596	 803	 0.005401	 0.0343	 0.05455	 399.238369	 399.238369	 399.238369	 0.0	 0.0	 1	 -30.0	 30.0;
	602	 803	 0.011419	 0.07275	 0.10245	 382.609677	 382.609677	 382.609677	 0.0	 0.0	 1	 -30.0	 30.0;
	3995	 5451	 0.01044	 0.05919	 0.1062	 492.606196	 492.606196	 492.606196	 0.0	 0.0	 1	 -30.0	 30.0;
	8101	 979	 0.050314	 0.112132	 0.01002	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8101	 979	 0.057017	 0.109893	 0.01135	 78.915699	 78.915699	 78.915699	 0.0	 0.0	 1	 -30.0	 30.0;
	979	 3893	 0.007	 0.028231	 0.00401	 89.076619	 89.076619	 89.076619	 0.0	 0.0	 1	 -30.0	 30.0;
	979	 7654	 0.010719	 0.040868	 0.00585	 72.536712	 72.536712	 72.536712	 0.0	 0.0	 1	 -30.0	 30.0;
	979	 4241	 0.04443	 0.10976	 0.01116	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	979	 513	 0.021372	 0.121033	 0.01035	 76.547656	 76.547656	 76.547656	 0.0	 0.0	 1	 -30.0	 30.0;
	979	 799	 0.020579	 0.095331	 0.01	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2643	 8101	 0.02386	 0.06986	 0.02731	 72.134512	 72.134512	 72.134512	 0.0	 0.0	 1	 -30.0	 30.0;
	8033	 2643	 0.062901	 0.105628	 0.00955	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2643	 1939	 0.035686	 0.149314	 0.0209	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5898	 2643	 0.00181	 0.006876	 0.00061	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5897	 2643	 0.002628	 0.01462	 0.00316	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5897	 2643	 0.002983	 0.014331	 0.00358	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	380	 2643	 0.006157	 0.03114	 0.00335	 75.774885	 75.774885	 75.774885	 0.0	 0.0	 1	 -30.0	 30.0;
	1846	 6764	 0.022	 0.043066	 0.00519	 68.828703	 68.828703	 68.828703	 0.0	 0.0	 1	 -30.0	 30.0;
	1289	 1846	 0.013438	 0.033479	 0.00296	 58.908988	 58.908988	 58.908988	 0.0	 0.0	 1	 -30.0	 30.0;
	1846	 7751	 0.013488	 0.028893	 0.00221	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3109	 8329	 0.114058	 0.230033	 0.02527	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8329	 855	 0.062901	 0.133777	 0.01366	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8329	 1810	 0.041868	 0.106554	 0.01034	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3103	 7538	 0.052347	 0.07786	 0.00802	 75.05203	 75.05203	 75.05203	 0.0	 0.0	 1	 -30.0	 30.0;
	7538	 5058	 0.003099	 0.006174	 0.00072	 60.190844	 60.190844	 60.190844	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 6655	 0.04357	 0.108678	 0.01068	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 7408	 0.020893	 0.043289	 0.00509	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4147	 8077	 0.035289	 0.072058	 0.0085	 71.915217	 71.915217	 71.915217	 0.0	 0.0	 1	 -30.0	 30.0;
	1939	 8101	 0.050579	 0.074298	 0.00768	 57.875387	 57.875387	 57.875387	 0.0	 0.0	 1	 -30.0	 30.0;
	3706	 8101	 0.042934	 0.087917	 0.01045	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 6460	 0.036711	 0.086397	 0.00943	 61.320661	 61.320661	 61.320661	 0.0	 0.0	 1	 -30.0	 30.0;
	6460	 7541	 0.053124	 0.100066	 0.00693	 61.807263	 61.807263	 61.807263	 0.0	 0.0	 1	 -30.0	 30.0;
	6460	 3703	 0.022959	 0.041727	 0.00334	 65.934238	 65.934238	 65.934238	 0.0	 0.0	 1	 -30.0	 30.0;
	3615	 1495	 0.00476	 0.023868	 0.00255	 60.090056	 60.090056	 60.090056	 0.0	 0.0	 1	 -30.0	 30.0;
	7019	 3615	 0.005529	 0.011182	 0.00133	 64.364688	 64.364688	 64.364688	 0.0	 0.0	 1	 -30.0	 30.0;
	6869	 659	 0.00183	 0.02821	 0.56605	 1693.066882	 1693.066882	 1693.066882	 0.0	 0.0	 1	 -30.0	 30.0;
	6758	 6869	 0.00198	 0.02074	 0.40897	 1249.10651	 1249.10651	 1249.10651	 0.0	 0.0	 1	 -30.0	 30.0;
	8061	 5401	 0.022917	 0.094893	 0.01245	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8061	 5401	 0.023347	 0.092868	 0.01269	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 2726	 0.030364	 0.073256	 0.01043	 64.086711	 64.086711	 64.086711	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 5855	 0.004562	 0.020132	 0.00248	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 5855	 0.010562	 0.020686	 0.00255	 66.493049	 66.493049	 66.493049	 0.0	 0.0	 1	 -30.0	 30.0;
	855	 5401	 0.01838	 0.07314	 0.00999	 85.956953	 85.956953	 85.956953	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 4573	 0.005628	 0.029702	 0.00306	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 4573	 0.005777	 0.029273	 0.00314	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2547	 5401	 0.014529	 0.236802	 0.009	 60.706406	 60.706406	 60.706406	 0.0	 0.0	 1	 -30.0	 30.0;
	2340	 1587	 0.005818	 0.032182	 0.00332	 73.964701	 73.964701	 73.964701	 0.0	 0.0	 1	 -30.0	 30.0;
	2340	 4265	 0.003636	 0.021843	 0.00837	 72.404487	 72.404487	 72.404487	 0.0	 0.0	 1	 -30.0	 30.0;
	3125	 1864	 0.00318	 0.02624	 0.70048	 1150.807431	 1150.807431	 1150.807431	 0.0	 0.0	 1	 -30.0	 30.0;
	3125	 6758	 0.00442	 0.03649	 0.9038	 1264.052446	 1264.052446	 1264.052446	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 1501	 0.005099	 0.027868	 0.00297	 62.528974	 62.528974	 62.528974	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 1587	 0.00995	 0.049397	 0.0058	 71.112533	 71.112533	 71.112533	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 1587	 0.01014	 0.048397	 0.00592	 70.927151	 70.927151	 70.927151	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 1534	 0.007917	 0.04757	 0.00466	 75.498241	 75.498241	 75.498241	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 82	 0.004008	 0.022182	 0.00237	 96.642581	 96.642581	 96.642581	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 185	 0.006603	 0.039124	 0.00364	 72.03239	 72.03239	 72.03239	 0.0	 0.0	 1	 -30.0	 30.0;
	7541	 5115	 0.00657	 0.028281	 0.00355	 74.431298	 74.431298	 74.431298	 0.0	 0.0	 1	 -30.0	 30.0;
	6655	 7541	 0.071471	 0.124661	 0.01173	 63.170093	 63.170093	 63.170093	 0.0	 0.0	 1	 -30.0	 30.0;
	6655	 7541	 0.069983	 0.127058	 0.01149	 59.465323	 59.465323	 59.465323	 0.0	 0.0	 1	 -30.0	 30.0;
	7541	 3336	 0.00743	 0.018182	 0.00733	 107.606566	 107.606566	 107.606566	 0.0	 0.0	 1	 -30.0	 30.0;
	8011	 7070	 0.004653	 0.024339	 0.00785	 71.035561	 71.035561	 71.035561	 0.0	 0.0	 1	 -30.0	 30.0;
	8077	 8011	 0.007157	 0.03462	 0.00419	 112.710747	 112.710747	 112.710747	 0.0	 0.0	 1	 -30.0	 30.0;
	8077	 8011	 0.007298	 0.033909	 0.00427	 102.873149	 102.873149	 102.873149	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 7055	 0.00024	 0.00281	 0.06108	 1225.573967	 1225.573967	 1225.573967	 0.0	 0.0	 1	 -30.0	 30.0;
	4911	 6568	 0.010711	 0.056603	 0.00585	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 4911	 0.064273	 0.068058	 0.00746	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7403	 5070	 0.013917	 0.06676	 0.00745	 80.675012	 80.675012	 80.675012	 0.0	 0.0	 1	 -30.0	 30.0;
	7403	 7796	 0.034298	 0.076091	 0.00831	 63.496082	 63.496082	 63.496082	 0.0	 0.0	 1	 -30.0	 30.0;
	4158	 2867	 0.00676	 0.044942	 0.00464	 74.986109	 74.986109	 74.986109	 0.0	 0.0	 1	 -30.0	 30.0;
	4158	 3812	 0.025579	 0.109438	 0.01403	 60.808337	 60.808337	 60.808337	 0.0	 0.0	 1	 -30.0	 30.0;
	4158	 3812	 0.026091	 0.107198	 0.0143	 73.806946	 73.806946	 73.806946	 0.0	 0.0	 1	 -30.0	 30.0;
	3005	 3077	 0.00319	 0.01543	 0.00178	 58.037905	 58.037905	 58.037905	 0.0	 0.0	 1	 -30.0	 30.0;
	3077	 2504	 0.003669	 0.014628	 0.00197	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2609	 1445	 0.001653	 0.007331	 0.00092	 71.196555	 71.196555	 71.196555	 0.0	 0.0	 1	 -30.0	 30.0;
	434	 2609	 0.009661	 0.04095	 0.00386	 72.418776	 72.418776	 72.418776	 0.0	 0.0	 1	 -30.0	 30.0;
	1372	 8182	 0.00089	 0.00981	 0.23011	 1178.864957	 1178.864957	 1178.864957	 0.0	 0.0	 1	 -30.0	 30.0;
	1372	 8182	 0.00087	 0.01	 0.22532	 1320.969818	 1320.969818	 1320.969818	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 7055	 0.00114	 0.01867	 0.4455	 1459.477071	 1459.477071	 1459.477071	 0.0	 0.0	 1	 -30.0	 30.0;
	4453	 2621	 0.034661	 0.089231	 0.00845	 64.032221	 64.032221	 64.032221	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 4453	 0.009463	 0.018603	 0.00519	 88.538384	 88.538384	 88.538384	 0.0	 0.0	 1	 -30.0	 30.0;
	2563	 6441	 0.032777	 0.061248	 0.00629	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 2563	 0.029182	 0.043207	 0.00506	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6129	 5413	 0.012826	 0.022587	 0.00274	 60.806432	 60.806432	 60.806432	 0.0	 0.0	 1	 -30.0	 30.0;
	1797	 8267	 0.01519	 0.065017	 0.0082	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	351	 8267	 0.002107	 0.009	 0.00115	 74.953719	 74.953719	 74.953719	 0.0	 0.0	 1	 -30.0	 30.0;
	8267	 4112	 0.010099	 0.046587	 0.0054	 68.109469	 68.109469	 68.109469	 0.0	 0.0	 1	 -30.0	 30.0;
	185	 1501	 0.001934	 0.009008	 0.0009	 70.789592	 70.789592	 70.789592	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 6764	 0.041537	 0.116843	 0.01002	 73.667672	 73.667672	 73.667672	 0.0	 0.0	 1	 -30.0	 30.0;
	6296	 7197	 0.013091	 0.050041	 0.00712	 65.642162	 65.642162	 65.642162	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 6441	 0.003058	 0.005579	 0.00063	 61.764395	 61.764395	 61.764395	 0.0	 0.0	 1	 -30.0	 30.0;
	1529	 8061	 0.008554	 0.035397	 0.00464	 61.671799	 61.671799	 61.671799	 0.0	 0.0	 1	 -30.0	 30.0;
	8358	 4950	 0.020314	 0.102727	 0.01104	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4622	 4950	 0.005008	 0.025364	 0.00273	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5027	 4950	 0.042182	 0.161132	 0.02292	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7065	 1196	 0.00014	 0.000581	 0.00124	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3123	 1971	 0.001339	 0.007438	 0.00074	 72.494224	 72.494224	 72.494224	 0.0	 0.0	 1	 -30.0	 30.0;
	2231	 1445	 0.004223	 0.009347	 0.00101	 107.166452	 107.166452	 107.166452	 0.0	 0.0	 1	 -30.0	 30.0;
	1445	 5053	 0.016314	 0.034562	 0.0041	 97.242355	 97.242355	 97.242355	 0.0	 0.0	 1	 -30.0	 30.0;
	8153	 1445	 0.009331	 0.045339	 0.0051	 88.512282	 88.512282	 88.512282	 0.0	 0.0	 1	 -30.0	 30.0;
	2231	 3651	 0.00038	 0.002769	 0.00022	 74.70013	 74.70013	 74.70013	 0.0	 0.0	 1	 -30.0	 30.0;
	8153	 2231	 0.007066	 0.043107	 0.00389	 72.122318	 72.122318	 72.122318	 0.0	 0.0	 1	 -30.0	 30.0;
	1686	 1797	 0.003124	 0.017231	 0.00167	 97.148807	 97.148807	 97.148807	 0.0	 0.0	 1	 -30.0	 30.0;
	2319	 4960	 0.020512	 0.048562	 0.00494	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3706	 4960	 0.016934	 0.03314	 0.00417	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 3311	 0.011083	 0.030769	 0.00334	 72.303318	 72.303318	 72.303318	 0.0	 0.0	 1	 -30.0	 30.0;
	434	 5984	 0.024314	 0.099174	 0.01303	 63.452833	 63.452833	 63.452833	 0.0	 0.0	 1	 -30.0	 30.0;
	434	 5984	 0.024769	 0.097058	 0.01327	 63.940769	 63.940769	 63.940769	 0.0	 0.0	 1	 -30.0	 30.0;
	434	 5984	 0.025231	 0.09495	 0.00135	 79.040874	 79.040874	 79.040874	 0.0	 0.0	 1	 -30.0	 30.0;
	434	 4691	 0.012917	 0.049612	 0.00692	 73.219555	 73.219555	 73.219555	 0.0	 0.0	 1	 -30.0	 30.0;
	434	 2983	 0.048058	 0.135157	 0.01169	 115.961685	 115.961685	 115.961685	 0.0	 0.0	 1	 -30.0	 30.0;
	434	 3651	 0.009372	 0.048876	 0.00555	 80.044372	 80.044372	 80.044372	 0.0	 0.0	 1	 -30.0	 30.0;
	434	 4951	 0.00538	 0.031752	 0.00316	 58.677118	 58.677118	 58.677118	 0.0	 0.0	 1	 -30.0	 30.0;
	434	 4951	 0.005273	 0.029397	 0.00309	 62.303773	 62.303773	 62.303773	 0.0	 0.0	 1	 -30.0	 30.0;
	434	 8089	 0.044562	 0.09762	 0.01137	 78.793381	 78.793381	 78.793381	 0.0	 0.0	 1	 -30.0	 30.0;
	5984	 3499	 0.017876	 0.097091	 0.00101	 113.091417	 113.091417	 113.091417	 0.0	 0.0	 1	 -30.0	 30.0;
	5984	 3226	 0.037207	 0.166008	 0.02178	 137.167755	 137.167755	 137.167755	 0.0	 0.0	 1	 -30.0	 30.0;
	6758	 8066	 0.00018	 0.00154	 0.03899	 1008.038467	 1008.038467	 1008.038467	 0.0	 0.0	 1	 -30.0	 30.0;
	6758	 8066	 0.00023	 0.00194	 0.05083	 914.652037	 914.652037	 914.652037	 0.0	 0.0	 1	 -30.0	 30.0;
	1148	 2195	 0.005669	 0.040521	 0.05699	 523.567367	 523.567367	 523.567367	 0.0	 0.0	 1	 -30.0	 30.0;
	1148	 4354	 0.001581	 0.012159	 0.04179	 381.224556	 381.224556	 381.224556	 0.0	 0.0	 1	 -30.0	 30.0;
	1148	 4354	 0.001409	 0.013781	 0.03723	 403.623125	 403.623125	 403.623125	 0.0	 0.0	 1	 -30.0	 30.0;
	1148	 3185	 0.00111	 0.0075	 0.01105	 449.06767	 449.06767	 449.06767	 0.0	 0.0	 1	 -30.0	 30.0;
	1148	 502	 0.0115	 0.07662	 0.11668	 476.890121	 476.890121	 476.890121	 0.0	 0.0	 1	 -30.0	 30.0;
	2014	 2666	 0.002661	 0.01286	 0.00142	 79.415638	 79.415638	 79.415638	 0.0	 0.0	 1	 -30.0	 30.0;
	1587	 4265	 0.010793	 0.046942	 0.01357	 94.238529	 94.238529	 94.238529	 0.0	 0.0	 1	 -30.0	 30.0;
	889	 8358	 0.023826	 0.100992	 0.01295	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8358	 6904	 0.014603	 0.07986	 0.0079	 81.124462	 81.124462	 81.124462	 0.0	 0.0	 1	 -30.0	 30.0;
	8358	 4622	 0.026132	 0.099818	 0.01495	 72.646454	 72.646454	 72.646454	 0.0	 0.0	 1	 -30.0	 30.0;
	7275	 3535	 0.002289	 0.012554	 0.00153	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7275	 5680	 0.00743	 0.030719	 0.00376	 78.068051	 78.068051	 78.068051	 0.0	 0.0	 1	 -30.0	 30.0;
	6854	 3103	 0.014653	 0.029174	 0.00366	 69.935275	 69.935275	 69.935275	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 6854	 0.016388	 0.04286	 0.00414	 91.494008	 91.494008	 91.494008	 0.0	 0.0	 1	 -30.0	 30.0;
	4126	 8158	 0.056248	 0.122041	 0.01373	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	309	 8158	 0.024901	 0.049099	 0.00639	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4218	 6512	 0.026554	 0.061851	 0.00654	 69.398184	 69.398184	 69.398184	 0.0	 0.0	 1	 -30.0	 30.0;
	3109	 6113	 0.073678	 0.305793	 0.02916	 74.048342	 74.048342	 74.048342	 0.0	 0.0	 1	 -30.0	 30.0;
	2814	 3109	 0.029083	 0.060017	 0.0056	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3109	 57	 0.021893	 0.134521	 0.01286	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1206	 5040	 0.018983	 0.03914	 0.00356	 62.235184	 62.235184	 62.235184	 0.0	 0.0	 1	 -30.0	 30.0;
	5040	 5152	 0.024529	 0.041612	 0.00471	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6420	 4938	 0.039421	 0.085686	 0.00949	 69.514785	 69.514785	 69.514785	 0.0	 0.0	 1	 -30.0	 30.0;
	6655	 4938	 0.039421	 0.085769	 0.00961	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6565	 6420	 0.00876	 0.016901	 0.00211	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 6565	 0.006967	 0.018248	 0.00167	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7587	 2504	 0.025099	 0.107901	 0.00893	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3350	 7587	 0.02605	 0.103438	 0.00928	 64.121958	 64.121958	 64.121958	 0.0	 0.0	 1	 -30.0	 30.0;
	4728	 2061	 0.012719	 0.033719	 0.00305	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2061	 7068	 0.022273	 0.043661	 0.00532	 71.110437	 71.110437	 71.110437	 0.0	 0.0	 1	 -30.0	 30.0;
	7300	 4747	 0.00124	 0.006653	 0.00071	 74.339465	 74.339465	 74.339465	 0.0	 0.0	 1	 -30.0	 30.0;
	1974	 4747	 0.001587	 0.007636	 0.00092	 91.79942	 91.79942	 91.79942	 0.0	 0.0	 1	 -30.0	 30.0;
	5565	 3443	 0.006207	 0.032331	 0.00298	 62.528593	 62.528593	 62.528593	 0.0	 0.0	 1	 -30.0	 30.0;
	5565	 3443	 0.006083	 0.032942	 0.00292	 81.025198	 81.025198	 81.025198	 0.0	 0.0	 1	 -30.0	 30.0;
	3443	 3410	 0.001314	 0.005446	 0.00071	 71.737457	 71.737457	 71.737457	 0.0	 0.0	 1	 -30.0	 30.0;
	3893	 391	 0.003851	 0.01662	 0.00218	 66.515913	 66.515913	 66.515913	 0.0	 0.0	 1	 -30.0	 30.0;
	2732	 7284	 0.005124	 0.031934	 0.00301	 89.833387	 89.833387	 89.833387	 0.0	 0.0	 1	 -30.0	 30.0;
	8153	 7284	 0.005008	 0.029562	 0.00294	 128.393099	 128.393099	 128.393099	 0.0	 0.0	 1	 -30.0	 30.0;
	533	 7409	 0.048331	 0.094372	 0.01169	 76.112496	 76.112496	 76.112496	 0.0	 0.0	 1	 -30.0	 30.0;
	533	 2358	 0.015678	 0.073826	 0.00867	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2429	 784	 0.005579	 0.019174	 0.0013	 90.521756	 90.521756	 90.521756	 0.0	 0.0	 1	 -30.0	 30.0;
	309	 2429	 0.029397	 0.077132	 0.00735	 74.573049	 74.573049	 74.573049	 0.0	 0.0	 1	 -30.0	 30.0;
	1534	 784	 0.002901	 0.006802	 0.00074	 77.579162	 77.579162	 77.579162	 0.0	 0.0	 1	 -30.0	 30.0;
	1534	 82	 0.004769	 0.020826	 0.00279	 95.95364	 95.95364	 95.95364	 0.0	 0.0	 1	 -30.0	 30.0;
	1534	 7899	 0.031388	 0.06305	 0.00587	 81.630879	 81.630879	 81.630879	 0.0	 0.0	 1	 -30.0	 30.0;
	1534	 3542	 0.032587	 0.068752	 0.00783	 85.689646	 85.689646	 85.689646	 0.0	 0.0	 1	 -30.0	 30.0;
	1534	 1231	 0.042802	 0.083983	 0.00227	 72.741527	 72.741527	 72.741527	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 3226	 0.01214	 0.069124	 0.00681	 131.74311	 131.74311	 131.74311	 0.0	 0.0	 1	 -30.0	 30.0;
	2621	 1714	 0.008388	 0.017033	 0.0021	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8103	 7934	 0.008521	 0.046653	 0.00463	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8103	 7710	 0.003331	 0.013818	 0.00135	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 2195	 0.016729	 0.090401	 0.16879	 510.62725	 510.62725	 510.62725	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 5487	 0.01526	 0.081479	 0.15891	 512.371702	 512.371702	 512.371702	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 7753	 0.00905	 0.068219	 0.09844	 471.92693	 471.92693	 471.92693	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 1759	 0.01205	 0.08575	 0.12153	 493.960071	 493.960071	 493.960071	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 6321	 0.007841	 0.04113	 0.07873	 505.127919	 505.127919	 505.127919	 0.0	 0.0	 1	 -30.0	 30.0;
	74	 217	 0.002413	 0.010686	 0.00111	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	799	 74	 0.005041	 0.022769	 0.00252	 58.116973	 58.116973	 58.116973	 0.0	 0.0	 1	 -30.0	 30.0;
	2167	 31	 0.00126	 0.007531	 0.01503	 427.376331	 427.376331	 427.376331	 0.0	 0.0	 1	 -30.0	 30.0;
	7019	 1888	 0.00176	 0.007603	 0.00107	 70.112274	 70.112274	 70.112274	 0.0	 0.0	 1	 -30.0	 30.0;
	7019	 1888	 0.00157	 0.00862	 0.00095	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8033	 2319	 0.02743	 0.059157	 0.00679	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1529	 1315	 0.028992	 0.060893	 0.00748	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3210	 2191	 0.012942	 0.051851	 0.00705	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 3210	 0.071157	 0.104149	 0.00841	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1065	 6072	 0.002017	 0.010686	 0.00448	 141.170126	 141.170126	 141.170126	 0.0	 0.0	 1	 -30.0	 30.0;
	2858	 6072	 0.00195	 0.009364	 0.00112	 102.824183	 102.824183	 102.824183	 0.0	 0.0	 1	 -30.0	 30.0;
	2858	 6072	 0.001992	 0.009174	 0.00114	 107.510732	 107.510732	 107.510732	 0.0	 0.0	 1	 -30.0	 30.0;
	1206	 519	 0.027017	 0.074521	 0.00708	 108.714473	 108.714473	 108.714473	 0.0	 0.0	 1	 -30.0	 30.0;
	519	 6420	 0.025107	 0.072339	 0.00595	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3953	 3394	 0.002942	 0.006248	 0.00038	 79.095555	 79.095555	 79.095555	 0.0	 0.0	 1	 -30.0	 30.0;
	3394	 3483	 0.006983	 0.028678	 0.00385	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1714	 5051	 0.049636	 0.077364	 0.00984	 60.776139	 60.776139	 60.776139	 0.0	 0.0	 1	 -30.0	 30.0;
	2776	 5051	 0.071752	 0.121198	 0.01436	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	351	 5006	 0.00219	 0.009174	 0.0012	 71.006791	 71.006791	 71.006791	 0.0	 0.0	 1	 -30.0	 30.0;
	5515	 351	 0.018719	 0.067983	 0.00626	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8153	 4691	 0.006339	 0.025397	 0.0034	 70.418639	 70.418639	 70.418639	 0.0	 0.0	 1	 -30.0	 30.0;
	6568	 18	 0.011876	 0.064967	 0.00646	 64.925595	 64.925595	 64.925595	 0.0	 0.0	 1	 -30.0	 30.0;
	6113	 3981	 0.004603	 0.024603	 0.00251	 71.164165	 71.164165	 71.164165	 0.0	 0.0	 1	 -30.0	 30.0;
	1630	 6113	 0.037934	 0.102868	 0.01202	 74.650403	 74.650403	 74.650403	 0.0	 0.0	 1	 -30.0	 30.0;
	2726	 6614	 0.020818	 0.067711	 0.007	 63.532853	 63.532853	 63.532853	 0.0	 0.0	 1	 -30.0	 30.0;
	2514	 1065	 0.020223	 0.048471	 0.00379	 72.643787	 72.643787	 72.643787	 0.0	 0.0	 1	 -30.0	 30.0;
	1065	 3410	 0.00705	 0.034314	 0.00379	 61.187483	 61.187483	 61.187483	 0.0	 0.0	 1	 -30.0	 30.0;
	1065	 6572	 0.015388	 0.074008	 0.0083	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1065	 6572	 0.015066	 0.075463	 0.00813	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1206	 29	 0.060331	 0.128752	 0.01196	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	29	 6368	 0.037752	 0.085843	 0.00761	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	29	 576	 0.060471	 0.109992	 0.01196	 61.976069	 61.976069	 61.976069	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 29	 0.021959	 0.050058	 0.00446	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6420	 1942	 0.005347	 0.026198	 0.0031	 67.869597	 67.869597	 67.869597	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 1942	 0.005058	 0.015769	 0.00133	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	889	 1010	 0.010256	 0.053223	 0.00577	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3253	 3981	 0.01476	 0.082157	 0.00867	 65.117645	 65.117645	 65.117645	 0.0	 0.0	 1	 -30.0	 30.0;
	4218	 1132	 0.047843	 0.112033	 0.01135	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7153	 3790	 0.013909	 0.036793	 0.00341	 63.195433	 63.195433	 63.195433	 0.0	 0.0	 1	 -30.0	 30.0;
	3790	 2814	 0.030289	 0.064818	 0.00488	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3790	 1001	 0.026132	 0.123132	 0.01535	 96.373368	 96.373368	 96.373368	 0.0	 0.0	 1	 -30.0	 30.0;
	3790	 1001	 0.026628	 0.120562	 0.01565	 104.075556	 104.075556	 104.075556	 0.0	 0.0	 1	 -30.0	 30.0;
	7495	 3790	 0.016727	 0.063959	 0.00905	 81.794922	 81.794922	 81.794922	 0.0	 0.0	 1	 -30.0	 30.0;
	6031	 4795	 0.002413	 0.010248	 0.00142	 76.080297	 76.080297	 76.080297	 0.0	 0.0	 1	 -30.0	 30.0;
	6031	 3812	 0.009	 0.040843	 0.00582	 61.259502	 61.259502	 61.259502	 0.0	 0.0	 1	 -30.0	 30.0;
	391	 7654	 0.008421	 0.018488	 0.00215	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7719	 7449	 0.014917	 0.034322	 0.00306	 73.223175	 73.223175	 73.223175	 0.0	 0.0	 1	 -30.0	 30.0;
	7719	 2528	 0.00743	 0.035942	 0.00404	 75.170728	 75.170728	 75.170728	 0.0	 0.0	 1	 -30.0	 30.0;
	4795	 7719	 0.003851	 0.016	 0.0021	 85.911227	 85.911227	 85.911227	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 7719	 0.00162	 0.008008	 0.00225	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3158	 7153	 0.014372	 0.045793	 0.00401	 58.747994	 58.747994	 58.747994	 0.0	 0.0	 1	 -30.0	 30.0;
	4627	 3158	 0.038678	 0.089967	 0.01002	 64.620183	 64.620183	 64.620183	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 4229	 0.009504	 0.021727	 0.00765	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4229	 4439	 0.018364	 0.096521	 0.01002	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4573	 5855	 0.00195	 0.010669	 0.00106	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5855	 5622	 0.021182	 0.046826	 0.00513	 70.474272	 70.474272	 70.474272	 0.0	 0.0	 1	 -30.0	 30.0;
	6652	 6904	 0.031752	 0.131826	 0.01732	 75.464899	 75.464899	 75.464899	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 4112	 0.002917	 0.01238	 0.00151	 108.045918	 108.045918	 108.045918	 0.0	 0.0	 1	 -30.0	 30.0;
	18	 1627	 0.016157	 0.035826	 0.00307	 83.580908	 83.580908	 83.580908	 0.0	 0.0	 1	 -30.0	 30.0;
	18	 2860	 0.003727	 0.020529	 0.00201	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	18	 5447	 0.019992	 0.079231	 0.01163	 63.573626	 63.573626	 63.573626	 0.0	 0.0	 1	 -30.0	 30.0;
	2867	 1627	 0.023653	 0.094587	 0.01281	 67.112829	 67.112829	 67.112829	 0.0	 0.0	 1	 -30.0	 30.0;
	2860	 1382	 0.009322	 0.049058	 0.00512	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 1382	 0.026727	 0.146752	 0.01447	 72.424111	 72.424111	 72.424111	 0.0	 0.0	 1	 -30.0	 30.0;
	4692	 502	 0.000531	 0.002919	 0.00513	 335.986541	 335.986541	 335.986541	 0.0	 0.0	 1	 -30.0	 30.0;
	517	 5622	 0.021992	 0.059397	 0.00535	 80.966516	 80.966516	 80.966516	 0.0	 0.0	 1	 -30.0	 30.0;
	517	 4627	 0.044413	 0.10176	 0.01167	 72.780203	 72.780203	 72.780203	 0.0	 0.0	 1	 -30.0	 30.0;
	3684	 517	 0.043223	 0.088562	 0.01045	 71.328589	 71.328589	 71.328589	 0.0	 0.0	 1	 -30.0	 30.0;
	3249	 2983	 0.006992	 0.014066	 0.0017	 139.376899	 139.376899	 139.376899	 0.0	 0.0	 1	 -30.0	 30.0;
	1548	 4874	 0.007256	 0.028802	 0.00407	 158.663995	 158.663995	 158.663995	 0.0	 0.0	 1	 -30.0	 30.0;
	1548	 4874	 0.006471	 0.032636	 0.00363	 123.854398	 123.854398	 123.854398	 0.0	 0.0	 1	 -30.0	 30.0;
	1548	 8089	 0.043198	 0.156397	 0.0216	 99.809307	 99.809307	 99.809307	 0.0	 0.0	 1	 -30.0	 30.0;
	7095	 4570	 0.016248	 0.04014	 0.00371	 60.373558	 60.373558	 60.373558	 0.0	 0.0	 1	 -30.0	 30.0;
	1309	 1041	 0.00206	 0.01393	 0.01952	 461.880516	 461.880516	 461.880516	 0.0	 0.0	 1	 -30.0	 30.0;
	1309	 1041	 0.002021	 0.01419	 0.01911	 499.402625	 499.402625	 499.402625	 0.0	 0.0	 1	 -30.0	 30.0;
	1309	 31	 0.00324	 0.02076	 0.03178	 449.475013	 449.475013	 449.475013	 0.0	 0.0	 1	 -30.0	 30.0;
	1309	 31	 0.00318	 0.021159	 0.03113	 457.922537	 457.922537	 457.922537	 0.0	 0.0	 1	 -30.0	 30.0;
	1206	 6420	 0.031603	 0.070331	 0.0078	 71.665057	 71.665057	 71.665057	 0.0	 0.0	 1	 -30.0	 30.0;
	1974	 1206	 0.003132	 0.014554	 0.00179	 90.98378	 90.98378	 90.98378	 0.0	 0.0	 1	 -30.0	 30.0;
	1375	 1206	 0.006669	 0.032091	 0.0039	 75.184636	 75.184636	 75.184636	 0.0	 0.0	 1	 -30.0	 30.0;
	4257	 7934	 0.008934	 0.046298	 0.00485	 70.877615	 70.877615	 70.877615	 0.0	 0.0	 1	 -30.0	 30.0;
	827	 4833	 0.002942	 0.012008	 0.00157	 59.985648	 59.985648	 59.985648	 0.0	 0.0	 1	 -30.0	 30.0;
	5115	 3703	 0.010942	 0.062207	 0.00637	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6532	 5368	 0.002529	 0.011777	 0.0021	 58.79029	 58.79029	 58.79029	 0.0	 0.0	 1	 -30.0	 30.0;
	6532	 458	 0.015107	 0.042769	 0.00546	 76.878409	 76.878409	 76.878409	 0.0	 0.0	 1	 -30.0	 30.0;
	7843	 8197	 0.00705	 0.022099	 0.00213	 61.540718	 61.540718	 61.540718	 0.0	 0.0	 1	 -30.0	 30.0;
	5505	 3497	 0.038231	 0.105893	 0.00988	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3574	 5505	 0.005901	 0.021289	 0.00191	 88.846274	 88.846274	 88.846274	 0.0	 0.0	 1	 -30.0	 30.0;
	103	 4728	 0.013636	 0.022686	 0.00266	 64.832809	 64.832809	 64.832809	 0.0	 0.0	 1	 -30.0	 30.0;
	6368	 576	 0.023826	 0.059364	 0.00486	 62.390652	 62.390652	 62.390652	 0.0	 0.0	 1	 -30.0	 30.0;
	6420	 3203	 0.016091	 0.045967	 0.00392	 89.773181	 89.773181	 89.773181	 0.0	 0.0	 1	 -30.0	 30.0;
	3203	 3919	 0.017033	 0.053008	 0.00523	 125.92141	 125.92141	 125.92141	 0.0	 0.0	 1	 -30.0	 30.0;
	6692	 3497	 0.017744	 0.09686	 0.00967	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5368	 4623	 0.003636	 0.018818	 0.00197	 71.079762	 71.079762	 71.079762	 0.0	 0.0	 1	 -30.0	 30.0;
	5368	 4623	 0.003562	 0.019174	 0.00178	 70.250595	 70.250595	 70.250595	 0.0	 0.0	 1	 -30.0	 30.0;
	5945	 5088	 0.008256	 0.021909	 0.00163	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5088	 7070	 0.026917	 0.061636	 0.00643	 61.902716	 61.902716	 61.902716	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 4042	 0.022702	 0.057149	 0.00679	 57.213691	 57.213691	 57.213691	 0.0	 0.0	 1	 -30.0	 30.0;
	4042	 7498	 0.023983	 0.070124	 0.00701	 67.697933	 67.697933	 67.697933	 0.0	 0.0	 1	 -30.0	 30.0;
	3288	 2379	 0.035231	 0.078314	 0.00994	 75.763072	 75.763072	 75.763072	 0.0	 0.0	 1	 -30.0	 30.0;
	2379	 2776	 0.02462	 0.053603	 0.00603	 64.854339	 64.854339	 64.854339	 0.0	 0.0	 1	 -30.0	 30.0;
	3535	 4498	 0.008091	 0.03214	 0.00444	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	377	 3072	 0.016793	 0.081388	 0.00913	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3072	 1010	 0.008636	 0.047388	 0.00467	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4708	 6420	 0.009364	 0.018207	 0.00227	 59.146573	 59.146573	 59.146573	 0.0	 0.0	 1	 -30.0	 30.0;
	6420	 7408	 0.023331	 0.063727	 0.00567	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6420	 450	 0.014983	 0.033579	 0.00263	 68.147002	 68.147002	 68.147002	 0.0	 0.0	 1	 -30.0	 30.0;
	2858	 5565	 0.004636	 0.019678	 0.00249	 135.292411	 135.292411	 135.292411	 0.0	 0.0	 1	 -30.0	 30.0;
	2858	 5565	 0.004727	 0.019273	 0.00253	 115.155571	 115.155571	 115.155571	 0.0	 0.0	 1	 -30.0	 30.0;
	2732	 139	 0.018446	 0.089686	 0.01008	 88.802262	 88.802262	 88.802262	 0.0	 0.0	 1	 -30.0	 30.0;
	8153	 2732	 0.011529	 0.056587	 0.00679	 122.306378	 122.306378	 122.306378	 0.0	 0.0	 1	 -30.0	 30.0;
	7337	 5680	 0.00862	 0.021587	 0.00246	 81.898186	 81.898186	 81.898186	 0.0	 0.0	 1	 -30.0	 30.0;
	7337	 2884	 0.005702	 0.013017	 0.00109	 76.994629	 76.994629	 76.994629	 0.0	 0.0	 1	 -30.0	 30.0;
	6468	 583	 0.048256	 0.078099	 0.00918	 66.539919	 66.539919	 66.539919	 0.0	 0.0	 1	 -30.0	 30.0;
	583	 3913	 0.065529	 0.159802	 0.01323	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5475	 583	 0.02681	 0.110702	 0.01462	 63.106076	 63.106076	 63.106076	 0.0	 0.0	 1	 -30.0	 30.0;
	57	 1630	 0.04538	 0.142983	 0.01484	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 3005	 0.024992	 0.097777	 0.01516	 67.190754	 67.190754	 67.190754	 0.0	 0.0	 1	 -30.0	 30.0;
	7968	 3005	 0.020256	 0.109372	 0.01102	 66.176015	 66.176015	 66.176015	 0.0	 0.0	 1	 -30.0	 30.0;
	3005	 472	 0.024636	 0.095653	 0.0134	 73.941457	 73.941457	 73.941457	 0.0	 0.0	 1	 -30.0	 30.0;
	2014	 4622	 0.003364	 0.017669	 0.00182	 65.888702	 65.888702	 65.888702	 0.0	 0.0	 1	 -30.0	 30.0;
	3336	 8003	 0.018463	 0.039124	 0.005	 72.462597	 72.462597	 72.462597	 0.0	 0.0	 1	 -30.0	 30.0;
	8003	 1117	 0.021636	 0.060793	 0.00546	 62.890592	 62.890592	 62.890592	 0.0	 0.0	 1	 -30.0	 30.0;
	6600	 103	 0.01786	 0.039711	 0.00348	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2195	 3185	 0.00588	 0.03186	 0.0588	 274.905943	 274.905943	 274.905943	 0.0	 0.0	 1	 -30.0	 30.0;
	5267	 6652	 0.045058	 0.177512	 0.02556	 75.095089	 75.095089	 75.095089	 0.0	 0.0	 1	 -30.0	 30.0;
	6652	 2479	 0.003686	 0.017711	 0.00202	 69.176793	 69.176793	 69.176793	 0.0	 0.0	 1	 -30.0	 30.0;
	6652	 2479	 0.003612	 0.018058	 0.00198	 80.258333	 80.258333	 80.258333	 0.0	 0.0	 1	 -30.0	 30.0;
	6652	 2479	 0.007876	 0.021066	 0.00185	 66.344821	 66.344821	 66.344821	 0.0	 0.0	 1	 -30.0	 30.0;
	2054	 6652	 0.03186	 0.159347	 0.01917	 74.59515	 74.59515	 74.59515	 0.0	 0.0	 1	 -30.0	 30.0;
	2776	 3253	 0.034901	 0.071347	 0.00845	 71.907596	 71.907596	 71.907596	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 4874	 0.006339	 0.033281	 0.00355	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 4874	 0.006207	 0.033917	 0.00348	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3226	 4874	 0.006207	 0.034983	 0.00357	 65.092496	 65.092496	 65.092496	 0.0	 0.0	 1	 -30.0	 30.0;
	5917	 8153	 0.006289	 0.024661	 0.0034	 85.903606	 85.903606	 85.903606	 0.0	 0.0	 1	 -30.0	 30.0;
	5917	 6890	 0.002554	 0.01376	 0.00133	 83.267494	 83.267494	 83.267494	 0.0	 0.0	 1	 -30.0	 30.0;
	855	 1315	 0.003579	 0.01486	 0.00195	 62.884114	 62.884114	 62.884114	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 1686	 0.01495	 0.02843	 0.00223	 87.696452	 87.696452	 87.696452	 0.0	 0.0	 1	 -30.0	 30.0;
	4439	 6685	 0.011727	 0.028934	 0.00386	 64.946744	 64.946744	 64.946744	 0.0	 0.0	 1	 -30.0	 30.0;
	6685	 7843	 0.013843	 0.048909	 0.00445	 63.163805	 63.163805	 63.163805	 0.0	 0.0	 1	 -30.0	 30.0;
	1714	 1686	 0.032388	 0.080711	 0.00784	 78.387371	 78.387371	 78.387371	 0.0	 0.0	 1	 -30.0	 30.0;
	1714	 1686	 0.011719	 0.074793	 0.00718	 87.972333	 87.972333	 87.972333	 0.0	 0.0	 1	 -30.0	 30.0;
	1686	 5515	 0.00057	 0.002612	 0.00024	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2160	 1155	 0.012554	 0.026314	 0.00237	 68.939017	 68.939017	 68.939017	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 2160	 0.022554	 0.049397	 0.00465	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	855	 2547	 0.005438	 0.021669	 0.00296	 65.31522	 65.31522	 65.31522	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 1372	 0.00079	 0.00721	 0.16684	 1149.67273	 1149.67273	 1149.67273	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 3627	 0.00023	 0.00228	 0.05302	 1120.031625	 1120.031625	 1120.031625	 0.0	 0.0	 1	 -30.0	 30.0;
	7019	 8297	 0.002248	 0.012083	 0.00139	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7019	 8297	 0.002198	 0.012314	 0.00136	 64.012597	 64.012597	 64.012597	 0.0	 0.0	 1	 -30.0	 30.0;
	6655	 7059	 0.014727	 0.064099	 0.00876	 82.875392	 82.875392	 82.875392	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 6655	 0.016364	 0.040901	 0.00395	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4241	 6655	 0.024471	 0.063686	 0.00546	 67.912656	 67.912656	 67.912656	 0.0	 0.0	 1	 -30.0	 30.0;
	7544	 3537	 0.00037	 0.00429	 0.08614	 1196.955015	 1196.955015	 1196.955015	 0.0	 0.0	 1	 -30.0	 30.0;
	8343	 3537	 0.00201	 0.02375	 0.4777	 1301.012505	 1301.012505	 1301.012505	 0.0	 0.0	 1	 -30.0	 30.0;
	3537	 2671	 9e-05	 0.00093	 0.01831	 1421.584372	 1421.584372	 1421.584372	 0.0	 0.0	 1	 -30.0	 30.0;
	3537	 1743	 9e-05	 0.00095	 0.01793	 1437.982252	 1437.982252	 1437.982252	 0.0	 0.0	 1	 -30.0	 30.0;
	5487	 8296	 0.004969	 0.034979	 0.05007	 446.83471	 446.83471	 446.83471	 0.0	 0.0	 1	 -30.0	 30.0;
	5487	 8296	 0.00468	 0.033031	 0.04667	 434.264594	 434.264594	 434.264594	 0.0	 0.0	 1	 -30.0	 30.0;
	8296	 5836	 0.00076	 0.007909	 0.01917	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	8296	 4988	 0.020539	 0.080461	 0.12379	 494.392183	 494.392183	 494.392183	 0.0	 0.0	 1	 -30.0	 30.0;
	1714	 2528	 0.024562	 0.099231	 0.01335	 83.620919	 83.620919	 83.620919	 0.0	 0.0	 1	 -30.0	 30.0;
	1714	 2776	 0.103397	 0.231174	 0.0206	 72.37305	 72.37305	 72.37305	 0.0	 0.0	 1	 -30.0	 30.0;
	1714	 57	 0.063843	 0.141661	 0.01882	 68.102991	 68.102991	 68.102991	 0.0	 0.0	 1	 -30.0	 30.0;
	7544	 659	 0.00059	 0.00906	 0.18397	 1823.856325	 1823.856325	 1823.856325	 0.0	 0.0	 1	 -30.0	 30.0;
	5487	 5836	 0.001979	 0.02175	 0.05121	 225.666891	 225.666891	 225.666891	 0.0	 0.0	 1	 -30.0	 30.0;
	5487	 1924	 0.005281	 0.040039	 0.05891	 502.694526	 502.694526	 502.694526	 0.0	 0.0	 1	 -30.0	 30.0;
	5487	 502	 0.012281	 0.069219	 0.12107	 512.558417	 512.558417	 512.558417	 0.0	 0.0	 1	 -30.0	 30.0;
	5487	 6321	 0.00668	 0.04144	 0.07014	 535.256111	 535.256111	 535.256111	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 5587	 0.00725	 0.03801	 0.07109	 563.913827	 563.913827	 563.913827	 0.0	 0.0	 1	 -30.0	 30.0;
	3627	 1864	 0.00225	 0.02188	 0.48605	 1428.965195	 1428.965195	 1428.965195	 0.0	 0.0	 1	 -30.0	 30.0;
	5451	 1759	 0.00525	 0.03749	 0.05254	 528.586954	 528.586954	 528.586954	 0.0	 0.0	 1	 -30.0	 30.0;
	5451	 1759	 0.00605	 0.03069	 0.06171	 531.951255	 531.951255	 531.951255	 0.0	 0.0	 1	 -30.0	 30.0;
	3336	 2967	 0.054793	 0.13405	 0.0107	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7059	 3336	 0.019099	 0.076488	 0.00907	 87.050189	 87.050189	 87.050189	 0.0	 0.0	 1	 -30.0	 30.0;
	3336	 6230	 0.035686	 0.057678	 0.00692	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6129	 6398	 0.00481	 0.020579	 0.00264	 102.36997	 102.36997	 102.36997	 0.0	 0.0	 1	 -30.0	 30.0;
	6129	 6398	 0.004909	 0.020149	 0.00269	 62.519067	 62.519067	 62.519067	 0.0	 0.0	 1	 -30.0	 30.0;
	6129	 3919	 0.010843	 0.055512	 0.00616	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	6129	 3919	 0.012289	 0.054397	 0.00698	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	450	 6129	 0.003562	 0.018124	 0.00409	 61.812788	 61.812788	 61.812788	 0.0	 0.0	 1	 -30.0	 30.0;
	7906	 7449	 0.038017	 0.081934	 0.00907	 73.805612	 73.805612	 73.805612	 0.0	 0.0	 1	 -30.0	 30.0;
	7906	 1001	 0.020149	 0.083124	 0.01091	 68.172151	 68.172151	 68.172151	 0.0	 0.0	 1	 -30.0	 30.0;
	7906	 6106	 0.009554	 0.040959	 0.00562	 61.110321	 61.110321	 61.110321	 0.0	 0.0	 1	 -30.0	 30.0;
	2547	 7461	 0.008331	 0.043322	 0.00454	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7461	 1810	 0.02114	 0.114479	 0.01241	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 2967	 0.017488	 0.03838	 0.00337	 79.402301	 79.402301	 79.402301	 0.0	 0.0	 1	 -30.0	 30.0;
	6398	 3854	 0.00381	 0.019256	 0.00207	 83.920997	 83.920997	 83.920997	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 3854	 0.001397	 0.005802	 0.00076	 74.209907	 74.209907	 74.209907	 0.0	 0.0	 1	 -30.0	 30.0;
	2073	 5680	 0.004719	 0.024603	 0.0025	 81.041012	 81.041012	 81.041012	 0.0	 0.0	 1	 -30.0	 30.0;
	2073	 5680	 0.00462	 0.025058	 0.00245	 73.028458	 73.028458	 73.028458	 0.0	 0.0	 1	 -30.0	 30.0;
	2884	 5680	 0.005413	 0.027876	 0.00294	 71.093671	 71.093671	 71.093671	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 5267	 0.032041	 0.196413	 0.01877	 63.10036	 63.10036	 63.10036	 0.0	 0.0	 1	 -30.0	 30.0;
	1800	 5680	 0.002198	 0.022248	 0.00362	 128.199525	 128.199525	 128.199525	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 170	 0.00262	 0.018463	 0.00426	 152.788757	 152.788757	 152.788757	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 377	 0.030347	 0.112149	 0.01322	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3483	 6692	 0.014512	 0.05981	 0.00795	 59.468371	 59.468371	 59.468371	 0.0	 0.0	 1	 -30.0	 30.0;
	1155	 7500	 0.005438	 0.009124	 0.00105	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8279	 1196	 0.005169	 0.022219	 0.04108	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	649	 5928	 0.007793	 0.029769	 0.00423	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	649	 7248	 0.006091	 0.028653	 0.00357	 68.095179	 68.095179	 68.095179	 0.0	 0.0	 1	 -30.0	 30.0;
	3812	 4570	 0.02876	 0.060388	 0.00667	 88.349383	 88.349383	 88.349383	 0.0	 0.0	 1	 -30.0	 30.0;
	1495	 1748	 0.02443	 0.09576	 0.01327	 85.67326	 85.67326	 85.67326	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 1748	 0.009083	 0.03857	 0.00493	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2776	 690	 0.048157	 0.08462	 0.00702	 68.723151	 68.723151	 68.723151	 0.0	 0.0	 1	 -30.0	 30.0;
	4498	 2073	 0.002512	 0.013826	 0.00133	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7500	 5718	 0.012298	 0.026826	 0.00232	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7620	 7796	 0.022744	 0.133521	 0.01347	 61.933391	 61.933391	 61.933391	 0.0	 0.0	 1	 -30.0	 30.0;
	4833	 4439	 0.022554	 0.088876	 0.01237	 78.176841	 78.176841	 78.176841	 0.0	 0.0	 1	 -30.0	 30.0;
	6468	 7899	 0.019231	 0.033802	 0.00386	 72.759055	 72.759055	 72.759055	 0.0	 0.0	 1	 -30.0	 30.0;
	8077	 5945	 0.010017	 0.022711	 0.00247	 66.703771	 66.703771	 66.703771	 0.0	 0.0	 1	 -30.0	 30.0;
	8077	 458	 0.00219	 0.011843	 0.00128	 109.56898	 109.56898	 109.56898	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 5179	 0.019281	 0.064488	 0.00546	 70.648794	 70.648794	 70.648794	 0.0	 0.0	 1	 -30.0	 30.0;
	2358	 5179	 0.02119	 0.091727	 0.01158	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3913	 7986	 0.003099	 0.013893	 0.0018	 68.1752	 68.1752	 68.1752	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 7986	 0.004132	 0.021959	 0.00234	 61.612736	 61.612736	 61.612736	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 7986	 0.004041	 0.02238	 0.00229	 80.480105	 80.480105	 80.480105	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 7968	 0.002471	 0.010901	 0.0021	 67.535224	 67.535224	 67.535224	 0.0	 0.0	 1	 -30.0	 30.0;
	7055	 8343	 0.002	 0.017	 0.49082	 1295.439043	 1295.439043	 1295.439043	 0.0	 0.0	 1	 -30.0	 30.0;
	1091	 8343	 0.0016	 0.01758	 0.38197	 1147.856155	 1147.856155	 1147.856155	 0.0	 0.0	 1	 -30.0	 30.0;
	7620	 299	 0.027397	 0.111917	 0.01489	 63.746242	 63.746242	 63.746242	 0.0	 0.0	 1	 -30.0	 30.0;
	7620	 6428	 0.008752	 0.044802	 0.00478	 80.124774	 80.124774	 80.124774	 0.0	 0.0	 1	 -30.0	 30.0;
	649	 5718	 0.045727	 0.07386	 0.00879	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5267	 7730	 0.044281	 0.119579	 0.01069	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1231	 7730	 0.057612	 0.11224	 0.01489	 65.261873	 65.261873	 65.261873	 0.0	 0.0	 1	 -30.0	 30.0;
	3953	 7730	 0.063314	 0.107273	 0.00918	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 4708	 0.006769	 0.017909	 0.00162	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6348	 3812	 0.003273	 0.01157	 0.0011	 79.246832	 79.246832	 79.246832	 0.0	 0.0	 1	 -30.0	 30.0;
	6348	 489	 0.000248	 0.001331	 0.00014	 68.582734	 68.582734	 68.582734	 0.0	 0.0	 1	 -30.0	 30.0;
	2479	 2460	 0.010603	 0.045727	 0.00579	 101.117074	 101.117074	 101.117074	 0.0	 0.0	 1	 -30.0	 30.0;
	2460	 3953	 0.016273	 0.089678	 0.0088	 72.790301	 72.790301	 72.790301	 0.0	 0.0	 1	 -30.0	 30.0;
	3542	 6798	 0.008397	 0.022777	 0.00204	 72.484127	 72.484127	 72.484127	 0.0	 0.0	 1	 -30.0	 30.0;
	6798	 1289	 0.013421	 0.036314	 0.00296	 68.449747	 68.449747	 68.449747	 0.0	 0.0	 1	 -30.0	 30.0;
	8153	 3651	 0.009628	 0.050752	 0.00524	 63.688894	 63.688894	 63.688894	 0.0	 0.0	 1	 -30.0	 30.0;
	5447	 299	 0.011777	 0.046843	 0.0064	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 299	 0.014446	 0.059967	 0.00782	 60.48311	 60.48311	 60.48311	 0.0	 0.0	 1	 -30.0	 30.0;
	5267	 2054	 0.005174	 0.029562	 0.0036	 71.351642	 71.351642	 71.351642	 0.0	 0.0	 1	 -30.0	 30.0;
	7498	 2428	 0.069256	 0.110017	 0.01323	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1366	 1793	 0.00524	 0.022124	 0.00291	 61.27322	 61.27322	 61.27322	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 8129	 0.005083	 0.019421	 0.00198	 75.288663	 75.288663	 75.288663	 0.0	 0.0	 1	 -30.0	 30.0;
	8129	 1207	 0.004099	 0.013868	 0.00154	 60.799383	 60.799383	 60.799383	 0.0	 0.0	 1	 -30.0	 30.0;
	8071	 6600	 0.04181	 0.081397	 0.00789	 61.28427	 61.28427	 61.28427	 0.0	 0.0	 1	 -30.0	 30.0;
	8071	 6296	 0.041446	 0.067174	 0.00799	 63.029485	 63.029485	 63.029485	 0.0	 0.0	 1	 -30.0	 30.0;
	31	 2153	 0.008841	 0.0587	 0.08921	 484.907438	 484.907438	 484.907438	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 3226	 0.011876	 0.064	 0.01206	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5027	 2014	 0.037579	 0.182612	 0.02042	 62.655293	 62.655293	 62.655293	 0.0	 0.0	 1	 -30.0	 30.0;
	139	 6614	 0.025752	 0.129421	 0.01394	 104.206637	 104.206637	 104.206637	 0.0	 0.0	 1	 -30.0	 30.0;
	1793	 7495	 0.00543	 0.011421	 0.00103	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7495	 3574	 0.003727	 0.010066	 0.00091	 84.65433	 84.65433	 84.65433	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 6452	 0.015868	 0.053702	 0.00512	 70.622882	 70.622882	 70.622882	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 8071	 0.026388	 0.120603	 0.01437	 69.888025	 69.888025	 69.888025	 0.0	 0.0	 1	 -30.0	 30.0;
	7300	 1974	 0.002372	 0.010669	 0.00138	 119.689509	 119.689509	 119.689509	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 1207	 0.001289	 0.005041	 0.00052	 71.319634	 71.319634	 71.319634	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 3316	 0.001438	 0.006421	 0.00079	 83.225388	 83.225388	 83.225388	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 6288	 0.001471	 0.006289	 0.0008	 61.915101	 61.915101	 61.915101	 0.0	 0.0	 1	 -30.0	 30.0;
	3627	 1091	 0.00105	 0.01056	 0.23998	 1115.725157	 1115.725157	 1115.725157	 0.0	 0.0	 1	 -30.0	 30.0;
	2596	 31	 0.01137	 0.056789	 0.11233	 395.555129	 395.555129	 395.555129	 0.0	 0.0	 1	 -30.0	 30.0;
	602	 31	 0.00519	 0.028151	 0.04155	 492.20152	 492.20152	 492.20152	 0.0	 0.0	 1	 -30.0	 30.0;
	1495	 5409	 0.030091	 0.150033	 0.01638	 65.392764	 65.392764	 65.392764	 0.0	 0.0	 1	 -30.0	 30.0;
	5475	 83	 0.011207	 0.023851	 0.00269	 70.191151	 70.191151	 70.191151	 0.0	 0.0	 1	 -30.0	 30.0;
	83	 7751	 0.073347	 0.103488	 0.01038	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4951	 5778	 0.064149	 0.131041	 0.01542	 120.636611	 120.636611	 120.636611	 0.0	 0.0	 1	 -30.0	 30.0;
	1422	 1196	 0.002341	 0.009719	 0.01369	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5058	 254	 0.051231	 0.126554	 0.01203	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1117	 254	 0.031967	 0.079413	 0.00783	 75.20426	 75.20426	 75.20426	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 489	 0.00024	 0.001	 0.00014	 65.975391	 65.975391	 65.975391	 0.0	 0.0	 1	 -30.0	 30.0;
	5053	 2785	 0.034008	 0.069388	 0.00823	 87.072099	 87.072099	 87.072099	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 936	 0.003	 0.01243	 0.00172	 73.796276	 73.796276	 73.796276	 0.0	 0.0	 1	 -30.0	 30.0;
	936	 6786	 0.036281	 0.073678	 0.00711	 75.888057	 75.888057	 75.888057	 0.0	 0.0	 1	 -30.0	 30.0;
	1974	 2943	 0.003587	 0.017231	 0.00211	 75.905204	 75.905204	 75.905204	 0.0	 0.0	 1	 -30.0	 30.0;
	1664	 6321	 0.00012	 0.00062	 0.00111	 308.706325	 308.706325	 308.706325	 0.0	 0.0	 1	 -30.0	 30.0;
	6759	 6106	 0.006909	 0.039231	 0.00406	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5897	 5898	 0.003314	 0.007017	 0.00255	 82.372595	 82.372595	 82.372595	 0.0	 0.0	 1	 -30.0	 30.0;
	8089	 8153	 0.011289	 0.063661	 0.00613	 69.206705	 69.206705	 69.206705	 0.0	 0.0	 1	 -30.0	 30.0;
	8089	 8153	 0.01105	 0.058942	 0.00599	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6890	 8153	 0.007711	 0.039413	 0.00414	 99.052348	 99.052348	 99.052348	 0.0	 0.0	 1	 -30.0	 30.0;
	513	 217	 0.004017	 0.013669	 0.00132	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3515	 1132	 0.040521	 0.08386	 0.00967	 75.404503	 75.404503	 75.404503	 0.0	 0.0	 1	 -30.0	 30.0;
	2317	 2422	 0.024579	 0.061231	 0.00595	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2785	 3684	 0.067992	 0.151463	 0.01636	 69.514785	 69.514785	 69.514785	 0.0	 0.0	 1	 -30.0	 30.0;
	4562	 7710	 0.003579	 0.011942	 0.00144	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5897	 380	 0.00776	 0.021587	 0.00172	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8089	 7339	 0.003298	 0.009463	 0.00308	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7380	 7339	 0.005157	 0.01376	 0.00125	 74.622014	 74.622014	 74.622014	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 7380	 0.009934	 0.034479	 0.00427	 74.629064	 74.629064	 74.629064	 0.0	 0.0	 1	 -30.0	 30.0;
	3316	 1375	 0.002008	 0.010802	 0.00118	 78.877213	 78.877213	 78.877213	 0.0	 0.0	 1	 -30.0	 30.0;
	6288	 2943	 0.001967	 0.011008	 0.00116	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	592	 5270	 0.003219	 0.01439	 0.05131	 254.361949	 254.361949	 254.361949	 0.0	 0.0	 1	 -30.0	 30.0;
	592	 1761	 0.00239	 0.01426	 0.05989	 240.649442	 240.649442	 240.649442	 0.0	 0.0	 1	 -30.0	 30.0;
	7869	 5914	 0.00143	 0.013591	 0.0415	 606.721117	 606.721117	 606.721117	 0.0	 0.0	 1	 -30.0	 30.0;
	7869	 6545	 0.004669	 0.05795	 0.13416	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7869	 1417	 0.00412	 0.043151	 0.07423	 628.09542	 628.09542	 628.09542	 0.0	 0.0	 1	 -30.0	 30.0;
	7869	 2843	 0.000521	 0.00612	 0.02052	 314.757799	 314.757799	 314.757799	 0.0	 0.0	 1	 -30.0	 30.0;
	4943	 4374	 0.005849	 0.02768	 0.00824	 278.91907	 278.91907	 278.91907	 0.0	 0.0	 1	 -30.0	 30.0;
	4331	 4943	 0.012742	 0.049311	 0.01307	 279.160691	 279.160691	 279.160691	 0.0	 0.0	 1	 -30.0	 30.0;
	5814	 6545	 0.00206	 0.01061	 0.03339	 368.383131	 368.383131	 368.383131	 0.0	 0.0	 1	 -30.0	 30.0;
	5814	 1830	 0.001591	 0.01	 0.02584	 229.462541	 229.462541	 229.462541	 0.0	 0.0	 1	 -30.0	 30.0;
	1163	 1421	 0.00098	 0.00874	 0.26102	 1561.412591	 1561.412591	 1561.412591	 0.0	 0.0	 1	 -30.0	 30.0;
	1163	 5017	 0.00045	 0.00548	 0.11706	 856.068155	 856.068155	 856.068155	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 5439	 0.000719	 0.003349	 0.0115	 262.990853	 262.990853	 262.990853	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 2055	 0.000919	 0.00687	 0.0211	 284.610173	 284.610173	 284.610173	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 5746	 0.000219	 0.0015	 0.0058	 288.601303	 288.601303	 288.601303	 0.0	 0.0	 1	 -30.0	 30.0;
	2980	 2377	 0.00355	 0.019669	 0.02695	 596.841603	 596.841603	 596.841603	 0.0	 0.0	 1	 -30.0	 30.0;
	2980	 682	 0.00389	 0.02201	 0.0313	 510.812059	 510.812059	 510.812059	 0.0	 0.0	 1	 -30.0	 30.0;
	2980	 6562	 0.00251	 0.01455	 0.02093	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	4022	 4142	 0.00825	 0.036781	 0.09258	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4022	 3804	 0.000581	 0.00412	 0.01069	 600.961147	 600.961147	 600.961147	 0.0	 0.0	 1	 -30.0	 30.0;
	6146	 8085	 0.00103	 0.01236	 0.26718	 1493.191648	 1493.191648	 1493.191648	 0.0	 0.0	 1	 -30.0	 30.0;
	6146	 5017	 0.0014	 0.01768	 0.36691	 1373.404989	 1373.404989	 1373.404989	 0.0	 0.0	 1	 -30.0	 30.0;
	4933	 321	 0.00088	 0.01169	 0.04491	 287.849108	 287.849108	 287.849108	 0.0	 0.0	 1	 -30.0	 30.0;
	3598	 131	 0.001711	 0.01164	 0.01869	 629.653539	 629.653539	 629.653539	 0.0	 0.0	 1	 -30.0	 30.0;
	3598	 4055	 0.00268	 0.015031	 0.02919	 565.757734	 565.757734	 565.757734	 0.0	 0.0	 1	 -30.0	 30.0;
	3598	 8217	 0.0018	 0.01132	 0.02123	 574.654136	 574.654136	 574.654136	 0.0	 0.0	 1	 -30.0	 30.0;
	1023	 3836	 0.00051	 0.00268	 0.11874	 477.988692	 477.988692	 477.988692	 0.0	 0.0	 1	 -30.0	 30.0;
	1023	 2265	 0.000651	 0.003289	 0.05377	 423.314326	 423.314326	 423.314326	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 3826	 0.0012	 0.01137	 0.31943	 1754.409193	 1754.409193	 1754.409193	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 6046	 0.00168	 0.02275	 0.45155	 1747.421304	 1747.421304	 1747.421304	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 5439	 0.002331	 0.0225	 0.06862	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 5439	 0.002081	 0.0255	 0.06113	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 624	 0.000781	 0.004979	 0.0118	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 1994	 0.00514	 0.06699	 0.15273	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6775	 3175	 0.00088	 0.00804	 0.2287	 1945.372021	 1945.372021	 1945.372021	 0.0	 0.0	 1	 -30.0	 30.0;
	6775	 2979	 0.00032	 0.00311	 0.08594	 1694.202899	 1694.202899	 1694.202899	 0.0	 0.0	 1	 -30.0	 30.0;
	6775	 198	 0.00015	 0.00197	 0.0682	 1027.065114	 1027.065114	 1027.065114	 0.0	 0.0	 1	 -30.0	 30.0;
	6968	 5270	 0.004719	 0.023831	 0.07504	 448.094084	 448.094084	 448.094084	 0.0	 0.0	 1	 -30.0	 30.0;
	6968	 2055	 0.00669	 0.029979	 0.23504	 461.993688	 461.993688	 461.993688	 0.0	 0.0	 1	 -30.0	 30.0;
	8312	 7607	 0.001031	 0.01225	 0.08539	 337.939428	 337.939428	 337.939428	 0.0	 0.0	 1	 -30.0	 30.0;
	8312	 7795	 0.00105	 0.00937	 0.03855	 555.216715	 555.216715	 555.216715	 0.0	 0.0	 1	 -30.0	 30.0;
	8312	 854	 0.00201	 0.01293	 0.03199	 406.708116	 406.708116	 406.708116	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 682	 0.002	 0.012229	 0.02204	 555.371803	 555.371803	 555.371803	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 1752	 8.1e-05	 0.000521	 0.00167	 401.483523	 401.483523	 401.483523	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 5914	 0.00113	 0.010969	 0.03293	 277.930346	 277.930346	 277.930346	 0.0	 0.0	 1	 -30.0	 30.0;
	8085	 7930	 0.00195	 0.02538	 0.46869	 1871.519696	 1871.519696	 1871.519696	 0.0	 0.0	 1	 -30.0	 30.0;
	8085	 2979	 0.00164	 0.01684	 0.43143	 1541.922586	 1541.922586	 1541.922586	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 5351	 0.006289	 0.06895	 0.18349	 327.946742	 327.946742	 327.946742	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 8161	 0.001169	 0.010229	 0.02277	 248.393164	 248.393164	 248.393164	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 5302	 0.00805	 0.060409	 0.09432	 233.075669	 233.075669	 233.075669	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 5302	 0.00789	 0.061581	 0.09236	 291.341823	 291.341823	 291.341823	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 6545	 0.007159	 0.04164	 0.08886	 540.540529	 540.540529	 540.540529	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 6545	 0.007289	 0.040729	 0.09051	 538.323192	 538.323192	 538.323192	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 6372	 0.004531	 0.02731	 0.04807	 313.792215	 313.792215	 313.792215	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 968	 0.004521	 0.033581	 0.05003	 535.224103	 535.224103	 535.224103	 0.0	 0.0	 1	 -30.0	 30.0;
	7607	 3095	 0.0005	 0.005081	 0.01489	 271.808759	 271.808759	 271.808759	 0.0	 0.0	 1	 -30.0	 30.0;
	7607	 736	 0.00132	 0.006521	 0.0205	 232.105131	 232.105131	 232.105131	 0.0	 0.0	 1	 -30.0	 30.0;
	4823	 5351	 0.004401	 0.030531	 0.05633	 321.780953	 321.780953	 321.780953	 0.0	 0.0	 1	 -30.0	 30.0;
	4823	 1417	 0.000469	 0.003409	 0.00602	 643.524564	 643.524564	 643.524564	 0.0	 0.0	 1	 -30.0	 30.0;
	2767	 3175	 0.00239	 0.02364	 0.61786	 1789.503314	 1789.503314	 1789.503314	 0.0	 0.0	 1	 -30.0	 30.0;
	2767	 3935	 0.00034	 0.0041	 0.08806	 1779.587843	 1779.587843	 1779.587843	 0.0	 0.0	 1	 -30.0	 30.0;
	2767	 6046	 0.00027	 0.00327	 0.06986	 1660.801616	 1660.801616	 1660.801616	 0.0	 0.0	 1	 -30.0	 30.0;
	2767	 6046	 0.00026	 0.00333	 0.0684	 1802.813016	 1802.813016	 1802.813016	 0.0	 0.0	 1	 -30.0	 30.0;
	2767	 2463	 0.00059	 0.00574	 0.156	 1570.311834	 1570.311834	 1570.311834	 0.0	 0.0	 1	 -30.0	 30.0;
	926	 7062	 0.000789	 0.003711	 0.01196	 286.46513	 286.46513	 286.46513	 0.0	 0.0	 1	 -30.0	 30.0;
	926	 6829	 0.00419	 0.04988	 0.11703	 219.752976	 219.752976	 219.752976	 0.0	 0.0	 1	 -30.0	 30.0;
	926	 4766	 0.001651	 0.010919	 0.02403	 219.571596	 219.571596	 219.571596	 0.0	 0.0	 1	 -30.0	 30.0;
	2263	 6372	 0.007281	 0.03162	 0.08034	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2263	 2081	 0.006831	 0.03505	 0.0666	 578.552289	 578.552289	 578.552289	 0.0	 0.0	 1	 -30.0	 30.0;
	3175	 5017	 0.00108	 0.01258	 0.28231	 1655.293313	 1655.293313	 1655.293313	 0.0	 0.0	 1	 -30.0	 30.0;
	3175	 3935	 0.00174	 0.0229	 0.45216	 1571.534731	 1571.534731	 1571.534731	 0.0	 0.0	 1	 -30.0	 30.0;
	3175	 2463	 0.00223	 0.02125	 0.57705	 1704.155229	 1704.155229	 1704.155229	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 5439	 0.0023	 0.014081	 0.03657	 369.777398	 369.777398	 369.777398	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 1761	 0.00213	 0.026831	 0.0619	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 5259	 0.001039	 0.00549	 0.0166	 282.818851	 282.818851	 282.818851	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 7502	 0.00301	 0.016711	 0.04538	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 1279	 0.000849	 0.005229	 0.01351	 355.522273	 355.522273	 355.522273	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 1461	 0.002781	 0.020281	 0.0376	 598.577672	 598.577672	 598.577672	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 854	 0.002159	 0.01389	 0.03437	 322.978978	 322.978978	 322.978978	 0.0	 0.0	 1	 -30.0	 30.0;
	135	 7378	 0.003502	 0.031631	 0.00912	 332.210809	 332.210809	 332.210809	 0.0	 0.0	 1	 -30.0	 30.0;
	4374	 6353	 0.003929	 0.024729	 0.01023	 271.951029	 271.951029	 271.951029	 0.0	 0.0	 1	 -30.0	 30.0;
	6353	 135	 0.00076	 0.005609	 0.00197	 262.590161	 262.590161	 262.590161	 0.0	 0.0	 1	 -30.0	 30.0;
	2377	 3836	 0.002039	 0.01249	 0.01547	 539.720126	 539.720126	 539.720126	 0.0	 0.0	 1	 -30.0	 30.0;
	4492	 7930	 0.00036	 0.00572	 0.15238	 1958.417793	 1958.417793	 1958.417793	 0.0	 0.0	 1	 -30.0	 30.0;
	4492	 1039	 0.00028	 0.00448	 0.10868	 1905.371174	 1905.371174	 1905.371174	 0.0	 0.0	 1	 -30.0	 30.0;
	2715	 5351	 0.001091	 0.01663	 0.05227	 474.976482	 474.976482	 474.976482	 0.0	 0.0	 1	 -30.0	 30.0;
	2715	 6372	 0.011909	 0.080909	 0.1231	 482.510245	 482.510245	 482.510245	 0.0	 0.0	 1	 -30.0	 30.0;
	2715	 131	 0.000401	 0.00232	 0.00894	 392.08299	 392.08299	 392.08299	 0.0	 0.0	 1	 -30.0	 30.0;
	2715	 131	 0.000349	 0.00263	 0.00797	 354.583363	 354.583363	 354.583363	 0.0	 0.0	 1	 -30.0	 30.0;
	1353	 5420	 0.000531	 0.0063	 0.02412	 307.666437	 307.666437	 307.666437	 0.0	 0.0	 1	 -30.0	 30.0;
	1353	 419	 0.005531	 0.02938	 0.05367	 534.532114	 534.532114	 534.532114	 0.0	 0.0	 1	 -30.0	 30.0;
	1353	 7165	 0.00019	 0.002521	 0.00785	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5420	 5351	 0.00075	 0.010909	 0.03263	 511.465943	 511.465943	 511.465943	 0.0	 0.0	 1	 -30.0	 30.0;
	7579	 3804	 0.007	 0.03088	 0.07578	 644.41508	 644.41508	 644.41508	 0.0	 0.0	 1	 -30.0	 30.0;
	7579	 4055	 0.002349	 0.009281	 0.02529	 569.47565	 569.47565	 569.47565	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 4751	 0.003219	 0.02125	 0.04809	 291.559784	 291.559784	 291.559784	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 4751	 0.004461	 0.027961	 0.05305	 531.340048	 531.340048	 531.340048	 0.0	 0.0	 1	 -30.0	 30.0;
	4761	 3901	 0.00105	 0.007901	 0.02657	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	6095	 4142	 0.002461	 0.01019	 0.02723	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6095	 3804	 0.00605	 0.028409	 0.06875	 536.893488	 536.893488	 536.893488	 0.0	 0.0	 1	 -30.0	 30.0;
	1912	 854	 7e-05	 0.00039	 0.00104	 252.383151	 252.383151	 252.383151	 0.0	 0.0	 1	 -30.0	 30.0;
	5439	 1761	 0.0047	 0.02175	 0.09382	 503.639914	 503.639914	 503.639914	 0.0	 0.0	 1	 -30.0	 30.0;
	6762	 3954	 0.00118	 0.00719	 0.01343	 605.0041	 605.0041	 605.0041	 0.0	 0.0	 1	 -30.0	 30.0;
	6762	 206	 0.002349	 0.01887	 0.02665	 345.582934	 345.582934	 345.582934	 0.0	 0.0	 1	 -30.0	 30.0;
	1914	 1446	 0.00104	 0.01314	 0.27809	 1906.389377	 1906.389377	 1906.389377	 0.0	 0.0	 1	 -30.0	 30.0;
	1914	 6046	 0.0004	 0.004	 0.10249	 2006.470806	 2006.470806	 2006.470806	 0.0	 0.0	 1	 -30.0	 30.0;
	8161	 6060	 0.001289	 0.006229	 0.01022	 482.011449	 482.011449	 482.011449	 0.0	 0.0	 1	 -30.0	 30.0;
	8161	 3246	 0.00555	 0.035419	 0.04153	 451.028559	 451.028559	 451.028559	 0.0	 0.0	 1	 -30.0	 30.0;
	8161	 3246	 0.00381	 0.0328	 0.04063	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4142	 5356	 0.00093	 0.006841	 0.02087	 251.965519	 251.965519	 251.965519	 0.0	 0.0	 1	 -30.0	 30.0;
	4142	 5356	 0.000909	 0.006979	 0.02045	 248.63818	 248.63818	 248.63818	 0.0	 0.0	 1	 -30.0	 30.0;
	2795	 5064	 0.001091	 0.0082	 0.01442	 523.098293	 523.098293	 523.098293	 0.0	 0.0	 1	 -30.0	 30.0;
	2795	 4316	 0.002081	 0.020419	 0.04497	 508.625588	 508.625588	 508.625588	 0.0	 0.0	 1	 -30.0	 30.0;
	3901	 3118	 0.00082	 0.00276	 0.00857	 237.060321	 237.060321	 237.060321	 0.0	 0.0	 1	 -30.0	 30.0;
	3901	 6372	 0.00162	 0.007021	 0.01655	 251.328782	 251.328782	 251.328782	 0.0	 0.0	 1	 -30.0	 30.0;
	7143	 5302	 0.002831	 0.015021	 0.02115	 573.192042	 573.192042	 573.192042	 0.0	 0.0	 1	 -30.0	 30.0;
	7143	 119	 0.006781	 0.03026	 0.05171	 515.199483	 515.199483	 515.199483	 0.0	 0.0	 1	 -30.0	 30.0;
	1421	 2979	 0.00041	 0.00523	 0.11604	 1801.454534	 1801.454534	 1801.454534	 0.0	 0.0	 1	 -30.0	 30.0;
	1421	 3826	 0.00062	 0.0098	 0.21409	 1839.228102	 1839.228102	 1839.228102	 0.0	 0.0	 1	 -30.0	 30.0;
	1421	 3826	 0.00083	 0.00975	 0.21448	 1857.40504	 1857.40504	 1857.40504	 0.0	 0.0	 1	 -30.0	 30.0;
	3246	 7795	 0.00131	 0.01564	 0.05189	 275.592597	 275.592597	 275.592597	 0.0	 0.0	 1	 -30.0	 30.0;
	3246	 6545	 0.002039	 0.026831	 0.07657	 232.284987	 232.284987	 232.284987	 0.0	 0.0	 1	 -30.0	 30.0;
	3246	 4316	 0.001031	 0.00945	 0.02885	 339.193087	 339.193087	 339.193087	 0.0	 0.0	 1	 -30.0	 30.0;
	3246	 3406	 0.001789	 0.015211	 0.04788	 275.126952	 275.126952	 275.126952	 0.0	 0.0	 1	 -30.0	 30.0;
	1761	 6545	 0.003021	 0.03739	 0.10346	 232.8478	 232.8478	 232.8478	 0.0	 0.0	 1	 -30.0	 30.0;
	1761	 343	 0.004211	 0.04031	 0.12272	 305.323353	 305.323353	 305.323353	 0.0	 0.0	 1	 -30.0	 30.0;
	1761	 3229	 0.004979	 0.029409	 0.08011	 614.022057	 614.022057	 614.022057	 0.0	 0.0	 1	 -30.0	 30.0;
	1761	 3229	 0.00488	 0.029979	 0.07848	 353.703897	 353.703897	 353.703897	 0.0	 0.0	 1	 -30.0	 30.0;
	1761	 2173	 0.002211	 0.02399	 0.06523	 251.11044	 251.11044	 251.11044	 0.0	 0.0	 1	 -30.0	 30.0;
	1761	 2173	 0.00231	 0.023021	 0.06769	 230.077177	 230.077177	 230.077177	 0.0	 0.0	 1	 -30.0	 30.0;
	419	 6372	 0.00719	 0.046841	 0.07983	 560.755294	 560.755294	 560.755294	 0.0	 0.0	 1	 -30.0	 30.0;
	1113	 5302	 0.00155	 0.00968	 0.02973	 484.421598	 484.421598	 484.421598	 0.0	 0.0	 1	 -30.0	 30.0;
	1113	 5302	 0.0015	 0.01051	 0.02831	 270.95025	 270.95025	 270.95025	 0.0	 0.0	 1	 -30.0	 30.0;
	1113	 2766	 0.00169	 0.013401	 0.01813	 259.96264	 259.96264	 259.96264	 0.0	 0.0	 1	 -30.0	 30.0;
	1113	 2314	 0.001659	 0.012409	 0.01774	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	2462	 6372	 0.005091	 0.0167	 0.05619	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2462	 2081	 0.009919	 0.04649	 0.10071	 568.75051	 568.75051	 568.75051	 0.0	 0.0	 1	 -30.0	 30.0;
	1876	 4766	 9.1e-05	 0.000531	 0.00124	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5302	 6545	 0.00982	 0.045331	 0.10057	 556.001681	 556.001681	 556.001681	 0.0	 0.0	 1	 -30.0	 30.0;
	5302	 8320	 0.003039	 0.02964	 0.09625	 216.573485	 216.573485	 216.573485	 0.0	 0.0	 1	 -30.0	 30.0;
	1752	 3621	 0.004159	 0.02051	 0.0658	 390.493245	 390.493245	 390.493245	 0.0	 0.0	 1	 -30.0	 30.0;
	3118	 6372	 0.00087	 0.00469	 0.01383	 245.892706	 245.892706	 245.892706	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 526	 0.0017	 0.021039	 0.04746	 417.060514	 417.060514	 417.060514	 0.0	 0.0	 1	 -30.0	 30.0;
	2979	 198	 0.00019	 0.0032	 0.08677	 911.329548	 911.329548	 911.329548	 0.0	 0.0	 1	 -30.0	 30.0;
	2254	 2655	 0.006979	 0.03975	 0.10729	 506.157519	 506.157519	 506.157519	 0.0	 0.0	 1	 -30.0	 30.0;
	2254	 526	 0.000521	 0.004081	 0.0572	 328.735518	 328.735518	 328.735518	 0.0	 0.0	 1	 -30.0	 30.0;
	2254	 968	 0.00382	 0.02214	 0.0701	 557.93361	 557.93361	 557.93361	 0.0	 0.0	 1	 -30.0	 30.0;
	1246	 3826	 0.00204	 0.02487	 0.52209	 1688.658397	 1688.658397	 1688.658397	 0.0	 0.0	 1	 -30.0	 30.0;
	5914	 3836	 0.00312	 0.018469	 0.03241	 573.969768	 573.969768	 573.969768	 0.0	 0.0	 1	 -30.0	 30.0;
	2655	 6372	 0.005479	 0.038841	 0.06048	 554.350205	 554.350205	 554.350205	 0.0	 0.0	 1	 -30.0	 30.0;
	119	 6545	 0.000789	 0.007729	 0.03256	 289.582129	 289.582129	 289.582129	 0.0	 0.0	 1	 -30.0	 30.0;
	5244	 6562	 0.001789	 0.01618	 0.02179	 586.898453	 586.898453	 586.898453	 0.0	 0.0	 1	 -30.0	 30.0;
	5244	 6562	 0.00175	 0.016479	 0.02133	 566.512215	 566.512215	 566.512215	 0.0	 0.0	 1	 -30.0	 30.0;
	6562	 3621	 0.00375	 0.025099	 0.05933	 306.419256	 306.419256	 306.419256	 0.0	 0.0	 1	 -30.0	 30.0;
	1472	 5835	 0.010778	 0.035609	 0.0	 196.218667	 196.218667	 196.218667	 0.0	 0.0	 1	 -30.0	 30.0;
	5835	 1472	 0.0096	 0.04036	 0.0	 195.501598	 195.501598	 195.501598	 0.0	 0.0	 1	 -30.0	 30.0;
	7201	 3804	 0.001031	 0.016919	 0.04358	 292.691506	 292.691506	 292.691506	 0.0	 0.0	 1	 -30.0	 30.0;
	7201	 3804	 0.00101	 0.01725	 0.04268	 229.717084	 229.717084	 229.717084	 0.0	 0.0	 1	 -30.0	 30.0;
	6545	 4438	 0.00124	 0.013169	 0.03573	 278.910028	 278.910028	 278.910028	 0.0	 0.0	 1	 -30.0	 30.0;
	6545	 4438	 0.00119	 0.01356	 0.03384	 606.962322	 606.962322	 606.962322	 0.0	 0.0	 1	 -30.0	 30.0;
	6545	 3406	 0.00119	 0.013281	 0.03282	 282.908779	 282.908779	 282.908779	 0.0	 0.0	 1	 -30.0	 30.0;
	3954	 6770	 0.00306	 0.02405	 0.03112	 351.538383	 351.538383	 351.538383	 0.0	 0.0	 1	 -30.0	 30.0;
	3954	 4751	 0.002469	 0.018081	 0.02783	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	7015	 5681	 0.0018	 0.014651	 0.04525	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7015	 2173	 0.001081	 0.010219	 0.03127	 245.254826	 245.254826	 245.254826	 0.0	 0.0	 1	 -30.0	 30.0;
	5681	 6829	 0.000669	 0.003521	 0.00934	 319.23858	 319.23858	 319.23858	 0.0	 0.0	 1	 -30.0	 30.0;
	6372	 321	 0.001039	 0.0142	 0.05059	 371.401438	 371.401438	 371.401438	 0.0	 0.0	 1	 -30.0	 30.0;
	6372	 1637	 0.002771	 0.019919	 0.05964	 235.887445	 235.887445	 235.887445	 0.0	 0.0	 1	 -30.0	 30.0;
	3095	 4438	 0.00295	 0.013401	 0.02644	 221.182299	 221.182299	 221.182299	 0.0	 0.0	 1	 -30.0	 30.0;
	4438	 2055	 0.00411	 0.02488	 0.15424	 224.066857	 224.066857	 224.066857	 0.0	 0.0	 1	 -30.0	 30.0;
	4438	 7694	 0.00061	 0.007211	 0.00216	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	968	 736	 0.002219	 0.011081	 0.03524	 241.588352	 241.588352	 241.588352	 0.0	 0.0	 1	 -30.0	 30.0;
	6488	 2692	 6e-05	 0.00066	 0.01637	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3836	 2314	 0.00411	 0.026081	 0.03724	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	8381	 6046	 0.00168	 0.02222	 0.41917	 1557.843285	 1557.843285	 1557.843285	 0.0	 0.0	 1	 -30.0	 30.0;
	8381	 2692	 0.00049	 0.0061	 0.13519	 1846.049473	 1846.049473	 1846.049473	 0.0	 0.0	 1	 -30.0	 30.0;
	2055	 5746	 0.00082	 0.00575	 0.01892	 332.007224	 332.007224	 332.007224	 0.0	 0.0	 1	 -30.0	 30.0;
	7165	 2081	 0.001409	 0.01918	 0.06003	 268.796168	 268.796168	 268.796168	 0.0	 0.0	 1	 -30.0	 30.0;
	5259	 7502	 0.001841	 0.011159	 0.0291	 228.849049	 228.849049	 228.849049	 0.0	 0.0	 1	 -30.0	 30.0;
	3714	 2692	 0.00109	 0.01044	 0.29924	 2080.512029	 2080.512029	 2080.512029	 0.0	 0.0	 1	 -30.0	 30.0;
	4394	 1039	 0.00088	 0.01608	 0.35869	 1936.117362	 1936.117362	 1936.117362	 0.0	 0.0	 1	 -30.0	 30.0;
	3804	 3979	 0.000591	 0.007781	 0.0252	 282.067418	 282.067418	 282.067418	 0.0	 0.0	 1	 -30.0	 30.0;
	3804	 2809	 0.001901	 0.0247	 0.0804	 295.424786	 295.424786	 295.424786	 0.0	 0.0	 1	 -30.0	 30.0;
	7062	 6184	 0.00382	 0.018401	 0.0563	 278.729791	 278.729791	 278.729791	 0.0	 0.0	 1	 -30.0	 30.0;
	6829	 6184	 0.004169	 0.02775	 0.06151	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6829	 2173	 0.001849	 0.01889	 0.05159	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2081	 2809	 0.00076	 0.01036	 0.03222	 285.671019	 285.671019	 285.671019	 0.0	 0.0	 1	 -30.0	 30.0;
	1830	 624	 0.00207	 0.009849	 0.03353	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7089	 343	 0.001849	 0.013841	 0.04527	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7089	 343	 0.00243	 0.015771	 0.03613	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6046	 1507	 0.00128	 0.01149	 0.31595	 1705.405769	 1705.405769	 1705.405769	 0.0	 0.0	 1	 -30.0	 30.0;
	1994	 654	 0.00057	 0.005961	 0.01659	 300.24013	 300.24013	 300.24013	 0.0	 0.0	 1	 -30.0	 30.0;
	1994	 5785	 0.00218	 0.015099	 0.02858	 280.854152	 280.854152	 280.854152	 0.0	 0.0	 1	 -30.0	 30.0;
	343	 4766	 0.00131	 0.008771	 0.02664	 559.075239	 559.075239	 559.075239	 0.0	 0.0	 1	 -30.0	 30.0;
	654	 5785	 0.00163	 0.008729	 0.0132	 262.250471	 262.250471	 262.250471	 0.0	 0.0	 1	 -30.0	 30.0;
	1279	 4272	 0.004831	 0.02588	 0.06123	 537.49936	 537.49936	 537.49936	 0.0	 0.0	 1	 -30.0	 30.0;
	206	 2843	 0.00062	 0.00857	 0.02449	 270.033822	 270.033822	 270.033822	 0.0	 0.0	 1	 -30.0	 30.0;
	3979	 5356	 0.002281	 0.0362	 0.10585	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1637	 8320	 0.00132	 0.01036	 0.02782	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 2173	 0.00281	 0.017099	 0.04517	 245.630543	 245.630543	 245.630543	 0.0	 0.0	 1	 -30.0	 30.0;
	2173	 1461	 0.00424	 0.0258	 0.06757	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	645	 7216	 0.00036	 0.00313	 0.09213	 1753.283707	 1753.283707	 1753.283707	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 8228	 0.00112	 0.0114	 0.29718	 1679.867754	 1679.867754	 1679.867754	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 5435	 0.00046	 0.007	 0.14613	 1069.034576	 1069.034576	 1069.034576	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 334	 0.00113	 0.01516	 0.40614	 1460.755256	 1460.755256	 1460.755256	 0.0	 0.0	 1	 -30.0	 30.0;
	8228	 1961	 0.00138	 0.01478	 0.36973	 1203.33343	 1203.33343	 1203.33343	 0.0	 0.0	 1	 -30.0	 30.0;
	8228	 469	 0.00107	 0.01447	 0.34246	 1457.165546	 1457.165546	 1457.165546	 0.0	 0.0	 1	 -30.0	 30.0;
	5535	 1261	 0.012651	 0.08939	 0.12174	 353.432207	 353.432207	 353.432207	 0.0	 0.0	 1	 -30.0	 30.0;
	5535	 5458	 0.00957	 0.05424	 0.08491	 333.415589	 333.415589	 333.415589	 0.0	 0.0	 1	 -30.0	 30.0;
	1190	 3131	 0.0017	 0.01823	 0.50667	 1014.443209	 1014.443209	 1014.443209	 0.0	 0.0	 1	 -30.0	 30.0;
	1190	 5452	 0.00092	 0.00892	 0.29068	 1293.349982	 1293.349982	 1293.349982	 0.0	 0.0	 1	 -30.0	 30.0;
	1190	 1724	 0.00063	 0.00829	 0.20794	 1263.981363	 1263.981363	 1263.981363	 0.0	 0.0	 1	 -30.0	 30.0;
	1961	 7917	 0.00052	 0.00757	 0.18021	 930.733991	 930.733991	 930.733991	 0.0	 0.0	 1	 -30.0	 30.0;
	7917	 5957	 0.00189	 0.02546	 0.71464	 1013.67314	 1013.67314	 1013.67314	 0.0	 0.0	 1	 -30.0	 30.0;
	7917	 3822	 0.00044	 0.00602	 0.1561	 1011.820365	 1011.820365	 1011.820365	 0.0	 0.0	 1	 -30.0	 30.0;
	128	 5098	 0.00138	 0.01477	 0.50511	 1791.038846	 1791.038846	 1791.038846	 0.0	 0.0	 1	 -30.0	 30.0;
	5098	 5868	 0.00055	 0.00597	 0.18674	 1650.416205	 1650.416205	 1650.416205	 0.0	 0.0	 1	 -30.0	 30.0;
	334	 3465	 0.00047	 0.00684	 0.15672	 1629.438056	 1629.438056	 1629.438056	 0.0	 0.0	 1	 -30.0	 30.0;
	1261	 3067	 0.0038	 0.026331	 0.0334	 483.546704	 483.546704	 483.546704	 0.0	 0.0	 1	 -30.0	 30.0;
	1961	 2235	 0.001	 0.00937	 0.2598	 836.812462	 836.812462	 836.812462	 0.0	 0.0	 1	 -30.0	 30.0;
	1961	 334	 0.00203	 0.01819	 0.54116	 1635.92902	 1635.92902	 1635.92902	 0.0	 0.0	 1	 -30.0	 30.0;
	5458	 5783	 0.002419	 0.015021	 0.02221	 426.437802	 426.437802	 426.437802	 0.0	 0.0	 1	 -30.0	 30.0;
	5458	 5783	 0.00274	 0.014719	 0.02517	 375.410477	 375.410477	 375.410477	 0.0	 0.0	 1	 -30.0	 30.0;
	5458	 3274	 0.014599	 0.077461	 0.10083	 333.570296	 333.570296	 333.570296	 0.0	 0.0	 1	 -30.0	 30.0;
	5458	 6447	 0.012461	 0.05613	 0.08607	 380.952866	 380.952866	 380.952866	 0.0	 0.0	 1	 -30.0	 30.0;
	5458	 3067	 0.014581	 0.083849	 0.09574	 357.852401	 357.852401	 357.852401	 0.0	 0.0	 1	 -30.0	 30.0;
	6453	 5957	 0.0006	 0.00665	 0.21174	 1576.88178	 1576.88178	 1576.88178	 0.0	 0.0	 1	 -30.0	 30.0;
	6453	 5957	 0.00057	 0.00856	 0.24311	 1321.737255	 1321.737255	 1321.737255	 0.0	 0.0	 1	 -30.0	 30.0;
	6453	 5452	 0.00234	 0.02648	 0.89205	 1998.479193	 1998.479193	 1998.479193	 0.0	 0.0	 1	 -30.0	 30.0;
	2235	 3571	 0.00019	 0.00167	 0.05205	 913.573282	 913.573282	 913.573282	 0.0	 0.0	 1	 -30.0	 30.0;
	2235	 1913	 0.00019	 0.00164	 0.05303	 838.310478	 838.310478	 838.310478	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 7505	 3e-05	 0.00047	 0.01248	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 764	 3e-05	 0.00048	 0.01222	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 3686	 0.00097	 0.01084	 0.36793	 982.583382	 982.583382	 982.583382	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 5310	 8e-05	 0.00073	 0.01727	 1103.746294	 1103.746294	 1103.746294	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 4521	 8e-05	 0.0006	 0.02184	 1030.165797	 1030.165797	 1030.165797	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 1419	 7e-05	 0.00067	 0.02103	 1029.541843	 1029.541843	 1029.541843	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 648	 7e-05	 0.00066	 0.02449	 1062.390256	 1062.390256	 1062.390256	 0.0	 0.0	 1	 -30.0	 30.0;
	3274	 507	 0.00145	 0.00707	 0.00958	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3274	 3079	 0.00164	 0.00693	 0.01086	 348.049097	 348.049097	 348.049097	 0.0	 0.0	 1	 -30.0	 30.0;
	334	 6541	 8e-05	 0.00084	 0.02079	 1144.448102	 1144.448102	 1144.448102	 0.0	 0.0	 1	 -30.0	 30.0;
	334	 4914	 0.0001	 0.00083	 0.02602	 1152.480523	 1152.480523	 1152.480523	 0.0	 0.0	 1	 -30.0	 30.0;
	334	 7391	 0.0001	 0.00081	 0.027	 1126.743079	 1126.743079	 1126.743079	 0.0	 0.0	 1	 -30.0	 30.0;
	2990	 5777	 0.00019	 0.00215	 0.05848	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	128	 3561	 0.00037	 0.00292	 0.13501	 1150.870616	 1150.870616	 1150.870616	 0.0	 0.0	 1	 -30.0	 30.0;
	128	 1901	 0.00033	 0.00332	 0.12028	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3230	 3712	 0.002031	 0.01382	 0.01998	 473.144388	 473.144388	 473.144388	 0.0	 0.0	 1	 -30.0	 30.0;
	3230	 2347	 0.001979	 0.014091	 0.01956	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5957	 2702	 4e-05	 0.00052	 0.01872	 1854.274739	 1854.274739	 1854.274739	 0.0	 0.0	 1	 -30.0	 30.0;
	5957	 1036	 4e-05	 0.00054	 0.01872	 1701.77262	 1701.77262	 1701.77262	 0.0	 0.0	 1	 -30.0	 30.0;
	3230	 6686	 0.00136	 0.0067	 0.00955	 303.692073	 303.692073	 303.692073	 0.0	 0.0	 1	 -30.0	 30.0;
	2990	 4007	 0.0001	 0.00078	 0.02402	 1143.628669	 1143.628669	 1143.628669	 0.0	 0.0	 1	 -30.0	 30.0;
	2990	 1464	 0.00011	 0.00076	 0.02449	 1098.622368	 1098.622368	 1098.622368	 0.0	 0.0	 1	 -30.0	 30.0;
	3131	 2990	 0.00376	 0.04872	 1.06146	 1461.240334	 1461.240334	 1461.240334	 0.0	 0.0	 1	 -30.0	 30.0;
	2990	 5336	 0.0002	 0.00258	 0.07285	 1186.487331	 1186.487331	 1186.487331	 0.0	 0.0	 1	 -30.0	 30.0;
	2990	 334	 0.00089	 0.0087	 0.25229	 1098.767168	 1098.767168	 1098.767168	 0.0	 0.0	 1	 -30.0	 30.0;
	265	 3230	 0.01282	 0.053159	 0.08859	 242.121061	 242.121061	 242.121061	 0.0	 0.0	 1	 -30.0	 30.0;
	265	 6343	 0.002219	 0.01038	 0.02509	 463.580004	 463.580004	 463.580004	 0.0	 0.0	 1	 -30.0	 30.0;
	265	 3230	 0.01307	 0.05205	 0.09029	 250.290799	 250.290799	 250.290799	 0.0	 0.0	 1	 -30.0	 30.0;
	265	 3067	 0.00449	 0.01863	 0.05085	 476.198514	 476.198514	 476.198514	 0.0	 0.0	 1	 -30.0	 30.0;
	128	 3822	 0.00215	 0.0248	 0.72596	 1754.797519	 1754.797519	 1754.797519	 0.0	 0.0	 1	 -30.0	 30.0;
	2141	 5673	 0.00192	 0.02113	 0.49768	 1082.015846	 1082.015846	 1082.015846	 0.0	 0.0	 1	 -30.0	 30.0;
	2141	 7216	 0.00165	 0.01704	 0.58637	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5957	 5868	 0.00168	 0.02469	 0.56593	 1078.120741	 1078.120741	 1078.120741	 0.0	 0.0	 1	 -30.0	 30.0;
	5957	 3822	 0.00222	 0.02324	 0.95146	 1290.22363	 1290.22363	 1290.22363	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 469	 0.00173	 0.01682	 0.44602	 1133.447952	 1133.447952	 1133.447952	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 4855	 0.00174	 0.01872	 0.50096	 1349.323524	 1349.323524	 1349.323524	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 2235	 0.00194	 0.02194	 0.48735	 1248.149518	 1248.149518	 1248.149518	 0.0	 0.0	 1	 -30.0	 30.0;
	8376	 3033	 0.013831	 0.056841	 0.10506	 373.062821	 373.062821	 373.062821	 0.0	 0.0	 1	 -30.0	 30.0;
	8376	 3033	 0.014091	 0.055599	 0.10701	 357.945377	 357.945377	 357.945377	 0.0	 0.0	 1	 -30.0	 30.0;
	3274	 182	 0.009081	 0.05263	 0.08773	 417.38898	 417.38898	 417.38898	 0.0	 0.0	 1	 -30.0	 30.0;
	3274	 4961	 0.007401	 0.05661	 0.06824	 436.771529	 436.771529	 436.771529	 0.0	 0.0	 1	 -30.0	 30.0;
	7216	 4855	 0.00164	 0.01627	 0.40651	 1412.962223	 1412.962223	 1412.962223	 0.0	 0.0	 1	 -30.0	 30.0;
	6447	 2345	 0.022909	 0.124591	 0.15812	 393.200613	 393.200613	 393.200613	 0.0	 0.0	 1	 -30.0	 30.0;
	2717	 4855	 0.00074	 0.00791	 0.18963	 1462.981218	 1462.981218	 1462.981218	 0.0	 0.0	 1	 -30.0	 30.0;
	2717	 1724	 0.00136	 0.01726	 0.35698	 1177.420911	 1177.420911	 1177.420911	 0.0	 0.0	 1	 -30.0	 30.0;
	182	 3230	 0.011211	 0.07026	 0.1091	 388.970945	 388.970945	 388.970945	 0.0	 0.0	 1	 -30.0	 30.0;
	182	 3230	 0.01143	 0.06882	 0.11124	 376.785691	 376.785691	 376.785691	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 3822	 0.00544	 0.06455	 1.74389	 909.884186	 909.884186	 909.884186	 0.0	 0.0	 1	 -30.0	 30.0;
	3033	 2345	 0.016289	 0.066719	 0.115	 388.317824	 388.317824	 388.317824	 0.0	 0.0	 1	 -30.0	 30.0;
	3033	 2345	 0.016591	 0.065271	 0.11713	 394.349102	 394.349102	 394.349102	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 1724	 0.00077	 0.0096	 0.29761	 1359.4687	 1359.4687	 1359.4687	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 1724	 0.00093	 0.00905	 0.35052	 1319.792993	 1319.792993	 1319.792993	 0.0	 0.0	 1	 -30.0	 30.0;
	2345	 4961	 0.021729	 0.15268	 0.20206	 351.264788	 351.264788	 351.264788	 0.0	 0.0	 1	 -30.0	 30.0;
	441	 6343	 0.00064	 0.002919	 0.02343	 218.455497	 218.455497	 218.455497	 0.0	 0.0	 1	 -30.0	 30.0;
	6343	 3067	 0.002211	 0.009169	 0.02004	 472.866221	 472.866221	 472.866221	 0.0	 0.0	 1	 -30.0	 30.0;
	3738	 8250	 0.00014	 0.001729	 0.0046	 350.454673	 350.454673	 350.454673	 0.0	 0.0	 1	 -30.0	 30.0;
	4568	 8250	 0.0002	 0.00281	 0.00707	 325.715688	 325.715688	 325.715688	 0.0	 0.0	 1	 -30.0	 30.0;
	2409	 5005	 0.000711	 0.004289	 0.00743	 639.1661	 639.1661	 639.1661	 0.0	 0.0	 1	 -30.0	 30.0;
	2409	 6334	 0.0007	 0.00438	 0.00728	 609.694078	 609.694078	 609.694078	 0.0	 0.0	 1	 -30.0	 30.0;
	3738	 2409	 0.00032	 0.00437	 0.01102	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	5005	 5250	 7e-05	 0.000401	 0.00066	 628.208211	 628.208211	 628.208211	 0.0	 0.0	 1	 -30.0	 30.0;
	6334	 7731	 7e-05	 0.000401	 0.00065	 584.009323	 584.009323	 584.009323	 0.0	 0.0	 1	 -30.0	 30.0;
	742	 5250	 0.00189	 0.0083	 0.01824	 635.553354	 635.553354	 635.553354	 0.0	 0.0	 1	 -30.0	 30.0;
	742	 7731	 0.00168	 0.009401	 0.01625	 577.875542	 577.875542	 577.875542	 0.0	 0.0	 1	 -30.0	 30.0;
	3738	 6523	 0.000151	 0.00169	 0.00521	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	5657	 6716	 0.0	 0.000103	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5657	 6716	 0.001	 0.120531	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 5657	 4.583678	 10.16446	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5657	 5156	 8.430371	 11.9126	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5657	 2624	 8.911157	 11.64008	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 5657	 7.455785	 17.24773	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 5657	 9.746074	 17.22748	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 5657	 0.796777	 2.654959	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2560	 5657	 0.960248	 2.559091	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 5657	 5.215909	 9.009917	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3731	 5657	 5.097107	 9.164256	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 5657	 19.22748	 20.93388	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 5657	 17.18905	 24.75	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5657	 2684	 17.2064	 22.05785	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 5657	 0.227459	 1.377252	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 5657	 0.13382	 0.643926	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 5657	 0.211219	 1.206674	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6801	 5657	 0.230165	 1.120413	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 5657	 29.19835	 48.54959	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 5657	 0.13231	 0.939504	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 5657	 0.842851	 2.338843	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 5657	 0.820764	 2.471488	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 5657	 0.553244	 1.973719	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 5657	 0.01405	 0.0548	 0.1144	 431.034423	 431.034423	 431.034423	 0.0	 0.0	 1	 -30.0	 30.0;
	5657	 1441	 1.071157	 2.739256	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5657	 1441	 0.00774	 0.04075	 0.05749	 455.789794	 455.789794	 455.789794	 0.0	 0.0	 1	 -30.0	 30.0;
	6035	 5657	 16.64566	 21.19835	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 5657	 16.22913	 16.64318	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 6716	 10.87128	 19.07149	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6716	 5156	 15.62583	 25.67355	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6716	 2624	 16.95331	 27.19835	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 6716	 16.6593	 34.37603	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 6716	 19.6814	 37.93595	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 6716	 1.881012	 4.967975	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2560	 6716	 1.902851	 5.765909	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 6716	 10.14587	 20.68595	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3731	 6716	 10.93058	 18.98595	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 6716	 36.07851	 50.20248	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 6716	 40.72727	 46.32438	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6716	 2684	 36.24587	 46.68595	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 6716	 0.444855	 2.8	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 6716	 0.273946	 1.391054	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 6716	 0.514545	 2.160744	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6801	 6716	 0.450992	 2.507851	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 6716	 0.292665	 1.871012	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 6716	 1.795062	 4.826033	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 6716	 1.551219	 5.755991	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 6716	 1.089959	 4.426653	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6716	 1441	 0.00757	 0.037729	 0.05624	 498.202314	 498.202314	 498.202314	 0.0	 0.0	 1	 -30.0	 30.0;
	6716	 1441	 2.158264	 6.029752	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6035	 6716	 35.04132	 44.83471	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 6716	 30.36983	 39.79132	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 3946	 0.00058	 0.00554	 0.18339	 1323.95137	 1323.95137	 1323.95137	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 5388	 0.00116	 0.01169	 0.35768	 1394.354836	 1394.354836	 1394.354836	 0.0	 0.0	 1	 -30.0	 30.0;
	5701	 3946	 0.00052	 0.00627	 0.16339	 1471.837679	 1471.837679	 1471.837679	 0.0	 0.0	 1	 -30.0	 30.0;
	5701	 5388	 0.00118	 0.01144	 0.36442	 1454.460429	 1454.460429	 1454.460429	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 5701	 0.001	 0.223012	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 3946	 0.05072	 0.617493	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 5388	 0.05373	 0.600208	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	292	 4904	 0.381143	 1.437258	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5701	 3946	 0.04991	 0.630229	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5701	 5388	 0.05131	 0.624993	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	292	 5701	 0.389938	 1.410526	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4088	 4710	 0.00059	 0.00463	 0.20204	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	4088	 1454	 0.00047	 0.0038	 0.15935	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	5691	 6935	 0.0006	 0.00453	 0.20578	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	5691	 4710	 0.03442	 0.298892	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5691	 6935	 0.03377	 0.305229	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5691	 6000	 0.00047	 0.00372	 0.16236	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	4068	 544	 0.00036	 0.00341	 0.11612	 1204.80841	 1204.80841	 1204.80841	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 4068	 0.00164	 0.01639	 0.51589	 1213.855085	 1213.855085	 1213.855085	 0.0	 0.0	 1	 -30.0	 30.0;
	7063	 5636	 0.0	 0.000103	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7063	 5636	 0.001	 0.13669	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7063	 6996	 2.103099	 5.086777	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7063	 6527	 0.004781	 0.02089	 0.04591	 498.020933	 498.020933	 498.020933	 0.0	 0.0	 1	 -30.0	 30.0;
	7063	 4355	 46.67975	 63.95455	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7063	 6888	 45.98967	 55.45455	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7063	 5823	 1.337128	 3.255992	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7063	 990	 0.09056	 0.365041	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7063	 3564	 0.085081	 0.477665	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7063	 3564	 0.008	 0.040669	 0.06203	 427.846549	 427.846549	 427.846549	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 6996	 2.446281	 4.115289	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 87	 0.00488	 0.020469	 0.04681	 591.653972	 591.653972	 591.653972	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 4355	 44.43595	 63.26653	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 6888	 47.34298	 50.52893	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 5823	 1.382355	 2.978719	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 990	 0.07226	 0.393864	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 990	 0.007831	 0.04144	 0.06071	 432.560914	 432.560914	 432.560914	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 3564	 0.08989	 0.428161	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 7232	 0.00055	 0.00435	 0.17271	 1827.44406	 1827.44406	 1827.44406	 0.0	 0.0	 1	 -30.0	 30.0;
	2058	 7232	 0.00128	 0.00706	 0.25912	 1915.943508	 1915.943508	 1915.943508	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 5043	 0.00053	 0.00407	 0.16804	 1314.274818	 1314.274818	 1314.274818	 0.0	 0.0	 1	 -30.0	 30.0;
	6316	 5043	 0.00056	 0.00478	 0.18777	 1741.104757	 1741.104757	 1741.104757	 0.0	 0.0	 1	 -30.0	 30.0;
	7561	 3391	 0.208393	 1.089612	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2274	 3391	 0.199571	 1.1759	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1056	 3391	 0.02232	 0.346918	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2821	 3391	 0.858172	 1.866898	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1840	 3391	 0.00031	 0.00216	 0.0967	 1575.182361	 1575.182361	 1575.182361	 0.0	 0.0	 1	 -30.0	 30.0;
	7722	 3391	 0.001	 0.274529	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 3391	 4.431302	 8.136427	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8032	 7755	 0.36115	 2.404917	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8032	 172	 0.319377	 2.230125	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8032	 3041	 0.325519	 2.183657	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4986	 8032	 1.726316	 5.458795	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8032	 6254	 2.428047	 7.275623	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8032	 8258	 0.00056	 0.00716	 0.17465	 1349.833613	 1349.833613	 1349.833613	 0.0	 0.0	 1	 -30.0	 30.0;
	8032	 8258	 0.527043	 3.451801	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8032	 5189	 0.515582	 3.196122	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8032	 5646	 1.334072	 5.856163	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8032	 7672	 0.0011	 0.01318	 0.3431	 1562.604554	 1562.604554	 1562.604554	 0.0	 0.0	 1	 -30.0	 30.0;
	8032	 7985	 0.00108	 0.01344	 0.3361	 1605.384235	 1605.384235	 1605.384235	 0.0	 0.0	 1	 -30.0	 30.0;
	8032	 5189	 0.00063	 0.00702	 0.19793	 1614.218975	 1614.218975	 1614.218975	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 937	 0.246612	 1.335723	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 937	 0.008229	 0.04962	 0.08326	 479.190527	 479.190527	 479.190527	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 3117	 0.219628	 1.572521	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 3675	 4.089256	 11.14855	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 1124	 0.00943	 0.04726	 0.09545	 526.873367	 526.873367	 526.873367	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 1124	 3.689876	 10.15083	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 394	 0.202581	 1.497417	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 1744	 0.1973	 1.490124	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 251	 0.0028	 0.013271	 0.02916	 464.578739	 464.578739	 464.578739	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 3024	 0.12369	 1.125744	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 1447	 1.335496	 4.761364	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 8114	 1.15	 4.888636	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 1071	 1.052913	 5.261983	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 3117	 0.00932	 0.04863	 0.09436	 490.801538	 490.801538	 490.801538	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 3675	 0.00961	 0.046281	 0.09729	 517.440064	 517.440064	 517.440064	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 5378	 0.0025	 0.015031	 0.02598	 427.215909	 427.215909	 427.215909	 0.0	 0.0	 1	 -30.0	 30.0;
	4391	 6897	 0.0008	 0.00519	 0.0084	 455.367589	 455.367589	 455.367589	 0.0	 0.0	 1	 -30.0	 30.0;
	4391	 1124	 0.00612	 0.03036	 0.05912	 506.487129	 506.487129	 506.487129	 0.0	 0.0	 1	 -30.0	 30.0;
	6897	 1695	 0.00038	 0.00243	 0.00393	 461.92548	 461.92548	 461.92548	 0.0	 0.0	 1	 -30.0	 30.0;
	4323	 5645	 0.000909	 0.005091	 0.00952	 455.841617	 455.841617	 455.841617	 0.0	 0.0	 1	 -30.0	 30.0;
	4323	 394	 0.00187	 0.00944	 0.01839	 451.683967	 451.683967	 451.683967	 0.0	 0.0	 1	 -30.0	 30.0;
	5645	 1695	 0.00043	 0.00238	 0.00446	 460.293437	 460.293437	 460.293437	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 3838	 0.00013	 0.00176	 0.04234	 1435.427858	 1435.427858	 1435.427858	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 3838	 0.00013	 0.00179	 0.04144	 1610.940584	 1610.940584	 1610.940584	 0.0	 0.0	 1	 -30.0	 30.0;
	6379	 972	 0.00018	 0.00189	 0.06238	 2093.855956	 2093.855956	 2093.855956	 0.0	 0.0	 1	 -30.0	 30.0;
	6379	 6507	 0.0002	 0.00185	 0.0707	 2045.504788	 2045.504788	 2045.504788	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 1387	 0.00039	 0.00344	 0.13109	 1881.824809	 1881.824809	 1881.824809	 0.0	 0.0	 1	 -30.0	 30.0;
	6507	 5188	 0.0004	 0.00337	 0.13366	 1946.866746	 1946.866746	 1946.866746	 0.0	 0.0	 1	 -30.0	 30.0;
	6379	 7633	 0.00027	 0.00274	 0.09232	 2271.102985	 2271.102985	 2271.102985	 0.0	 0.0	 1	 -30.0	 30.0;
	6379	 1138	 0.00056	 0.00437	 0.18862	 2119.613803	 2119.613803	 2119.613803	 0.0	 0.0	 1	 -30.0	 30.0;
	6379	 6037	 0.00026	 0.00279	 0.0904	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	5599	 2526	 0.001349	 0.00763	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5599	 2364	 0.00374	 0.02218	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5599	 6638	 0.000349	 0.00186	 0.0	 232.989551	 232.989551	 232.989551	 0.0	 0.0	 1	 -30.0	 30.0;
	5599	 2364	 0.004651	 0.02025	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5599	 6638	 0.00037	 0.00182	 0.0	 232.791023	 232.791023	 232.791023	 0.0	 0.0	 1	 -30.0	 30.0;
	6803	 3733	 0.001	 0.209093	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6803	 7561	 0.00062	 0.00513	 0.19541	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	6803	 2274	 0.04427	 0.493158	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6803	 1387	 2.319321	 5.378532	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4429	 6803	 2.762188	 4.809072	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 6803	 24.69598	 23.43698	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6803	 7640	 1.383864	 4.675693	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7088	 6803	 0.470817	 2.500277	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1048	 6803	 0.00099	 0.00946	 0.31191	 2244.297975	 2244.297975	 2244.297975	 0.0	 0.0	 1	 -30.0	 30.0;
	4927	 6803	 0.05862	 0.781925	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3733	 2274	 0.04335	 0.502652	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3733	 2274	 0.00063	 0.00502	 0.19924	 1710.467168	 1710.467168	 1710.467168	 0.0	 0.0	 1	 -30.0	 30.0;
	3733	 1387	 2.364751	 5.268767	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4429	 3733	 2.814266	 4.706787	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 3733	 25.15305	 22.92729	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3733	 8247	 0.00032	 0.00223	 0.09984	 2289.240433	 2289.240433	 2289.240433	 0.0	 0.0	 1	 -30.0	 30.0;
	3733	 7640	 1.353809	 4.329363	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7088	 3733	 0.460582	 2.315097	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4927	 3733	 0.0574	 0.796953	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7274	 1917	 0.00439	 0.016341	 0.0518	 242.387035	 242.387035	 242.387035	 0.0	 0.0	 1	 -30.0	 30.0;
	229	 5191	 0.004039	 0.019031	 0.04007	 543.11834	 543.11834	 543.11834	 0.0	 0.0	 1	 -30.0	 30.0;
	229	 7703	 0.001331	 0.007669	 0.01326	 521.358413	 521.358413	 521.358413	 0.0	 0.0	 1	 -30.0	 30.0;
	5191	 6563	 0.001091	 0.005159	 0.01134	 551.743434	 551.743434	 551.743434	 0.0	 0.0	 1	 -30.0	 30.0;
	7703	 1890	 0.00131	 0.00782	 0.01299	 463.519798	 463.519798	 463.519798	 0.0	 0.0	 1	 -30.0	 30.0;
	1890	 2487	 0.00449	 0.022021	 0.04465	 476.050285	 476.050285	 476.050285	 0.0	 0.0	 1	 -30.0	 30.0;
	7561	 2274	 0.0	 4e-05	 0.00136	 1450.818723	 1450.818723	 1450.818723	 0.0	 0.0	 1	 -30.0	 30.0;
	7561	 2274	 0.001	 0.229342	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1056	 7561	 0.159093	 0.880956	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2821	 7561	 0.11009	 0.785942	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1840	 7561	 0.00133	 0.01275	 0.42052	 2134.251711	 2134.251711	 2134.251711	 0.0	 0.0	 1	 -30.0	 30.0;
	7722	 7561	 0.08106	 0.897645	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 7561	 0.0009	 0.00658	 0.28274	 1533.169459	 1533.169459	 1533.169459	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 7561	 1.066967	 3.005956	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1861	 7561	 0.00037	 0.00335	 0.11768	 1702.717107	 1702.717107	 1702.717107	 0.0	 0.0	 1	 -30.0	 30.0;
	1056	 2274	 0.14919	 0.968975	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2821	 2274	 0.107472	 0.83054	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2274	 1387	 6.591066	 12.31994	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7722	 2274	 0.089861	 0.931163	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7722	 2274	 0.00151	 0.0125	 0.47659	 2133.063039	 2133.063039	 2133.063039	 0.0	 0.0	 1	 -30.0	 30.0;
	4429	 2274	 7.50831	 11.99515	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 2274	 57.05332	 52.93698	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 2274	 1.218213	 2.697091	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 2274	 0.00091	 0.00644	 0.28798	 1489.05894	 1489.05894	 1489.05894	 0.0	 0.0	 1	 -30.0	 30.0;
	7640	 2274	 5.391066	 9.229224	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7088	 2274	 1.899723	 5.672438	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1060	 2274	 0.00034	 0.00341	 0.11528	 1833.097162	 1833.097162	 1833.097162	 0.0	 0.0	 1	 -30.0	 30.0;
	4927	 2274	 0.372853	 1.916066	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	162	 2641	 0.001	 0.398657	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	162	 1999	 0.00157	 0.00875	 0.01382	 407.457643	 407.457643	 407.457643	 0.0	 0.0	 1	 -30.0	 30.0;
	1778	 2641	 0.013419	 0.18632	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1778	 1999	 0.001771	 0.00857	 0.01567	 358.04788	 358.04788	 358.04788	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 6442	 3e-05	 0.00035	 0.0147	 1334.287418	 1334.287418	 1334.287418	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 4220	 4e-05	 0.00047	 0.01897	 1306.737349	 1306.737349	 1306.737349	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 6996	 6.406818	 19.24731	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 6996	 5.408471	 18.64401	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	220	 6996	 4.777893	 12.85021	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6996	 973	 7.316529	 22.04545	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6996	 973	 0.00518	 0.053229	 0.20193	 405.225445	 405.225445	 405.225445	 0.0	 0.0	 1	 -30.0	 30.0;
	4355	 6996	 1.28	 5.819421	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6888	 6996	 1.306178	 5.47314	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6996	 5823	 0.001	 0.244421	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	990	 6996	 0.326384	 2.031736	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3564	 6996	 0.34876	 2.295661	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6996	 5823	 0.000401	 0.00324	 0.01013	 436.861457	 436.861457	 436.861457	 0.0	 0.0	 1	 -30.0	 30.0;
	172	 7755	 1.103116	 4.165166	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3041	 7755	 0.982756	 4.720568	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4986	 7755	 17.77701	 32.87327	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7755	 6254	 11.94321	 24.78324	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8258	 7755	 0.13187	 1.326939	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 7755	 0.129169	 1.352909	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 7755	 15.47438	 32.5367	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 7755	 0.00019	 0.00211	 0.05553	 1256.680838	 1256.680838	 1256.680838	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 7755	 0.0002	 0.00206	 0.05662	 1234.248771	 1234.248771	 1234.248771	 0.0	 0.0	 1	 -30.0	 30.0;
	6970	 3514	 0.00013	 0.001771	 0.00463	 349.25703	 349.25703	 349.25703	 0.0	 0.0	 1	 -30.0	 30.0;
	6091	 4836	 0.008081	 0.041651	 0.08445	 417.671339	 417.671339	 417.671339	 0.0	 0.0	 1	 -30.0	 30.0;
	6091	 4836	 0.168091	 0.83657	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6091	 4836	 0.008229	 0.040771	 0.08604	 442.754795	 442.754795	 442.754795	 0.0	 0.0	 1	 -30.0	 30.0;
	4815	 4836	 2.293802	 5.98719	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 4836	 2.825	 5.516736	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4836	 3961	 0.731178	 1.985165	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7084	 6091	 0.001349	 0.01345	 0.04665	 327.082137	 327.082137	 327.082137	 0.0	 0.0	 1	 -30.0	 30.0;
	586	 7084	 0.00051	 0.00643	 0.01752	 411.540607	 411.540607	 411.540607	 0.0	 0.0	 1	 -30.0	 30.0;
	6749	 6091	 0.00137	 0.013159	 0.04751	 301.981153	 301.981153	 301.981153	 0.0	 0.0	 1	 -30.0	 30.0;
	586	 6749	 0.0005	 0.00655	 0.01716	 393.981387	 393.981387	 393.981387	 0.0	 0.0	 1	 -30.0	 30.0;
	8206	 5971	 0.001	 0.425381	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5894	 5971	 4.659141	 9.407202	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4335	 5971	 1.022853	 3.286357	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5971	 3912	 1.18795	 4.384626	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5971	 5092	 1.213781	 4.303324	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4222	 5971	 8.581024	 12.40582	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6785	 5971	 0.203857	 1.400623	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5971	 3912	 0.00082	 0.0099	 0.25793	 2151.726372	 2151.726372	 2151.726372	 0.0	 0.0	 1	 -30.0	 30.0;
	6785	 5971	 0.00056	 0.0066	 0.17182	 1802.403628	 1802.403628	 1802.403628	 0.0	 0.0	 1	 -30.0	 30.0;
	4074	 5971	 0.00031	 0.00634	 0.21893	 1023.405637	 1023.405637	 1023.405637	 0.0	 0.0	 1	 -30.0	 30.0;
	5894	 8206	 4.02687	 9.790858	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4335	 8206	 1.000554	 3.350416	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8206	 5092	 0.00081	 0.0101	 0.25266	 1525.745197	 1525.745197	 1525.745197	 0.0	 0.0	 1	 -30.0	 30.0;
	8206	 3912	 1.418213	 3.650623	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8206	 5092	 1.263504	 4.137327	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4222	 8206	 8.415512	 12.67105	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6785	 8206	 0.172188	 1.486496	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4815	 6091	 0.008531	 0.04201	 0.08867	 457.444318	 457.444318	 457.444318	 0.0	 0.0	 1	 -30.0	 30.0;
	4815	 6091	 0.19088	 1.317025	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 6091	 0.20351	 1.242748	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6091	 6563	 0.003419	 0.02226	 0.0355	 517.970487	 517.970487	 517.970487	 0.0	 0.0	 1	 -30.0	 30.0;
	6091	 3961	 0.05611	 0.44343	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 6091	 0.00869	 0.041091	 0.09031	 457.715626	 457.715626	 457.715626	 0.0	 0.0	 1	 -30.0	 30.0;
	6091	 3782	 0.003349	 0.02268	 0.03475	 508.932715	 508.932715	 508.932715	 0.0	 0.0	 1	 -30.0	 30.0;
	6328	 6091	 0.00176	 0.018651	 0.06155	 802.722411	 802.722411	 802.722411	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 1755	 0.00019	 0.00245	 0.05615	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 1755	 0.00019	 0.00227	 0.05493	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4934	 3912	 0.00018	 0.00209	 0.05447	 2260.529993	 2260.529993	 2260.529993	 0.0	 0.0	 1	 -30.0	 30.0;
	2024	 5092	 0.00017	 0.00213	 0.05336	 1761.360225	 1761.360225	 1761.360225	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 381	 0.00024	 0.0025	 0.07634	 1383.038101	 1383.038101	 1383.038101	 0.0	 0.0	 1	 -30.0	 30.0;
	5894	 4335	 0.897576	 2.903878	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4222	 5894	 0.01432	 0.301302	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5240	 5894	 0.00025	 0.00245	 0.07778	 1409.983304	 1409.983304	 1409.983304	 0.0	 0.0	 1	 -30.0	 30.0;
	5894	 6785	 3.381094	 7.270776	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4281	 2821	 0.00142	 0.01435	 0.48502	 1804.488082	 1804.488082	 1804.488082	 0.0	 0.0	 1	 -30.0	 30.0;
	4281	 985	 0.00023	 0.00181	 0.07208	 1842.416981	 1842.416981	 1842.416981	 0.0	 0.0	 1	 -30.0	 30.0;
	7217	 2821	 0.00139	 0.01463	 0.47492	 1846.210727	 1846.210727	 1846.210727	 0.0	 0.0	 1	 -30.0	 30.0;
	7217	 6212	 0.00023	 0.00178	 0.07347	 1850.017636	 1850.017636	 1850.017636	 0.0	 0.0	 1	 -30.0	 30.0;
	1056	 5589	 0.00047	 0.00384	 0.15877	 1237.154632	 1237.154632	 1237.154632	 0.0	 0.0	 1	 -30.0	 30.0;
	1056	 2718	 0.0005	 0.00403	 0.16655	 1665.075174	 1665.075174	 1665.075174	 0.0	 0.0	 1	 -30.0	 30.0;
	7722	 2718	 0.00025	 0.00236	 0.07786	 1253.717056	 1253.717056	 1253.717056	 0.0	 0.0	 1	 -30.0	 30.0;
	1056	 2821	 0.838573	 2.37223	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7722	 1056	 0.078193	 0.509841	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 1056	 5.654848	 7.590028	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6661	 2821	 0.0009	 0.0069	 0.2846	 1827.728394	 1827.728394	 1827.728394	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 6661	 0.0002	 0.00149	 0.06146	 2125.99551	 2125.99551	 2125.99551	 0.0	 0.0	 1	 -30.0	 30.0;
	8303	 2821	 0.00092	 0.00675	 0.28997	 1881.44109	 1881.44109	 1881.44109	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 8303	 0.0002	 0.00145	 0.06262	 2097.743163	 2097.743163	 2097.743163	 0.0	 0.0	 1	 -30.0	 30.0;
	7722	 2821	 0.413608	 1.666759	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 2821	 0.03562	 0.272507	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4447	 564	 0.0001	 0.00144	 0.03317	 1762.454119	 1762.454119	 1762.454119	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 4447	 9e-05	 0.00129	 0.02848	 1991.928992	 1991.928992	 1991.928992	 0.0	 0.0	 1	 -30.0	 30.0;
	1452	 5996	 0.0001	 0.00133	 0.03245	 2107.544769	 2107.544769	 2107.544769	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 1452	 9e-05	 0.00132	 0.02788	 2147.727274	 2147.727274	 2147.727274	 0.0	 0.0	 1	 -30.0	 30.0;
	564	 7616	 0.00063	 0.00676	 0.19823	 1947.420933	 1947.420933	 1947.420933	 0.0	 0.0	 1	 -30.0	 30.0;
	5996	 2128	 0.00065	 0.00662	 0.20205	 1798.424934	 1798.424934	 1798.424934	 0.0	 0.0	 1	 -30.0	 30.0;
	3946	 7616	 0.00017	 0.00236	 0.0546	 1676.471549	 1676.471549	 1676.471549	 0.0	 0.0	 1	 -30.0	 30.0;
	3946	 2128	 0.00017	 0.00219	 0.05341	 1765.120403	 1765.120403	 1765.120403	 0.0	 0.0	 1	 -30.0	 30.0;
	1128	 8106	 0.0017	 0.007469	 0.02515	 275.897438	 275.897438	 275.897438	 0.0	 0.0	 1	 -30.0	 30.0;
	8106	 6527	 0.001039	 0.005599	 0.01573	 515.784777	 515.784777	 515.784777	 0.0	 0.0	 1	 -30.0	 30.0;
	1128	 6760	 0.001729	 0.00731	 0.02563	 496.593897	 496.593897	 496.593897	 0.0	 0.0	 1	 -30.0	 30.0;
	6760	 87	 0.001021	 0.0057	 0.01539	 510.503789	 510.503789	 510.503789	 0.0	 0.0	 1	 -30.0	 30.0;
	1128	 1638	 0.00168	 0.007159	 0.02631	 427.540564	 427.540564	 427.540564	 0.0	 0.0	 1	 -30.0	 30.0;
	1638	 6527	 0.00112	 0.00495	 0.01749	 432.637505	 432.637505	 432.637505	 0.0	 0.0	 1	 -30.0	 30.0;
	8106	 6760	 0.001	 0.364917	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1128	 8106	 0.106669	 0.821178	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8106	 6527	 0.0977	 0.935248	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8106	 87	 0.10481	 0.756446	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1128	 6760	 0.094539	 0.895083	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6760	 6527	 0.09563	 0.921384	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6760	 87	 0.085479	 0.810062	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3946	 3303	 0.0002	 0.0021	 0.06172	 1505.696397	 1505.696397	 1505.696397	 0.0	 0.0	 1	 -30.0	 30.0;
	3303	 5929	 0.00051	 0.00613	 0.17787	 1699.049732	 1699.049732	 1699.049732	 0.0	 0.0	 1	 -30.0	 30.0;
	6617	 5581	 0.00062	 0.006331	 0.02172	 302.946737	 302.946737	 302.946737	 0.0	 0.0	 1	 -30.0	 30.0;
	5581	 1447	 0.00075	 0.00981	 0.02957	 377.47044	 377.47044	 377.47044	 0.0	 0.0	 1	 -30.0	 30.0;
	3946	 7811	 0.00105	 0.01369	 0.32909	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	7811	 444	 0.00132	 0.01291	 0.41076	 1670.839508	 1670.839508	 1670.839508	 0.0	 0.0	 1	 -30.0	 30.0;
	3946	 5568	 0.00103	 0.01395	 0.32209	 1796.476065	 1796.476065	 1796.476065	 0.0	 0.0	 1	 -30.0	 30.0;
	5568	 6845	 0.00134	 0.01263	 0.41836	 2096.861861	 2096.861861	 2096.861861	 0.0	 0.0	 1	 -30.0	 30.0;
	3946	 5388	 0.269647	 1.156579	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	292	 3946	 0.06211	 0.718075	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3946	 534	 0.00062	 0.005	 0.18404	 1598.885372	 1598.885372	 1598.885372	 0.0	 0.0	 1	 -30.0	 30.0;
	4553	 3946	 0.00031	 0.00248	 0.10243	 1760.792216	 1760.792216	 1760.792216	 0.0	 0.0	 1	 -30.0	 30.0;
	3946	 2175	 0.0006	 0.0051	 0.18029	 1690.953468	 1690.953468	 1690.953468	 0.0	 0.0	 1	 -30.0	 30.0;
	742	 2487	 0.007331	 0.044461	 0.07089	 463.647069	 463.647069	 463.647069	 0.0	 0.0	 1	 -30.0	 30.0;
	742	 2487	 0.00718	 0.0453	 0.06938	 459.322519	 459.322519	 459.322519	 0.0	 0.0	 1	 -30.0	 30.0;
	6617	 336	 0.0002	 0.00211	 0.00668	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	4568	 336	 0.000659	 0.002909	 0.02552	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	6037	 6744	 0.00088	 0.0079	 0.30106	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	7633	 7262	 0.00089	 0.00774	 0.30697	 2194.076919	 2194.076919	 2194.076919	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 3957	 0.00089	 0.00706	 0.30347	 2095.955548	 2095.955548	 2095.955548	 0.0	 0.0	 1	 -30.0	 30.0;
	1387	 1702	 0.0009	 0.0069	 0.30909	 2008.892906	 2008.892906	 2008.892906	 0.0	 0.0	 1	 -30.0	 30.0;
	4429	 1387	 0.527957	 1.890097	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 1387	 6.434972	 8.855956	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7640	 1387	 0.02292	 0.469398	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7088	 1387	 0.03034	 0.81482	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4927	 1387	 0.225173	 1.343006	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3914	 3053	 0.0001	 0.00122	 0.04187	 1349.567709	 1349.567709	 1349.567709	 0.0	 0.0	 1	 -30.0	 30.0;
	8359	 3053	 0.00025	 0.00221	 0.11189	 1903.080051	 1903.080051	 1903.080051	 0.0	 0.0	 1	 -30.0	 30.0;
	81	 950	 2.696676	 13.13573	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	81	 5013	 3.125	 11.9903	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 81	 0.00054	 0.00664	 0.22073	 1690.430874	 1690.430874	 1690.430874	 0.0	 0.0	 1	 -30.0	 30.0;
	2620	 81	 0.899169	 5.002355	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4308	 81	 0.06172	 1.437119	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	54	 81	 0.521247	 2.927216	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8359	 81	 0.00397	 0.614771	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7556	 81	 0.956579	 5.569321	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 81	 0.071011	 1.246122	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 81	 22.47576	 40.81994	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	571	 81	 0.00141	 0.00778	 0.19423	 2204.088485	 2204.088485	 2204.088485	 0.0	 0.0	 1	 -30.0	 30.0;
	5780	 1702	 0.00021	 0.00179	 0.07124	 1985.278091	 1985.278091	 1985.278091	 0.0	 0.0	 1	 -30.0	 30.0;
	7640	 3957	 0.00021	 0.00175	 0.07261	 2018.696487	 2018.696487	 2018.696487	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 4710	 0.00051	 0.00411	 0.17181	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	1656	 6935	 0.00052	 0.00402	 0.17505	 2297.40778	 2297.40778	 2297.40778	 0.0	 0.0	 1	 -30.0	 30.0;
	4710	 6935	 0.00439	 0.248677	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4815	 2039	 0.0	 0.000103	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4815	 2039	 0.001	 0.289959	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4815	 3403	 9.9e-05	 0.000789	 0.00289	 279.113129	 279.113129	 279.113129	 0.0	 0.0	 1	 -30.0	 30.0;
	4815	 3961	 0.13343	 0.727438	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 3961	 0.11368	 0.773802	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4286	 6813	 0.0001	 0.0011	 0.03679	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	4476	 4286	 0.00069	 0.00512	 0.22636	 2237.04089	 2237.04089	 2237.04089	 0.0	 0.0	 1	 -30.0	 30.0;
	7345	 1320	 0.0001	 0.00102	 0.03599	 2288.359131	 2288.359131	 2288.359131	 0.0	 0.0	 1	 -30.0	 30.0;
	2218	 7345	 0.0007	 0.005	 0.23055	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	5158	 3516	 0.00031	 0.00399	 0.09656	 1596.803551	 1596.803551	 1596.803551	 0.0	 0.0	 1	 -30.0	 30.0;
	950	 5158	 9e-05	 0.00103	 0.02544	 1577.635395	 1577.635395	 1577.635395	 0.0	 0.0	 1	 -30.0	 30.0;
	3516	 4893	 0.00021	 0.00231	 0.06482	 1549.664749	 1549.664749	 1549.664749	 0.0	 0.0	 1	 -30.0	 30.0;
	4893	 1965	 8e-05	 0.00082	 0.02308	 1436.158437	 1436.158437	 1436.158437	 0.0	 0.0	 1	 -30.0	 30.0;
	1965	 8123	 0.00016	 0.00203	 0.04892	 1463.403769	 1463.403769	 1463.403769	 0.0	 0.0	 1	 -30.0	 30.0;
	8123	 6493	 3e-05	 0.00036	 0.01167	 1399.166127	 1399.166127	 1399.166127	 0.0	 0.0	 1	 -30.0	 30.0;
	54	 6493	 0.00061	 0.00766	 0.18271	 1572.089576	 1572.089576	 1572.089576	 0.0	 0.0	 1	 -30.0	 30.0;
	950	 5013	 0.0	 3.5e-05	 0.0	 1924.465613	 1924.465613	 1924.465613	 0.0	 0.0	 1	 -30.0	 30.0;
	950	 5013	 0.01257	 0.43678	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2620	 950	 22.73892	 49.0	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4308	 950	 4.844044	 19.18698	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	54	 950	 0.001	 1.752701	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8359	 950	 0.908172	 6.096537	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6425	 950	 4.358657	 9.756232	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7556	 950	 25.29224	 66.18213	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 950	 1.071399	 5.397922	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 950	 0.155789	 0.985526	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2620	 5013	 23.51524	 49.62604	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4308	 5013	 5.179155	 18.97368	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	54	 5013	 0.0144	 1.921053	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8359	 5013	 0.997091	 6.027978	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6425	 5013	 4.636704	 9.781162	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7556	 5013	 29.33518	 59.12049	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 5013	 1.098269	 5.695983	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 5013	 0.00085	 0.00853	 0.24675	 1796.200947	 1796.200947	 1796.200947	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 5013	 0.15653	 1.070014	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5531	 5388	 0.00015	 0.00148	 0.04891	 2038.763057	 2038.763057	 2038.763057	 0.0	 0.0	 1	 -30.0	 30.0;
	429	 5388	 0.00014	 0.00167	 0.04357	 1373.44448	 1373.44448	 1373.44448	 0.0	 0.0	 1	 -30.0	 30.0;
	292	 5388	 0.525672	 1.551039	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5869	 7206	 0.00411	 0.01861	 0.04081	 497.955774	 497.955774	 497.955774	 0.0	 0.0	 1	 -30.0	 30.0;
	3782	 5869	 0.000969	 0.005841	 0.0101	 484.078652	 484.078652	 484.078652	 0.0	 0.0	 1	 -30.0	 30.0;
	7206	 2487	 0.004581	 0.02156	 0.04549	 504.435549	 504.435549	 504.435549	 0.0	 0.0	 1	 -30.0	 30.0;
	2385	 5883	 0.00026	 0.00323	 0.10874	 968.449639	 968.449639	 968.449639	 0.0	 0.0	 1	 -30.0	 30.0;
	2385	 5883	 0.00026	 0.00329	 0.10643	 990.219578	 990.219578	 990.219578	 0.0	 0.0	 1	 -30.0	 30.0;
	172	 7672	 6e-05	 0.00065	 0.01567	 1202.176351	 1202.176351	 1202.176351	 0.0	 0.0	 1	 -30.0	 30.0;
	7672	 1442	 0.00038	 0.00377	 0.12003	 1327.668109	 1327.668109	 1327.668109	 0.0	 0.0	 1	 -30.0	 30.0;
	3041	 7985	 6e-05	 0.00066	 0.01534	 1374.844427	 1374.844427	 1374.844427	 0.0	 0.0	 1	 -30.0	 30.0;
	7985	 1869	 0.00038	 0.00369	 0.12225	 1495.047714	 1495.047714	 1495.047714	 0.0	 0.0	 1	 -30.0	 30.0;
	172	 3041	 0.01122	 0.71669	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4986	 172	 25.10803	 39.16205	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	172	 6254	 32.07964	 43.87258	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	172	 8258	 0.427673	 3.90554	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	172	 5189	 0.418573	 3.979224	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 172	 23.26662	 36.54363	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4986	 3041	 25.59141	 38.34626	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3041	 6254	 32.6849	 42.93906	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3041	 8258	 0.409481	 3.684488	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3041	 5189	 0.464072	 3.610803	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 3041	 23.70568	 35.76593	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	937	 3117	 0.0	 0.000103	 0.0	 405.930771	 405.930771	 405.930771	 0.0	 0.0	 1	 -30.0	 30.0;
	937	 3117	 0.001	 0.19151	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	937	 3675	 17.56446	 20.66736	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	937	 1124	 13.87645	 21.76446	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	937	 394	 1.145248	 3.637603	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	937	 1744	 1.372004	 3.186983	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 937	 0.119159	 0.998905	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	937	 1447	 6.052479	 9.575826	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8114	 937	 4.474793	 10.74483	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 937	 4.534711	 10.47087	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3117	 3675	 18.49236	 22.54545	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3117	 1124	 13.69401	 22.82645	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3117	 394	 1.333636	 3.866942	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3117	 1744	 1.179442	 4.148554	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 3117	 0.114281	 1.035289	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3117	 1447	 5.617769	 11.75372	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8114	 3117	 4.939669	 11.00083	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 3117	 4.903306	 10.93058	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6975	 1320	 2e-05	 0.00021	 0.0099	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	6975	 1893	 0.00028	 0.00263	 0.09558	 2271.212901	 2271.212901	 2271.212901	 0.0	 0.0	 1	 -30.0	 30.0;
	2973	 6813	 2e-05	 0.00023	 0.00882	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	2973	 8049	 0.00027	 0.00268	 0.09359	 2293.565329	 2293.565329	 2293.565329	 0.0	 0.0	 1	 -30.0	 30.0;
	1128	 6527	 0.02601	 0.665517	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1128	 87	 0.028591	 0.528326	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7191	 5942	 0.01088	 0.212832	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2215	 5942	 0.00032	 0.00331	 0.10347	 1593.04798	 1593.04798	 1593.04798	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 5942	 0.00031	 0.00306	 0.10122	 1242.332529	 1242.332529	 1242.332529	 0.0	 0.0	 1	 -30.0	 30.0;
	4335	 215	 0.00057	 0.01002	 0.40595	 2281.156674	 2281.156674	 2281.156674	 0.0	 0.0	 1	 -30.0	 30.0;
	4335	 2072	 0.00053	 0.00558	 0.16379	 1971.287173	 1971.287173	 1971.287173	 0.0	 0.0	 1	 -30.0	 30.0;
	4335	 3912	 22.58241	 30.56787	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4335	 5092	 22.12119	 31.16759	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4222	 4335	 1.627632	 4.119529	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7950	 4335	 0.0003	 0.00319	 0.09362	 1586.969036	 1586.969036	 1586.969036	 0.0	 0.0	 1	 -30.0	 30.0;
	6785	 4335	 0.00232	 0.519501	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4335	 8175	 0.00058	 0.00981	 0.41361	 2237.274544	 2237.274544	 2237.274544	 0.0	 0.0	 1	 -30.0	 30.0;
	8249	 8175	 0.00065	 0.00643	 0.21784	 2216.299027	 2216.299027	 2216.299027	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 215	 0.00063	 0.00655	 0.2134	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	1840	 7722	 0.001	 0.215229	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1840	 7191	 0.00102	 0.00911	 0.32053	 1501.319504	 1501.319504	 1501.319504	 0.0	 0.0	 1	 -30.0	 30.0;
	7722	 5946	 0.00094	 0.00901	 0.29689	 1756.942525	 1756.942525	 1756.942525	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 7722	 3.359072	 5.253809	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	985	 4294	 0.00019	 0.00221	 0.05932	 1497.604082	 1497.604082	 1497.604082	 0.0	 0.0	 1	 -30.0	 30.0;
	7191	 985	 0.00039	 0.00355	 0.12404	 1569.920875	 1569.920875	 1569.920875	 0.0	 0.0	 1	 -30.0	 30.0;
	985	 1046	 0.0001	 0.00073	 0.02981	 2215.108381	 2215.108381	 2215.108381	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 544	 0.00018	 0.00226	 0.05811	 1552.380397	 1552.380397	 1552.380397	 0.0	 0.0	 1	 -30.0	 30.0;
	7573	 6212	 0.00038	 0.00368	 0.1194	 987.365054	 987.365054	 987.365054	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 6455	 0.00047	 0.00386	 0.15773	 1843.85247	 1843.85247	 1843.85247	 0.0	 0.0	 1	 -30.0	 30.0;
	6527	 87	 0.001	 0.309525	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2641	 1999	 0.000711	 0.00393	 0.01225	 564.505981	 564.505981	 564.505981	 0.0	 0.0	 1	 -30.0	 30.0;
	2641	 6925	 0.001219	 0.00569	 0.01778	 231.391041	 231.391041	 231.391041	 0.0	 0.0	 1	 -30.0	 30.0;
	7568	 5703	 0.00125	 0.005581	 0.01813	 460.078906	 460.078906	 460.078906	 0.0	 0.0	 1	 -30.0	 30.0;
	1999	 5703	 0.0007	 0.00401	 0.01199	 279.163427	 279.163427	 279.163427	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 4429	 0.0599	 0.313109	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4429	 2971	 0.00051	 0.00517	 0.16114	 1772.235322	 1772.235322	 1772.235322	 0.0	 0.0	 1	 -30.0	 30.0;
	4429	 7640	 0.92403	 2.090097	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4429	 7088	 0.05633	 0.587403	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4429	 4927	 0.333109	 1.178601	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4568	 6523	 0.0002	 0.002599	 0.00692	 398.665649	 398.665649	 398.665649	 0.0	 0.0	 1	 -30.0	 30.0;
	5903	 3665	 6e-05	 0.00066	 0.02297	 1850.542863	 1850.542863	 1850.542863	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 4294	 0.00203	 0.01921	 0.65626	 1425.544637	 1425.544637	 1425.544637	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 7556	 0.00132	 0.01562	 0.56572	 1649.102479	 1649.102479	 1649.102479	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 1755	 0.00039	 0.00541	 0.17125	 2160.661814	 2160.661814	 2160.661814	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 7556	 0.0013	 0.01592	 0.55009	 1686.05464	 1686.05464	 1686.05464	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 6047	 0.00084	 0.00852	 0.34862	 2105.324073	 2105.324073	 2105.324073	 0.0	 0.0	 1	 -30.0	 30.0;
	5903	 2777	 0.00016	 0.0017	 0.06742	 1556.822449	 1556.822449	 1556.822449	 0.0	 0.0	 1	 -30.0	 30.0;
	1652	 4641	 0.00092	 0.00761	 0.29003	 1691.300987	 1691.300987	 1691.300987	 0.0	 0.0	 1	 -30.0	 30.0;
	1652	 444	 0.00062	 0.00468	 0.19331	 1730.487008	 1730.487008	 1730.487008	 0.0	 0.0	 1	 -30.0	 30.0;
	5544	 1656	 0.00094	 0.00746	 0.29571	 1581.232345	 1581.232345	 1581.232345	 0.0	 0.0	 1	 -30.0	 30.0;
	5544	 6845	 0.00063	 0.00458	 0.19696	 1650.863108	 1650.863108	 1650.863108	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 1656	 0.0	 3.5e-05	 0.0	 1550.15246	 1550.15246	 1550.15246	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 1656	 0.001	 0.227327	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 3317	 3e-05	 0.00034	 0.01043	 2021.064616	 2021.064616	 2021.064616	 0.0	 0.0	 1	 -30.0	 30.0;
	7088	 4641	 0.00052	 0.00501	 0.16506	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	3683	 1656	 0.00059	 0.00491	 0.18707	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	219	 1124	 0.006229	 0.029719	 0.06026	 504.648176	 504.648176	 504.648176	 0.0	 0.0	 1	 -30.0	 30.0;
	219	 394	 0.00194	 0.00924	 0.01875	 493.473088	 493.473088	 493.473088	 0.0	 0.0	 1	 -30.0	 30.0;
	2837	 2384	 0.00189	 0.00769	 0.02943	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2837	 8111	 0.0037	 0.017021	 0.0577	 488.18867	 488.18867	 488.18867	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 1042	 0.00168	 0.008719	 0.02622	 453.101096	 453.101096	 453.101096	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 5601	 0.003771	 0.016669	 0.05881	 531.314518	 531.314518	 531.314518	 0.0	 0.0	 1	 -30.0	 30.0;
	5842	 6925	 0.004669	 0.024729	 0.03859	 448.148574	 448.148574	 448.148574	 0.0	 0.0	 1	 -30.0	 30.0;
	1082	 7568	 0.0	 0.000103	 0.0	 286.915533	 286.915533	 286.915533	 0.0	 0.0	 1	 -30.0	 30.0;
	1082	 7568	 0.00099	 0.00607	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5842	 1082	 0.00476	 0.02624	 0.04071	 397.032845	 397.032845	 397.032845	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 5281	 0.00051	 0.00286	 0.00493	 459.3591	 459.3591	 459.3591	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 5281	 0.0005	 0.002909	 0.00483	 488.033582	 488.033582	 488.033582	 0.0	 0.0	 1	 -30.0	 30.0;
	3675	 1124	 0.0	 0.000103	 0.0	 302.002492	 302.002492	 302.002492	 0.0	 0.0	 1	 -30.0	 30.0;
	3675	 1124	 0.001	 0.18874	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3675	 394	 0.704421	 2.986983	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3675	 1744	 0.680207	 2.970661	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 3675	 4.389256	 10.44091	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3675	 1447	 0.00861	 0.432252	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8114	 3675	 0.006521	 0.039849	 0.0689	 470.446165	 470.446165	 470.446165	 0.0	 0.0	 1	 -30.0	 30.0;
	8114	 3675	 0.450599	 2.525826	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 3675	 0.51345	 2.178099	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3675	 1792	 0.000159	 0.002091	 0.00547	 369.55372	 369.55372	 369.55372	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 394	 0.547603	 3.122934	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 1744	 0.63281	 2.590496	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 1124	 4.541736	 8.227686	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 1447	 0.00687	 0.424525	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8114	 1124	 0.394752	 2.341736	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 1124	 0.00638	 0.04063	 0.0675	 458.385895	 458.385895	 458.385895	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 1124	 0.459607	 1.981798	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 1776	 0.000159	 0.00213	 0.00535	 341.245428	 341.245428	 341.245428	 0.0	 0.0	 1	 -30.0	 30.0;
	2384	 1042	 0.001	 0.319917	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3026	 2384	 0.074539	 0.567996	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3026	 1042	 0.054219	 0.438326	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 3749	 0.00049	 0.0046	 0.16791	 1744.333126	 1744.333126	 1744.333126	 0.0	 0.0	 1	 -30.0	 30.0;
	7427	 3749	 0.00063	 0.00676	 0.21595	 1549.956322	 1549.956322	 1549.956322	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 2096	 0.02777	 0.440042	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3194	 2096	 0.02704	 0.444668	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3194	 2096	 0.00048	 0.00469	 0.16449	 1806.788419	 1806.788419	 1806.788419	 0.0	 0.0	 1	 -30.0	 30.0;
	7427	 2096	 0.00062	 0.00626	 0.21126	 1521.537456	 1521.537456	 1521.537456	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 3194	 0.0	 4e-05	 0.00136	 1429.479891	 1429.479891	 1429.479891	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 3194	 0.001	 0.247292	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 5410	 3e-05	 0.00035	 0.0107	 1529.440215	 1529.440215	 1529.440215	 0.0	 0.0	 1	 -30.0	 30.0;
	8215	 1519	 0.00014	 0.00118	 0.02927	 1270.355829	 1270.355829	 1270.355829	 0.0	 0.0	 1	 -30.0	 30.0;
	3194	 7049	 3e-05	 0.00034	 0.0109	 1527.344572	 1527.344572	 1527.344572	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 5410	 0.00072	 0.00903	 0.22686	 1538.281538	 1538.281538	 1538.281538	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 7049	 0.00082	 0.00885	 0.25705	 1688.302322	 1688.302322	 1688.302322	 0.0	 0.0	 1	 -30.0	 30.0;
	6744	 879	 0.00012	 0.00093	 0.03979	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6299	 6563	 0.000831	 0.004229	 0.00859	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8221	 3782	 0.000841	 0.00414	 0.00875	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7950	 5531	 0.00049	 0.00607	 0.15204	 1892.518906	 1892.518906	 1892.518906	 0.0	 0.0	 1	 -30.0	 30.0;
	6785	 2072	 0.00048	 0.00567	 0.14764	 1559.814532	 1559.814532	 1559.814532	 0.0	 0.0	 1	 -30.0	 30.0;
	6785	 429	 0.00047	 0.00578	 0.14462	 1353.299586	 1353.299586	 1353.299586	 0.0	 0.0	 1	 -30.0	 30.0;
	4986	 5646	 6e-05	 0.00069	 0.0167	 1623.453889	 1623.453889	 1623.453889	 0.0	 0.0	 1	 -30.0	 30.0;
	4986	 6254	 0.198269	 1.245429	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4986	 8258	 28.23615	 48.46122	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4986	 5189	 32.00069	 47.49169	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4986	 5646	 0.001	 0.339079	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 5092	 0.001	 0.23876	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6785	 3912	 7.242382	 14.44598	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6785	 5092	 7.08795	 14.71814	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 5083	 0.00493	 0.059419	 0.16378	 293.646421	 293.646421	 293.646421	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 5083	 0.01006	 0.07863	 0.12554	 529.496904	 529.496904	 529.496904	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 5156	 0.001	 0.434587	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 2624	 0.001	 0.434132	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 4084	 9.525206	 20.12748	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 7277	 0.490393	 3.121901	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 236	 0.324483	 3.440909	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 5360	 7.110331	 13.27211	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 2560	 8.147314	 13.64236	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 5082	 1.873657	 4.730165	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 3731	 1.953223	 4.544628	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 570	 0.893533	 3.267562	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 3111	 0.947417	 3.197521	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 2684	 1.735227	 5.478926	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 4590	 49.21281	 47.44215	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 4590	 21.70248	 30.12603	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 4274	 9.99835	 24.78719	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 6801	 10.26198	 26.88017	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 973	 0.625785	 4.196281	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 4590	 0.531426	 3.034091	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 4590	 3.245868	 10.84669	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 4590	 3.282025	 10.98388	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 1441	 0.002919	 0.01451	 0.04697	 559.589659	 559.589659	 559.589659	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 1441	 0.001	 0.67564	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 6035	 0.227169	 1.409215	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 5721	 0.192229	 1.194917	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 1441	 0.002979	 0.0142	 0.04787	 562.220436	 562.220436	 562.220436	 0.0	 0.0	 1	 -30.0	 30.0;
	4699	 5021	 0.000151	 0.0015	 0.00497	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4699	 3961	 0.000151	 0.001461	 0.00507	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5883	 1359	 0.00136	 0.0167	 0.3953	 1437.374752	 1437.374752	 1437.374752	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 2624	 0.0	 0.000103	 0.0	 328.943953	 328.943953	 328.943953	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 2624	 0.001	 0.256632	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 5156	 6.78595	 11.8655	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 5156	 1.097169	 5.085744	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 5156	 0.904029	 5.181818	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 5156	 4.170248	 8.645247	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2560	 5156	 4.773967	 8.884503	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 5156	 0.874421	 3.172727	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3731	 5156	 1.05436	 2.929339	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 5156	 0.513368	 2.495455	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 5156	 0.604525	 2.218802	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2684	 5156	 1.308616	 3.033264	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 5156	 39.69008	 38.26033	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 5156	 17.11942	 22.4938	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 5156	 20.47789	 32.19835	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6801	 5156	 21.35331	 30.98554	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 5156	 1.604091	 6.167149	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 5156	 1.137851	 5.037397	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 5156	 6.625413	 15.09483	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 5156	 6.196074	 16.5874	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 5156	 59.24587	 56.3595	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 1441	 0.086409	 1.077231	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6035	 5156	 0.080841	 0.916612	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 5156	 0.07195	 0.701488	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 2624	 5.952479	 12.55207	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 2624	 1.208636	 4.790289	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 2624	 0.897293	 4.88781	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 2624	 4.399793	 8.436157	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2560	 2624	 4.466736	 9.775413	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 2624	 0.924855	 3.415083	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3731	 2624	 1.008368	 3.168595	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 2624	 0.519401	 2.533471	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 2624	 0.611653	 2.252893	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2684	 2624	 1.180868	 3.490496	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 2624	 38.08471	 41.4876	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 2624	 19.69132	 22.41116	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 2624	 21.63017	 31.43802	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6801	 2624	 20.91529	 32.94215	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 2624	 1.695537	 6.03657	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 2624	 1.302851	 4.551033	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 2624	 5.718182	 16.36116	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 2624	 6.683678	 15.9062	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2624	 1441	 0.10661	 0.987583	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6035	 2624	 0.079729	 0.948512	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 2624	 0.06449	 0.807169	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 2624	 0.002151	 0.02656	 0.0604	 273.517392	 273.517392	 273.517392	 0.0	 0.0	 1	 -30.0	 30.0;
	5883	 4377	 0.00094	 0.01246	 0.34666	 1727.533758	 1727.533758	 1727.533758	 0.0	 0.0	 1	 -30.0	 30.0;
	4377	 4412	 0.00109	 0.00971	 0.4561	 1968.868364	 1968.868364	 1968.868364	 0.0	 0.0	 1	 -30.0	 30.0;
	5883	 2738	 0.00099	 0.01086	 0.40729	 1697.670846	 1697.670846	 1697.670846	 0.0	 0.0	 1	 -30.0	 30.0;
	5883	 2738	 0.00092	 0.0127	 0.34839	 1621.618227	 1621.618227	 1621.618227	 0.0	 0.0	 1	 -30.0	 30.0;
	2738	 4412	 0.00097	 0.01101	 0.40635	 1938.378866	 1938.378866	 1938.378866	 0.0	 0.0	 1	 -30.0	 30.0;
	394	 1744	 0.0	 0.000103	 0.0	 233.919316	 233.919316	 233.919316	 0.0	 0.0	 1	 -30.0	 30.0;
	394	 1744	 0.001	 0.236901	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 394	 1.033202	 3.18595	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1447	 394	 0.07336	 0.952996	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8114	 394	 4.823554	 9.755785	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 394	 4.344835	 10.74711	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6970	 394	 0.000789	 0.01039	 0.0272	 281.979396	 281.979396	 281.979396	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 1744	 0.877293	 3.230992	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1447	 1744	 0.08095	 0.839008	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8114	 1744	 4.635744	 9.702067	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 1744	 4.775207	 9.229752	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5946	 2215	 0.00017	 0.0018	 0.0582	 1954.988021	 1954.988021	 1954.988021	 0.0	 0.0	 1	 -30.0	 30.0;
	7573	 3881	 0.00017	 0.00184	 0.05697	 1271.162757	 1271.162757	 1271.162757	 0.0	 0.0	 1	 -30.0	 30.0;
	7844	 1893	 6e-05	 0.00055	 0.01834	 2271.418912	 2271.418912	 2271.418912	 0.0	 0.0	 1	 -30.0	 30.0;
	5054	 8049	 5e-05	 0.00051	 0.01794	 2228.525366	 2228.525366	 2228.525366	 0.0	 0.0	 1	 -30.0	 30.0;
	6434	 6535	 1e-05	 4e-05	 0.0	 1659.304916	 1659.304916	 1659.304916	 0.0	 0.0	 1	 -30.0	 30.0;
	6434	 6535	 0.001	 0.502417	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6434	 444	 0.11597	 1.150069	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6434	 3944	 0.00027	 0.00201	 0.08964	 1646.450016	 1646.450016	 1646.450016	 0.0	 0.0	 1	 -30.0	 30.0;
	6434	 292	 12.69044	 26.69945	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 6434	 5.039543	 12.54224	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3691	 6434	 4.861565	 13.04917	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6535	 444	 0.131427	 1.127078	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6535	 2276	 0.00034	 0.00324	 0.10679	 1806.702197	 1806.702197	 1806.702197	 0.0	 0.0	 1	 -30.0	 30.0;
	6535	 292	 14.34765	 23.73407	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 6535	 4.937535	 12.78878	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3691	 6535	 4.758934	 13.29571	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 251	 0.00189	 0.01011	 0.01969	 499.436539	 499.436539	 499.436539	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 6718	 0.00193	 0.009901	 0.02007	 512.024945	 512.024945	 512.024945	 0.0	 0.0	 1	 -30.0	 30.0;
	290	 6718	 0.00095	 0.004461	 0.00979	 497.968348	 497.968348	 497.968348	 0.0	 0.0	 1	 -30.0	 30.0;
	290	 5378	 0.000841	 0.00505	 0.00872	 466.497332	 466.497332	 466.497332	 0.0	 0.0	 1	 -30.0	 30.0;
	5834	 3024	 0.00074	 0.00837	 0.02581	 433.671297	 433.671297	 433.671297	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 1447	 3.807645	 6.613017	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8114	 3024	 0.512211	 2.208058	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 3024	 0.432727	 2.575207	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 290	 0.00551	 0.13675	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7427	 6000	 0.00018	 0.00165	 0.05914	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	7427	 1454	 0.00017	 0.00168	 0.05849	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	2777	 3914	 0.00022	 0.00207	 0.09688	 1437.878259	 1437.878259	 1437.878259	 0.0	 0.0	 1	 -30.0	 30.0;
	6576	 5332	 6e-05	 0.000531	 0.00129	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 4008	 6e-05	 0.000521	 0.00132	 513.633362	 513.633362	 513.633362	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 5360	 2.538636	 7.69814	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 2560	 2.881818	 7.882025	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 5082	 0.648822	 3.687603	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 3731	 0.662004	 3.615496	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 570	 0.347417	 1.771488	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 3111	 0.302727	 2.122521	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 2684	 0.13874	 1.055682	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 4084	 32.21488	 46.94215	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 4084	 16.64897	 25.36157	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 1441	 31.40496	 45.72727	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 6035	 1.96531	 5.971488	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 5721	 1.628843	 5.349793	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 2684	 0.003831	 0.04362	 0.12635	 227.828594	 227.828594	 227.828594	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 2684	 0.003901	 0.042711	 0.12878	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2620	 4308	 0.0	 3.5e-05	 0.0	 1468.282852	 1468.282852	 1468.282852	 0.0	 0.0	 1	 -30.0	 30.0;
	2620	 4308	 0.03143	 0.812673	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6666	 2620	 6e-05	 0.00062	 0.01407	 1639.575333	 1639.575333	 1639.575333	 0.0	 0.0	 1	 -30.0	 30.0;
	54	 2620	 5.540582	 14.44598	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8359	 2620	 0.171863	 2.799169	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6425	 2620	 31.73753	 62.63988	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7556	 2620	 0.0037	 0.670762	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 2620	 4.69723	 16.67659	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 2620	 13.8608	 37.26524	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5054	 4308	 6e-05	 0.00063	 0.01377	 2051.042709	 2051.042709	 2051.042709	 0.0	 0.0	 1	 -30.0	 30.0;
	54	 4308	 0.842036	 5.10651	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8359	 4308	 0.001	 0.767382	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7556	 4308	 0.0122	 0.920499	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 4308	 0.831094	 4.707341	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 4308	 13.1392	 39.18767	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7177	 6666	 0.00022	 0.0023	 0.07588	 1777.959507	 1777.959507	 1777.959507	 0.0	 0.0	 1	 -30.0	 30.0;
	7473	 7844	 0.00022	 0.00213	 0.07423	 2269.967626	 2269.967626	 2269.967626	 0.0	 0.0	 1	 -30.0	 30.0;
	7552	 6254	 0.00034	 0.003	 0.11433	 2027.433159	 2027.433159	 2027.433159	 0.0	 0.0	 1	 -30.0	 30.0;
	292	 7552	 0.00022	 0.00172	 0.07388	 2263.451651	 2263.451651	 2263.451651	 0.0	 0.0	 1	 -30.0	 30.0;
	4592	 6254	 0.00034	 0.00294	 0.11657	 2209.325618	 2209.325618	 2209.325618	 0.0	 0.0	 1	 -30.0	 30.0;
	1945	 4592	 0.00022	 0.00168	 0.07525	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	8258	 6254	 25.47853	 44.51731	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 6254	 24.93629	 45.35734	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 6254	 0.138622	 1.351247	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8114	 1447	 1.420021	 4.04938	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 1447	 1.226446	 4.635537	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1447	 5281	 0.000771	 0.0083	 0.03054	 374.674286	 374.674286	 374.674286	 0.0	 0.0	 1	 -30.0	 30.0;
	2526	 8241	 0.00449	 0.023349	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	579	 6439	 0.001	 0.313037	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	579	 5842	 0.025331	 0.364938	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	579	 5842	 0.004219	 0.018211	 0.0463	 236.348136	 236.348136	 236.348136	 0.0	 0.0	 1	 -30.0	 30.0;
	6439	 5842	 0.02581	 0.357169	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6439	 5842	 0.00413	 0.01686	 0.0453	 567.372629	 567.372629	 567.372629	 0.0	 0.0	 1	 -30.0	 30.0;
	444	 3157	 0.00018	 0.00157	 0.05526	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	292	 444	 4.622922	 11.33102	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 444	 1.337465	 6.217936	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3691	 444	 1.319252	 5.765305	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6845	 4792	 0.00017	 0.0016	 0.05413	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	6845	 3944	 0.00017	 0.00163	 0.05298	 1799.368764	 1799.368764	 1799.368764	 0.0	 0.0	 1	 -30.0	 30.0;
	6845	 3599	 2e-05	 0.00022	 0.0076	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8111	 5601	 0.0	 0.000103	 0.0	 548.098679	 548.098679	 548.098679	 0.0	 0.0	 1	 -30.0	 30.0;
	8111	 5601	 0.01018	 0.46657	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5562	 8111	 0.00887	 0.046021	 0.13858	 241.260648	 241.260648	 241.260648	 0.0	 0.0	 1	 -30.0	 30.0;
	3442	 8111	 0.007479	 0.02551	 0.08524	 556.942496	 556.942496	 556.942496	 0.0	 0.0	 1	 -30.0	 30.0;
	1479	 5601	 0.00762	 0.024979	 0.08688	 571.81721	 571.81721	 571.81721	 0.0	 0.0	 1	 -30.0	 30.0;
	6744	 3157	 0.00034	 0.00277	 0.11449	 2118.112496	 2118.112496	 2118.112496	 0.0	 0.0	 1	 -30.0	 30.0;
	7262	 4792	 0.00035	 0.00271	 0.11665	 1800.977354	 1800.977354	 1800.977354	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 2276	 0.00146	 0.01134	 0.48903	 1564.8654	 1564.8654	 1564.8654	 0.0	 0.0	 1	 -30.0	 30.0;
	8114	 1071	 0.0	 0.000103	 0.0	 219.695819	 219.695819	 219.695819	 0.0	 0.0	 1	 -30.0	 30.0;
	8114	 1071	 0.001	 0.250041	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8114	 4674	 0.00031	 0.00232	 0.3001	 445.285356	 445.285356	 445.285356	 0.0	 0.0	 1	 -30.0	 30.0;
	3026	 5562	 0.0	 0.000103	 0.0	 266.147862	 266.147862	 266.147862	 0.0	 0.0	 1	 -30.0	 30.0;
	3026	 5562	 0.001	 0.319463	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3026	 5842	 0.002479	 0.011479	 0.02267	 448.58564	 448.58564	 448.58564	 0.0	 0.0	 1	 -30.0	 30.0;
	3026	 1143	 1.778616	 5.164256	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1999	 3026	 0.00644	 0.026229	 0.0492	 427.561522	 427.561522	 427.561522	 0.0	 0.0	 1	 -30.0	 30.0;
	3720	 3026	 0.342769	 1.509876	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5562	 5842	 0.002521	 0.01124	 0.02311	 454.622253	 454.622253	 454.622253	 0.0	 0.0	 1	 -30.0	 30.0;
	5562	 1143	 1.29219	 4.678099	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3720	 5562	 0.236529	 1.420661	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 236	 0.0	 0.000103	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 236	 0.05505	 0.67124	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	220	 7277	 4.467975	 11.21446	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 5082	 34.72521	 52.45248	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 3731	 36.34711	 50.63223	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 570	 22.76033	 33.1281	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 3111	 21.48554	 36.70661	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 2684	 39.50826	 49.23967	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 7277	 17.04917	 42.27893	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6801	 7277	 16.04855	 40.82025	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 973	 0.053771	 1.208946	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 973	 0.003281	 0.016341	 0.09716	 519.511458	 519.511458	 519.511458	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 7277	 0.825227	 5.014463	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 4355	 4.278926	 11.33285	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 6888	 3.46157	 11.98905	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 7277	 4.532025	 17.77417	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 7277	 0.009169	 0.03831	 0.10447	 520.941924	 520.941924	 520.941924	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 7277	 4.582645	 17.99917	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 5823	 4.507231	 15.28285	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 1441	 0.001	 1.211157	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 6035	 7.098967	 16.7219	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 5721	 6.249587	 14.57107	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	220	 236	 3.945041	 12.27665	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 5082	 34.19215	 51.58471	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 3731	 31.52686	 50.73347	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 570	 18.00289	 35.73554	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 3111	 21.65083	 34.30165	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 2684	 35.85331	 52.29959	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 236	 18.05847	 51.41322	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6801	 236	 21.28512	 43.97521	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 973	 0.036771	 0.970744	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 236	 0.78843	 6.091736	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 4355	 3.228512	 12.74483	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 6888	 3.551653	 11.03347	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 236	 5.941736	 18.63595	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 236	 4.915083	 20.96901	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 236	 0.01039	 0.037539	 0.11815	 500.974461	 500.974461	 500.974461	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 5823	 4.096281	 15.0905	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 1441	 0.001	 1.352211	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 6035	 6.635537	 16.54979	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 5721	 5.82438	 14.40847	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3691	 1945	 0.00046	 0.00466	 0.15732	 2258.411972	 2258.411972	 2258.411972	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 292	 0.03625	 0.46376	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 292	 0.00045	 0.00475	 0.15405	 2227.180706	 2227.180706	 2227.180706	 0.0	 0.0	 1	 -30.0	 30.0;
	3691	 292	 0.04062	 0.4091	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 1441	 0.006271	 0.0373	 0.16824	 285.120401	 285.120401	 285.120401	 0.0	 0.0	 1	 -30.0	 30.0;
	586	 5021	 0.000331	 0.00331	 0.01147	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	586	 3961	 0.000341	 0.00324	 0.01168	 269.816623	 269.816623	 269.816623	 0.0	 0.0	 1	 -30.0	 30.0;
	586	 1350	 0.00013	 0.00132	 0.00437	 399.056989	 399.056989	 399.056989	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 2560	 0.001	 0.1802	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 5082	 0.04812	 0.726715	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 5082	 0.005169	 0.036401	 0.08293	 508.047533	 508.047533	 508.047533	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 3731	 0.04006	 0.78624	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 5360	 0.559318	 2.376033	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 5360	 0.574607	 2.433264	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 2684	 0.449463	 2.310744	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 5360	 0.18062	 1.392789	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 5360	 0.092211	 0.750041	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 5360	 6.405372	 12.55372	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6801	 5360	 5.734504	 14.28161	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 5360	 15.87066	 21.82231	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 5360	 45.78719	 60.88223	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 5360	 52.13017	 54.55165	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 5360	 0.615	 2.63781	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 1441	 16.26798	 23.5124	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 6035	 0.818636	 3.652686	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 5721	 0.670434	 2.968182	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2560	 5082	 0.041711	 0.912376	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2560	 3731	 0.04611	 0.822479	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2560	 3731	 0.005271	 0.03561	 0.08447	 547.759925	 547.759925	 547.759925	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 2560	 0.605434	 2.534091	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 2560	 0.542851	 2.99876	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2560	 2684	 0.520909	 2.569628	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 2560	 0.177789	 1.458264	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 2560	 0.09881	 0.801281	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 2560	 6.124793	 15.47397	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6801	 2560	 5.91157	 16.17149	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 2560	 14.54876	 25.34091	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 2560	 54.67355	 60.11777	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 2560	 0.802355	 2.58657	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2560	 1441	 19.94897	 25.18388	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2560	 6035	 1.027479	 3.393802	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2560	 5721	 0.843471	 3.042975	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 6794	 0.00078	 0.00782	 0.26443	 1927.295785	 1927.295785	 1927.295785	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 7640	 7.575485	 11.77562	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 7088	 1.23705	 3.353947	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 4927	 3.429501	 6.941136	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 1390	 0.00076	 0.00797	 0.25892	 1836.192579	 1836.192579	 1836.192579	 0.0	 0.0	 1	 -30.0	 30.0;
	7484	 1390	 0.00025	 0.00233	 0.08577	 1954.445681	 1954.445681	 1954.445681	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 6794	 0.00179	 0.01397	 0.60249	 1615.305629	 1615.305629	 1615.305629	 0.0	 0.0	 1	 -30.0	 30.0;
	8359	 54	 0.173643	 1.472438	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	54	 7556	 5.182133	 18.94529	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	54	 2470	 0.188989	 1.114889	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 54	 1.860596	 8.193906	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	220	 287	 0.00424	 0.029211	 0.05345	 572.506531	 572.506531	 572.506531	 0.0	 0.0	 1	 -30.0	 30.0;
	220	 973	 6.176859	 17.47149	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 220	 10.52665	 27.33264	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	220	 4355	 0.202	 1.377087	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	220	 6888	 0.19876	 1.343988	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	220	 6888	 0.00545	 0.042341	 0.06601	 563.604795	 563.604795	 563.604795	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 220	 7.300207	 16.26798	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 220	 6.816736	 17.84773	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	220	 5823	 3.997727	 8.729958	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	220	 1441	 15.84711	 34.44008	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	220	 990	 30.61777	 53.27893	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	220	 3564	 36.28512	 62.88017	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	54	 2470	 0.00082	 0.01007	 0.24211	 1582.600042	 1582.600042	 1582.600042	 0.0	 0.0	 1	 -30.0	 30.0;
	6757	 6991	 0.0005	 0.004169	 0.00631	 573.593289	 573.593289	 573.593289	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 6757	 0.00525	 0.033151	 0.06338	 505.114201	 505.114201	 505.114201	 0.0	 0.0	 1	 -30.0	 30.0;
	6991	 4221	 0.001969	 0.01718	 0.02496	 510.262584	 510.262584	 510.262584	 0.0	 0.0	 1	 -30.0	 30.0;
	4221	 3905	 0.001289	 0.009229	 0.01637	 561.30134	 561.30134	 561.30134	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 3586	 0.00043	 0.00349	 0.0055	 561.38098	 561.38098	 561.38098	 0.0	 0.0	 1	 -30.0	 30.0;
	3586	 6092	 0.000979	 0.008901	 0.01234	 510.425674	 510.425674	 510.425674	 0.0	 0.0	 1	 -30.0	 30.0;
	6092	 287	 0.000219	 0.00155	 0.00272	 532.059473	 532.059473	 532.059473	 0.0	 0.0	 1	 -30.0	 30.0;
	6383	 6472	 0.00025	 0.00319	 0.10266	 909.210869	 909.210869	 909.210869	 0.0	 0.0	 1	 -30.0	 30.0;
	6383	 6472	 0.00024	 0.00295	 0.10043	 858.218427	 858.218427	 858.218427	 0.0	 0.0	 1	 -30.0	 30.0;
	7640	 663	 0.00022	 0.00171	 0.07373	 1465.353296	 1465.353296	 1465.353296	 0.0	 0.0	 1	 -30.0	 30.0;
	3910	 663	 0.0005	 0.00382	 0.14859	 1543.648332	 1543.648332	 1543.648332	 0.0	 0.0	 1	 -30.0	 30.0;
	5780	 2304	 0.0002	 0.00192	 0.06748	 1270.798126	 1270.798126	 1270.798126	 0.0	 0.0	 1	 -30.0	 30.0;
	3910	 2304	 0.0005	 0.00383	 0.14829	 1588.129406	 1588.129406	 1588.129406	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 3731	 0.0	 0.000103	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 3731	 0.001	 0.268678	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 5082	 0.042159	 0.956198	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 5082	 0.002341	 0.022341	 0.07898	 301.176373	 301.176373	 301.176373	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 5082	 0.04555	 0.93969	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 2684	 0.077909	 1.08686	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4029	 5082	 0.0003	 0.003289	 0.01013	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 5082	 1.527831	 6.098554	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 5082	 0.958926	 2.68595	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 5082	 28.84298	 48.1157	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6801	 5082	 33.55372	 46.46901	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 5082	 47.90702	 63.74587	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 5082	 28.68802	 30.77066	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 5082	 4.526653	 11.10372	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 1441	 6.754959	 11.13905	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 6035	 0.105229	 1.236012	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 5721	 0.085781	 1.020186	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 3731	 0.044289	 0.919483	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 3731	 0.047781	 0.901963	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3731	 2684	 0.076341	 1.006446	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6518	 3731	 0.0003	 0.00336	 0.00993	 621.673184	 621.673184	 621.673184	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 3731	 1.621322	 5.733678	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 3731	 0.903202	 2.852273	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 3731	 30.65289	 49.86157	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6801	 3731	 32.78719	 47.26653	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 3731	 44.17355	 62.70041	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 3731	 25.07438	 35.58471	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 3731	 5.060744	 9.753098	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3731	 1441	 6.015083	 12.60103	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3731	 6035	 0.099409	 1.193017	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3731	 6035	 0.002021	 0.01812	 0.07377	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3731	 5721	 0.09157	 0.961405	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4222	 5240	 0.00032	 0.00387	 0.10059	 1353.71358	 1353.71358	 1353.71358	 0.0	 0.0	 1	 -30.0	 30.0;
	4222	 3260	 0.00038	 0.00378	 0.1204	 1468.151875	 1468.151875	 1468.151875	 0.0	 0.0	 1	 -30.0	 30.0;
	3255	 6124	 0.00032	 0.00394	 0.09853	 1504.451122	 1504.451122	 1504.451122	 0.0	 0.0	 1	 -30.0	 30.0;
	3255	 549	 0.00038	 0.0037	 0.12263	 1411.441829	 1411.441829	 1411.441829	 0.0	 0.0	 1	 -30.0	 30.0;
	4222	 6785	 6.036911	 10.78324	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5883	 6472	 0.0008	 0.00945	 0.23125	 1501.551842	 1501.551842	 1501.551842	 0.0	 0.0	 1	 -30.0	 30.0;
	6472	 565	 0.00079	 0.00828	 0.33875	 1380.379715	 1380.379715	 1380.379715	 0.0	 0.0	 1	 -30.0	 30.0;
	5883	 6472	 0.00078	 0.00964	 0.22644	 1432.652315	 1432.652315	 1432.652315	 0.0	 0.0	 1	 -30.0	 30.0;
	6472	 565	 0.00081	 0.00811	 0.34526	 1318.110687	 1318.110687	 1318.110687	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 3111	 0.0	 0.000103	 0.0	 433.63967	 433.63967	 433.63967	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 3111	 0.001	 0.26281	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 2684	 0.001	 0.461798	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 2684	 0.00164	 0.020729	 0.05245	 541.62119	 541.62119	 541.62119	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 570	 7.774793	 17.76901	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 570	 3.756405	 9.209917	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 973	 27.82645	 45.00826	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 570	 20.96901	 31.09711	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 570	 18.12293	 35.08471	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 1441	 3.360124	 8.657025	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 6035	 0.14569	 1.294938	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 5721	 0.125919	 1.049607	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 2684	 0.001	 0.471508	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 2684	 0.001599	 0.02112	 0.05134	 232.711765	 232.711765	 232.711765	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 3111	 8.624174	 16.76653	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 3111	 4.365909	 9.241321	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 973	 29.57231	 44.15909	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 3111	 22.67562	 29.81818	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 3111	 22.21281	 29.92975	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 1441	 3.288017	 9.179959	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 6035	 0.15644	 1.276653	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 5721	 0.124669	 1.119298	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 2684	 6.748554	 16.31901	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 2684	 3.853099	 7.976446	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 2684	 53.92562	 59.04132	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 2684	 37.32851	 39.04752	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 2684	 16.76198	 30.60331	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2684	 1441	 6.070868	 12.11942	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6035	 2684	 0.29624	 1.60312	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 2684	 0.293884	 1.293946	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8359	 7556	 0.15633	 3.578947	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8359	 2470	 0.242957	 1.518213	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8359	 1153	 8.069251	 24.53047	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8359	 3201	 0.00029	 0.00357	 0.12575	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	2215	 4885	 0.00012	 0.00131	 0.04268	 1791.716771	 1791.716771	 1791.716771	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 6094	 0.0	 0.000103	 0.0	 278.891357	 278.891357	 278.891357	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 6094	 0.001	 0.168909	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 4274	 0.837231	 3.56405	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 6801	 0.690682	 3.987397	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 6801	 0.00988	 0.05469	 0.15166	 582.032049	 582.032049	 582.032049	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 7416	 5.606818	 11.56529	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 7416	 15.6624	 27.83058	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 7416	 16.76116	 26.42355	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 1801	 0.039521	 0.57	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 1441	 25.64463	 32.3843	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 6035	 12.49401	 21.31612	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 5721	 10.90826	 18.38058	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 4274	 0.367355	 2.263636	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 6801	 0.394566	 2.152479	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 6094	 2.95062	 6.117354	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 6094	 8.41281	 14.42025	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 6094	 8.672314	 14.29339	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 1801	 0.0192	 0.321384	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 1441	 12.78037	 18.27831	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 6035	 6.830371	 10.80145	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 5721	 5.092149	 10.9593	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4412	 6425	 0.00043	 0.00522	 0.1263	 1222.377191	 1222.377191	 1222.377191	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 6425	 0.00184	 0.01667	 0.53893	 1595.770209	 1595.770209	 1595.770209	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 6425	 0.248089	 2.761427	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1894	 4445	 0.00037	 0.00464	 0.15876	 1496.425941	 1496.425941	 1496.425941	 0.0	 0.0	 1	 -30.0	 30.0;
	1894	 5234	 0.00059	 0.00694	 0.25699	 1555.577832	 1555.577832	 1555.577832	 0.0	 0.0	 1	 -30.0	 30.0;
	8258	 7884	 0.00027	 0.00348	 0.08358	 1483.489427	 1483.489427	 1483.489427	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 7884	 0.00027	 0.00354	 0.0818	 1549.2343	 1549.2343	 1549.2343	 0.0	 0.0	 1	 -30.0	 30.0;
	8258	 5189	 0.02114	 0.839889	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 8258	 30.32756	 43.46053	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 5189	 30.89958	 42.53601	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 6801	 0.0	 0.000103	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 6801	 0.001	 0.238595	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 4274	 0.256632	 1.964752	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 4274	 0.63343	 3.574793	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 4274	 0.709752	 3.284711	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 4274	 0.01324	 0.090909	 0.16004	 512.380847	 512.380847	 512.380847	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 4274	 0.000591	 1.201426	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 1441	 1.821963	 7.541736	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 6801	 0.210826	 2.191942	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 6801	 0.746074	 3.056198	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 6801	 0.740041	 3.16219	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 6801	 0.000841	 1.29095	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6801	 1441	 2.154545	 7.118182	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4445	 1781	 8e-05	 0.00105	 0.03658	 1497.246691	 1497.246691	 1497.246691	 0.0	 0.0	 1	 -30.0	 30.0;
	7473	 7556	 0.00025	 0.00186	 0.08844	 2126.473348	 2126.473348	 2126.473348	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 5083	 9.1e-05	 0.000581	 0.00112	 576.483181	 576.483181	 576.483181	 0.0	 0.0	 1	 -30.0	 30.0;
	7177	 7556	 0.00023	 0.00211	 0.07879	 1904.85187	 1904.85187	 1904.85187	 0.0	 0.0	 1	 -30.0	 30.0;
	4313	 7282	 8e-05	 0.00107	 0.03581	 1629.220856	 1629.220856	 1629.220856	 0.0	 0.0	 1	 -30.0	 30.0;
	4313	 7556	 2e-05	 0.0002	 0.00472	 1424.322398	 1424.322398	 1424.322398	 0.0	 0.0	 1	 -30.0	 30.0;
	7001	 1588	 0.00063	 0.00406	 0.00826	 555.114212	 555.114212	 555.114212	 0.0	 0.0	 1	 -30.0	 30.0;
	7001	 973	 9.1e-05	 0.00056	 0.00111	 543.27419	 543.27419	 543.27419	 0.0	 0.0	 1	 -30.0	 30.0;
	8047	 1886	 0.00064	 0.003969	 0.00842	 553.212767	 553.212767	 553.212767	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 8047	 9.1e-05	 0.00055	 0.00113	 494.295015	 494.295015	 494.295015	 0.0	 0.0	 1	 -30.0	 30.0;
	7556	 1781	 2e-05	 0.0002	 0.00535	 1596.383633	 1596.383633	 1596.383633	 0.0	 0.0	 1	 -30.0	 30.0;
	7282	 4423	 0.00091	 0.01097	 0.39624	 1478.887437	 1478.887437	 1478.887437	 0.0	 0.0	 1	 -30.0	 30.0;
	1588	 2278	 0.00711	 0.045841	 0.09356	 516.302245	 516.302245	 516.302245	 0.0	 0.0	 1	 -30.0	 30.0;
	1886	 7886	 0.00724	 0.044849	 0.09529	 556.175821	 556.175821	 556.175821	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 7556	 5.952838	 17.29294	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 7556	 20.08726	 50.82479	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 973	 4.890702	 15.41012	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4355	 973	 5.639256	 15.40868	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6888	 973	 4.76281	 15.7	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 973	 21.2624	 53.66529	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 973	 25.16942	 46.14463	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 5823	 5.023554	 17.83409	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 1441	 0.483492	 3.46095	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	100	 973	 0.000211	 0.0012	 0.00194	 435.126912	 435.126912	 435.126912	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 6035	 9.888017	 20.17066	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 5721	 9.581818	 15.8126	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1359	 964	 0.00015	 0.00151	 0.04535	 1612.410957	 1612.410957	 1612.410957	 0.0	 0.0	 1	 -30.0	 30.0;
	4423	 1731	 0.00044	 0.00443	 0.19022	 1568.215533	 1568.215533	 1568.215533	 0.0	 0.0	 1	 -30.0	 30.0;
	2278	 4590	 0.00301	 0.01868	 0.03962	 502.367203	 502.367203	 502.367203	 0.0	 0.0	 1	 -30.0	 30.0;
	7886	 4590	 0.00268	 0.02118	 0.0353	 494.1083	 494.1083	 494.1083	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 964	 0.00044	 0.00433	 0.19387	 1493.897216	 1493.897216	 1493.897216	 0.0	 0.0	 1	 -30.0	 30.0;
	1731	 1359	 0.00015	 0.00148	 0.0462	 1450.987875	 1450.987875	 1450.987875	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 4355	 36.67975	 64.23967	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 6888	 34.68595	 57.82851	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 3212	 0.001	 0.997107	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 3212	 0.001	 0.990558	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 3212	 0.00389	 0.03206	 0.04613	 489.006787	 489.006787	 489.006787	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 1801	 2.394421	 10.2281	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 1441	 0.001	 0.942996	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 6035	 7.162397	 16.07149	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 5721	 6.970248	 12.65785	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4125	 5607	 0.00041	 0.00489	 0.21356	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	7965	 5607	 0.00035	 0.00415	 0.1885	 2116.916585	 2116.916585	 2116.916585	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 3996	 0.00041	 0.00478	 0.21767	 2040.85146	 2040.85146	 2040.85146	 0.0	 0.0	 1	 -30.0	 30.0;
	7965	 3996	 0.00036	 0.00406	 0.19206	 1735.14955	 1735.14955	 1735.14955	 0.0	 0.0	 1	 -30.0	 30.0;
	4125	 6747	 0.00069	 0.00736	 0.21961	 1841.778547	 1841.778547	 1841.778547	 0.0	 0.0	 1	 -30.0	 30.0;
	3201	 4125	 0.00035	 0.00355	 0.15003	 2189.455184	 2189.455184	 2189.455184	 0.0	 0.0	 1	 -30.0	 30.0;
	2218	 4125	 0.0003	 0.0037	 0.13435	 2226.837136	 2226.837136	 2226.837136	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 5127	 0.00079	 0.00639	 0.25232	 2186.541424	 2186.541424	 2186.541424	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 2470	 10.65028	 23.35249	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4476	 2470	 0.00035	 0.00375	 0.14437	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	571	 2470	 0.00035	 0.00368	 0.1472	 2030.224497	 2030.224497	 2030.224497	 0.0	 0.0	 1	 -30.0	 30.0;
	4355	 6888	 0.0	 0.000103	 0.0	 483.283398	 483.283398	 483.283398	 0.0	 0.0	 1	 -30.0	 30.0;
	4355	 6888	 0.001	 0.307397	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 4355	 30.07851	 44.4938	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 4355	 28.13843	 48.89876	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4355	 5823	 1.021095	 4.339256	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4355	 1441	 19.04773	 44.46694	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4355	 990	 11.71198	 25.83058	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4355	 3564	 13.4062	 28.03306	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 6888	 25.77686	 44.3843	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 6888	 29.27686	 39.66322	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6888	 5823	 0.90343	 4.251446	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6888	 1441	 15.67913	 46.04752	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6888	 990	 10.06777	 25.78512	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6888	 3564	 11.7936	 27.51653	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4303	 5127	 0.00037	 0.00319	 0.12089	 1766.881691	 1766.881691	 1766.881691	 0.0	 0.0	 1	 -30.0	 30.0;
	2661	 6747	 0.00037	 0.0032	 0.12142	 1685.678819	 1685.678819	 1685.678819	 0.0	 0.0	 1	 -30.0	 30.0;
	2971	 8247	 6e-05	 0.00057	 0.01778	 2289.240433	 2289.240433	 2289.240433	 0.0	 0.0	 1	 -30.0	 30.0;
	4927	 2971	 0.00081	 0.00793	 0.25734	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 2361	 0.0	 0.000103	 0.0	 534.079806	 534.079806	 534.079806	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 2361	 0.001	 0.218595	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 1801	 5.508884	 16.92169	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 1441	 0.417335	 3.096901	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 6035	 35.56405	 45.20868	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 5721	 26.29545	 47.22107	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 1801	 5.134091	 18.53492	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 1441	 0.373512	 3.536364	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 6035	 31.99174	 51.7624	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 5721	 26.61157	 47.82645	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5823	 1441	 22.02479	 61.94007	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	990	 5823	 0.20395	 1.135248	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3564	 5823	 0.207314	 1.339256	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 1441	 15.82955	 28.76446	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 6035	 27.39876	 40.44215	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 5721	 23.59711	 35.69835	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6035	 1441	 1.210248	 3.369008	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 1441	 0.914421	 3.375826	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3442	 1143	 0.005729	 0.02032	 0.06514	 418.132411	 418.132411	 418.132411	 0.0	 0.0	 1	 -30.0	 30.0;
	1479	 1143	 0.005841	 0.019909	 0.06641	 440.798859	 440.798859	 440.798859	 0.0	 0.0	 1	 -30.0	 30.0;
	3720	 1143	 0.084781	 0.493471	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 3691	 0.0	 4e-05	 0.00136	 1351.239484	 1351.239484	 1351.239484	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 3691	 0.001	 0.19356	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 7427	 0.00192	 0.01356	 0.6072	 2287.097401	 2287.097401	 2287.097401	 0.0	 0.0	 1	 -30.0	 30.0;
	3691	 7427	 0.00172	 0.01537	 0.54096	 2157.070788	 2157.070788	 2157.070788	 0.0	 0.0	 1	 -30.0	 30.0;
	1755	 3831	 0.00035	 0.00346	 0.15707	 1936.447768	 1936.447768	 1936.447768	 0.0	 0.0	 1	 -30.0	 30.0;
	990	 3564	 0.0	 0.000103	 0.0	 542.642026	 542.642026	 542.642026	 0.0	 0.0	 1	 -30.0	 30.0;
	990	 3564	 0.001	 0.159719	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	990	 5490	 0.000341	 0.00199	 0.00559	 594.646748	 594.646748	 594.646748	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 6825	 0.00219	 0.012901	 0.05905	 267.521171	 267.521171	 267.521171	 0.0	 0.0	 1	 -30.0	 30.0;
	6825	 4018	 0.002531	 0.013539	 0.07283	 250.025206	 250.025206	 250.025206	 0.0	 0.0	 1	 -30.0	 30.0;
	4018	 6544	 0.002281	 0.01263	 0.06169	 298.140919	 298.140919	 298.140919	 0.0	 0.0	 1	 -30.0	 30.0;
	6544	 100	 0.00232	 0.01393	 0.06281	 238.421817	 238.421817	 238.421817	 0.0	 0.0	 1	 -30.0	 30.0;
	5780	 1861	 0.00043	 0.00418	 0.14721	 1826.456133	 1826.456133	 1826.456133	 0.0	 0.0	 1	 -30.0	 30.0;
	7088	 7640	 0.113102	 0.936981	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7640	 1060	 0.00043	 0.00419	 0.14734	 1995.810934	 1995.810934	 1995.810934	 0.0	 0.0	 1	 -30.0	 30.0;
	4927	 7640	 0.124889	 1.006302	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2364	 8241	 0.0	 0.000103	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2364	 8241	 0.003651	 0.01288	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8241	 6638	 0.004021	 0.01951	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7088	 1048	 0.00057	 0.00402	 0.18006	 2104.269669	 2104.269669	 2104.269669	 0.0	 0.0	 1	 -30.0	 30.0;
	3683	 4927	 0.00064	 0.00448	 0.20032	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	7088	 4927	 0.00646	 0.473407	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2968	 1861	 8e-05	 0.00061	 0.02325	 900.438655	 900.438655	 900.438655	 0.0	 0.0	 1	 -30.0	 30.0;
	706	 1060	 6e-05	 0.00065	 0.01998	 1108.524018	 1108.524018	 1108.524018	 0.0	 0.0	 1	 -30.0	 30.0;
	3720	 3442	 0.00012	 0.000461	 0.00152	 407.259878	 407.259878	 407.259878	 0.0	 0.0	 1	 -30.0	 30.0;
	3720	 1479	 0.00013	 0.00045	 0.00155	 377.156073	 377.156073	 377.156073	 0.0	 0.0	 1	 -30.0	 30.0;
	6035	 5721	 0.0	 0.000103	 0.0	 297.538858	 297.538858	 297.538858	 0.0	 0.0	 1	 -30.0	 30.0;
	6035	 5721	 0.001	 0.249814	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7792	 6941	 0.0001	 0.00075	 0.77789	 1245.886697	 1245.886697	 1245.886697	 0.0	 0.0	 1	 -30.0	 30.0;
	7792	 6792	 0.0038	 0.11597	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7792	 6792	 0.0001	 0.00081	 0.40407	 1283.725426	 1283.725426	 1283.725426	 0.0	 0.0	 1	 -30.0	 30.0;
	6179	 6941	 0.0001	 0.00094	 0.58389	 1300.277977	 1300.277977	 1300.277977	 0.0	 0.0	 1	 -30.0	 30.0;
	6179	 6941	 9e-05	 0.00107	 0.5335	 1181.670775	 1181.670775	 1181.670775	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 6179	 7e-05	 0.00085	 0.39053	 1150.20783	 1150.20783	 1150.20783	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 6179	 8e-05	 0.00081	 0.48117	 1284.752843	 1284.752843	 1284.752843	 0.0	 0.0	 1	 -30.0	 30.0;
	6941	 6792	 0.00018	 0.00171	 1.06574	 1104.971166	 1104.971166	 1104.971166	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 2292	 0.00017	 0.00191	 0.05127	 1415.821354	 1415.821354	 1415.821354	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 2292	 0.00016	 0.00194	 0.05023	 1373.971681	 1373.971681	 1373.971681	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 7199	 0.0005	 0.00317	 0.1002	 1526.829876	 1526.829876	 1526.829876	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 7199	 0.00048	 0.00322	 0.09807	 1552.75885	 1552.75885	 1552.75885	 0.0	 0.0	 1	 -30.0	 30.0;
	6792	 3960	 0.00427	 0.19732	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6792	 3960	 0.0001	 0.00122	 0.95678	 1164.879304	 1164.879304	 1164.879304	 0.0	 0.0	 1	 -30.0	 30.0;
	6792	 3960	 0.0001	 0.00119	 0.97672	 1266.230361	 1266.230361	 1266.230361	 0.0	 0.0	 1	 -30.0	 30.0;
	3960	 4094	 0.0024	 0.02048	 0.84984	 1552.197423	 1552.197423	 1552.197423	 0.0	 0.0	 1	 -30.0	 30.0;
	3960	 177	 0.00042	 0.00474	 0.14676	 1897.742875	 1897.742875	 1897.742875	 0.0	 0.0	 1	 -30.0	 30.0;
	3281	 1909	 0.0	 0.000103	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3281	 1909	 0.003409	 0.129831	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3281	 7023	 0.00605	 0.024031	 0.07065	 468.452886	 468.452886	 468.452886	 0.0	 0.0	 1	 -30.0	 30.0;
	1909	 7023	 0.005919	 0.0245	 0.06917	 433.784088	 433.784088	 433.784088	 0.0	 0.0	 1	 -30.0	 30.0;
	2612	 5623	 0.406364	 1.478988	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2612	 358	 0.12912	 0.95312	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2612	 4523	 0.23062	 0.90281	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 2612	 0.05107	 0.366901	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2612	 358	 0.00207	 0.0168	 0.08303	 315.543146	 315.543146	 315.543146	 0.0	 0.0	 1	 -30.0	 30.0;
	2612	 1482	 0.00119	 0.009659	 0.04779	 529.761353	 529.761353	 529.761353	 0.0	 0.0	 1	 -30.0	 30.0;
	3216	 2612	 0.120151	 0.700041	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2612	 5323	 0.032581	 0.326756	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3380	 5031	 2e-05	 0.0002	 0.00601	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3380	 870	 0.00025	 0.00344	 0.12743	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3380	 870	 0.01671	 0.288767	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3380	 2341	 0.01954	 0.281191	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 3380	 0.00356	 0.222701	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 3380	 0.00271	 0.199571	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4213	 5031	 0.00016	 0.00253	 0.08027	 944.139787	 944.139787	 944.139787	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 5031	 0.00018	 0.00214	 0.0555	 1277.577373	 1277.577373	 1277.577373	 0.0	 0.0	 1	 -30.0	 30.0;
	5623	 358	 0.002091	 0.0138	 0.06906	 281.19443	 281.19443	 281.19443	 0.0	 0.0	 1	 -30.0	 30.0;
	5623	 358	 0.291467	 1.202521	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4523	 5623	 0.204719	 0.794277	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 5623	 0.026401	 0.214814	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 5623	 0.00295	 0.01256	 0.04253	 439.779166	 439.779166	 439.779166	 0.0	 0.0	 1	 -30.0	 30.0;
	4838	 7087	 0.359525	 1.423657	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3796	 7087	 0.32907	 1.339607	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3796	 7087	 0.00469	 0.03913	 0.18279	 334.283623	 334.283623	 334.283623	 0.0	 0.0	 1	 -30.0	 30.0;
	2414	 7087	 0.000841	 0.00544	 0.03236	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2414	 7087	 0.014581	 0.16557	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4370	 7087	 1.038884	 1.650227	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6898	 7087	 0.863926	 1.96155	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	48	 358	 0.005081	 0.02426	 0.0791	 434.420444	 434.420444	 434.420444	 0.0	 0.0	 1	 -30.0	 30.0;
	1480	 48	 0.470062	 1.363636	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	48	 6466	 0.035969	 0.35219	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	48	 8316	 0.0033	 0.01864	 0.05088	 483.406478	 483.406478	 483.406478	 0.0	 0.0	 1	 -30.0	 30.0;
	48	 8316	 0.018021	 0.1825	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4629	 5711	 0.002651	 0.027659	 0.08744	 256.645589	 256.645589	 256.645589	 0.0	 0.0	 1	 -30.0	 30.0;
	4643	 4629	 0.00226	 0.04061	 0.06212	 532.284674	 532.284674	 532.284674	 0.0	 0.0	 1	 -30.0	 30.0;
	4629	 7513	 0.000711	 0.0098	 0.02356	 267.498308	 267.498308	 267.498308	 0.0	 0.0	 1	 -30.0	 30.0;
	2090	 4629	 0.002211	 0.037599	 0.06077	 255.407935	 255.407935	 255.407935	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 2196	 0.0016	 0.01356	 0.51826	 1323.364274	 1323.364274	 1323.364274	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 2196	 0.00165	 0.01328	 0.52819	 1299.526994	 1299.526994	 1299.526994	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 870	 0.01336	 0.25865	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 870	 0.00015	 0.00253	 0.07483	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8036	 1516	 0.00225	 0.02106	 0.71123	 1642.586504	 1642.586504	 1642.586504	 0.0	 0.0	 1	 -30.0	 30.0;
	3848	 1516	 0.00426	 0.03506	 1.32273	 1706.167283	 1706.167283	 1706.167283	 0.0	 0.0	 1	 -30.0	 30.0;
	6148	 1516	 0.00043	 0.00581	 0.20816	 2025.797583	 2025.797583	 2025.797583	 0.0	 0.0	 1	 -30.0	 30.0;
	4523	 3593	 0.001151	 0.009909	 0.0435	 435.584174	 435.584174	 435.584174	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 3593	 0.000961	 0.00751	 0.02752	 615.698682	 615.698682	 615.698682	 0.0	 0.0	 1	 -30.0	 30.0;
	771	 3593	 0.00032	 0.00324	 0.01186	 447.740468	 447.740468	 447.740468	 0.0	 0.0	 1	 -30.0	 30.0;
	8036	 1516	 0.00245	 0.02191	 0.76733	 1080.145959	 1080.145959	 1080.145959	 0.0	 0.0	 1	 -30.0	 30.0;
	1028	 1516	 0.00037	 0.00606	 0.18033	 930.758343	 930.758343	 930.758343	 0.0	 0.0	 1	 -30.0	 30.0;
	6327	 1516	 0.0029	 0.0289	 0.89272	 1763.742834	 1763.742834	 1763.742834	 0.0	 0.0	 1	 -30.0	 30.0;
	6399	 358	 0.000151	 0.00156	 0.00506	 275.154388	 275.154388	 275.154388	 0.0	 0.0	 1	 -30.0	 30.0;
	8248	 358	 0.00014	 0.00144	 0.00495	 291.890918	 291.890918	 291.890918	 0.0	 0.0	 1	 -30.0	 30.0;
	4523	 358	 0.026841	 0.406942	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 358	 0.025909	 0.304649	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2383	 749	 0.0	 0.00012	 0.0	 2059.061965	 2059.061965	 2059.061965	 0.0	 0.0	 1	 -30.0	 30.0;
	2383	 749	 0.001	 0.18678	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7662	 2383	 0.989958	 2.675	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7518	 2383	 0.994529	 2.704017	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3787	 2383	 0.154938	 0.902078	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3014	 2383	 0.141247	 1.002008	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8271	 2383	 0.01709	 0.303539	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2383	 6730	 0.00081	 0.00826	 0.24179	 1561.014393	 1561.014393	 1561.014393	 0.0	 0.0	 1	 -30.0	 30.0;
	2383	 3743	 0.00174	 0.01199	 0.54183	 1487.917657	 1487.917657	 1487.917657	 0.0	 0.0	 1	 -30.0	 30.0;
	2383	 5619	 0.00136	 0.012	 0.42329	 1042.479673	 1042.479673	 1042.479673	 0.0	 0.0	 1	 -30.0	 30.0;
	7662	 749	 1.135249	 2.306648	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7518	 749	 1.077147	 2.483726	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3787	 749	 0.140319	 0.988089	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3014	 749	 0.15108	 0.940582	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8271	 749	 0.00045	 0.00442	 0.15175	 1387.828988	 1387.828988	 1387.828988	 0.0	 0.0	 1	 -30.0	 30.0;
	8271	 749	 0.01578	 0.332528	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 749	 0.00032	 0.00308	 0.10147	 2062.217277	 2062.217277	 2062.217277	 0.0	 0.0	 1	 -30.0	 30.0;
	294	 4213	 0.00018	 0.0025	 0.08139	 1961.130808	 1961.130808	 1961.130808	 0.0	 0.0	 1	 -30.0	 30.0;
	2635	 4213	 0.03152	 0.366053	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1480	 3424	 0.00251	 0.13469	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1480	 4838	 0.00943	 0.04787	 0.12183	 433.07076	 433.07076	 433.07076	 0.0	 0.0	 1	 -30.0	 30.0;
	1480	 6466	 0.002781	 0.02494	 0.10699	 282.302527	 282.302527	 282.302527	 0.0	 0.0	 1	 -30.0	 30.0;
	1480	 6466	 0.22876	 0.857376	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1480	 8316	 0.113521	 0.454752	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8036	 6912	 0.00159	 0.01603	 0.49748	 1446.824232	 1446.824232	 1446.824232	 0.0	 0.0	 1	 -30.0	 30.0;
	3424	 3796	 0.00924	 0.04881	 0.11935	 501.222907	 501.222907	 501.222907	 0.0	 0.0	 1	 -30.0	 30.0;
	3424	 8316	 0.00643	 0.027271	 0.09824	 546.045575	 546.045575	 546.045575	 0.0	 0.0	 1	 -30.0	 30.0;
	8036	 3848	 0.00183	 0.01368	 0.57847	 1839.406469	 1839.406469	 1839.406469	 0.0	 0.0	 1	 -30.0	 30.0;
	7432	 4868	 0.0	 0.00012	 0.0	 984.488811	 984.488811	 984.488811	 0.0	 0.0	 1	 -30.0	 30.0;
	7432	 4868	 0.001	 0.191392	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2959	 7432	 0.00081	 0.00981	 0.35587	 1554.988761	 1554.988761	 1554.988761	 0.0	 0.0	 1	 -30.0	 30.0;
	7432	 4500	 0.090907	 0.571413	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7432	 4500	 0.00058	 0.00647	 0.2001	 1573.887064	 1573.887064	 1573.887064	 0.0	 0.0	 1	 -30.0	 30.0;
	7432	 8143	 0.441572	 1.595429	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7432	 4403	 0.0463	 0.493158	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7432	 5419	 0.053	 0.456427	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5419	 4868	 0.00048	 0.00707	 0.21018	 1527.220176	 1527.220176	 1527.220176	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 4500	 0.0007	 0.00626	 0.21496	 1787.730837	 1787.730837	 1787.730837	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 4500	 0.099273	 0.491122	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 8143	 0.411558	 1.466205	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 4403	 0.05226	 0.428179	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 5419	 0.04979	 0.473137	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6503	 1297	 0.00018	 0.00218	 0.05434	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	3490	 3976	 0.344619	 1.353116	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3490	 2166	 0.581787	 1.764958	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3490	 7187	 0.075831	 0.835526	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3490	 7187	 0.00095	 0.0105	 0.32475	 1500.552725	 1500.552725	 1500.552725	 0.0	 0.0	 1	 -30.0	 30.0;
	3490	 1898	 0.081281	 0.782202	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3490	 6730	 0.06719	 0.554377	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3490	 5619	 0.00409	 0.271641	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3490	 5619	 0.00041	 0.00351	 0.13804	 1478.268749	 1478.268749	 1478.268749	 0.0	 0.0	 1	 -30.0	 30.0;
	7220	 590	 0.00138	 0.008789	 0.02153	 551.481271	 551.481271	 551.481271	 0.0	 0.0	 1	 -30.0	 30.0;
	7220	 3001	 0.002331	 0.01832	 0.04663	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3976	 2166	 0.0	 0.00011	 0.0	 1905.669329	 1905.669329	 1905.669329	 0.0	 0.0	 1	 -30.0	 30.0;
	3976	 2166	 0.001	 0.311717	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1448	 3976	 0.00043	 0.00408	 0.14672	 1851.350449	 1851.350449	 1851.350449	 0.0	 0.0	 1	 -30.0	 30.0;
	3976	 7187	 0.083899	 0.525478	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3976	 1898	 0.07124	 0.605921	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3976	 1297	 0.00013	 0.00147	 0.03966	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	3976	 6730	 2.055194	 4.798753	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8143	 3976	 0.00048	 0.00587	 0.16772	 1771.956912	 1771.956912	 1771.956912	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 3976	 0.81115	 2.560526	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	918	 7220	 0.00095	 0.004169	 0.01466	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7355	 7220	 0.01012	 0.04631	 0.08989	 498.22975	 498.22975	 498.22975	 0.0	 0.0	 1	 -30.0	 30.0;
	2731	 2166	 0.00013	 0.0014	 0.04059	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1078	 2166	 0.00013	 0.00143	 0.03973	 1444.257991	 1444.257991	 1444.257991	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 7187	 0.091447	 0.726385	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 7187	 0.00093	 0.00869	 0.29632	 998.478412	 998.478412	 998.478412	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 1898	 0.089307	 0.727078	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 6730	 3.590651	 5.504778	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2635	 2166	 0.00047	 0.00544	 0.16411	 1609.859196	 1609.859196	 1609.859196	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 2166	 1.2741	 3.747645	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7227	 3831	 0.00142	 0.01566	 0.6303	 1433.257182	 1433.257182	 1433.257182	 0.0	 0.0	 1	 -30.0	 30.0;
	1898	 6047	 0.00082	 0.00794	 0.37094	 2117.220005	 2117.220005	 2117.220005	 0.0	 0.0	 1	 -30.0	 30.0;
	7662	 7518	 0.0	 0.00011	 0.0	 1429.204114	 1429.204114	 1429.204114	 0.0	 0.0	 1	 -30.0	 30.0;
	7662	 7518	 0.001	 0.149882	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3787	 7662	 0.088033	 0.626579	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3787	 7662	 0.001	 0.00866	 0.22327	 1299.188032	 1299.188032	 1299.188032	 0.0	 0.0	 1	 -30.0	 30.0;
	3014	 7662	 0.090852	 0.619418	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8271	 7662	 0.87133	 2.390028	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3787	 7518	 0.087632	 0.633012	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3014	 7518	 0.097832	 0.57669	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8271	 7518	 0.857064	 2.463089	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7518	 3743	 0.0004	 0.0039	 0.09838	 1107.035216	 1107.035216	 1107.035216	 0.0	 0.0	 1	 -30.0	 30.0;
	4838	 3796	 0.001	 0.486508	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2414	 4838	 0.003909	 0.034711	 0.15186	 592.263273	 592.263273	 592.263273	 0.0	 0.0	 1	 -30.0	 30.0;
	2414	 4838	 0.497789	 2.055971	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4838	 4370	 0.357087	 1.677376	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4838	 6898	 0.349194	 1.694876	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2414	 3796	 0.438409	 2.013802	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3796	 4370	 0.307107	 1.517831	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3796	 6898	 0.354174	 1.443988	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7817	 2258	 0.00274	 0.144159	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7817	 5973	 0.00039	 0.00175	 0.006	 224.526023	 224.526023	 224.526023	 0.0	 0.0	 1	 -30.0	 30.0;
	2258	 8094	 0.000401	 0.001711	 0.00611	 463.610107	 463.610107	 463.610107	 0.0	 0.0	 1	 -30.0	 30.0;
	7227	 4639	 0.06537	 0.54912	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7227	 1448	 0.00098	 0.00852	 0.31768	 1105.013947	 1105.013947	 1105.013947	 0.0	 0.0	 1	 -30.0	 30.0;
	7227	 1448	 0.076039	 0.582729	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7227	 1821	 0.00185	 0.01418	 0.59674	 1070.023819	 1070.023819	 1070.023819	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 7227	 0.790374	 2.170014	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1527	 590	 0.00188	 0.0087	 0.02894	 503.76528	 503.76528	 503.76528	 0.0	 0.0	 1	 -30.0	 30.0;
	1527	 3218	 0.042461	 0.437066	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	375	 3218	 0.00068	 0.008531	 0.0272	 490.127458	 490.127458	 490.127458	 0.0	 0.0	 1	 -30.0	 30.0;
	3490	 7187	 0.00107	 0.01108	 0.32435	 1955.393459	 1955.393459	 1955.393459	 0.0	 0.0	 1	 -30.0	 30.0;
	3490	 6730	 0.00092	 0.00947	 0.27717	 1722.871874	 1722.871874	 1722.871874	 0.0	 0.0	 1	 -30.0	 30.0;
	3787	 3014	 0.0	 0.00011	 0.0	 1685.703172	 1685.703172	 1685.703172	 0.0	 0.0	 1	 -30.0	 30.0;
	3787	 3014	 0.001	 0.196378	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3787	 8271	 0.102652	 0.915512	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3014	 8271	 0.110602	 0.871537	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5506	 3014	 0.00153	 0.01371	 0.31254	 1320.428795	 1320.428795	 1320.428795	 0.0	 0.0	 1	 -30.0	 30.0;
	8079	 3014	 0.00296	 0.02271	 0.63138	 1081.634102	 1081.634102	 1081.634102	 0.0	 0.0	 1	 -30.0	 30.0;
	4639	 1448	 0.0	 0.0001	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4639	 1448	 0.001	 0.229661	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4639	 1821	 0.00076	 0.0066	 0.2459	 1099.369402	 1099.369402	 1099.369402	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 4639	 0.134051	 0.802355	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 1448	 0.136413	 0.960942	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7724	 8094	 0.0027	 0.02195	 0.07162	 502.077604	 502.077604	 502.077604	 0.0	 0.0	 1	 -30.0	 30.0;
	7724	 3001	 0.001211	 0.004961	 0.01837	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1954	 6399	 0.010091	 0.211612	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1954	 8248	 0.008349	 0.215682	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 1954	 0.000401	 0.001781	 0.00535	 256.547278	 256.547278	 256.547278	 0.0	 0.0	 1	 -30.0	 30.0;
	6399	 8248	 0.00076	 0.205461	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8143	 6148	 0.00086	 0.0138	 0.37901	 1716.690254	 1716.690254	 1716.690254	 0.0	 0.0	 1	 -30.0	 30.0;
	2635	 1028	 0.00101	 0.01174	 0.44381	 1630.140333	 1630.140333	 1630.140333	 0.0	 0.0	 1	 -30.0	 30.0;
	7187	 1898	 0.0	 0.00011	 0.0	 1483.518387	 1483.518387	 1483.518387	 0.0	 0.0	 1	 -30.0	 30.0;
	7187	 1898	 0.001	 0.17286	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7187	 6730	 0.917036	 2.770706	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 7187	 0.299162	 1.508587	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1898	 6730	 0.973546	 2.445291	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 1898	 0.335817	 1.383795	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	709	 4370	 0.00114	 0.00625	 0.01594	 556.396069	 556.396069	 556.396069	 0.0	 0.0	 1	 -30.0	 30.0;
	4564	 709	 0.00069	 0.00343	 0.02608	 313.778116	 313.778116	 313.778116	 0.0	 0.0	 1	 -30.0	 30.0;
	6504	 709	 0.000669	 0.00349	 0.02555	 323.7628	 323.7628	 323.7628	 0.0	 0.0	 1	 -30.0	 30.0;
	1374	 709	 0.00264	 0.01612	 0.0693	 546.524557	 546.524557	 546.524557	 0.0	 0.0	 1	 -30.0	 30.0;
	2959	 3848	 0.001	 0.01303	 0.4362	 1767.616219	 1767.616219	 1767.616219	 0.0	 0.0	 1	 -30.0	 30.0;
	862	 3848	 0.00018	 0.00112	 0.06237	 831.227152	 831.227152	 831.227152	 0.0	 0.0	 1	 -30.0	 30.0;
	5464	 1226	 0.000771	 0.0027	 0.00545	 426.880584	 426.880584	 426.880584	 0.0	 0.0	 1	 -30.0	 30.0;
	1075	 1226	 0.000719	 0.003039	 0.00495	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1226	 6898	 0.00138	 0.005409	 0.0184	 509.84076	 509.84076	 509.84076	 0.0	 0.0	 1	 -30.0	 30.0;
	1682	 6912	 0.00017	 0.0011	 0.06071	 1764.130502	 1764.130502	 1764.130502	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 4523	 0.01424	 0.207211	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6466	 4523	 0.00288	 0.023031	 0.11118	 357.676736	 357.676736	 357.676736	 0.0	 0.0	 1	 -30.0	 30.0;
	8271	 5693	 0.00059	 0.00738	 0.19892	 1229.72313	 1229.72313	 1229.72313	 0.0	 0.0	 1	 -30.0	 30.0;
	3793	 4403	 2e-05	 0.0002	 0.0083	 1270.387422	 1270.387422	 1270.387422	 0.0	 0.0	 1	 -30.0	 30.0;
	2959	 5990	 0.00034	 0.00243	 0.122	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 2341	 0.00939	 0.239481	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 2341	 0.0003	 0.00385	 0.14929	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 7513	 0.00082	 0.0117	 0.02754	 379.840959	 379.840959	 379.840959	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 5711	 0.000831	 0.010711	 0.03388	 239.563827	 239.563827	 239.563827	 0.0	 0.0	 1	 -30.0	 30.0;
	4210	 1948	 0.0	 0.00011	 0.0	 1164.350128	 1164.350128	 1164.350128	 0.0	 0.0	 1	 -30.0	 30.0;
	4210	 1948	 0.001	 0.424958	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4210	 2635	 0.00035	 0.00315	 0.10812	 2077.425168	 2077.425168	 2077.425168	 0.0	 0.0	 1	 -30.0	 30.0;
	4210	 2635	 0.01362	 0.396288	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4210	 5693	 0.088213	 0.739543	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1948	 2635	 0.01388	 0.388199	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1948	 5693	 0.0012	 0.01148	 0.36391	 1868.41638	 1868.41638	 1868.41638	 0.0	 0.0	 1	 -30.0	 30.0;
	1948	 5693	 0.086413	 0.754086	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	294	 8143	 0.00049	 0.00475	 0.16449	 1570.946319	 1570.946319	 1570.946319	 0.0	 0.0	 1	 -30.0	 30.0;
	2630	 5100	 0.002669	 0.01443	 0.04143	 432.824982	 432.824982	 432.824982	 0.0	 0.0	 1	 -30.0	 30.0;
	3218	 590	 0.00338	 0.01488	 0.05173	 572.347252	 572.347252	 572.347252	 0.0	 0.0	 1	 -30.0	 30.0;
	3216	 8094	 0.00101	 0.005841	 0.01811	 268.664324	 268.664324	 268.664324	 0.0	 0.0	 1	 -30.0	 30.0;
	6148	 1821	 0.00034	 0.00381	 0.15065	 1760.88107	 1760.88107	 1760.88107	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 1821	 0.00017	 0.00223	 0.05319	 1702.520311	 1702.520311	 1702.520311	 0.0	 0.0	 1	 -30.0	 30.0;
	5323	 5973	 0.00161	 0.013789	 0.06062	 553.814066	 553.814066	 553.814066	 0.0	 0.0	 1	 -30.0	 30.0;
	1821	 7181	 0.00032	 0.00234	 0.11759	 1781.359003	 1781.359003	 1781.359003	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 6730	 0.01246	 0.249882	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4500	 2635	 0.00073	 0.00838	 0.25339	 1518.514439	 1518.514439	 1518.514439	 0.0	 0.0	 1	 -30.0	 30.0;
	4500	 8143	 0.01019	 0.13124	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4500	 8143	 0.00078	 0.00873	 0.26973	 1606.634775	 1606.634775	 1606.634775	 0.0	 0.0	 1	 -30.0	 30.0;
	4500	 4403	 0.463179	 1.173823	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4500	 5419	 0.428629	 1.321537	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 2635	 0.099591	 0.647687	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 2635	 0.00019	 0.00245	 0.07706	 1554.717592	 1554.717592	 1554.717592	 0.0	 0.0	 1	 -30.0	 30.0;
	8143	 4403	 1.591828	 3.383587	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8143	 5419	 1.558587	 3.254017	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2414	 4370	 1.410971	 2.609298	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2414	 6898	 1.456178	 2.474793	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4370	 6898	 0.0	 0.000103	 0.0	 504.348669	 504.348669	 504.348669	 0.0	 0.0	 1	 -30.0	 30.0;
	4370	 6898	 0.001	 0.139341	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4403	 5419	 0.0	 0.00012	 0.0	 1119.815084	 1119.815084	 1119.815084	 0.0	 0.0	 1	 -30.0	 30.0;
	4403	 5419	 0.001	 0.196801	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7046	 1482	 0.00025	 0.00232	 0.01016	 257.22593	 257.22593	 257.22593	 0.0	 0.0	 1	 -30.0	 30.0;
	5323	 7046	 0.000719	 0.005461	 0.02933	 285.665304	 285.665304	 285.665304	 0.0	 0.0	 1	 -30.0	 30.0;
	1482	 7941	 0.00012	 0.00069	 0.0	 234.743911	 234.743911	 234.743911	 0.0	 0.0	 1	 -30.0	 30.0;
	5932	 1482	 0.003099	 0.11999	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6466	 8316	 0.0	 0.000103	 0.0	 232.419117	 232.419117	 232.419117	 0.0	 0.0	 1	 -30.0	 30.0;
	6466	 8316	 0.001	 0.13145	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3216	 5323	 0.10799	 0.554256	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7553	 7755	 0.00077	 0.00927	 0.40578	 1762.088829	 1762.088829	 1762.088829	 0.0	 0.0	 1	 -30.0	 30.0;
	5929	 7755	 0.00078	 0.00908	 0.41358	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	4422	 6254	 0.00038	 0.0045	 0.20244	 790.420693	 790.420693	 790.420693	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 5860	 0.00147	 0.0125	 0.4929	 1793.591266	 1793.591266	 1793.591266	 0.0	 0.0	 1	 -30.0	 30.0;
	6048	 6254	 0.00039	 0.00441	 0.20633	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 1129	 0.00202	 0.01654	 0.67923	 1615.267455	 1615.267455	 1615.267455	 0.0	 0.0	 1	 -30.0	 30.0;
	5929	 7553	 0.0	 3.5e-05	 0.0	 1464.004687	 1464.004687	 1464.004687	 0.0	 0.0	 1	 -30.0	 30.0;
	5929	 7553	 0.00147	 0.112341	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5929	 4422	 0.00069	 0.00564	 0.18589	 1642.263338	 1642.263338	 1642.263338	 0.0	 0.0	 1	 -30.0	 30.0;
	7553	 6048	 0.00068	 0.00574	 0.18202	 1600.79475	 1600.79475	 1600.79475	 0.0	 0.0	 1	 -30.0	 30.0;
	4422	 6048	 0.0	 3.5e-05	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4422	 6048	 0.00088	 0.07777	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	534	 4422	 0.00062	 0.00515	 0.18247	 1212.057597	 1212.057597	 1212.057597	 0.0	 0.0	 1	 -30.0	 30.0;
	2175	 6048	 0.0007	 0.00505	 0.2068	 1205.840435	 1205.840435	 1205.840435	 0.0	 0.0	 1	 -30.0	 30.0;
	534	 2175	 0.0	 3.5e-05	 0.0	 1095.720456	 1095.720456	 1095.720456	 0.0	 0.0	 1	 -30.0	 30.0;
	534	 2175	 0.00076	 0.06481	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2811	 414	 0.00011	 0.00149	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5347	 1763	 9.9e-05	 0.000979	 0.0	 280.003645	 280.003645	 280.003645	 0.0	 0.0	 1	 -30.0	 30.0;
	4402	 3585	 0.01788	 0.227831	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4402	 3585	 0.004669	 0.015969	 0.03215	 424.005172	 424.005172	 424.005172	 0.0	 0.0	 1	 -30.0	 30.0;
	6196	 4402	 0.011229	 0.03868	 0.07741	 383.319575	 383.319575	 383.319575	 0.0	 0.0	 1	 -30.0	 30.0;
	349	 4402	 0.01001	 0.043841	 0.06896	 395.680113	 395.680113	 395.680113	 0.0	 0.0	 1	 -30.0	 30.0;
	4402	 430	 0.002151	 0.01032	 0.0213	 374.875862	 374.875862	 374.875862	 0.0	 0.0	 1	 -30.0	 30.0;
	3876	 5349	 0.003281	 0.017901	 0.04863	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	2214	 3876	 0.005271	 0.026909	 0.07367	 474.902177	 474.902177	 474.902177	 0.0	 0.0	 1	 -30.0	 30.0;
	3876	 7659	 0.00044	 0.002169	 0.00639	 505.996716	 505.996716	 505.996716	 0.0	 0.0	 1	 -30.0	 30.0;
	3876	 7659	 0.00045	 0.00213	 0.00651	 505.418661	 505.418661	 505.418661	 0.0	 0.0	 1	 -30.0	 30.0;
	2865	 5651	 0.452251	 2.097438	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5651	 1103	 0.247659	 1.380679	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1138	 5651	 0.436378	 1.290097	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 5651	 0.218089	 1.220914	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4352	 5651	 0.0612	 1.024169	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 5651	 0.06168	 0.959765	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 5651	 0.0011	 0.00838	 0.33964	 1622.547576	 1622.547576	 1622.547576	 0.0	 0.0	 1	 -30.0	 30.0;
	3910	 5651	 0.05459	 0.962258	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 5651	 0.00126	 0.01278	 0.39143	 1517.428443	 1517.428443	 1517.428443	 0.0	 0.0	 1	 -30.0	 30.0;
	7744	 1471	 5e-05	 0.000229	 0.00081	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 7744	 0.001331	 0.009331	 0.02305	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	7744	 8349	 6e-05	 0.00031	 0.00084	 473.467901	 473.467901	 473.467901	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 5820	 0.00155	 0.00805	 0.02726	 370.930458	 370.930458	 370.930458	 0.0	 0.0	 1	 -30.0	 30.0;
	5820	 140	 0.351674	 1.414483	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 5820	 0.239545	 1.416095	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4754	 1763	 0.00011	 0.00088	 0.10721	 399.839287	 399.839287	 399.839287	 0.0	 0.0	 1	 -30.0	 30.0;
	1478	 414	 0.00012	 0.00064	 0.13346	 303.802959	 303.802959	 303.802959	 0.0	 0.0	 1	 -30.0	 30.0;
	7447	 414	 0.002349	 0.01088	 0.01892	 449.418237	 449.418237	 449.418237	 0.0	 0.0	 1	 -30.0	 30.0;
	7447	 414	 0.0023	 0.011099	 0.01854	 433.166785	 433.166785	 433.166785	 0.0	 0.0	 1	 -30.0	 30.0;
	414	 771	 0.004771	 0.03713	 0.16488	 347.748067	 347.748067	 347.748067	 0.0	 0.0	 1	 -30.0	 30.0;
	7324	 1763	 0.00056	 0.0013	 0.12734	 365.842282	 365.842282	 365.842282	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 1763	 0.001091	 0.007409	 0.02704	 453.522539	 453.522539	 453.522539	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 1763	 0.00168	 0.007479	 0.02676	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1304	 1763	 0.003151	 0.01876	 0.05102	 526.960627	 526.960627	 526.960627	 0.0	 0.0	 1	 -30.0	 30.0;
	1055	 2399	 0.005719	 0.255764	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2871	 1055	 0.000599	 0.00294	 0.00951	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2871	 2399	 0.00062	 0.00288	 0.00969	 568.595041	 568.595041	 568.595041	 0.0	 0.0	 1	 -30.0	 30.0;
	5149	 4351	 0.001169	 0.012591	 0.03659	 351.916386	 351.916386	 351.916386	 0.0	 0.0	 1	 -30.0	 30.0;
	5149	 4351	 0.00131	 0.01119	 0.04134	 268.996982	 268.996982	 268.996982	 0.0	 0.0	 1	 -30.0	 30.0;
	5811	 4351	 0.000159	 0.00137	 0.00499	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3737	 4351	 0.000159	 0.001341	 0.00509	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7721	 1176	 0.00051	 0.0025	 0.04207	 311.17668	 311.17668	 311.17668	 0.0	 0.0	 1	 -30.0	 30.0;
	4067	 6437	 0.00031	 0.001289	 0.11495	 469.307965	 469.307965	 469.307965	 0.0	 0.0	 1	 -30.0	 30.0;
	7721	 6437	 0.05163	 0.55124	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6945	 6437	 0.201229	 1.043864	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7029	 5245	 1.027128	 2.385331	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7029	 148	 0.288306	 1.382335	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6345	 7029	 0.05949	 0.340661	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7029	 2370	 0.007211	 0.030409	 0.10181	 248.800508	 248.800508	 248.800508	 0.0	 0.0	 1	 -30.0	 30.0;
	7836	 7029	 0.899153	 2.660744	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5068	 7029	 0.809979	 2.92686	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7029	 4837	 0.00251	 0.011211	 0.0404	 423.976593	 423.976593	 423.976593	 0.0	 0.0	 1	 -30.0	 30.0;
	7355	 4359	 0.08695	 0.512231	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7355	 7981	 0.006289	 0.693946	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1511	 7355	 0.140669	 0.495269	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7964	 7355	 0.00882	 0.041831	 0.07707	 493.394972	 493.394972	 493.394972	 0.0	 0.0	 1	 -30.0	 30.0;
	6327	 1669	 2e-05	 0.00025	 0.00757	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4684	 4038	 0.000159	 0.00074	 0.00233	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	913	 6041	 0.004469	 0.139591	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	913	 2190	 0.001039	 0.006211	 0.01297	 447.01228	 447.01228	 447.01228	 0.0	 0.0	 1	 -30.0	 30.0;
	6735	 8255	 0.00813	 0.186659	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6735	 2190	 0.00101	 0.00625	 0.01246	 407.658076	 407.658076	 407.658076	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 516	 8.1e-05	 0.000781	 0.00238	 456.728704	 456.728704	 456.728704	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 6301	 0.0003	 0.002031	 0.0041	 494.527837	 494.527837	 494.527837	 0.0	 0.0	 1	 -30.0	 30.0;
	6464	 516	 9.1e-05	 0.000719	 0.00278	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	6464	 7362	 0.00086	 0.005581	 0.02151	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 1103	 0.00062	 0.00605	 0.19445	 874.472165	 874.472165	 874.472165	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 516	 0.00181	 0.009599	 0.03449	 301.696127	 301.696127	 301.696127	 0.0	 0.0	 1	 -30.0	 30.0;
	5735	 516	 0.00099	 0.00481	 0.01427	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	516	 4092	 0.00038	 0.00218	 0.00626	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3324	 1274	 0.00031	 0.00342	 0.1086	 1785.211985	 1785.211985	 1785.211985	 0.0	 0.0	 1	 -30.0	 30.0;
	6455	 1274	 0.00083	 0.00929	 0.26519	 1441.82536	 1441.82536	 1441.82536	 0.0	 0.0	 1	 -30.0	 30.0;
	2955	 1274	 0.00074	 0.00793	 0.30117	 2107.869252	 2107.869252	 2107.869252	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 2955	 0.00016	 0.00166	 0.05189	 1849.697761	 1849.697761	 1849.697761	 0.0	 0.0	 1	 -30.0	 30.0;
	1274	 7421	 0.0	 0.00012	 0.0	 1135.452108	 1135.452108	 1135.452108	 0.0	 0.0	 1	 -30.0	 30.0;
	1274	 7421	 0.01471	 0.443012	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1205	 7421	 0.00037	 0.00337	 0.11641	 1868.463111	 1868.463111	 1868.463111	 0.0	 0.0	 1	 -30.0	 30.0;
	6196	 2632	 0.001461	 0.006711	 0.02463	 271.809521	 271.809521	 271.809521	 0.0	 0.0	 1	 -30.0	 30.0;
	1696	 2632	 0.001479	 0.00656	 0.02509	 604.26829	 604.26829	 604.26829	 0.0	 0.0	 1	 -30.0	 30.0;
	6546	 4359	 0.00068	 0.0113	 0.04379	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4441	 2835	 0.00019	 0.00196	 0.0695	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2497	 2835	 0.00019	 0.00198	 0.06439	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1205	 4885	 0.00886	 0.294079	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1205	 4885	 0.00028	 0.00275	 0.09336	 1731.537462	 1731.537462	 1731.537462	 0.0	 0.0	 1	 -30.0	 30.0;
	3324	 4885	 0.01321	 0.296717	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7565	 7999	 0.001	 0.169901	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7565	 140	 0.03111	 0.255	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 7565	 0.00057	 0.002849	 0.00853	 238.87603	 238.87603	 238.87603	 0.0	 0.0	 1	 -30.0	 30.0;
	7999	 140	 0.03143	 0.234731	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 7999	 0.000581	 0.002789	 0.00869	 554.238938	 554.238938	 554.238938	 0.0	 0.0	 1	 -30.0	 30.0;
	7799	 3557	 0.00157	 0.007	 0.02151	 581.132387	 581.132387	 581.132387	 0.0	 0.0	 1	 -30.0	 30.0;
	7799	 619	 0.00131	 0.00636	 0.01933	 606.515349	 606.515349	 606.515349	 0.0	 0.0	 1	 -30.0	 30.0;
	6754	 3557	 0.001669	 0.00724	 0.025	 532.760988	 532.760988	 532.760988	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 3775	 0.00663	 0.249339	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 1045	 0.000169	 0.00032	 0.03116	 268.496281	 268.496281	 268.496281	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 3596	 0.000151	 0.00038	 0.04218	 304.012156	 304.012156	 304.012156	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 2407	 0.000841	 0.009581	 0.02766	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 488	 0.0355	 0.360558	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 619	 0.027539	 0.325145	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 3508	 0.025271	 0.339442	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 7821	 0.000169	 0.000219	 0.02927	 278.067905	 278.067905	 278.067905	 0.0	 0.0	 1	 -30.0	 30.0;
	2209	 140	 0.000401	 0.0018	 0.0058	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 2209	 0.00205	 0.01162	 0.03066	 315.696328	 315.696328	 315.696328	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 2209	 0.000651	 0.0045	 0.00984	 333.36872	 333.36872	 333.36872	 0.0	 0.0	 1	 -30.0	 30.0;
	2674	 140	 0.00038	 0.00187	 0.00555	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 2674	 0.002091	 0.01139	 0.03126	 445.657643	 445.657643	 445.657643	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 2674	 0.00064	 0.004169	 0.00963	 375.187943	 375.187943	 375.187943	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 140	 0.03551	 0.421116	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 801	 0.090159	 0.624236	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 7253	 0.025919	 0.457603	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 2366	 0.140581	 0.992087	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 7288	 0.00082	 0.007331	 0.01985	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	7447	 745	 0.008469	 0.038599	 0.12888	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7447	 5854	 0.003729	 0.012081	 0.03914	 459.638029	 459.638029	 459.638029	 0.0	 0.0	 1	 -30.0	 30.0;
	6345	 5245	 0.071281	 0.33186	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6345	 5245	 0.011919	 0.055651	 0.08325	 430.260127	 430.260127	 430.260127	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 8371	 0.0038	 0.01182	 0.03987	 460.743078	 460.743078	 460.743078	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 7014	 0.00233	 0.0191	 0.71999	 2055.786865	 2055.786865	 2055.786865	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 5754	 0.00258	 0.02125	 0.79958	 1821.436199	 1821.436199	 1821.436199	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 7014	 0.00246	 0.01795	 0.76234	 2122.714486	 2122.714486	 2122.714486	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 8311	 0.00231	 0.02199	 0.71653	 1664.021429	 1664.021429	 1664.021429	 0.0	 0.0	 1	 -30.0	 30.0;
	6455	 2835	 0.00105	 0.0114	 0.36542	 1936.965755	 1936.965755	 1936.965755	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 788	 0.00268	 0.02035	 0.83233	 1865.012277	 1865.012277	 1865.012277	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 1820	 0.00124	 0.005711	 0.021	 276.063576	 276.063576	 276.063576	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 8347	 0.0002	 0.0022	 0.00566	 581.02836	 581.02836	 581.02836	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 2522	 0.00019	 0.00225	 0.00555	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 6248	 0.001169	 0.005159	 0.01741	 557.180272	 557.180272	 557.180272	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 7685	 0.001271	 0.005591	 0.02136	 269.095293	 269.095293	 269.095293	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 3016	 0.00182	 0.01218	 0.0343	 491.285473	 491.285473	 491.285473	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 6494	 0.00107	 0.005789	 0.01549	 230.18692	 230.18692	 230.18692	 0.0	 0.0	 1	 -30.0	 30.0;
	5870	 69	 0.00026	 0.00275	 0.0846	 1632.570331	 1632.570331	 1632.570331	 0.0	 0.0	 1	 -30.0	 30.0;
	5870	 723	 0.0001	 0.00093	 0.03377	 1929.731048	 1929.731048	 1929.731048	 0.0	 0.0	 1	 -30.0	 30.0;
	8305	 7496	 0.00019	 0.00166	 0.06341	 1896.43639	 1896.43639	 1896.43639	 0.0	 0.0	 1	 -30.0	 30.0;
	8305	 7496	 0.00019	 0.00163	 0.06463	 1928.912931	 1928.912931	 1928.912931	 0.0	 0.0	 1	 -30.0	 30.0;
	3434	 4982	 0.00126	 0.00953	 0.38902	 1829.849705	 1829.849705	 1829.849705	 0.0	 0.0	 1	 -30.0	 30.0;
	3434	 7009	 0.00131	 0.00994	 0.40489	 1957.497	 1957.497	 1957.497	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 4982	 0.00128	 0.00933	 0.39636	 1799.593203	 1799.593203	 1799.593203	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 8295	 0.00134	 0.00972	 0.41253	 1778.359022	 1778.359022	 1778.359022	 0.0	 0.0	 1	 -30.0	 30.0;
	3434	 1775	 0.001	 0.180201	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3434	 7009	 1.365928	 3.472299	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3434	 8295	 0.186177	 1.029224	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	616	 3434	 0.98608	 2.33608	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3434	 7000	 0.487888	 1.618975	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3434	 4892	 0.850277	 2.290235	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 7009	 1.29162	 3.486565	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 8295	 0.201801	 0.8991	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	616	 1775	 0.842729	 2.35651	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 7000	 0.415547	 1.630194	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 4892	 0.830956	 1.995914	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	430	 8130	 0.005729	 0.021281	 0.05386	 400.850978	 400.850978	 400.850978	 0.0	 0.0	 1	 -30.0	 30.0;
	430	 8130	 0.005081	 0.029331	 0.08408	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6329	 8130	 0.00576	 0.035781	 0.08156	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3585	 8130	 0.002021	 0.00976	 0.02545	 544.025623	 544.025623	 544.025623	 0.0	 0.0	 1	 -30.0	 30.0;
	2889	 8130	 0.00563	 0.03313	 0.07978	 466.93173	 466.93173	 466.93173	 0.0	 0.0	 1	 -30.0	 30.0;
	7914	 6316	 0.001	 0.260568	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6265	 7914	 0.127098	 1.298546	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5223	 7914	 0.04182	 0.986219	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5223	 7914	 0.00129	 0.01393	 0.42962	 1929.347988	 1929.347988	 1929.347988	 0.0	 0.0	 1	 -30.0	 30.0;
	2058	 7914	 0.00082	 0.00915	 0.27462	 1893.718767	 1893.718767	 1893.718767	 0.0	 0.0	 1	 -30.0	 30.0;
	297	 7914	 0.00119	 0.01287	 0.39523	 1788.993225	 1788.993225	 1788.993225	 0.0	 0.0	 1	 -30.0	 30.0;
	6265	 6316	 0.118677	 1.418975	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6265	 6316	 0.00148	 0.01585	 0.4955	 1922.222538	 1922.222538	 1922.222538	 0.0	 0.0	 1	 -30.0	 30.0;
	5223	 6316	 0.04574	 0.913504	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7058	 6316	 0.00116	 0.01192	 0.38664	 1456.055855	 1456.055855	 1456.055855	 0.0	 0.0	 1	 -30.0	 30.0;
	6455	 1046	 0.06698	 0.909972	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6455	 1046	 0.00042	 0.00331	 0.14062	 2042.444254	 2042.444254	 2042.444254	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 3769	 0.002591	 0.01299	 0.03353	 252.057733	 252.057733	 252.057733	 0.0	 0.0	 1	 -30.0	 30.0;
	3769	 2090	 0.01169	 0.067849	 0.20339	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6641	 3373	 0.00074	 0.00368	 0.00663	 457.225594	 457.225594	 457.225594	 0.0	 0.0	 1	 -30.0	 30.0;
	6641	 148	 0.00064	 0.0042	 0.01042	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6641	 4837	 0.0018	 0.01139	 0.02956	 598.290359	 598.290359	 598.290359	 0.0	 0.0	 1	 -30.0	 30.0;
	762	 3373	 0.00082	 0.003401	 0.00774	 476.980431	 476.980431	 476.980431	 0.0	 0.0	 1	 -30.0	 30.0;
	762	 148	 0.00069	 0.00381	 0.01117	 228.566309	 228.566309	 228.566309	 0.0	 0.0	 1	 -30.0	 30.0;
	762	 4837	 0.00189	 0.01094	 0.03095	 603.654417	 603.654417	 603.654417	 0.0	 0.0	 1	 -30.0	 30.0;
	3373	 4715	 0.000151	 0.000711	 0.00246	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3373	 1236	 0.00013	 0.000789	 0.00233	 295.407639	 295.407639	 295.407639	 0.0	 0.0	 1	 -30.0	 30.0;
	3373	 6651	 5e-05	 0.00024	 0.00074	 266.272847	 266.272847	 266.272847	 0.0	 0.0	 1	 -30.0	 30.0;
	3373	 783	 5e-05	 0.00025	 0.00073	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7836	 3373	 0.00012	 0.000711	 0.0016	 310.823827	 310.823827	 310.823827	 0.0	 0.0	 1	 -30.0	 30.0;
	5068	 3373	 0.00011	 0.000719	 0.00157	 270.086788	 270.086788	 270.086788	 0.0	 0.0	 1	 -30.0	 30.0;
	594	 3783	 0.003091	 0.015719	 0.04755	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3783	 7835	 0.018159	 0.39124	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3783	 5747	 0.169419	 0.883946	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3783	 3160	 0.656054	 1.65126	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3783	 4757	 0.452913	 1.939091	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3783	 7889	 0.055969	 0.74907	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3439	 3783	 0.549483	 1.897438	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 3783	 0.483574	 1.959731	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3783	 6915	 0.279731	 1.818967	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3783	 6915	 0.006521	 0.02749	 0.08096	 399.311531	 399.311531	 399.311531	 0.0	 0.0	 1	 -30.0	 30.0;
	6748	 5522	 0.07687	 1.255956	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6748	 5522	 0.00068	 0.00577	 0.2297	 1681.041288	 1681.041288	 1681.041288	 0.0	 0.0	 1	 -30.0	 30.0;
	4067	 6323	 0.00812	 0.12314	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	13	 4067	 0.00157	 0.007031	 0.02061	 523.375317	 523.375317	 523.375317	 0.0	 0.0	 1	 -30.0	 30.0;
	1926	 4067	 0.001599	 0.00688	 0.02099	 513.789593	 513.789593	 513.789593	 0.0	 0.0	 1	 -30.0	 30.0;
	4067	 7721	 0.00113	 0.00724	 0.01355	 632.552957	 632.552957	 632.552957	 0.0	 0.0	 1	 -30.0	 30.0;
	4067	 7721	 0.001271	 0.007091	 0.01535	 608.508247	 608.508247	 608.508247	 0.0	 0.0	 1	 -30.0	 30.0;
	594	 7889	 0.000919	 0.005211	 0.01443	 587.639217	 587.639217	 587.639217	 0.0	 0.0	 1	 -30.0	 30.0;
	6754	 5735	 0.00199	 0.010219	 0.02314	 528.120547	 528.120547	 528.120547	 0.0	 0.0	 1	 -30.0	 30.0;
	6754	 7746	 0.005409	 0.02475	 0.04868	 528.760332	 528.760332	 528.760332	 0.0	 0.0	 1	 -30.0	 30.0;
	6754	 4417	 0.00482	 0.02805	 0.04337	 574.148481	 574.148481	 574.148481	 0.0	 0.0	 1	 -30.0	 30.0;
	6754	 2965	 0.028479	 0.302273	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6754	 5747	 0.11506	 0.606198	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6754	 5735	 0.025271	 0.321983	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6754	 8093	 0.00194	 0.010091	 0.08242	 248.209116	 248.209116	 248.209116	 0.0	 0.0	 1	 -30.0	 30.0;
	6754	 2965	 0.00314	 0.019719	 0.05134	 276.605431	 276.605431	 276.605431	 0.0	 0.0	 1	 -30.0	 30.0;
	3751	 6373	 0.00042	 0.00384	 0.14129	 1913.837334	 1913.837334	 1913.837334	 0.0	 0.0	 1	 -30.0	 30.0;
	3751	 723	 0.00031	 0.00229	 0.0998	 1769.041836	 1769.041836	 1769.041836	 0.0	 0.0	 1	 -30.0	 30.0;
	3751	 1018	 0.00024	 0.00235	 0.07144	 1669.806825	 1669.806825	 1669.806825	 0.0	 0.0	 1	 -30.0	 30.0;
	3751	 2205	 0.00103	 0.01072	 0.33055	 1697.535919	 1697.535919	 1697.535919	 0.0	 0.0	 1	 -30.0	 30.0;
	2217	 7721	 0.00275	 0.01311	 0.03965	 499.932286	 499.932286	 499.932286	 0.0	 0.0	 1	 -30.0	 30.0;
	2217	 7754	 0.001771	 0.01225	 0.02388	 481.551139	 481.551139	 481.551139	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 5349	 0.001	 0.385207	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 5349	 0.003349	 0.022711	 0.03426	 448.573827	 448.573827	 448.573827	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 4681	 0.00032	 0.001531	 0.00462	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 5555	 0.359525	 1.472438	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 4684	 1.632355	 4.693388	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 7372	 0.08494	 0.651364	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 7362	 0.052581	 0.671529	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7659	 281	 0.12794	 1.157789	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	619	 281	 0.002461	 0.014531	 0.02375	 638.151742	 638.151742	 638.151742	 0.0	 0.0	 1	 -30.0	 30.0;
	6943	 6176	 0.002659	 0.013271	 0.04286	 601.345247	 601.345247	 601.345247	 0.0	 0.0	 1	 -30.0	 30.0;
	6943	 6176	 0.002711	 0.01299	 0.04368	 275.906202	 275.906202	 275.906202	 0.0	 0.0	 1	 -30.0	 30.0;
	4248	 4684	 3.9e-05	 0.0002	 0.00074	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2913	 4684	 5e-05	 0.00031	 0.00081	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3231	 6227	 0.00089	 0.00698	 0.28591	 2083.737108	 2083.737108	 2083.737108	 0.0	 0.0	 1	 -30.0	 30.0;
	3231	 5018	 0.00028	 0.00271	 0.08013	 2014.123457	 2014.123457	 2014.123457	 0.0	 0.0	 1	 -30.0	 30.0;
	1556	 2865	 0.00025	 0.00273	 0.0818	 1372.034001	 1372.034001	 1372.034001	 0.0	 0.0	 1	 -30.0	 30.0;
	1556	 1103	 0.00027	 0.00238	 0.08344	 1637.148626	 1637.148626	 1637.148626	 0.0	 0.0	 1	 -30.0	 30.0;
	1556	 5018	 0.00027	 0.00277	 0.07842	 1955.221674	 1955.221674	 1955.221674	 0.0	 0.0	 1	 -30.0	 30.0;
	2865	 1103	 0.00808	 0.60428	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1138	 2865	 0.01086	 0.386371	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2865	 5018	 0.03494	 0.767659	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2865	 4352	 0.0265	 0.810665	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 2865	 0.524993	 2.841898	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3910	 2865	 0.475568	 2.62313	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7836	 148	 0.02113	 0.408595	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5068	 148	 0.022469	 0.384442	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8311	 5816	 0.00045	 0.0038	 0.15224	 2058.553851	 2058.553851	 2058.553851	 0.0	 0.0	 1	 -30.0	 30.0;
	8311	 5816	 0.00047	 0.00374	 0.16119	 1867.070403	 1867.070403	 1867.070403	 0.0	 0.0	 1	 -30.0	 30.0;
	7835	 6999	 0.00019	 0.00086	 0.00262	 409.649069	 409.649069	 409.649069	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 7835	 0.542397	 1.40281	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3160	 7835	 1.299236	 2.713017	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7835	 4757	 1.066591	 3.481612	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7835	 7889	 0.276529	 1.159153	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3439	 7835	 1.192211	 3.154339	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 7835	 1.210785	 2.840289	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6915	 7835	 0.804979	 2.837397	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	801	 8339	 9.1e-05	 0.00055	 0.0014	 337.05196	 337.05196	 337.05196	 0.0	 0.0	 1	 -30.0	 30.0;
	7253	 801	 0.009909	 0.377748	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	801	 2366	 0.914793	 3.247727	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2763	 8339	 0.000349	 0.002159	 0.00556	 647.101872	 647.101872	 647.101872	 0.0	 0.0	 1	 -30.0	 30.0;
	7253	 6999	 0.00132	 0.00624	 0.01907	 547.84871	 547.84871	 547.84871	 0.0	 0.0	 1	 -30.0	 30.0;
	7253	 8339	 0.00088	 0.005159	 0.01252	 517.37719	 517.37719	 517.37719	 0.0	 0.0	 1	 -30.0	 30.0;
	5274	 2366	 0.001349	 0.01051	 0.05416	 482.816991	 482.816991	 482.816991	 0.0	 0.0	 1	 -30.0	 30.0;
	481	 1852	 0.000539	 0.003099	 0.00825	 618.436916	 618.436916	 618.436916	 0.0	 0.0	 1	 -30.0	 30.0;
	481	 7288	 0.00207	 0.01182	 0.03149	 578.415873	 578.415873	 578.415873	 0.0	 0.0	 1	 -30.0	 30.0;
	6323	 7721	 0.000539	 0.003159	 0.00825	 245.69494	 245.69494	 245.69494	 0.0	 0.0	 1	 -30.0	 30.0;
	6323	 7754	 0.004081	 0.0247	 0.06557	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6905	 3780	 0.000531	 0.003521	 0.0059	 499.537517	 499.537517	 499.537517	 0.0	 0.0	 1	 -30.0	 30.0;
	7209	 1819	 0.000539	 0.00345	 0.00601	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1511	 7209	 0.005169	 0.02325	 0.03636	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6943	 4417	 0.000669	 0.004099	 0.00602	 578.955442	 578.955442	 578.955442	 0.0	 0.0	 1	 -30.0	 30.0;
	6943	 5840	 0.000599	 0.00344	 0.00519	 356.047361	 356.047361	 356.047361	 0.0	 0.0	 1	 -30.0	 30.0;
	349	 6943	 0.00139	 0.008919	 0.01245	 262.996569	 262.996569	 262.996569	 0.0	 0.0	 1	 -30.0	 30.0;
	6943	 7746	 0.00069	 0.00419	 0.00628	 574.813796	 574.813796	 574.813796	 0.0	 0.0	 1	 -30.0	 30.0;
	1696	 6943	 0.001539	 0.008099	 0.0138	 275.686717	 275.686717	 275.686717	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 2453	 0.00062	 0.00356	 0.01007	 496.583989	 496.583989	 496.583989	 0.0	 0.0	 1	 -30.0	 30.0;
	2453	 7889	 0.001091	 0.006479	 0.01286	 444.628424	 444.628424	 444.628424	 0.0	 0.0	 1	 -30.0	 30.0;
	8135	 6635	 6e-05	 0.00052	 0.02087	 1972.102657	 1972.102657	 1972.102657	 0.0	 0.0	 1	 -30.0	 30.0;
	8135	 7207	 0.00023	 0.00485	 0.17201	 1899.054627	 1899.054627	 1899.054627	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 6635	 7e-05	 0.00051	 0.02127	 1915.436052	 1915.436052	 1915.436052	 0.0	 0.0	 1	 -30.0	 30.0;
	6790	 5349	 5e-05	 0.000229	 0.00082	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1200	 5349	 8.1e-05	 0.0003	 0.00107	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3725	 5349	 6e-05	 0.000341	 0.00095	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5555	 5349	 0.339112	 2.39938	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4684	 5349	 0.982252	 4.492975	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5349	 7372	 0.299979	 2.042583	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5349	 7362	 0.216508	 1.7125	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	73	 5349	 0.002841	 0.01551	 0.04214	 277.856422	 277.856422	 277.856422	 0.0	 0.0	 1	 -30.0	 30.0;
	7659	 5349	 0.00326	 1.128223	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4146	 5349	 0.00232	 0.016961	 0.04206	 348.258294	 348.258294	 348.258294	 0.0	 0.0	 1	 -30.0	 30.0;
	2015	 5349	 0.003979	 0.02513	 0.03704	 503.364414	 503.364414	 503.364414	 0.0	 0.0	 1	 -30.0	 30.0;
	6673	 5349	 0.002281	 0.017289	 0.04118	 597.452809	 597.452809	 597.452809	 0.0	 0.0	 1	 -30.0	 30.0;
	1138	 1103	 0.111143	 0.652313	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	14	 1103	 0.00045	 0.00399	 0.15258	 1718.495639	 1718.495639	 1718.495639	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 1103	 0.01009	 0.588213	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4352	 1103	 0.0029	 0.60196	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 1103	 0.468573	 2.303532	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3910	 1103	 0.401032	 2.262812	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 1103	 0.00054	 0.00451	 0.18353	 1783.440166	 1783.440166	 1783.440166	 0.0	 0.0	 1	 -30.0	 30.0;
	14	 1103	 0.0004	 0.00439	 0.13731	 1663.350086	 1663.350086	 1663.350086	 0.0	 0.0	 1	 -30.0	 30.0;
	2148	 2366	 0.00132	 0.0077	 0.01898	 224.091244	 224.091244	 224.091244	 0.0	 0.0	 1	 -30.0	 30.0;
	2148	 7889	 0.002289	 0.013909	 0.03278	 461.61378	 461.61378	 461.61378	 0.0	 0.0	 1	 -30.0	 30.0;
	4558	 2875	 0.00015	 0.00153	 0.04776	 1459.299363	 1459.299363	 1459.299363	 0.0	 0.0	 1	 -30.0	 30.0;
	4558	 5593	 0.00022	 0.00174	 0.07202	 1793.92957	 1793.92957	 1793.92957	 0.0	 0.0	 1	 -30.0	 30.0;
	4558	 8368	 0.00031	 0.00276	 0.10567	 1522.604365	 1522.604365	 1522.604365	 0.0	 0.0	 1	 -30.0	 30.0;
	7253	 2366	 0.498802	 2.231818	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7253	 7889	 0.00243	 0.01461	 0.03115	 536.812705	 536.812705	 536.812705	 0.0	 0.0	 1	 -30.0	 30.0;
	7253	 7288	 0.0013	 0.005919	 0.02135	 561.478148	 561.478148	 561.478148	 0.0	 0.0	 1	 -30.0	 30.0;
	4684	 5555	 2.422314	 7.164876	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4684	 5555	 0.005271	 0.03874	 0.06348	 586.345929	 586.345929	 586.345929	 0.0	 0.0	 1	 -30.0	 30.0;
	5555	 7372	 0.157781	 1.324793	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5555	 7372	 0.00695	 0.055591	 0.08519	 586.267433	 586.267433	 586.267433	 0.0	 0.0	 1	 -30.0	 30.0;
	5555	 7362	 0.211777	 1.52969	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7659	 5555	 0.1823	 1.686529	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1982	 7638	 2.525346	 8.326177	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1982	 7638	 0.00086	 0.00871	 0.24623	 2296.190148	 2296.190148	 2296.190148	 0.0	 0.0	 1	 -30.0	 30.0;
	7638	 1667	 0.13018	 1.288158	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7638	 3260	 5.25734	 15.96122	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7638	 6227	 0.196787	 1.606648	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7878	 1667	 0.00124	 0.01282	 0.35391	 1660.98459	 1660.98459	 1660.98459	 0.0	 0.0	 1	 -30.0	 30.0;
	13	 1926	 0.0	 0.000103	 0.0	 267.580234	 267.580234	 267.580234	 0.0	 0.0	 1	 -30.0	 30.0;
	13	 1926	 0.227149	 1.244607	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	13	 1852	 0.024581	 0.402459	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 13	 0.04388	 0.657934	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6329	 13	 0.12525	 0.756384	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2889	 13	 0.18987	 0.937128	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	13	 7961	 0.00163	 0.007031	 0.02291	 232.306326	 232.306326	 232.306326	 0.0	 0.0	 1	 -30.0	 30.0;
	1926	 1852	 0.456736	 1.546157	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 1926	 0.03062	 0.528388	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6329	 1926	 0.192099	 0.773678	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2889	 1926	 0.027081	 0.45345	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2889	 1926	 0.002211	 0.01299	 0.03229	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 5584	 0.00344	 0.015909	 0.02714	 231.070196	 231.070196	 231.070196	 0.0	 0.0	 1	 -30.0	 30.0;
	1138	 5018	 0.123539	 0.685277	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1138	 4352	 0.096593	 0.575748	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1138	 5470	 0.225512	 1.104709	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1138	 3910	 0.17135	 1.111427	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1138	 5018	 0.00117	 0.00907	 0.39123	 1819.680835	 1819.680835	 1819.680835	 0.0	 0.0	 1	 -30.0	 30.0;
	3378	 1614	 3e-05	 0.00039	 0.01156	 1795.739563	 1795.739563	 1795.739563	 0.0	 0.0	 1	 -30.0	 30.0;
	565	 3378	 0.00079	 0.0065	 0.26159	 1765.659452	 1765.659452	 1765.659452	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 3378	 0.00091	 0.00755	 0.30391	 2123.019223	 2123.019223	 2123.019223	 0.0	 0.0	 1	 -30.0	 30.0;
	565	 3378	 0.00081	 0.00636	 0.26652	 1875.407561	 1875.407561	 1875.407561	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 3378	 0.00086	 0.00818	 0.28587	 1872.918327	 1872.918327	 1872.918327	 0.0	 0.0	 1	 -30.0	 30.0;
	2214	 4684	 0.003979	 0.02364	 0.05889	 600.473783	 600.473783	 600.473783	 0.0	 0.0	 1	 -30.0	 30.0;
	4684	 7372	 6.941322	 16.0093	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4684	 7362	 6.73657	 15.66095	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7659	 4684	 0.185229	 2.220661	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1982	 1667	 5.786496	 13.8054	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1982	 3260	 0.04375	 0.648878	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1982	 549	 0.0008	 0.00847	 0.26865	 1736.620581	 1736.620581	 1736.620581	 0.0	 0.0	 1	 -30.0	 30.0;
	1982	 6227	 0.19205	 1.80741	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1982	 6227	 0.00157	 0.01084	 0.63402	 2034.447376	 2034.447376	 2034.447376	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 1982	 0.00155	 0.01203	 0.51873	 2227.693427	 2227.693427	 2227.693427	 0.0	 0.0	 1	 -30.0	 30.0;
	1982	 3747	 0.00062	 0.00656	 0.20806	 1788.847767	 1788.847767	 1788.847767	 0.0	 0.0	 1	 -30.0	 30.0;
	1982	 1667	 0.00203	 0.0219	 0.60893	 2233.58479	 2233.58479	 2233.58479	 0.0	 0.0	 1	 -30.0	 30.0;
	1982	 7121	 0.00017	 0.00135	 0.05208	 1900.16695	 1900.16695	 1900.16695	 0.0	 0.0	 1	 -30.0	 30.0;
	4437	 7685	 0.000341	 0.001729	 0.01133	 434.513039	 434.513039	 434.513039	 0.0	 0.0	 1	 -30.0	 30.0;
	3160	 4437	 0.00101	 0.00926	 0.03427	 568.650293	 568.650293	 568.650293	 0.0	 0.0	 1	 -30.0	 30.0;
	2190	 4437	 0.00055	 0.00262	 0.00926	 240.127021	 240.127021	 240.127021	 0.0	 0.0	 1	 -30.0	 30.0;
	1820	 7685	 0.018781	 0.265517	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 1820	 0.0298	 0.392211	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1820	 2171	 0.00057	 0.002841	 0.00933	 537.231862	 537.231862	 537.231862	 0.0	 0.0	 1	 -30.0	 30.0;
	2190	 1820	 0.00943	 0.27814	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 7685	 0.027961	 0.338967	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7685	 3221	 0.000581	 0.002781	 0.00951	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2190	 7685	 0.010831	 0.239876	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 5122	 0.00261	 0.01243	 0.0358	 387.818266	 387.818266	 387.818266	 0.0	 0.0	 1	 -30.0	 30.0;
	2416	 3775	 0.00214	 0.01187	 0.03186	 541.776659	 541.776659	 541.776659	 0.0	 0.0	 1	 -30.0	 30.0;
	488	 3775	 0.04931	 0.648058	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	488	 3775	 0.001711	 0.010781	 0.03681	 581.665096	 581.665096	 581.665096	 0.0	 0.0	 1	 -30.0	 30.0;
	3775	 4030	 0.00068	 0.003271	 0.01067	 255.798512	 255.798512	 255.798512	 0.0	 0.0	 1	 -30.0	 30.0;
	619	 3775	 0.07599	 0.788884	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3508	 3775	 0.05989	 0.967314	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6567	 3775	 0.00036	 0.002719	 0.01126	 241.357435	 241.357435	 241.357435	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 1018	 0.00022	 0.00201	 0.07516	 1715.344935	 1715.344935	 1715.344935	 0.0	 0.0	 1	 -30.0	 30.0;
	5223	 750	 0.04617	 0.493712	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 6706	 0.00031	 0.00302	 0.0995	 1832.500852	 1832.500852	 1832.500852	 0.0	 0.0	 1	 -30.0	 30.0;
	6265	 5223	 0.001	 0.254681	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6265	 2205	 0.00034	 0.00288	 0.11445	 1800.897056	 1800.897056	 1800.897056	 0.0	 0.0	 1	 -30.0	 30.0;
	4604	 8295	 8e-05	 0.00085	 0.02483	 1291.821031	 1291.821031	 1291.821031	 0.0	 0.0	 1	 -30.0	 30.0;
	4604	 8295	 8e-05	 0.00087	 0.02431	 1317.763827	 1317.763827	 1317.763827	 0.0	 0.0	 1	 -30.0	 30.0;
	4604	 8295	 7e-05	 0.00089	 0.02379	 1324.737236	 1324.737236	 1324.737236	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 5584	 0.808079	 2.998967	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	269	 5584	 0.11606	 0.766157	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 5584	 0.044669	 0.42969	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 5584	 0.0045	 0.023841	 0.04053	 438.327361	 438.327361	 438.327361	 0.0	 0.0	 1	 -30.0	 30.0;
	3687	 375	 0.009969	 0.07739	 0.22162	 256.654353	 256.654353	 256.654353	 0.0	 0.0	 1	 -30.0	 30.0;
	1374	 3687	 0.01431	 0.10638	 0.13415	 390.982133	 390.982133	 390.982133	 0.0	 0.0	 1	 -30.0	 30.0;
	3687	 4643	 0.00774	 0.06957	 0.11908	 496.624	 496.624	 496.624	 0.0	 0.0	 1	 -30.0	 30.0;
	114	 375	 0.016669	 0.26188	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7981	 375	 0.009969	 0.061409	 0.1339	 599.201072	 599.201072	 599.201072	 0.0	 0.0	 1	 -30.0	 30.0;
	114	 375	 0.001729	 0.00995	 0.02672	 409.078254	 409.078254	 409.078254	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 5506	 0.0015	 0.01398	 0.30616	 1258.071571	 1258.071571	 1258.071571	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 7014	 0.00243	 0.01942	 0.75784	 1435.447603	 1435.447603	 1435.447603	 0.0	 0.0	 1	 -30.0	 30.0;
	7708	 745	 0.00455	 0.02705	 0.06801	 503.845301	 503.845301	 503.845301	 0.0	 0.0	 1	 -30.0	 30.0;
	4837	 7708	 0.004331	 0.01676	 0.06138	 606.195647	 606.195647	 606.195647	 0.0	 0.0	 1	 -30.0	 30.0;
	7708	 1780	 0.24907	 0.891963	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7708	 745	 0.033831	 0.228099	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	269	 3291	 0.344318	 0.959132	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 3886	 0.087211	 0.561364	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 1363	 0.003909	 0.019531	 0.06125	 216.567007	 216.567007	 216.567007	 0.0	 0.0	 1	 -30.0	 30.0;
	5974	 723	 0.01509	 0.413102	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5974	 1786	 9e-05	 0.001	 0.03216	 2075.341372	 2075.341372	 2075.341372	 0.0	 0.0	 1	 -30.0	 30.0;
	5974	 5918	 0.00094	 0.00943	 0.03022	 1741.443061	 1741.443061	 1741.443061	 0.0	 0.0	 1	 -30.0	 30.0;
	5974	 4096	 0.03361	 0.58162	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3768	 2058	 0.0001	 0.00107	 0.13718	 1602.09992	 1602.09992	 1602.09992	 0.0	 0.0	 1	 -30.0	 30.0;
	3768	 788	 0.00084	 0.00882	 0.28008	 1609.915799	 1609.915799	 1609.915799	 0.0	 0.0	 1	 -30.0	 30.0;
	2214	 269	 0.00501	 0.021599	 0.04073	 582.486643	 582.486643	 582.486643	 0.0	 0.0	 1	 -30.0	 30.0;
	269	 3886	 0.04149	 0.219607	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	269	 1621	 0.000781	 0.00744	 0.02392	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	5405	 7311	 0.011789	 0.277645	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5405	 7311	 0.0052	 0.02574	 0.07842	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7311	 5988	 0.031669	 0.507603	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7311	 5988	 0.00438	 0.025461	 0.06618	 317.340564	 317.340564	 317.340564	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 7311	 0.27186	 0.993388	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	69	 723	 0.0037	 0.327618	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	723	 4096	 0.01026	 0.269931	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2871	 536	 0.000281	 0.0023	 0.00532	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6905	 6648	 0.000539	 0.005021	 0.01143	 279.068165	 279.068165	 279.068165	 0.0	 0.0	 1	 -30.0	 30.0;
	6905	 4359	 0.251054	 1.054483	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7964	 6905	 0.00539	 0.022409	 0.0366	 382.198523	 382.198523	 382.198523	 0.0	 0.0	 1	 -30.0	 30.0;
	1780	 771	 0.18813	 0.545888	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1780	 1304	 0.02382	 0.200979	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1780	 1304	 0.00375	 0.019289	 0.06158	 494.312162	 494.312162	 494.312162	 0.0	 0.0	 1	 -30.0	 30.0;
	1780	 2370	 0.003151	 0.01874	 0.05036	 323.754798	 323.754798	 323.754798	 0.0	 0.0	 1	 -30.0	 30.0;
	1780	 745	 0.02419	 0.20719	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4324	 5405	 0.005479	 0.022531	 0.08146	 571.222389	 571.222389	 571.222389	 0.0	 0.0	 1	 -30.0	 30.0;
	4324	 5600	 0.008581	 0.133581	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5269	 3508	 0.000849	 0.00436	 0.0121	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 4701	 0.0004	 0.00418	 0.13271	 1871.523645	 1871.523645	 1871.523645	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 297	 0.00023	 0.00253	 0.0736	 1914.101264	 1914.101264	 1914.101264	 0.0	 0.0	 1	 -30.0	 30.0;
	4983	 2459	 0.000659	 0.006909	 0.02466	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 2186	 0.14356	 0.922161	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 4165	 0.05061	 0.949861	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2242	 7685	 0.001669	 0.19101	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3538	 2242	 0.008901	 0.19594	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3538	 7685	 0.008849	 0.207376	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	528	 2058	 0.04068	 0.314813	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	528	 788	 0.001	 0.358151	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	528	 788	 0.00029	 0.00339	 0.0914	 1487.854472	 1487.854472	 1487.854472	 0.0	 0.0	 1	 -30.0	 30.0;
	528	 5754	 0.001	 0.381247	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3324	 1205	 0.0	 0.00011	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3324	 1205	 0.001	 0.261032	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 2168	 5e-05	 0.000409	 0.00116	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6567	 3557	 0.00036	 0.00411	 0.01252	 559.074477	 559.074477	 559.074477	 0.0	 0.0	 1	 -30.0	 30.0;
	4115	 1557	 0.0	 0.000103	 0.0	 235.092954	 235.092954	 235.092954	 0.0	 0.0	 1	 -30.0	 30.0;
	4115	 1557	 0.06963	 0.647459	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	488	 4115	 0.00138	 0.00794	 0.02018	 564.787197	 564.787197	 564.787197	 0.0	 0.0	 1	 -30.0	 30.0;
	619	 4115	 0.04905	 0.618285	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6673	 4115	 0.01481	 0.65845	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4146	 4115	 0.057229	 0.834525	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	73	 1557	 0.00276	 0.034271	 0.09028	 277.382394	 277.382394	 277.382394	 0.0	 0.0	 1	 -30.0	 30.0;
	619	 1557	 0.045901	 0.629938	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6673	 1557	 0.05236	 0.804298	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4146	 1557	 0.010979	 0.705971	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3324	 2058	 0.00111	 0.00985	 0.37649	 1962.488632	 1962.488632	 1962.488632	 0.0	 0.0	 1	 -30.0	 30.0;
	3260	 1667	 12.66967	 25.61427	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 6227	 0.7509	 2.64626	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7372	 7362	 0.001	 0.522603	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7372	 7362	 0.0	 0.000103	 0.0	 338.792983	 338.792983	 338.792983	 0.0	 0.0	 1	 -30.0	 30.0;
	7659	 7372	 1.015517	 3.518182	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3508	 7372	 0.00274	 0.01674	 0.05173	 612.997411	 612.997411	 612.997411	 0.0	 0.0	 1	 -30.0	 30.0;
	8157	 7372	 0.001031	 0.006669	 0.02988	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7659	 7362	 0.827397	 3.941942	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3307	 1667	 0.00018	 0.00147	 0.04956	 2021.697784	 2021.697784	 2021.697784	 0.0	 0.0	 1	 -30.0	 30.0;
	4829	 1667	 0.00025	 0.00253	 0.07717	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3449	 1667	 0.00045	 0.00372	 0.13673	 1644.713739	 1644.713739	 1644.713739	 0.0	 0.0	 1	 -30.0	 30.0;
	7145	 1667	 0.00019	 0.00142	 0.06148	 1764.719572	 1764.719572	 1764.719572	 0.0	 0.0	 1	 -30.0	 30.0;
	5533	 1667	 0.00017	 0.00161	 0.05477	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4204	 1621	 0.00031	 0.00387	 0.03188	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 6708	 0.00057	 0.00261	 0.00953	 369.204297	 369.204297	 369.204297	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 1739	 0.000591	 0.002591	 0.00987	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2416	 619	 0.001599	 0.00775	 0.02278	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	488	 619	 0.014031	 0.614215	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	488	 3508	 0.012341	 0.556384	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	488	 3508	 0.001599	 0.00738	 0.02419	 378.389154	 378.389154	 378.389154	 0.0	 0.0	 1	 -30.0	 30.0;
	8244	 1614	 0.077687	 1.036288	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8244	 565	 0.00057	 0.00542	 0.19206	 2046.788238	 2046.788238	 2046.788238	 0.0	 0.0	 1	 -30.0	 30.0;
	8244	 565	 0.001	 0.513781	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8244	 1351	 0.01036	 0.396828	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8244	 1351	 0.00067	 0.00594	 0.22858	 1978.863475	 1978.863475	 1978.863475	 0.0	 0.0	 1	 -30.0	 30.0;
	8244	 4290	 0.897853	 2.161981	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1351	 3894	 0.0015	 0.01442	 0.50193	 1538.7653	 1538.7653	 1538.7653	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 3894	 0.00139	 0.01387	 0.42737	 1870.994468	 1870.994468	 1870.994468	 0.0	 0.0	 1	 -30.0	 30.0;
	565	 1614	 0.001	 0.795637	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1351	 1614	 0.230298	 1.27597	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 1614	 0.05565	 0.673331	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8305	 14	 0.00019	 0.00214	 0.06427	 1767.601081	 1767.601081	 1767.601081	 0.0	 0.0	 1	 -30.0	 30.0;
	8305	 14	 0.00019	 0.00198	 0.06287	 1766.940927	 1766.940927	 1766.940927	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 4352	 0.07358	 0.966343	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 5018	 0.06384	 1.43054	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3910	 5018	 0.076281	 1.166136	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 4352	 0.210457	 1.788158	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3910	 4352	 0.185533	 1.718213	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 4352	 2e-05	 0.00024	 0.00745	 1578.668078	 1578.668078	 1578.668078	 0.0	 0.0	 1	 -30.0	 30.0;
	297	 4653	 0.01408	 0.37133	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7058	 4653	 0.01647	 0.363712	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7058	 4653	 0.00068	 0.00621	 0.21206	 1823.333072	 1823.333072	 1823.333072	 0.0	 0.0	 1	 -30.0	 30.0;
	4653	 788	 0.00079	 0.00807	 0.24891	 1841.233575	 1841.233575	 1841.233575	 0.0	 0.0	 1	 -30.0	 30.0;
	2205	 5223	 0.00052	 0.00514	 0.17427	 1875.586585	 1875.586585	 1875.586585	 0.0	 0.0	 1	 -30.0	 30.0;
	788	 2058	 0.111198	 0.57367	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5754	 2058	 0.126101	 0.495623	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 1363	 0.0032	 0.016281	 0.03007	 489.52273	 489.52273	 489.52273	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 1363	 0.003659	 0.01407	 0.03445	 528.686027	 528.686027	 528.686027	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 1621	 0.002281	 0.010039	 0.03839	 246.920782	 246.920782	 246.920782	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 1621	 0.001919	 0.011669	 0.03237	 232.747202	 232.747202	 232.747202	 0.0	 0.0	 1	 -30.0	 30.0;
	6648	 4359	 0.00236	 0.02263	 0.06913	 282.083423	 282.083423	 282.083423	 0.0	 0.0	 1	 -30.0	 30.0;
	2871	 6648	 0.009849	 0.054531	 0.14748	 305.736031	 305.736031	 305.736031	 0.0	 0.0	 1	 -30.0	 30.0;
	1304	 771	 0.02949	 0.13405	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1304	 771	 0.005021	 0.030341	 0.08218	 271.263093	 271.263093	 271.263093	 0.0	 0.0	 1	 -30.0	 30.0;
	3260	 7121	 0.00076	 0.00675	 0.25223	 2030.174476	 2030.174476	 2030.174476	 0.0	 0.0	 1	 -30.0	 30.0;
	3260	 6227	 0.568047	 3.572576	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	575	 4030	 0.003419	 0.014531	 0.05386	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1852	 575	 0.002979	 0.016461	 0.0453	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 2965	 0.09382	 0.44438	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6945	 2965	 0.003789	 0.02306	 0.04756	 390.05656	 390.05656	 390.05656	 0.0	 0.0	 1	 -30.0	 30.0;
	2472	 3449	 0.00014	 0.00108	 0.04496	 1839.48216	 1839.48216	 1839.48216	 0.0	 0.0	 1	 -30.0	 30.0;
	2472	 8305	 0.00015	 0.00119	 0.04852	 1837.300295	 1837.300295	 1837.300295	 0.0	 0.0	 1	 -30.0	 30.0;
	1786	 8305	 0.00031	 0.00232	 0.09283	 2020.114205	 2020.114205	 2020.114205	 0.0	 0.0	 1	 -30.0	 30.0;
	1640	 1786	 0.00025	 0.00193	 0.08514	 1430.418455	 1430.418455	 1430.418455	 0.0	 0.0	 1	 -30.0	 30.0;
	8305	 7207	 0.137791	 1.05367	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8305	 6706	 0.00054	 0.00395	 0.16687	 1905.885212	 1905.885212	 1905.885212	 0.0	 0.0	 1	 -30.0	 30.0;
	5020	 2459	 0.00113	 0.012581	 0.04248	 310.196616	 310.196616	 310.196616	 0.0	 0.0	 1	 -30.0	 30.0;
	5020	 2871	 0.00238	 0.02086	 0.08955	 275.430269	 275.430269	 275.430269	 0.0	 0.0	 1	 -30.0	 30.0;
	5020	 6329	 0.127331	 1.369545	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5020	 2025	 0.699669	 2.452893	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8194	 5988	 0.00331	 0.025159	 0.11776	 535.549521	 535.549521	 535.549521	 0.0	 0.0	 1	 -30.0	 30.0;
	565	 1351	 0.01975	 0.825554	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 565	 0.507639	 2.270152	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5405	 5988	 0.20336	 0.874897	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5405	 5600	 0.00732	 0.030659	 0.11167	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 5405	 0.075401	 0.292748	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 5405	 0.00314	 0.02136	 0.09397	 248.153864	 248.153864	 248.153864	 0.0	 0.0	 1	 -30.0	 30.0;
	8311	 6327	 0.00044	 0.00325	 0.13816	 1895.018671	 1895.018671	 1895.018671	 0.0	 0.0	 1	 -30.0	 30.0;
	47	 2190	 0.00076	 0.00364	 0.01273	 267.807721	 267.807721	 267.807721	 0.0	 0.0	 1	 -30.0	 30.0;
	47	 5412	 0.00075	 0.00474	 0.01175	 243.186099	 243.186099	 243.186099	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 3160	 3.557851	 5.439876	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 4757	 4.011157	 6.327273	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 7889	 0.006	 0.327025	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3439	 5747	 3.78905	 6.419628	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 5747	 3.833471	 5.760331	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3538	 5747	 0.000841	 0.00362	 0.01002	 379.733122	 379.733122	 379.733122	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 1828	 0.03	 0.279855	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 1828	 0.00107	 0.004849	 0.01757	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 6915	 3.092975	 5.176033	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 6915	 0.02688	 0.291116	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 6915	 0.00188	 0.0132	 0.04087	 563.160489	 563.160489	 563.160489	 0.0	 0.0	 1	 -30.0	 30.0;
	5932	 1304	 0.001469	 0.00724	 0.02184	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5932	 1304	 0.0015	 0.007081	 0.02224	 270.418303	 270.418303	 270.418303	 0.0	 0.0	 1	 -30.0	 30.0;
	7288	 4928	 0.0017	 0.00806	 0.02325	 606.342352	 606.342352	 606.342352	 0.0	 0.0	 1	 -30.0	 30.0;
	1852	 2362	 0.00369	 0.016091	 0.05386	 534.873155	 534.873155	 534.873155	 0.0	 0.0	 1	 -30.0	 30.0;
	7721	 6426	 0.00301	 0.0177	 0.047	 605.308179	 605.308179	 605.308179	 0.0	 0.0	 1	 -30.0	 30.0;
	5593	 4327	 5e-05	 0.00053	 0.01592	 1434.702544	 1434.702544	 1434.702544	 0.0	 0.0	 1	 -30.0	 30.0;
	4701	 3573	 6e-05	 0.0005	 0.01713	 1501.912524	 1501.912524	 1501.912524	 0.0	 0.0	 1	 -30.0	 30.0;
	4701	 5219	 4e-05	 0.00047	 0.01454	 2204.941485	 2204.941485	 2204.941485	 0.0	 0.0	 1	 -30.0	 30.0;
	7889	 147	 0.00174	 0.016521	 0.06438	 413.115491	 413.115491	 413.115491	 0.0	 0.0	 1	 -30.0	 30.0;
	1436	 5044	 0.00019	 0.00196	 0.0649	 1831.938108	 1831.938108	 1831.938108	 0.0	 0.0	 1	 -30.0	 30.0;
	2205	 5821	 0.00074	 0.00584	 0.24125	 2053.2509	 2053.2509	 2053.2509	 0.0	 0.0	 1	 -30.0	 30.0;
	1436	 1570	 0.00019	 0.00183	 0.06224	 2262.578247	 2262.578247	 2262.578247	 0.0	 0.0	 1	 -30.0	 30.0;
	5593	 2352	 0.00018	 0.00186	 0.06097	 2196.733989	 2196.733989	 2196.733989	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 3910	 0.0	 0.00011	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 3910	 0.001	 0.413968	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 5018	 0.00215	 0.02177	 0.66355	 1523.336919	 1523.336919	 1523.336919	 0.0	 0.0	 1	 -30.0	 30.0;
	6345	 745	 0.008659	 0.0422	 0.05975	 389.347805	 389.347805	 389.347805	 0.0	 0.0	 1	 -30.0	 30.0;
	69	 6331	 0.00029	 0.00252	 0.09063	 1434.351734	 1434.351734	 1434.351734	 0.0	 0.0	 1	 -30.0	 30.0;
	69	 4096	 0.0343	 0.612763	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2366	 7754	 0.00036	 0.00195	 0.00558	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2366	 7754	 0.000409	 0.00213	 0.00543	 282.046461	 282.046461	 282.046461	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 2525	 0.00118	 0.008719	 0.01341	 477.77416	 477.77416	 477.77416	 0.0	 0.0	 1	 -30.0	 30.0;
	3439	 4495	 0.0053	 0.023409	 0.08261	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 4495	 0.005401	 0.022909	 0.08416	 612.986741	 612.986741	 612.986741	 0.0	 0.0	 1	 -30.0	 30.0;
	5412	 4495	 0.000901	 0.00412	 0.01477	 615.381267	 615.381267	 615.381267	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 2190	 0.05139	 0.435785	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3160	 4757	 0.01661	 0.339194	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3160	 7889	 2.441736	 4.517975	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3439	 3160	 0.03336	 0.374174	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 3160	 0.033219	 0.37814	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3160	 4092	 0.003151	 0.017599	 0.05201	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6915	 3160	 0.02231	 0.393079	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7947	 3307	 0.0005	 0.00519	 0.16674	 2058.238583	 2058.238583	 2058.238583	 0.0	 0.0	 1	 -30.0	 30.0;
	7947	 7784	 0.00024	 0.00227	 0.07779	 1790.732793	 1790.732793	 1790.732793	 0.0	 0.0	 1	 -30.0	 30.0;
	7947	 6331	 0.00049	 0.00529	 0.16319	 1455.286444	 1455.286444	 1455.286444	 0.0	 0.0	 1	 -30.0	 30.0;
	7947	 4906	 0.00036	 0.00305	 0.11465	 1455.232473	 1455.232473	 1455.232473	 0.0	 0.0	 1	 -30.0	 30.0;
	3513	 5149	 0.00264	 0.014781	 0.04058	 274.400288	 274.400288	 274.400288	 0.0	 0.0	 1	 -30.0	 30.0;
	6262	 5149	 0.002539	 0.01357	 0.03928	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2025	 5149	 0.0053	 0.021599	 0.07962	 553.361377	 553.361377	 553.361377	 0.0	 0.0	 1	 -30.0	 30.0;
	6032	 5149	 0.003091	 0.01568	 0.04932	 262.244755	 262.244755	 262.244755	 0.0	 0.0	 1	 -30.0	 30.0;
	8356	 5149	 0.00274	 0.0127	 0.04242	 233.005555	 233.005555	 233.005555	 0.0	 0.0	 1	 -30.0	 30.0;
	2025	 5149	 0.04224	 0.3325	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 4982	 0.00086	 0.00873	 0.26836	 1789.559917	 1789.559917	 1789.559917	 0.0	 0.0	 1	 -30.0	 30.0;
	8311	 4982	 0.00206	 0.01561	 0.63618	 1689.125046	 1689.125046	 1689.125046	 0.0	 0.0	 1	 -30.0	 30.0;
	3335	 8295	 0.00032	 0.00271	 0.10771	 1536.722311	 1536.722311	 1536.722311	 0.0	 0.0	 1	 -30.0	 30.0;
	7058	 3335	 0.00051	 0.00524	 0.17072	 1774.106525	 1774.106525	 1774.106525	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 7009	 0.00032	 0.00265	 0.10974	 1838.078921	 1838.078921	 1838.078921	 0.0	 0.0	 1	 -30.0	 30.0;
	297	 228	 0.0005	 0.00534	 0.16716	 1672.196016	 1672.196016	 1672.196016	 0.0	 0.0	 1	 -30.0	 30.0;
	7009	 8295	 0.0	 0.00011	 0.0	 1583.855848	 1583.855848	 1583.855848	 0.0	 0.0	 1	 -30.0	 30.0;
	7009	 8295	 0.163629	 1.021814	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	616	 7009	 0.001	 0.350312	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7000	 7009	 0.0571	 0.699515	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3417	 7009	 0.00022	 0.00214	 0.06822	 1416.287345	 1416.287345	 1416.287345	 0.0	 0.0	 1	 -30.0	 30.0;
	4892	 7009	 0.05584	 0.597071	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4165	 8295	 0.00044	 0.00329	 0.13718	 1962.394512	 1962.394512	 1962.394512	 0.0	 0.0	 1	 -30.0	 30.0;
	616	 8295	 0.0684	 0.765166	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	616	 8295	 0.0005	 0.00377	 0.16816	 1745.101222	 1745.101222	 1745.101222	 0.0	 0.0	 1	 -30.0	 30.0;
	7000	 8295	 0.02916	 0.635783	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4939	 8295	 0.00021	 0.00218	 0.06677	 1773.732021	 1773.732021	 1773.732021	 0.0	 0.0	 1	 -30.0	 30.0;
	4892	 8295	 0.076648	 0.893421	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6196	 7130	 0.003581	 0.01713	 0.06044	 261.258214	 261.258214	 261.258214	 0.0	 0.0	 1	 -30.0	 30.0;
	349	 108	 0.003651	 0.01676	 0.06158	 322.18944	 322.18944	 322.18944	 0.0	 0.0	 1	 -30.0	 30.0;
	5918	 5416	 0.0	 0.0001	 0.0	 894.36366	 894.36366	 894.36366	 0.0	 0.0	 1	 -30.0	 30.0;
	5918	 5416	 0.001	 0.363179	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5918	 2205	 0.03201	 0.610942	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5416	 2205	 0.03493	 0.703809	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5416	 2875	 0.00038	 0.00378	 0.12455	 1724.909597	 1724.909597	 1724.909597	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 5988	 0.662562	 1.966736	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 5988	 0.007461	 0.03539	 0.11275	 555.232719	 555.232719	 555.232719	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 1351	 1.057548	 2.384834	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1852	 7130	 0.00313	 0.015591	 0.0514	 304.446554	 304.446554	 304.446554	 0.0	 0.0	 1	 -30.0	 30.0;
	1852	 108	 0.00325	 0.01495	 0.05337	 347.021783	 347.021783	 347.021783	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 1852	 0.174211	 0.885269	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6329	 1852	 0.05432	 0.507293	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2889	 1852	 0.315744	 1.143306	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6945	 7721	 0.106531	 0.728988	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4701	 2205	 0.00046	 0.00355	 0.1514	 1913.436503	 1913.436503	 1913.436503	 0.0	 0.0	 1	 -30.0	 30.0;
	5593	 2205	 0.00046	 0.00356	 0.15188	 1505.735888	 1505.735888	 1505.735888	 0.0	 0.0	 1	 -30.0	 30.0;
	2525	 4757	 0.00056	 0.00351	 0.00895	 468.275316	 468.275316	 468.275316	 0.0	 0.0	 1	 -30.0	 30.0;
	6915	 2525	 0.001271	 0.00699	 0.01306	 489.220175	 489.220175	 489.220175	 0.0	 0.0	 1	 -30.0	 30.0;
	4757	 7889	 2.229752	 5.528926	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3439	 4757	 0.186169	 1.134959	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 4757	 0.191419	 0.99374	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6915	 4757	 0.001	 0.342025	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8368	 5522	 8e-05	 0.00071	 0.02592	 1872.331231	 1872.331231	 1872.331231	 0.0	 0.0	 1	 -30.0	 30.0;
	1436	 5522	 0.00047	 0.00487	 0.15853	 1314.634184	 1314.634184	 1314.634184	 0.0	 0.0	 1	 -30.0	 30.0;
	3439	 7889	 2.630992	 4.595455	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 7889	 2.602893	 4.194835	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3538	 7889	 0.002849	 0.0122	 0.0368	 412.659754	 412.659754	 412.659754	 0.0	 0.0	 1	 -30.0	 30.0;
	6915	 7889	 1.630455	 4.689463	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2875	 5522	 0.136641	 1.051662	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 5522	 0.00035	 0.00282	 0.11661	 1541.724474	 1541.724474	 1541.724474	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 8311	 0.00092	 0.0092	 0.2838	 1835.683807	 1835.683807	 1835.683807	 0.0	 0.0	 1	 -30.0	 30.0;
	2186	 4165	 0.0	 0.0001	 0.0	 1025.969245	 1025.969245	 1025.969245	 0.0	 0.0	 1	 -30.0	 30.0;
	2186	 4165	 0.02074	 0.459238	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2186	 1436	 0.00025	 0.00224	 0.08553	 1886.110873	 1886.110873	 1886.110873	 0.0	 0.0	 1	 -30.0	 30.0;
	6945	 7754	 0.000651	 0.0037	 0.00982	 246.66624	 246.66624	 246.66624	 0.0	 0.0	 1	 -30.0	 30.0;
	3439	 4782	 0.001	 0.238182	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3439	 6915	 0.168469	 0.943719	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 6915	 0.1577	 0.919711	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5854	 4359	 0.0033	 0.023531	 0.06839	 316.83872	 316.83872	 316.83872	 0.0	 0.0	 1	 -30.0	 30.0;
	8371	 4359	 0.00336	 0.023031	 0.06968	 561.400033	 561.400033	 561.400033	 0.0	 0.0	 1	 -30.0	 30.0;
	7981	 4359	 0.050961	 0.353843	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1511	 4359	 0.07906	 0.386591	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1511	 4359	 0.00224	 0.02005	 0.06754	 338.456896	 338.456896	 338.456896	 0.0	 0.0	 1	 -30.0	 30.0;
	7964	 4359	 0.001979	 0.018841	 0.072	 286.876665	 286.876665	 286.876665	 0.0	 0.0	 1	 -30.0	 30.0;
	3016	 20	 0.0003	 0.002669	 0.01028	 537.965766	 537.965766	 537.965766	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 1640	 0.00017	 0.00166	 0.05075	 1429.847155	 1429.847155	 1429.847155	 0.0	 0.0	 1	 -30.0	 30.0;
	7145	 4096	 0.00057	 0.00619	 0.18422	 1764.719572	 1764.719572	 1764.719572	 0.0	 0.0	 1	 -30.0	 30.0;
	5533	 7903	 8e-05	 0.00082	 0.02265	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	619	 3508	 0.001	 0.452087	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	619	 6673	 0.028289	 0.776901	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	619	 4146	 0.027469	 0.75064	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3508	 2015	 0.001409	 0.00714	 0.01369	 485.093391	 485.093391	 485.093391	 0.0	 0.0	 1	 -30.0	 30.0;
	4837	 6032	 0.00776	 0.04488	 0.12714	 264.957077	 264.957077	 264.957077	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 2253	 0.00028	 0.0023	 0.09163	 1479.700289	 1479.700289	 1479.700289	 0.0	 0.0	 1	 -30.0	 30.0;
	2933	 609	 0.00015	 0.00155	 0.04675	 1605.167694	 1605.167694	 1605.167694	 0.0	 0.0	 1	 -30.0	 30.0;
	4146	 475	 0.000229	 0.00113	 0.00304	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6673	 3049	 0.00024	 0.001099	 0.0031	 530.440006	 530.440006	 530.440006	 0.0	 0.0	 1	 -30.0	 30.0;
	5854	 7981	 0.000651	 0.005031	 0.01147	 226.683916	 226.683916	 226.683916	 0.0	 0.0	 1	 -30.0	 30.0;
	8371	 7981	 0.000581	 0.0057	 0.01024	 568.625525	 568.625525	 568.625525	 0.0	 0.0	 1	 -30.0	 30.0;
	1511	 7981	 0.395351	 1.062603	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7058	 1436	 0.00073	 0.00574	 0.22316	 1960.493691	 1960.493691	 1960.493691	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 5593	 0.00074	 0.00562	 0.22745	 2126.93539	 2126.93539	 2126.93539	 0.0	 0.0	 1	 -30.0	 30.0;
	723	 4096	 0.00021	 0.00217	 0.06651	 1588.306456	 1588.306456	 1588.306456	 0.0	 0.0	 1	 -30.0	 30.0;
	7836	 5068	 0.001	 0.253636	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7076	 2933	 0.00078	 0.00691	 0.2642	 1646.611928	 1646.611928	 1646.611928	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 5754	 0.00135	 0.01007	 0.42526	 2035.035788	 2035.035788	 2035.035788	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 6329	 0.048271	 0.517335	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 6329	 0.001901	 0.01187	 0.027	 295.61455	 295.61455	 295.61455	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 2889	 0.02499	 0.413099	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 2889	 0.00186	 0.01099	 0.02641	 543.571791	 543.571791	 543.571791	 0.0	 0.0	 1	 -30.0	 30.0;
	297	 7058	 0.00351	 0.296032	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2171	 8255	 0.000169	 0.000789	 0.00279	 352.870157	 352.870157	 352.870157	 0.0	 0.0	 1	 -30.0	 30.0;
	2190	 2171	 0.000211	 0.001031	 0.00355	 295.356959	 295.356959	 295.356959	 0.0	 0.0	 1	 -30.0	 30.0;
	3221	 6041	 0.00038	 0.001909	 0.00632	 224.91279	 224.91279	 224.91279	 0.0	 0.0	 1	 -30.0	 30.0;
	2190	 3221	 0.000219	 0.001	 0.00362	 231.369321	 231.369321	 231.369321	 0.0	 0.0	 1	 -30.0	 30.0;
	616	 7000	 0.0114	 0.491198	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	616	 4892	 0.0111	 0.44741	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6329	 2889	 0.065849	 0.525558	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6329	 7961	 0.00095	 0.0053	 0.01475	 527.720824	 527.720824	 527.720824	 0.0	 0.0	 1	 -30.0	 30.0;
	5412	 2190	 0.00139	 0.008281	 0.02203	 245.998638	 245.998638	 245.998638	 0.0	 0.0	 1	 -30.0	 30.0;
	6248	 6494	 0.001	 0.26688	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4837	 1856	 0.00036	 0.00286	 0.01313	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6915	 1828	 0.02231	 0.26281	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6915	 1828	 0.001669	 0.01064	 0.02196	 579.160828	 579.160828	 579.160828	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 7151	 3e-05	 0.00031	 0.00971	 2028.0762	 2028.0762	 2028.0762	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 390	 3e-05	 0.0003	 0.01101	 1960.514094	 1960.514094	 1960.514094	 0.0	 0.0	 1	 -30.0	 30.0;
	7207	 6706	 0.0004	 0.00637	 2.1986	 1663.396159	 1663.396159	 1663.396159	 0.0	 0.0	 1	 -30.0	 30.0;
	7076	 4906	 0.00018	 0.0019	 0.0597	 1727.150697	 1727.150697	 1727.150697	 0.0	 0.0	 1	 -30.0	 30.0;
	7076	 7784	 0.00032	 0.00267	 0.10002	 1729.708382	 1729.708382	 1729.708382	 0.0	 0.0	 1	 -30.0	 30.0;
	3417	 7000	 0.00023	 0.00202	 0.07866	 1644.267494	 1644.267494	 1644.267494	 0.0	 0.0	 1	 -30.0	 30.0;
	7000	 4892	 0.001	 0.382043	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7149	 8356	 0.00011	 0.00075	 0.0014	 543.535972	 543.535972	 543.535972	 0.0	 0.0	 1	 -30.0	 30.0;
	7993	 8356	 0.00013	 0.000531	 0.00208	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6673	 4146	 0.010909	 0.62314	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1363	 1621	 0.005969	 0.037081	 0.10316	 247.249248	 247.249248	 247.249248	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 8249	 0.0	 0.00011	 0.0	 1515.583566	 1515.583566	 1515.583566	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 8249	 0.001	 0.39696	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 7602	 0.192888	 1.242729	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8249	 1485	 0.00078	 0.00629	 0.26024	 1904.212778	 1904.212778	 1904.212778	 0.0	 0.0	 1	 -30.0	 30.0;
	8249	 7602	 0.215693	 1.63338	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1485	 7602	 0.00048	 0.00397	 0.15883	 2120.642538	 2120.642538	 2120.642538	 0.0	 0.0	 1	 -30.0	 30.0;
	3747	 7602	 0.00049	 0.00388	 0.16183	 2038.269423	 2038.269423	 2038.269423	 0.0	 0.0	 1	 -30.0	 30.0;
	6567	 7888	 0.000211	 0.00113	 0.00284	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4939	 4892	 3e-05	 0.00035	 0.01109	 1323.088497	 1323.088497	 1323.088497	 0.0	 0.0	 1	 -30.0	 30.0;
	2871	 2025	 0.007409	 0.042281	 0.13096	 268.151048	 268.151048	 268.151048	 0.0	 0.0	 1	 -30.0	 30.0;
	3388	 5932	 0.00012	 0.0007	 0.0	 274.895654	 274.895654	 274.895654	 0.0	 0.0	 1	 -30.0	 30.0;
	788	 5754	 0.0	 0.00011	 0.0	 879.526324	 879.526324	 879.526324	 0.0	 0.0	 1	 -30.0	 30.0;
	788	 5754	 0.001	 0.284017	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7965	 7484	 1.997645	 4.178116	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7965	 2829	 0.00015	 0.00152	 0.04716	 1353.704366	 1353.704366	 1353.704366	 0.0	 0.0	 1	 -30.0	 30.0;
	7965	 1172	 0.00014	 0.00141	 0.04613	 1327.271227	 1327.271227	 1327.271227	 0.0	 0.0	 1	 -30.0	 30.0;
	7965	 4303	 0.00103	 0.00914	 0.34598	 1661.761241	 1661.761241	 1661.761241	 0.0	 0.0	 1	 -30.0	 30.0;
	7965	 2661	 0.00105	 0.00896	 0.35277	 1540.358752	 1540.358752	 1540.358752	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 7965	 0.334702	 1.492936	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 7965	 0.00142	 0.01428	 0.47948	 1733.484357	 1733.484357	 1733.484357	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 7965	 0.340893	 1.460526	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 7965	 0.00139	 0.01455	 0.46949	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	355	 4236	 0.0004	 0.00376	 0.14492	 1977.004777	 1977.004777	 1977.004777	 0.0	 0.0	 1	 -30.0	 30.0;
	355	 4830	 0.00101	 0.01129	 0.37192	 1726.503049	 1726.503049	 1726.503049	 0.0	 0.0	 1	 -30.0	 30.0;
	355	 4159	 0.00076	 0.0089	 0.27101	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	355	 4236	 0.0004	 0.00368	 0.14771	 2102.34252	 2102.34252	 2102.34252	 0.0	 0.0	 1	 -30.0	 30.0;
	355	 2431	 0.00099	 0.01151	 0.36417	 1815.953566	 1815.953566	 1815.953566	 0.0	 0.0	 1	 -30.0	 30.0;
	355	 849	 0.00075	 0.00824	 0.26512	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	7199	 4243	 0.00156	 0.01568	 0.52998	 1775.972464	 1775.972464	 1775.972464	 0.0	 0.0	 1	 -30.0	 30.0;
	7199	 4243	 0.00152	 0.01599	 0.51894	 1741.763594	 1741.763594	 1741.763594	 0.0	 0.0	 1	 -30.0	 30.0;
	438	 6354	 0.00539	 0.01612	 0.06314	 600.763381	 600.763381	 600.763381	 0.0	 0.0	 1	 -30.0	 30.0;
	438	 6354	 0.0048	 0.018271	 0.05625	 583.994081	 583.994081	 583.994081	 0.0	 0.0	 1	 -30.0	 30.0;
	7422	 782	 0.008729	 0.034159	 0.10083	 437.515722	 437.515722	 437.515722	 0.0	 0.0	 1	 -30.0	 30.0;
	7422	 782	 0.00855	 0.03482	 0.09873	 423.284223	 423.284223	 423.284223	 0.0	 0.0	 1	 -30.0	 30.0;
	3785	 1738	 0.00146	 0.00651	 0.0	 1159.963363	 1159.963363	 1159.963363	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 1738	 0.134252	 0.771745	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 1738	 0.00072	 0.00587	 0.24108	 1823.277785	 1823.277785	 1823.277785	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 1738	 0.00071	 0.006	 0.23653	 1897.319008	 1897.319008	 1897.319008	 0.0	 0.0	 1	 -30.0	 30.0;
	5784	 1738	 0.00013	 0.00132	 0.04328	 1842.808598	 1842.808598	 1842.808598	 0.0	 0.0	 1	 -30.0	 30.0;
	3086	 1738	 0.322853	 1.362742	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2583	 8120	 0.161841	 1.112975	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2583	 8120	 0.00356	 0.022409	 0.08577	 600.594576	 600.594576	 600.594576	 0.0	 0.0	 1	 -30.0	 30.0;
	395	 8120	 0.211508	 1.021529	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	395	 8120	 0.00838	 0.038479	 0.12634	 226.665626	 226.665626	 226.665626	 0.0	 0.0	 1	 -30.0	 30.0;
	438	 8120	 0.912748	 1.922025	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 7431	 0.005211	 0.016901	 0.06075	 474.439581	 474.439581	 474.439581	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 7431	 0.219566	 0.646591	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 7431	 0.00531	 0.016539	 0.06189	 482.331151	 482.331151	 482.331151	 0.0	 0.0	 1	 -30.0	 30.0;
	4759	 6583	 0.140519	 0.391918	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 4759	 0.00131	 0.01484	 0.47656	 1834.750509	 1834.750509	 1834.750509	 0.0	 0.0	 1	 -30.0	 30.0;
	4759	 4159	 0.05123	 0.434093	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4759	 4159	 0.0006	 0.00673	 0.22193	 1886.84935	 1886.84935	 1886.84935	 0.0	 0.0	 1	 -30.0	 30.0;
	4759	 7585	 0.05191	 0.445222	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4724	 4759	 0.736704	 3.325	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4598	 4759	 2.622299	 8.981301	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6967	 5867	 0.0	 3.5e-05	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6967	 5867	 0.001	 0.291627	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 6967	 0.00016	 0.00138	 0.05229	 1420.755066	 1420.755066	 1420.755066	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 6967	 0.00017	 0.00135	 0.05331	 1450.286255	 1450.286255	 1450.286255	 0.0	 0.0	 1	 -30.0	 30.0;
	432	 5867	 0.00017	 0.00133	 0.05434	 1254.633242	 1254.633242	 1254.633242	 0.0	 0.0	 1	 -30.0	 30.0;
	7186	 5867	 0.00017	 0.0013	 0.05536	 1345.875981	 1345.875981	 1345.875981	 0.0	 0.0	 1	 -30.0	 30.0;
	7199	 2233	 0.00189	 0.01446	 0.59875	 1341.395096	 1341.395096	 1341.395096	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 892	 0.00074	 0.00698	 0.23645	 1405.029188	 1405.029188	 1405.029188	 0.0	 0.0	 1	 -30.0	 30.0;
	7199	 432	 0.00193	 0.01416	 0.61026	 1352.280066	 1352.280066	 1352.280066	 0.0	 0.0	 1	 -30.0	 30.0;
	7186	 3803	 0.00073	 0.00711	 0.23142	 1365.209998	 1365.209998	 1365.209998	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 7484	 0.136731	 0.910873	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 7484	 0.00128	 0.0134	 0.44392	 1876.396804	 1876.396804	 1876.396804	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 7484	 0.13394	 0.92874	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 1995	 0.271641	 0.707964	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 1995	 0.00037	 0.0037	 0.12426	 1665.678066	 1665.678066	 1665.678066	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 1995	 0.00038	 0.00363	 0.12685	 1882.253284	 1882.253284	 1882.253284	 0.0	 0.0	 1	 -30.0	 30.0;
	4724	 1995	 0.00156	 0.01473	 0.54676	 1841.527781	 1841.527781	 1841.527781	 0.0	 0.0	 1	 -30.0	 30.0;
	4598	 1995	 0.00159	 0.01442	 0.55727	 1690.218282	 1690.218282	 1690.218282	 0.0	 0.0	 1	 -30.0	 30.0;
	7525	 3842	 0.01049	 0.04336	 0.12284	 443.873942	 443.873942	 443.873942	 0.0	 0.0	 1	 -30.0	 30.0;
	1704	 3842	 0.010271	 0.04418	 0.12023	 457.509478	 457.509478	 457.509478	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 3842	 0.00881	 0.037021	 0.0865	 470.866845	 470.866845	 470.866845	 0.0	 0.0	 1	 -30.0	 30.0;
	2194	 3842	 0.004409	 0.01682	 0.05151	 483.884316	 483.884316	 483.884316	 0.0	 0.0	 1	 -30.0	 30.0;
	2194	 3842	 0.00432	 0.017151	 0.05046	 541.125443	 541.125443	 541.125443	 0.0	 0.0	 1	 -30.0	 30.0;
	6815	 3842	 0.01025	 0.042341	 0.11984	 563.279758	 563.279758	 563.279758	 0.0	 0.0	 1	 -30.0	 30.0;
	3422	 2481	 0.05386	 0.203789	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3422	 2481	 0.005	 0.017849	 0.04792	 366.690502	 366.690502	 366.690502	 0.0	 0.0	 1	 -30.0	 30.0;
	3422	 2481	 0.004909	 0.01824	 0.04704	 343.79428	 343.79428	 343.79428	 0.0	 0.0	 1	 -30.0	 30.0;
	2481	 2902	 0.442645	 0.98938	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2481	 2902	 0.00789	 0.025831	 0.09286	 527.989084	 527.989084	 527.989084	 0.0	 0.0	 1	 -30.0	 30.0;
	2481	 2902	 0.00774	 0.02638	 0.0911	 476.576135	 476.576135	 476.576135	 0.0	 0.0	 1	 -30.0	 30.0;
	5860	 462	 0.00141	 0.01209	 0.47667	 1774.508673	 1774.508673	 1774.508673	 0.0	 0.0	 1	 -30.0	 30.0;
	5860	 7627	 0.104079	 0.42973	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	892	 4236	 0.00139	 0.01016	 0.44742	 1374.321833	 1374.321833	 1374.321833	 0.0	 0.0	 1	 -30.0	 30.0;
	3803	 4236	 0.00142	 0.00994	 0.45571	 1415.509377	 1415.509377	 1415.509377	 0.0	 0.0	 1	 -30.0	 30.0;
	1993	 347	 9e-05	 0.00064	 0.01813	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1993	 4303	 0.195942	 0.820914	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1993	 2661	 0.199778	 0.804155	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 1993	 0.02836	 0.37876	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	347	 4303	 0.00109	 0.00814	 0.36229	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 347	 0.00054	 0.00424	 0.18131	 2110.645452	 2110.645452	 2110.645452	 0.0	 0.0	 1	 -30.0	 30.0;
	2846	 462	 0.00263	 0.02613	 0.95605	 1620.347283	 1620.347283	 1620.347283	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 6273	 0.00166	 0.01885	 0.60522	 1577.824951	 1577.824951	 1577.824951	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 3086	 0.847576	 2.035042	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1129	 462	 0.00094	 0.00794	 0.31303	 1651.201413	 1651.201413	 1651.201413	 0.0	 0.0	 1	 -30.0	 30.0;
	2583	 1277	 0.014081	 0.055831	 0.16451	 469.442857	 469.442857	 469.442857	 0.0	 0.0	 1	 -30.0	 30.0;
	2583	 395	 2.006198	 3.572314	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2583	 395	 0.0122	 0.05982	 0.21601	 242.566891	 242.566891	 242.566891	 0.0	 0.0	 1	 -30.0	 30.0;
	2583	 438	 0.30564	 1.254566	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2583	 438	 0.0235	 0.076229	 0.27448	 565.155673	 565.155673	 565.155673	 0.0	 0.0	 1	 -30.0	 30.0;
	2583	 2902	 0.029969	 0.12889	 0.33931	 484.675378	 484.675378	 484.675378	 0.0	 0.0	 1	 -30.0	 30.0;
	2583	 2902	 0.02932	 0.119341	 0.33193	 510.429484	 510.429484	 510.429484	 0.0	 0.0	 1	 -30.0	 30.0;
	6004	 4095	 0.00699	 0.02886	 0.08199	 639.034256	 639.034256	 639.034256	 0.0	 0.0	 1	 -30.0	 30.0;
	4095	 782	 0.004909	 0.014719	 0.05766	 558.910244	 558.910244	 558.910244	 0.0	 0.0	 1	 -30.0	 30.0;
	8127	 6815	 0.005591	 0.01814	 0.06525	 472.099546	 472.099546	 472.099546	 0.0	 0.0	 1	 -30.0	 30.0;
	8127	 6815	 0.00569	 0.01776	 0.06648	 528.333174	 528.333174	 528.333174	 0.0	 0.0	 1	 -30.0	 30.0;
	6583	 4159	 0.03624	 0.415741	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6583	 7585	 0.03359	 0.482777	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6583	 7585	 0.00088	 0.01001	 0.32139	 1722.411806	 1722.411806	 1722.411806	 0.0	 0.0	 1	 -30.0	 30.0;
	6583	 849	 0.001	 0.00981	 0.36424	 2189.738201	 2189.738201	 2189.738201	 0.0	 0.0	 1	 -30.0	 30.0;
	4724	 6583	 0.706579	 3.541136	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4598	 6583	 2.102562	 10.3982	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	438	 1277	 0.00962	 0.03813	 0.1124	 535.249634	 535.249634	 535.249634	 0.0	 0.0	 1	 -30.0	 30.0;
	6964	 4696	 0.04235	 0.255499	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6964	 6341	 0.03604	 0.287562	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6964	 6341	 0.00069	 0.00676	 0.25112	 1972.631175	 1972.631175	 1972.631175	 0.0	 0.0	 1	 -30.0	 30.0;
	6964	 4202	 0.02303	 0.242479	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 6964	 0.002	 0.02189	 0.72223	 2071.816822	 2071.816822	 2071.816822	 0.0	 0.0	 1	 -30.0	 30.0;
	4830	 4598	 0.00063	 0.00569	 0.22889	 1854.078602	 1854.078602	 1854.078602	 0.0	 0.0	 1	 -30.0	 30.0;
	2431	 4724	 0.00064	 0.00557	 0.2332	 1917.165747	 1917.165747	 1917.165747	 0.0	 0.0	 1	 -30.0	 30.0;
	4696	 6341	 0.001	 0.193123	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4696	 4202	 0.01778	 0.156988	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4696	 4202	 0.00104	 0.00843	 0.33955	 1622.313265	 1622.313265	 1622.313265	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 4696	 0.00096	 0.01465	 0.50375	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 4696	 0.003	 0.02517	 1.09679	 1966.468642	 1966.468642	 1966.468642	 0.0	 0.0	 1	 -30.0	 30.0;
	6341	 4202	 0.462929	 1.374931	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	96	 6341	 0.00244	 0.01729	 0.77702	 2087.240596	 2087.240596	 2087.240596	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 6341	 0.00094	 0.01356	 0.4928	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	7525	 6163	 0.01526	 0.05118	 0.17718	 411.302069	 411.302069	 411.302069	 0.0	 0.0	 1	 -30.0	 30.0;
	1704	 6163	 0.01555	 0.05011	 0.18059	 430.163721	 430.163721	 430.163721	 0.0	 0.0	 1	 -30.0	 30.0;
	395	 438	 0.26188	 0.583802	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2846	 7199	 0.0036	 0.04	 1.31756	 1574.507727	 1574.507727	 1574.507727	 0.0	 0.0	 1	 -30.0	 30.0;
	2846	 448	 0.00363	 0.03446	 1.33225	 1651.968191	 1651.968191	 1651.968191	 0.0	 0.0	 1	 -30.0	 30.0;
	2846	 3086	 0.00099	 0.01049	 0.35944	 1218.075331	 1218.075331	 1218.075331	 0.0	 0.0	 1	 -30.0	 30.0;
	8141	 4202	 0.00332	 0.03036	 1.06338	 1674.140278	 1674.140278	 1674.140278	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 1298	 0.00027	 0.00309	 0.09942	 1767.594499	 1767.594499	 1767.594499	 0.0	 0.0	 1	 -30.0	 30.0;
	4780	 1298	 0.00031	 0.00303	 0.11268	 1431.600545	 1431.600545	 1431.600545	 0.0	 0.0	 1	 -30.0	 30.0;
	3422	 2902	 0.027099	 0.21312	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3422	 2902	 0.00357	 0.011021	 0.03973	 566.526314	 566.526314	 566.526314	 0.0	 0.0	 1	 -30.0	 30.0;
	3422	 2902	 0.00351	 0.01126	 0.03899	 507.61504	 507.61504	 507.61504	 0.0	 0.0	 1	 -30.0	 30.0;
	7199	 448	 0.00037	 0.00418	 0.13766	 1255.03539	 1255.03539	 1255.03539	 0.0	 0.0	 1	 -30.0	 30.0;
	3752	 6004	 0.04124	 0.192349	 0.0	 246.715395	 246.715395	 246.715395	 0.0	 0.0	 1	 -30.0	 30.0;
	3752	 6004	 0.015669	 0.064711	 0.18353	 636.937332	 636.937332	 636.937332	 0.0	 0.0	 1	 -30.0	 30.0;
	3752	 6004	 0.016	 0.06349	 0.18743	 632.552957	 632.552957	 632.552957	 0.0	 0.0	 1	 -30.0	 30.0;
	6004	 782	 0.012281	 0.03676	 0.14412	 620.421431	 620.421431	 620.421431	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 173	 0.02043	 0.19226	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 173	 0.00287	 0.01095	 0.03367	 508.141653	 508.141653	 508.141653	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 173	 0.00281	 0.011169	 0.03299	 496.105008	 496.105008	 496.105008	 0.0	 0.0	 1	 -30.0	 30.0;
	7627	 6273	 0.00054	 0.00596	 0.1861	 1602.9674	 1602.9674	 1602.9674	 0.0	 0.0	 1	 -30.0	 30.0;
	6260	 7627	 0.00134	 0.01244	 0.48288	 1896.339637	 1896.339637	 1896.339637	 0.0	 0.0	 1	 -30.0	 30.0;
	892	 3803	 0.001	 0.265693	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8141	 892	 0.15358	 0.524508	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6502	 892	 0.613823	 2.118352	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6502	 892	 0.00081	 0.0077	 0.27595	 1361.289224	 1361.289224	 1361.289224	 0.0	 0.0	 1	 -30.0	 30.0;
	892	 4724	 0.00228	 0.02083	 0.79746	 1745.0874	 1745.0874	 1745.0874	 0.0	 0.0	 1	 -30.0	 30.0;
	8141	 3803	 0.168047	 0.592382	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8141	 3803	 0.0008	 0.00785	 0.27032	 1575.064547	 1575.064547	 1575.064547	 0.0	 0.0	 1	 -30.0	 30.0;
	6502	 3803	 0.698199	 2.371468	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3803	 4598	 0.00232	 0.02039	 0.81251	 1887.287039	 1887.287039	 1887.287039	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 5433	 0.00177	 0.01939	 0.61823	 2142.278208	 2142.278208	 2142.278208	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 5433	 0.00173	 0.01976	 0.60535	 2179.993857	 2179.993857	 2179.993857	 0.0	 0.0	 1	 -30.0	 30.0;
	8141	 6502	 0.0	 3.5e-05	 0.0	 1618.886783	 1618.886783	 1618.886783	 0.0	 0.0	 1	 -30.0	 30.0;
	8141	 6502	 0.001	 0.213047	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8141	 4598	 0.00194	 0.01469	 0.60971	 1573.430946	 1573.430946	 1573.430946	 0.0	 0.0	 1	 -30.0	 30.0;
	96	 8141	 0.00123	 0.00838	 0.39207	 1526.171697	 1526.171697	 1526.171697	 0.0	 0.0	 1	 -30.0	 30.0;
	8141	 2781	 0.00121	 0.0116	 0.37729	 1689.584455	 1689.584455	 1689.584455	 0.0	 0.0	 1	 -30.0	 30.0;
	8141	 4094	 0.00346	 0.03846	 1.26564	 1713.145958	 1713.145958	 1713.145958	 0.0	 0.0	 1	 -30.0	 30.0;
	6502	 4724	 0.00198	 0.01438	 0.62144	 1681.411185	 1681.411185	 1681.411185	 0.0	 0.0	 1	 -30.0	 30.0;
	6502	 4094	 0.00338	 0.0392	 1.23927	 1692.284965	 1692.284965	 1692.284965	 0.0	 0.0	 1	 -30.0	 30.0;
	6502	 177	 0.00248	 0.02446	 0.79576	 900.560418	 900.560418	 900.560418	 0.0	 0.0	 1	 -30.0	 30.0;
	4303	 2661	 0.001	 0.26367	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 4303	 0.580512	 1.382895	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5859	 4303	 0.00094	 0.00807	 0.28556	 2253.732975	 2253.732975	 2253.732975	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 2661	 0.00232	 0.01638	 0.73547	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 2661	 0.00217	 0.0131	 0.57337	 1883.219491	 1883.219491	 1883.219491	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 2661	 0.568421	 1.409488	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1606	 5071	 0.005331	 0.017341	 0.06161	 280.496344	 280.496344	 280.496344	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 7585	 0.00199	 0.02218	 0.73055	 1775.258997	 1775.258997	 1775.258997	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 4724	 0.00163	 0.01513	 0.51173	 2166.840143	 2166.840143	 2166.840143	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 4598	 0.00159	 0.01541	 0.50084	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 5859	 0.00136	 0.00959	 0.44952	 2210.455711	 2210.455711	 2210.455711	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 7905	 0.00042	 0.00496	 0.15691	 1596.354673	 1596.354673	 1596.354673	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 4780	 0.00041	 0.00505	 0.15358	 960.180275	 960.180275	 960.180275	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 6815	 0.016591	 0.06199	 0.17718	 361.2087	 361.2087	 361.2087	 0.0	 0.0	 1	 -30.0	 30.0;
	4159	 7585	 0.0	 3.5e-05	 0.0	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	4159	 7585	 0.001	 0.404868	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4724	 4159	 0.130547	 2.317729	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4598	 4159	 0.431627	 6.284488	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4724	 7585	 0.127403	 2.421884	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4598	 7585	 0.397583	 6.979917	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3086	 6260	 0.00356	 0.03374	 1.30463	 1665.535241	 1665.535241	 1665.535241	 0.0	 0.0	 1	 -30.0	 30.0;
	4724	 4598	 0.00164	 0.14108	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 6260	 0.00058	 0.00658	 0.21154	 1940.735148	 1940.735148	 1940.735148	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 6260	 0.00065	 0.00645	 0.23974	 1914.516575	 1914.516575	 1914.516575	 0.0	 0.0	 1	 -30.0	 30.0;
	2781	 177	 0.079079	 0.405817	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2781	 177	 0.00139	 0.01268	 0.44775	 1495.547272	 1495.547272	 1495.547272	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 455	 0.0	 3.5e-05	 0.0	 1001.894363	 1001.894363	 1001.894363	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 455	 0.001	 0.270111	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7626	 6163	 0.185091	 0.839215	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7626	 6163	 0.004651	 0.039669	 0.11195	 513.522857	 513.522857	 513.522857	 0.0	 0.0	 1	 -30.0	 30.0;
	7626	 6163	 0.00476	 0.042841	 0.11444	 513.586112	 513.586112	 513.586112	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 177	 0.0018	 0.02033	 0.63949	 1187.104703	 1187.104703	 1187.104703	 0.0	 0.0	 1	 -30.0	 30.0;
	7073	 6307	 0.001	 0.335748	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 7073	 0.0001	 0.00068	 0.02901	 1595.060034	 1595.060034	 1595.060034	 0.0	 0.0	 1	 -30.0	 30.0;
	4780	 6307	 0.0001	 0.00067	 0.02955	 1598.250229	 1598.250229	 1598.250229	 0.0	 0.0	 1	 -30.0	 30.0;
	4458	 8344	 0.026107	 0.07605	 0.01003	 75.253607	 75.253607	 75.253607	 0.0	 0.0	 1	 -30.0	 30.0;
	7294	 4458	 0.019727	 0.062124	 0.0076	 88.838081	 88.838081	 88.838081	 0.0	 0.0	 1	 -30.0	 30.0;
	6355	 8344	 0.026603	 0.074438	 0.01022	 85.798626	 85.798626	 85.798626	 0.0	 0.0	 1	 -30.0	 30.0;
	7294	 6355	 0.020107	 0.060851	 0.00775	 89.054899	 89.054899	 89.054899	 0.0	 0.0	 1	 -30.0	 30.0;
	7379	 6059	 0.014017	 0.040471	 0.00536	 67.068437	 67.068437	 67.068437	 0.0	 0.0	 1	 -30.0	 30.0;
	6059	 1269	 0.012488	 0.045289	 0.00479	 63.434161	 63.434161	 63.434161	 0.0	 0.0	 1	 -30.0	 30.0;
	6538	 5029	 0.014281	 0.039612	 0.00546	 75.12062	 75.12062	 75.12062	 0.0	 0.0	 1	 -30.0	 30.0;
	5029	 6632	 0.010826	 0.032686	 0.00415	 63.020721	 63.020721	 63.020721	 0.0	 0.0	 1	 -30.0	 30.0;
	4060	 6096	 0.012554	 0.049893	 0.00487	 73.452568	 73.452568	 73.452568	 0.0	 0.0	 1	 -30.0	 30.0;
	6096	 7359	 0.00705	 0.023174	 0.00281	 75.217216	 75.217216	 75.217216	 0.0	 0.0	 1	 -30.0	 30.0;
	3992	 4491	 0.018818	 0.054132	 0.00479	 75.272278	 75.272278	 75.272278	 0.0	 0.0	 1	 -30.0	 30.0;
	1269	 4491	 0.032769	 0.043661	 0.00361	 64.95989	 64.95989	 64.95989	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 4060	 0.015322	 0.049653	 0.00588	 110.17066	 110.17066	 110.17066	 0.0	 0.0	 1	 -30.0	 30.0;
	2290	 601	 0.002413	 0.006917	 0.00069	 97.308468	 97.308468	 97.308468	 0.0	 0.0	 1	 -30.0	 30.0;
	601	 4862	 0.010537	 0.025917	 0.00292	 70.822743	 70.822743	 70.822743	 0.0	 0.0	 1	 -30.0	 30.0;
	3992	 7379	 0.009124	 0.032314	 0.0035	 69.828962	 69.828962	 69.828962	 0.0	 0.0	 1	 -30.0	 30.0;
	3992	 6538	 0.008934	 0.032934	 0.00343	 75.170918	 75.170918	 75.170918	 0.0	 0.0	 1	 -30.0	 30.0;
	8344	 3710	 0.0	 0.000413	 0.0	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	7622	 3710	 0.015562	 0.044669	 0.00562	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	5972	 3710	 0.013	 0.049983	 0.005	 64.935884	 64.935884	 64.935884	 0.0	 0.0	 1	 -30.0	 30.0;
	8344	 4940	 0.014347	 0.041182	 0.00519	 96.365938	 96.365938	 96.365938	 0.0	 0.0	 1	 -30.0	 30.0;
	8344	 4940	 0.014628	 0.040322	 0.00529	 87.886977	 87.886977	 87.886977	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 626	 0.017446	 0.029752	 0.00367	 59.759685	 59.759685	 59.759685	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 5964	 0.031579	 0.070992	 0.00668	 58.214903	 58.214903	 58.214903	 0.0	 0.0	 1	 -30.0	 30.0;
	3107	 1565	 0.007843	 0.018793	 0.0021	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4010	 1565	 0.007992	 0.018413	 0.00214	 61.528715	 61.528715	 61.528715	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 6977	 0.001271	 0.016781	 0.0439	 567.726244	 567.726244	 567.726244	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 6977	 0.00124	 0.015539	 0.04295	 611.444627	 611.444627	 611.444627	 0.0	 0.0	 1	 -30.0	 30.0;
	626	 3992	 0.033777	 0.06419	 0.00707	 70.299179	 70.299179	 70.299179	 0.0	 0.0	 1	 -30.0	 30.0;
	3992	 1074	 0.014347	 0.028397	 0.00316	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5964	 3992	 0.023331	 0.052182	 0.00489	 95.2466	 95.2466	 95.2466	 0.0	 0.0	 1	 -30.0	 30.0;
	3992	 6283	 0.009446	 0.022636	 0.00633	 57.993703	 57.993703	 57.993703	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 1269	 0.006992	 0.025488	 0.00272	 71.084907	 71.084907	 71.084907	 0.0	 0.0	 1	 -30.0	 30.0;
	6283	 1074	 0.003339	 0.008851	 0.00525	 64.615229	 64.615229	 64.615229	 0.0	 0.0	 1	 -30.0	 30.0;
	7622	 4433	 0.016471	 0.06081	 0.00633	 161.816812	 161.816812	 161.816812	 0.0	 0.0	 1	 -30.0	 30.0;
	6712	 5972	 0.020149	 0.058727	 0.00777	 100.887681	 100.887681	 100.887681	 0.0	 0.0	 1	 -30.0	 30.0;
	4940	 555	 0.013992	 0.054	 0.00539	 98.415231	 98.415231	 98.415231	 0.0	 0.0	 1	 -30.0	 30.0;
	4940	 3633	 0.013686	 0.05	 0.00527	 119.656929	 119.656929	 119.656929	 0.0	 0.0	 1	 -30.0	 30.0;
	4940	 4110	 0.000223	 0.000826	 6e-05	 93.968745	 93.968745	 93.968745	 0.0	 0.0	 1	 -30.0	 30.0;
	4940	 3050	 0.000248	 0.00081	 7e-05	 101.674362	 101.674362	 101.674362	 0.0	 0.0	 1	 -30.0	 30.0;
	8360	 4433	 0.036512	 0.098843	 0.01359	 120.381498	 120.381498	 120.381498	 0.0	 0.0	 1	 -30.0	 30.0;
	555	 187	 0.012876	 0.037438	 0.00495	 93.319624	 93.319624	 93.319624	 0.0	 0.0	 1	 -30.0	 30.0;
	3633	 187	 0.013124	 0.036636	 0.00504	 90.08831	 90.08831	 90.08831	 0.0	 0.0	 1	 -30.0	 30.0;
	2097	 3107	 0.013909	 0.033041	 0.00368	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 4010	 0.014182	 0.032372	 0.00375	 79.206631	 79.206631	 79.206631	 0.0	 0.0	 1	 -30.0	 30.0;
	4677	 7545	 0.00474	 0.027521	 0.04875	 305.277246	 305.277246	 305.277246	 0.0	 0.0	 1	 -30.0	 30.0;
	4677	 6228	 0.00538	 0.026969	 0.05525	 321.763044	 321.763044	 321.763044	 0.0	 0.0	 1	 -30.0	 30.0;
	4420	 7359	 0.020372	 0.06276	 0.00772	 112.689789	 112.689789	 112.689789	 0.0	 0.0	 1	 -30.0	 30.0;
	8360	 6712	 0.0	 0.000413	 0.0	 165.30343	 165.30343	 165.30343	 0.0	 0.0	 1	 -30.0	 30.0;
	5588	 5362	 0.0053	 0.02831	 0.03929	 424.51921	 424.51921	 424.51921	 0.0	 0.0	 1	 -30.0	 30.0;
	5588	 5362	 0.00601	 0.02774	 0.04453	 447.944712	 447.944712	 447.944712	 0.0	 0.0	 1	 -30.0	 30.0;
	7545	 5588	 0.00113	 0.006229	 0.01189	 295.312757	 295.312757	 295.312757	 0.0	 0.0	 1	 -30.0	 30.0;
	6228	 5588	 0.001151	 0.00611	 0.01213	 230.844233	 230.844233	 230.844233	 0.0	 0.0	 1	 -30.0	 30.0;
	2290	 2097	 0.014364	 0.029529	 0.00388	 75.306192	 75.306192	 75.306192	 0.0	 0.0	 1	 -30.0	 30.0;
	4420	 2290	 0.009017	 0.019727	 0.00237	 98.519258	 98.519258	 98.519258	 0.0	 0.0	 1	 -30.0	 30.0;
	4420	 2290	 0.00919	 0.019314	 0.00242	 99.908761	 99.908761	 99.908761	 0.0	 0.0	 1	 -30.0	 30.0;
	6228	 4157	 9.1e-05	 0.000219	 0.0	 287.78471	 287.78471	 287.78471	 0.0	 0.0	 1	 -30.0	 30.0;
	7545	 4157	 9.1e-05	 0.000229	 0.0	 253.434852	 253.434852	 253.434852	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 4420	 0.00205	 0.00562	 0.00078	 303.954998	 303.954998	 303.954998	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 5175	 0.016	 0.049818	 0.00614	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 5175	 0.014331	 0.054347	 0.00545	 59.042165	 59.042165	 59.042165	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 4420	 0.00738	 0.021149	 0.00206	 58.163842	 58.163842	 58.163842	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 7982	 0.011256	 0.027769	 0.0026	 74.291452	 74.291452	 74.291452	 0.0	 0.0	 1	 -30.0	 30.0;
	453	 4420	 0.007207	 0.019587	 0.00202	 67.871502	 67.871502	 67.871502	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 453	 0.01195	 0.024826	 0.00292	 68.898816	 68.898816	 68.898816	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 2873	 0.00796	 0.04504	 0.08493	 127.332495	 127.332495	 127.332495	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 6289	 0.00844	 0.068649	 0.02157	 144.176862	 144.176862	 144.176862	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 5328	 0.021551	 0.0842	 0.21639	 261.827885	 261.827885	 261.827885	 0.0	 0.0	 1	 -30.0	 30.0;
	2017	 7949	 0.002809	 0.01632	 0.00585	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	2017	 326	 0.00028	 0.00084	 0.02673	 251.862964	 251.862964	 251.862964	 0.0	 0.0	 1	 -30.0	 30.0;
	2017	 326	 0.00032	 0.000822	 0.03029	 252.241763	 252.241763	 252.241763	 0.0	 0.0	 1	 -30.0	 30.0;
	2017	 2567	 0.007711	 0.054271	 0.02431	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2017	 4104	 0.002298	 0.017129	 0.18446	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	7281	 8097	 0.004711	 0.026049	 0.01193	 201.457428	 201.457428	 201.457428	 0.0	 0.0	 1	 -30.0	 30.0;
	7281	 4947	 0.008462	 0.03792	 0.01733	 195.893647	 195.893647	 195.893647	 0.0	 0.0	 1	 -30.0	 30.0;
	7147	 1624	 0.00095	 0.01117	 0.24986	 1107.986943	 1107.986943	 1107.986943	 0.0	 0.0	 1	 -30.0	 30.0;
	7147	 4640	 0.00142	 0.01429	 0.37777	 1182.813374	 1182.813374	 1182.813374	 0.0	 0.0	 1	 -30.0	 30.0;
	5258	 7158	 0.000569	 0.005382	 0.0929	 261.340746	 261.340746	 261.340746	 0.0	 0.0	 1	 -30.0	 30.0;
	3017	 1889	 0.00984	 0.04424	 0.02041	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3017	 3903	 0.0166	 0.105449	 0.07307	 105.444482	 105.444482	 105.444482	 0.0	 0.0	 1	 -30.0	 30.0;
	767	 6768	 0.007209	 0.034969	 0.01431	 105.128816	 105.128816	 105.128816	 0.0	 0.0	 1	 -30.0	 30.0;
	767	 1525	 0.023951	 0.07004	 0.02867	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8097	 2078	 0.002258	 0.01644	 0.00875	 252.722667	 252.722667	 252.722667	 0.0	 0.0	 1	 -30.0	 30.0;
	4408	 1259	 0.00948	 0.02892	 0.04356	 107.211434	 107.211434	 107.211434	 0.0	 0.0	 1	 -30.0	 30.0;
	4408	 2327	 0.01224	 0.04384	 0.06914	 162.80273	 162.80273	 162.80273	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 2327	 0.016	 0.062369	 0.01861	 155.274804	 155.274804	 155.274804	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 2046	 0.020422	 0.082729	 0.02999	 129.87731	 129.87731	 129.87731	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 2046	 0.020009	 0.08436	 0.02938	 103.959422	 103.959422	 103.959422	 0.0	 0.0	 1	 -30.0	 30.0;
	4044	 2046	 0.010702	 0.030338	 0.01312	 141.720381	 141.720381	 141.720381	 0.0	 0.0	 1	 -30.0	 30.0;
	4044	 2046	 0.010902	 0.02968	 0.01336	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5090	 2413	 0.00848	 0.040809	 0.01717	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5090	 3759	 0.012862	 0.05772	 0.02574	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5084	 1624	 0.00047	 0.00546	 0.18642	 892.452308	 892.452308	 892.452308	 0.0	 0.0	 1	 -30.0	 30.0;
	6993	 6958	 0.002871	 0.02108	 0.02396	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6993	 3903	 0.004849	 0.02916	 0.01015	 149.723755	 149.723755	 149.723755	 0.0	 0.0	 1	 -30.0	 30.0;
	6993	 3903	 0.004751	 0.029711	 0.00994	 142.019679	 142.019679	 142.019679	 0.0	 0.0	 1	 -30.0	 30.0;
	4686	 3903	 0.001569	 0.005489	 0.00176	 118.542943	 118.542943	 118.542943	 0.0	 0.0	 1	 -30.0	 30.0;
	6033	 5889	 0.0003	 0.00316	 0.05829	 1226.895591	 1226.895591	 1226.895591	 0.0	 0.0	 1	 -30.0	 30.0;
	6033	 4640	 0.00114	 0.01207	 0.35564	 1152.573326	 1152.573326	 1152.573326	 0.0	 0.0	 1	 -30.0	 30.0;
	6033	 5523	 0.00147	 0.01724	 0.82394	 1114.658249	 1114.658249	 1114.658249	 0.0	 0.0	 1	 -30.0	 30.0;
	6033	 8374	 0.00039	 0.00552	 0.12156	 1269.417924	 1269.417924	 1269.417924	 0.0	 0.0	 1	 -30.0	 30.0;
	7949	 2567	 0.004991	 0.036511	 0.01915	 113.169082	 113.169082	 113.169082	 0.0	 0.0	 1	 -30.0	 30.0;
	7949	 7341	 0.007302	 0.041071	 0.05157	 135.568656	 135.568656	 135.568656	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 5424	 0.00022	 0.00305	 0.06498	 904.005329	 904.005329	 904.005329	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 260	 0.00074	 0.00834	 0.21328	 961.139242	 961.139242	 961.139242	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 3841	 0.00126	 0.0174	 0.3602	 882.877773	 882.877773	 882.877773	 0.0	 0.0	 1	 -30.0	 30.0;
	3850	 2873	 0.00216	 0.012578	 0.10273	 233.851801	 233.851801	 233.851801	 0.0	 0.0	 1	 -30.0	 30.0;
	3850	 585	 0.001329	 0.0106	 0.00365	 222.928449	 222.928449	 222.928449	 0.0	 0.0	 1	 -30.0	 30.0;
	3850	 6289	 0.006049	 0.063742	 0.02119	 114.194803	 114.194803	 114.194803	 0.0	 0.0	 1	 -30.0	 30.0;
	4880	 7664	 0.006769	 0.02648	 0.03167	 136.100742	 136.100742	 136.100742	 0.0	 0.0	 1	 -30.0	 30.0;
	4880	 7368	 0.016022	 0.047791	 0.01956	 111.000728	 111.000728	 111.000728	 0.0	 0.0	 1	 -30.0	 30.0;
	4880	 2567	 0.02884	 0.096209	 0.06197	 260.402061	 260.402061	 260.402061	 0.0	 0.0	 1	 -30.0	 30.0;
	6752	 7368	 0.00656	 0.024578	 0.0081	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6752	 1259	 0.00388	 0.017342	 0.01777	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6752	 7024	 0.01772	 0.064978	 0.04576	 237.501838	 237.501838	 237.501838	 0.0	 0.0	 1	 -30.0	 30.0;
	2873	 589	 0.01312	 0.052809	 0.07034	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	2873	 585	 0.001738	 0.002889	 0.11805	 178.690486	 178.690486	 178.690486	 0.0	 0.0	 1	 -30.0	 30.0;
	589	 7287	 0.001169	 0.003489	 0.13077	 309.867094	 309.867094	 309.867094	 0.0	 0.0	 1	 -30.0	 30.0;
	3774	 6858	 0.00368	 0.035022	 0.01377	 134.125944	 134.125944	 134.125944	 0.0	 0.0	 1	 -30.0	 30.0;
	3774	 6205	 0.001391	 0.010338	 0.00535	 114.041516	 114.041516	 114.041516	 0.0	 0.0	 1	 -30.0	 30.0;
	3774	 4187	 0.004222	 0.030831	 0.01604	 143.022537	 143.022537	 143.022537	 0.0	 0.0	 1	 -30.0	 30.0;
	2735	 5187	 0.004271	 0.036089	 0.06696	 132.435116	 132.435116	 132.435116	 0.0	 0.0	 1	 -30.0	 30.0;
	2735	 6858	 0.00596	 0.04024	 0.03238	 150.587875	 150.587875	 150.587875	 0.0	 0.0	 1	 -30.0	 30.0;
	3505	 4652	 0.011529	 0.046698	 0.01283	 151.232977	 151.232977	 151.232977	 0.0	 0.0	 1	 -30.0	 30.0;
	3505	 2327	 0.02252	 0.087338	 0.0258	 120.255855	 120.255855	 120.255855	 0.0	 0.0	 1	 -30.0	 30.0;
	5993	 3342	 0.004071	 0.035591	 0.01535	 163.298183	 163.298183	 163.298183	 0.0	 0.0	 1	 -30.0	 30.0;
	5993	 4187	 0.004138	 0.0386	 0.09434	 165.930294	 165.930294	 165.930294	 0.0	 0.0	 1	 -30.0	 30.0;
	2570	 2281	 0.010911	 0.027231	 0.2464	 107.45981	 107.45981	 107.45981	 0.0	 0.0	 1	 -30.0	 30.0;
	71	 5902	 0.00256	 0.024622	 0.00972	 111.260795	 111.260795	 111.260795	 0.0	 0.0	 1	 -30.0	 30.0;
	71	 4187	 0.005129	 0.040671	 0.01966	 128.463697	 128.463697	 128.463697	 0.0	 0.0	 1	 -30.0	 30.0;
	7664	 6768	 0.005462	 0.032671	 0.0108	 115.593607	 115.593607	 115.593607	 0.0	 0.0	 1	 -30.0	 30.0;
	7664	 1525	 0.002871	 0.014209	 0.00608	 111.430969	 111.430969	 111.430969	 0.0	 0.0	 1	 -30.0	 30.0;
	7664	 1525	 0.002929	 0.013911	 0.0062	 111.979163	 111.979163	 111.979163	 0.0	 0.0	 1	 -30.0	 30.0;
	7664	 180	 0.003422	 0.011009	 0.00374	 237.420518	 237.420518	 237.420518	 0.0	 0.0	 1	 -30.0	 30.0;
	5902	 6858	 0.00212	 0.016769	 0.00796	 135.197391	 135.197391	 135.197391	 0.0	 0.0	 1	 -30.0	 30.0;
	1784	 4640	 0.00125	 0.01387	 0.42569	 1729.688637	 1729.688637	 1729.688637	 0.0	 0.0	 1	 -30.0	 30.0;
	7808	 2327	 0.004289	 0.017071	 0.06656	 272.622372	 272.622372	 272.622372	 0.0	 0.0	 1	 -30.0	 30.0;
	7808	 4793	 0.0084	 0.024738	 0.03888	 256.484682	 256.484682	 256.484682	 0.0	 0.0	 1	 -30.0	 30.0;
	2281	 3903	 0.01044	 0.039671	 0.01267	 137.789751	 137.789751	 137.789751	 0.0	 0.0	 1	 -30.0	 30.0;
	2281	 3903	 0.010218	 0.040418	 0.0124	 168.315588	 168.315588	 168.315588	 0.0	 0.0	 1	 -30.0	 30.0;
	2281	 3407	 0.008351	 0.02432	 0.03888	 238.519244	 238.519244	 238.519244	 0.0	 0.0	 1	 -30.0	 30.0;
	3342	 2188	 0.00188	 0.006711	 0.1829	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3342	 7341	 0.00132	 0.00352	 -0.21274	 129.896796	 129.896796	 129.896796	 0.0	 0.0	 1	 -30.0	 30.0;
	6722	 3841	 0.00113	 0.01322	 0.39074	 1418.874648	 1418.874648	 1418.874648	 0.0	 0.0	 1	 -30.0	 30.0;
	6722	 1624	 0.00098	 0.01301	 0.25792	 1061.470121	 1061.470121	 1061.470121	 0.0	 0.0	 1	 -30.0	 30.0;
	1889	 4947	 0.005271	 0.05104	 0.01852	 165.312472	 165.312472	 165.312472	 0.0	 0.0	 1	 -30.0	 30.0;
	1889	 6844	 0.017458	 0.109631	 0.03602	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1889	 201	 0.002831	 0.01016	 0.01323	 163.125931	 163.125931	 163.125931	 0.0	 0.0	 1	 -30.0	 30.0;
	1889	 201	 0.001978	 0.010902	 0.01288	 176.14515	 176.14515	 176.14515	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 3841	 0.00059	 0.00764	 0.16549	 805.880667	 805.880667	 805.880667	 0.0	 0.0	 1	 -30.0	 30.0;
	1225	 7368	 0.000231	 0.000769	 0.00047	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5187	 2078	 0.002809	 0.02468	 0.05365	 174.756998	 174.756998	 174.756998	 0.0	 0.0	 1	 -30.0	 30.0;
	5187	 7158	 0.009942	 0.050222	 0.02026	 217.422086	 217.422086	 217.422086	 0.0	 0.0	 1	 -30.0	 30.0;
	3841	 7437	 0.00117	 0.01756	 0.38857	 1559.028666	 1559.028666	 1559.028666	 0.0	 0.0	 1	 -30.0	 30.0;
	3841	 8216	 9e-05	 0.0017	 0.03454	 883.620199	 883.620199	 883.620199	 0.0	 0.0	 1	 -30.0	 30.0;
	2078	 5798	 0.002569	 0.02344	 0.00926	 112.412782	 112.412782	 112.412782	 0.0	 0.0	 1	 -30.0	 30.0;
	2078	 4292	 0.00144	 0.011369	 0.00486	 147.394839	 147.394839	 147.394839	 0.0	 0.0	 1	 -30.0	 30.0;
	8226	 7434	 0.002129	 0.019689	 0.00821	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3903	 6844	 0.00756	 0.048378	 0.05422	 111.710002	 111.710002	 111.710002	 0.0	 0.0	 1	 -30.0	 30.0;
	3903	 4652	 0.031138	 0.104969	 0.0381	 137.536179	 137.536179	 137.536179	 0.0	 0.0	 1	 -30.0	 30.0;
	7437	 5523	 0.00043	 0.00623	 0.16698	 1213.776762	 1213.776762	 1213.776762	 0.0	 0.0	 1	 -30.0	 30.0;
	6858	 2303	 0.000769	 0.005769	 0.00292	 117.819379	 117.819379	 117.819379	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 4187	 0.01464	 0.043018	 0.01701	 115.576979	 115.576979	 115.576979	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 121	 0.006609	 0.014329	 0.38187	 129.547874	 129.547874	 129.547874	 0.0	 0.0	 1	 -30.0	 30.0;
	3825	 5523	 0.00021	 0.00252	 0.07942	 859.773047	 859.773047	 859.773047	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 4187	 0.002689	 0.019791	 0.00972	 148.552802	 148.552802	 148.552802	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 4187	 0.002738	 0.01936	 0.0099	 157.00902	 157.00902	 157.00902	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 4187	 0.001338	 0.010018	 0.02019	 196.492764	 196.492764	 196.492764	 0.0	 0.0	 1	 -30.0	 30.0;
	6205	 4187	 0.001698	 0.012871	 0.0062	 151.276365	 151.276365	 151.276365	 0.0	 0.0	 1	 -30.0	 30.0;
	1500	 4187	 0.00384	 0.028342	 0.01425	 137.819629	 137.819629	 137.819629	 0.0	 0.0	 1	 -30.0	 30.0;
	2567	 7434	 0.00616	 0.033618	 0.05121	 159.817281	 159.817281	 159.817281	 0.0	 0.0	 1	 -30.0	 30.0;
	2567	 7024	 0.01488	 0.045698	 0.01825	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5889	 8374	 4e-05	 0.00051	 0.01741	 1226.631003	 1226.631003	 1226.631003	 0.0	 0.0	 1	 -30.0	 30.0;
	1525	 2413	 0.028751	 0.090409	 0.09316	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1525	 3759	 0.00092	 0.004609	 0.00187	 247.786323	 247.786323	 247.786323	 0.0	 0.0	 1	 -30.0	 30.0;
	3582	 2327	 0.005151	 0.012329	 0.29654	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 4292	 0.002129	 0.018	 0.03246	 104.629465	 104.629465	 104.629465	 0.0	 0.0	 1	 -30.0	 30.0;
	201	 5328	 0.008929	 0.041471	 0.04082	 136.775462	 136.775462	 136.775462	 0.0	 0.0	 1	 -30.0	 30.0;
	201	 1936	 0.0222	 0.091822	 0.02525	 165.504469	 165.504469	 165.504469	 0.0	 0.0	 1	 -30.0	 30.0;
	3407	 4793	 0.005671	 0.021169	 0.02506	 251.546518	 251.546518	 251.546518	 0.0	 0.0	 1	 -30.0	 30.0;
	4292	 1936	 0.00956	 0.035551	 0.05292	 278.66212	 278.66212	 278.66212	 0.0	 0.0	 1	 -30.0	 30.0;
	2046	 7434	 0.003169	 0.021911	 0.00964	 174.594099	 174.594099	 174.594099	 0.0	 0.0	 1	 -30.0	 30.0;
	2046	 7434	 0.00324	 0.021471	 0.00983	 244.144599	 244.144599	 244.144599	 0.0	 0.0	 1	 -30.0	 30.0;
	2046	 4187	 0.01168	 0.055391	 0.08798	 192.709185	 192.709185	 192.709185	 0.0	 0.0	 1	 -30.0	 30.0;
	2046	 4187	 0.011902	 0.054209	 0.08964	 211.788678	 211.788678	 211.788678	 0.0	 0.0	 1	 -30.0	 30.0;
	4187	 121	 0.01908	 0.062769	 0.36975	 111.347571	 111.347571	 111.347571	 0.0	 0.0	 1	 -30.0	 30.0;
	3759	 4104	 0.001591	 0.011098	 0.00459	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	5949	 1177	 0.003289	 0.019091	 0.03572	 462.056561	 462.056561	 462.056561	 0.0	 0.0	 1	 -30.0	 30.0;
	5949	 1518	 0.004169	 0.025349	 0.04586	 484.538962	 484.538962	 484.538962	 0.0	 0.0	 1	 -30.0	 30.0;
	5949	 3729	 0.00439	 0.023909	 0.05804	 476.201562	 476.201562	 476.201562	 0.0	 0.0	 1	 -30.0	 30.0;
	4289	 3862	 0.00156	 0.01956	 0.53992	 1340.057676	 1340.057676	 1340.057676	 0.0	 0.0	 1	 -30.0	 30.0;
	3862	 6702	 0.00029	 0.00391	 0.12748	 1854.05754	 1854.05754	 1854.05754	 0.0	 0.0	 1	 -30.0	 30.0;
	3862	 5327	 0.00179	 0.02522	 0.80239	 1653.726847	 1653.726847	 1653.726847	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 3862	 0.00079	 0.00756	 0.26735	 1866.439868	 1866.439868	 1866.439868	 0.0	 0.0	 1	 -30.0	 30.0;
	3862	 1341	 0.00027	 0.00281	 0.06816	 1665.433882	 1665.433882	 1665.433882	 0.0	 0.0	 1	 -30.0	 30.0;
	3862	 1341	 0.00026	 0.00286	 0.06674	 1571.216172	 1571.216172	 1571.216172	 0.0	 0.0	 1	 -30.0	 30.0;
	2047	 239	 0.000281	 0.00213	 0.0052	 359.676112	 359.676112	 359.676112	 0.0	 0.0	 1	 -30.0	 30.0;
	2047	 7733	 0.000419	 0.00299	 0.00785	 258.637344	 258.637344	 258.637344	 0.0	 0.0	 1	 -30.0	 30.0;
	3408	 4372	 0.001659	 0.009091	 0.018	 364.84469	 364.84469	 364.84469	 0.0	 0.0	 1	 -30.0	 30.0;
	3408	 5661	 0.00439	 0.03324	 0.08166	 396.716573	 396.716573	 396.716573	 0.0	 0.0	 1	 -30.0	 30.0;
	5438	 7865	 0.000841	 0.00612	 0.01716	 405.018154	 405.018154	 405.018154	 0.0	 0.0	 1	 -30.0	 30.0;
	5438	 181	 0.003341	 0.022841	 0.058	 551.997214	 551.997214	 551.997214	 0.0	 0.0	 1	 -30.0	 30.0;
	5438	 3192	 0.00581	 0.04232	 0.12566	 262.560266	 262.560266	 262.560266	 0.0	 0.0	 1	 -30.0	 30.0;
	5438	 1302	 0.00495	 0.02919	 0.04457	 444.914974	 444.914974	 444.914974	 0.0	 0.0	 1	 -30.0	 30.0;
	5438	 5078	 0.01789	 0.07795	 0.16192	 398.978492	 398.978492	 398.978492	 0.0	 0.0	 1	 -30.0	 30.0;
	5438	 4507	 0.00186	 0.014289	 0.03878	 386.682733	 386.682733	 386.682733	 0.0	 0.0	 1	 -30.0	 30.0;
	5438	 2139	 0.002281	 0.014401	 0.04256	 254.473216	 254.473216	 254.473216	 0.0	 0.0	 1	 -30.0	 30.0;
	4106	 2686	 0.00031	 0.00132	 0.00239	 267.777999	 267.777999	 267.777999	 0.0	 0.0	 1	 -30.0	 30.0;
	4106	 6291	 0.001349	 0.0077	 0.01017	 399.585888	 399.585888	 399.585888	 0.0	 0.0	 1	 -30.0	 30.0;
	5171	 5381	 0.00586	 0.02574	 0.06732	 485.221043	 485.221043	 485.221043	 0.0	 0.0	 1	 -30.0	 30.0;
	5171	 5482	 0.00556	 0.020211	 0.06365	 607.964868	 607.964868	 607.964868	 0.0	 0.0	 1	 -30.0	 30.0;
	4719	 2646	 0.00026	 0.001159	 0.12727	 568.505494	 568.505494	 568.505494	 0.0	 0.0	 1	 -30.0	 30.0;
	2646	 6034	 0.000599	 0.002419	 0.31101	 591.796866	 591.796866	 591.796866	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 6476	 0.0005	 0.00386	 0.009	 261.154568	 261.154568	 261.154568	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 5566	 0.00107	 0.008289	 0.01652	 536.373353	 536.373353	 536.373353	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 5566	 0.001091	 0.00811	 0.01683	 245.223961	 245.223961	 245.223961	 0.0	 0.0	 1	 -30.0	 30.0;
	6719	 6056	 0.00038	 0.00255	 0.00726	 548.622625	 548.622625	 548.622625	 0.0	 0.0	 1	 -30.0	 30.0;
	4719	 5858	 0.000271	 0.000979	 0.14244	 278.737031	 278.737031	 278.737031	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 1493	 7e-05	 0.00076	 0.10408	 266.750304	 266.750304	 266.750304	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 7772	 0.000521	 0.003901	 0.0096	 241.950732	 241.950732	 241.950732	 0.0	 0.0	 1	 -30.0	 30.0;
	4289	 7477	 0.0016	 0.01839	 0.38509	 1263.046748	 1263.046748	 1263.046748	 0.0	 0.0	 1	 -30.0	 30.0;
	5252	 1267	 0.007651	 0.058781	 0.16238	 481.88494	 481.88494	 481.88494	 0.0	 0.0	 1	 -30.0	 30.0;
	5252	 5665	 0.00394	 0.02182	 0.05366	 226.294482	 226.294482	 226.294482	 0.0	 0.0	 1	 -30.0	 30.0;
	5252	 7558	 0.003461	 0.03005	 0.07832	 554.41003	 554.41003	 554.41003	 0.0	 0.0	 1	 -30.0	 30.0;
	5252	 681	 0.00337	 0.01831	 0.0459	 450.192533	 450.192533	 450.192533	 0.0	 0.0	 1	 -30.0	 30.0;
	7511	 3909	 0.000581	 0.00194	 0.1989	 505.111915	 505.111915	 505.111915	 0.0	 0.0	 1	 -30.0	 30.0;
	6699	 3909	 0.000539	 0.001719	 0.17952	 234.490512	 234.490512	 234.490512	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 841	 0.00249	 0.03075	 0.59862	 1587.246787	 1587.246787	 1587.246787	 0.0	 0.0	 1	 -30.0	 30.0;
	841	 4014	 0.0014	 0.01409	 0.33536	 1706.794528	 1706.794528	 1706.794528	 0.0	 0.0	 1	 -30.0	 30.0;
	7106	 5981	 0.008	 0.050031	 0.07101	 399.584745	 399.584745	 399.584745	 0.0	 0.0	 1	 -30.0	 30.0;
	7106	 5078	 0.002211	 0.01562	 0.01967	 575.604096	 575.604096	 575.604096	 0.0	 0.0	 1	 -30.0	 30.0;
	1291	 3305	 0.00281	 0.021831	 0.03108	 492.299831	 492.299831	 492.299831	 0.0	 0.0	 1	 -30.0	 30.0;
	1291	 7092	 0.000711	 0.004919	 0.00656	 257.315096	 257.315096	 257.315096	 0.0	 0.0	 1	 -30.0	 30.0;
	2650	 5529	 0.001841	 0.00738	 0.00847	 364.989108	 364.989108	 364.989108	 0.0	 0.0	 1	 -30.0	 30.0;
	2650	 3168	 0.002849	 0.008979	 0.01308	 367.707909	 367.707909	 367.707909	 0.0	 0.0	 1	 -30.0	 30.0;
	7571	 3305	 0.00232	 0.014099	 0.04337	 250.808266	 250.808266	 250.808266	 0.0	 0.0	 1	 -30.0	 30.0;
	7571	 3305	 0.00237	 0.0138	 0.04419	 254.378716	 254.378716	 254.378716	 0.0	 0.0	 1	 -30.0	 30.0;
	7571	 6263	 0.00081	 0.004591	 0.00913	 491.232126	 491.232126	 491.232126	 0.0	 0.0	 1	 -30.0	 30.0;
	7571	 6007	 0.002219	 0.010469	 0.03064	 283.924281	 283.924281	 283.924281	 0.0	 0.0	 1	 -30.0	 30.0;
	5683	 1713	 0.001081	 0.00851	 0.05702	 253.810187	 253.810187	 253.810187	 0.0	 0.0	 1	 -30.0	 30.0;
	1713	 7234	 0.00087	 0.006969	 0.02047	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1713	 7234	 0.00088	 0.006831	 0.02087	 242.549363	 242.549363	 242.549363	 0.0	 0.0	 1	 -30.0	 30.0;
	1713	 4226	 0.000349	 0.00237	 0.00773	 268.813696	 268.813696	 268.813696	 0.0	 0.0	 1	 -30.0	 30.0;
	644	 5895	 0.00232	 0.00924	 0.01751	 382.371139	 382.371139	 382.371139	 0.0	 0.0	 1	 -30.0	 30.0;
	644	 3452	 0.00812	 0.03669	 0.06171	 411.64692	 411.64692	 411.64692	 0.0	 0.0	 1	 -30.0	 30.0;
	1996	 6093	 0.003521	 0.02825	 0.06753	 488.000812	 488.000812	 488.000812	 0.0	 0.0	 1	 -30.0	 30.0;
	1996	 4322	 0.00264	 0.017651	 0.05145	 224.960422	 224.960422	 224.960422	 0.0	 0.0	 1	 -30.0	 30.0;
	6936	 5895	 0.00486	 0.02149	 0.0442	 472.399433	 472.399433	 472.399433	 0.0	 0.0	 1	 -30.0	 30.0;
	6936	 6140	 0.006831	 0.034669	 0.05963	 437.514579	 437.514579	 437.514579	 0.0	 0.0	 1	 -30.0	 30.0;
	6936	 6418	 0.017211	 0.108151	 0.15779	 388.117391	 388.117391	 388.117391	 0.0	 0.0	 1	 -30.0	 30.0;
	6936	 7444	 0.00063	 0.00475	 0.01195	 437.976794	 437.976794	 437.976794	 0.0	 0.0	 1	 -30.0	 30.0;
	6936	 7444	 0.00062	 0.004841	 0.0117	 380.949818	 380.949818	 380.949818	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 2271	 0.0009	 0.01092	 0.30354	 1871.380162	 1871.380162	 1871.380162	 0.0	 0.0	 1	 -30.0	 30.0;
	2271	 6276	 0.00124	 0.01096	 0.41979	 1808.379238	 1808.379238	 1808.379238	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 2681	 0.003211	 0.00176	 0.00454	 310.027049	 310.027049	 310.027049	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 7092	 0.001521	 0.008031	 0.02227	 304.773496	 304.773496	 304.773496	 0.0	 0.0	 1	 -30.0	 30.0;
	4925	 1736	 0.0005	 0.00441	 0.12541	 1435.04019	 1435.04019	 1435.04019	 0.0	 0.0	 1	 -30.0	 30.0;
	4925	 1364	 0.00247	 0.02573	 0.62683	 1724.722674	 1724.722674	 1724.722674	 0.0	 0.0	 1	 -30.0	 30.0;
	4925	 1165	 0.00042	 0.00367	 0.09617	 1308.039885	 1308.039885	 1308.039885	 0.0	 0.0	 1	 -30.0	 30.0;
	6736	 3896	 0.0023	 0.01644	 0.024	 459.626598	 459.626598	 459.626598	 0.0	 0.0	 1	 -30.0	 30.0;
	6736	 3896	 0.00226	 0.01676	 0.0235	 469.735886	 469.735886	 469.735886	 0.0	 0.0	 1	 -30.0	 30.0;
	6736	 3896	 0.0023	 0.0162	 0.02471	 479.874133	 479.874133	 479.874133	 0.0	 0.0	 1	 -30.0	 30.0;
	6736	 3896	 0.00225	 0.015	 0.02417	 429.145933	 429.145933	 429.145933	 0.0	 0.0	 1	 -30.0	 30.0;
	2129	 5393	 0.007281	 0.035729	 0.0942	 439.96893	 439.96893	 439.96893	 0.0	 0.0	 1	 -30.0	 30.0;
	2038	 5393	 0.001919	 0.00945	 0.02493	 455.394262	 455.394262	 455.394262	 0.0	 0.0	 1	 -30.0	 30.0;
	3478	 1067	 0.005211	 0.02981	 0.03943	 520.448463	 520.448463	 520.448463	 0.0	 0.0	 1	 -30.0	 30.0;
	3478	 6291	 0.000659	 0.00586	 0.00221	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3478	 6291	 0.000591	 0.00664	 0.00197	 263.008763	 263.008763	 263.008763	 0.0	 0.0	 1	 -30.0	 30.0;
	3478	 2676	 0.011969	 0.07424	 0.10468	 542.634786	 542.634786	 542.634786	 0.0	 0.0	 1	 -30.0	 30.0;
	5683	 2787	 0.000531	 0.003919	 0.03462	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3754	 3070	 0.001521	 0.00718	 0.01157	 440.06343	 440.06343	 440.06343	 0.0	 0.0	 1	 -30.0	 30.0;
	3754	 3070	 0.001211	 0.00613	 0.00912	 478.677251	 478.677251	 478.677251	 0.0	 0.0	 1	 -30.0	 30.0;
	3754	 4375	 0.00676	 0.03725	 0.05131	 419.611652	 419.611652	 419.611652	 0.0	 0.0	 1	 -30.0	 30.0;
	3754	 4320	 0.00399	 0.018091	 0.03041	 386.883547	 386.883547	 386.883547	 0.0	 0.0	 1	 -30.0	 30.0;
	6043	 4745	 0.000341	 0.00339	 0.00786	 279.441976	 279.441976	 279.441976	 0.0	 0.0	 1	 -30.0	 30.0;
	6043	 3729	 0.001271	 0.0102	 0.01646	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6043	 3729	 0.00125	 0.010401	 0.01613	 331.928346	 331.928346	 331.928346	 0.0	 0.0	 1	 -30.0	 30.0;
	4418	 460	 0.00261	 0.016651	 0.02966	 306.664653	 306.664653	 306.664653	 0.0	 0.0	 1	 -30.0	 30.0;
	8313	 460	 0.000219	 0.002409	 0.32232	 528.080537	 528.080537	 528.080537	 0.0	 0.0	 1	 -30.0	 30.0;
	6140	 6315	 0.00601	 0.02814	 0.04548	 448.899626	 448.899626	 448.899626	 0.0	 0.0	 1	 -30.0	 30.0;
	6315	 6350	 0.008969	 0.03787	 0.069	 275.352916	 275.352916	 275.352916	 0.0	 0.0	 1	 -30.0	 30.0;
	6315	 6241	 0.00232	 0.01094	 0.01765	 443.904807	 443.904807	 443.904807	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 6276	 0.00196	 0.02382	 0.66228	 1652.935057	 1652.935057	 1652.935057	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 8051	 0.00422	 0.03598	 1.10237	 1220.864036	 1220.864036	 1220.864036	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 8051	 0.0043	 0.03522	 1.12317	 1283.739905	 1283.739905	 1283.739905	 0.0	 0.0	 1	 -30.0	 30.0;
	7709	 6014	 0.00208	 0.01691	 0.55078	 1561.764059	 1561.764059	 1561.764059	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 2476	 0.00544	 0.05439	 1.29424	 1279.068149	 1279.068149	 1279.068149	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 6809	 0.00239	 0.02598	 0.60825	 1348.968108	 1348.968108	 1348.968108	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 346	 0.00396	 0.03096	 1.00098	 1731.548651	 1731.548651	 1731.548651	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 346	 0.00353	 0.03509	 0.89178	 1550.82841	 1550.82841	 1550.82841	 0.0	 0.0	 1	 -30.0	 30.0;
	3320	 8039	 0.000531	 0.003729	 0.005	 521.784809	 521.784809	 521.784809	 0.0	 0.0	 1	 -30.0	 30.0;
	3320	 8039	 0.00038	 0.0025	 0.0074	 222.734321	 222.734321	 222.734321	 0.0	 0.0	 1	 -30.0	 30.0;
	3320	 8039	 0.00039	 0.00244	 0.00755	 239.275752	 239.275752	 239.275752	 0.0	 0.0	 1	 -30.0	 30.0;
	3320	 4419	 0.00836	 0.044521	 0.07368	 411.996725	 411.996725	 411.996725	 0.0	 0.0	 1	 -30.0	 30.0;
	1475	 966	 0.00264	 0.03029	 0.63268	 1383.347445	 1383.347445	 1383.347445	 0.0	 0.0	 1	 -30.0	 30.0;
	1475	 7989	 0.00396	 0.04589	 0.96451	 787.658973	 787.658973	 787.658973	 0.0	 0.0	 1	 -30.0	 30.0;
	7749	 6049	 0.00411	 0.021729	 0.03745	 410.585311	 410.585311	 410.585311	 0.0	 0.0	 1	 -30.0	 30.0;
	7749	 6705	 0.00607	 0.0285	 0.05541	 460.164261	 460.164261	 460.164261	 0.0	 0.0	 1	 -30.0	 30.0;
	7363	 2261	 0.00075	 0.0047	 0.01387	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7631	 2261	 0.00114	 0.007969	 0.02092	 560.785778	 560.785778	 560.785778	 0.0	 0.0	 1	 -30.0	 30.0;
	2854	 2645	 0.00036	 0.00324	 0.08914	 1326.848017	 1326.848017	 1326.848017	 0.0	 0.0	 1	 -30.0	 30.0;
	2854	 8148	 0.00094	 0.00874	 0.23192	 1231.908943	 1231.908943	 1231.908943	 0.0	 0.0	 1	 -30.0	 30.0;
	2241	 8069	 0.00949	 0.05145	 0.07187	 493.945591	 493.945591	 493.945591	 0.0	 0.0	 1	 -30.0	 30.0;
	2241	 4463	 0.011719	 0.0337	 0.06488	 415.536309	 415.536309	 415.536309	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 2241	 0.0022	 0.012331	 0.0411	 436.999779	 436.999779	 436.999779	 0.0	 0.0	 1	 -30.0	 30.0;
	3810	 2037	 0.00038	 0.00448	 0.09815	 1411.457625	 1411.457625	 1411.457625	 0.0	 0.0	 1	 -30.0	 30.0;
	3810	 5327	 0.00098	 0.01126	 0.25795	 1011.50049	 1011.50049	 1011.50049	 0.0	 0.0	 1	 -30.0	 30.0;
	36	 5370	 0.00055	 0.00621	 0.13477	 1794.757559	 1794.757559	 1794.757559	 0.0	 0.0	 1	 -30.0	 30.0;
	36	 1911	 0.00163	 0.01287	 0.40301	 1713.951569	 1713.951569	 1713.951569	 0.0	 0.0	 1	 -30.0	 30.0;
	5708	 5559	 0.0018	 0.01886	 0.04523	 281.768674	 281.768674	 281.768674	 0.0	 0.0	 1	 -30.0	 30.0;
	5708	 5559	 0.0047	 0.024969	 0.03581	 249.747039	 249.747039	 249.747039	 0.0	 0.0	 1	 -30.0	 30.0;
	5708	 2410	 0.009711	 0.059669	 0.08431	 406.681061	 406.681061	 406.681061	 0.0	 0.0	 1	 -30.0	 30.0;
	5708	 4721	 0.005271	 0.03451	 0.09799	 287.615905	 287.615905	 287.615905	 0.0	 0.0	 1	 -30.0	 30.0;
	840	 1069	 0.016169	 0.11936	 0.16403	 429.229764	 429.229764	 429.229764	 0.0	 0.0	 1	 -30.0	 30.0;
	840	 1224	 0.00226	 0.014789	 0.02294	 426.345207	 426.345207	 426.345207	 0.0	 0.0	 1	 -30.0	 30.0;
	7865	 1293	 0.00151	 0.01081	 0.03097	 600.226099	 600.226099	 600.226099	 0.0	 0.0	 1	 -30.0	 30.0;
	643	 4227	 0.00228	 0.0217	 0.76722	 1823.53645	 1823.53645	 1823.53645	 0.0	 0.0	 1	 -30.0	 30.0;
	643	 3264	 0.00137	 0.01593	 0.4613	 1728.824447	 1728.824447	 1728.824447	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 3458	 0.00099	 0.0121	 0.24926	 1117.001367	 1117.001367	 1117.001367	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 2059	 0.0	 0.01881	 0.41004	 1140.861683	 1140.861683	 1140.861683	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 7034	 0.00143	 0.0163	 0.35353	 1212.850703	 1212.850703	 1212.850703	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 6606	 0.00057	 0.00562	 0.14915	 1147.06634	 1147.06634	 1147.06634	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 6606	 0.00055	 0.00572	 0.14604	 1194.533573	 1194.533573	 1194.533573	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 5893	 0.00057	 0.00658	 0.19029	 1452.426655	 1452.426655	 1452.426655	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 4878	 0.00075	 0.0082	 0.1938	 1269.038812	 1269.038812	 1269.038812	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 732	 0.00253	 0.02153	 0.62922	 1318.165974	 1318.165974	 1318.165974	 0.0	 0.0	 1	 -30.0	 30.0;
	181	 7782	 0.00236	 0.011219	 0.03658	 545.863052	 545.863052	 545.863052	 0.0	 0.0	 1	 -30.0	 30.0;
	2906	 6397	 0.00173	 0.0154	 0.43998	 1445.283435	 1445.283435	 1445.283435	 0.0	 0.0	 1	 -30.0	 30.0;
	2906	 2505	 0.00385	 0.04172	 1.00164	 1188.496753	 1188.496753	 1188.496753	 0.0	 0.0	 1	 -30.0	 30.0;
	2906	 2505	 0.00377	 0.04251	 0.98033	 1182.043963	 1182.043963	 1182.043963	 0.0	 0.0	 1	 -30.0	 30.0;
	2906	 1364	 0.00199	 0.02121	 0.5037	 1595.989383	 1595.989383	 1595.989383	 0.0	 0.0	 1	 -30.0	 30.0;
	2906	 1032	 0.00236	 0.01933	 0.6099	 1191.661279	 1191.661279	 1191.661279	 0.0	 0.0	 1	 -30.0	 30.0;
	2906	 1032	 0.00241	 0.01891	 0.62119	 1148.429429	 1148.429429	 1148.429429	 0.0	 0.0	 1	 -30.0	 30.0;
	2091	 3113	 0.000521	 0.004729	 0.15416	 230.886149	 230.886149	 230.886149	 0.0	 0.0	 1	 -30.0	 30.0;
	2091	 7776	 0.00094	 0.005581	 0.02629	 247.599434	 247.599434	 247.599434	 0.0	 0.0	 1	 -30.0	 30.0;
	4219	 991	 0.00134	 0.01324	 0.44968	 1220.657368	 1220.657368	 1220.657368	 0.0	 0.0	 1	 -30.0	 30.0;
	4219	 2580	 0.00073	 0.00638	 0.24442	 1304.544953	 1304.544953	 1304.544953	 0.0	 0.0	 1	 -30.0	 30.0;
	1326	 2229	 0.00248	 0.02774	 0.83587	 1840.12191	 1840.12191	 1840.12191	 0.0	 0.0	 1	 -30.0	 30.0;
	1326	 431	 0.00152	 0.013	 0.37644	 1600.771056	 1600.771056	 1600.771056	 0.0	 0.0	 1	 -30.0	 30.0;
	1326	 431	 0.00155	 0.01272	 0.38342	 1692.182947	 1692.182947	 1692.182947	 0.0	 0.0	 1	 -30.0	 30.0;
	1326	 7441	 0.00117	 0.01301	 0.28981	 1370.095005	 1370.095005	 1370.095005	 0.0	 0.0	 1	 -30.0	 30.0;
	1326	 2832	 0.00197	 0.02054	 0.48554	 1123.966221	 1123.966221	 1123.966221	 0.0	 0.0	 1	 -30.0	 30.0;
	1326	 8162	 0.00157	 0.01909	 0.53074	 1640.529693	 1640.529693	 1640.529693	 0.0	 0.0	 1	 -30.0	 30.0;
	2787	 4053	 0.00107	 0.008669	 0.04933	 241.059453	 241.059453	 241.059453	 0.0	 0.0	 1	 -30.0	 30.0;
	4053	 1367	 0.000469	 0.00314	 0.13255	 343.398368	 343.398368	 343.398368	 0.0	 0.0	 1	 -30.0	 30.0;
	1079	 640	 0.000409	 0.00305	 0.00769	 268.686806	 268.686806	 268.686806	 0.0	 0.0	 1	 -30.0	 30.0;
	1126	 640	 0.00569	 0.032979	 0.10568	 275.310238	 275.310238	 275.310238	 0.0	 0.0	 1	 -30.0	 30.0;
	3181	 8052	 0.00087	 0.006771	 0.01515	 529.81432	 529.81432	 529.81432	 0.0	 0.0	 1	 -30.0	 30.0;
	3181	 7782	 0.002151	 0.014039	 0.04245	 544.945481	 544.945481	 544.945481	 0.0	 0.0	 1	 -30.0	 30.0;
	5770	 6152	 9.9e-05	 0.00043	 0.04608	 555.226623	 555.226623	 555.226623	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 5770	 0.000151	 0.0005	 0.0704	 282.136008	 282.136008	 282.136008	 0.0	 0.0	 1	 -30.0	 30.0;
	7105	 7648	 0.001531	 0.00812	 0.02192	 238.365421	 238.365421	 238.365421	 0.0	 0.0	 1	 -30.0	 30.0;
	7105	 7648	 0.00113	 0.00857	 0.02074	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3874	 6525	 0.00226	 0.01868	 0.09983	 526.767434	 526.767434	 526.767434	 0.0	 0.0	 1	 -30.0	 30.0;
	3874	 4226	 0.000401	 0.00239	 0.00835	 354.091426	 354.091426	 354.091426	 0.0	 0.0	 1	 -30.0	 30.0;
	3852	 1749	 0.001169	 0.008349	 0.01269	 523.2751	 523.2751	 523.2751	 0.0	 0.0	 1	 -30.0	 30.0;
	3852	 5729	 0.00324	 0.02312	 0.03518	 540.661703	 540.661703	 540.661703	 0.0	 0.0	 1	 -30.0	 30.0;
	563	 3970	 0.006031	 0.034789	 0.05445	 498.025125	 498.025125	 498.025125	 0.0	 0.0	 1	 -30.0	 30.0;
	563	 733	 0.0103	 0.05269	 0.09313	 454.379904	 454.379904	 454.379904	 0.0	 0.0	 1	 -30.0	 30.0;
	2691	 6276	 0.00129	 0.01494	 0.43238	 1484.80776	 1484.80776	 1484.80776	 0.0	 0.0	 1	 -30.0	 30.0;
	2691	 6276	 0.00126	 0.01523	 0.42338	 1379.027156	 1379.027156	 1379.027156	 0.0	 0.0	 1	 -30.0	 30.0;
	4511	 4463	 0.001031	 0.00601	 0.01921	 279.115415	 279.115415	 279.115415	 0.0	 0.0	 1	 -30.0	 30.0;
	4511	 4463	 0.00105	 0.00588	 0.01957	 268.551152	 268.551152	 268.551152	 0.0	 0.0	 1	 -30.0	 30.0;
	2394	 5284	 0.00197	 0.01719	 0.47473	 1133.387399	 1133.387399	 1133.387399	 0.0	 0.0	 1	 -30.0	 30.0;
	2394	 1779	 0.00114	 0.01237	 0.27421	 1411.597159	 1411.597159	 1411.597159	 0.0	 0.0	 1	 -30.0	 30.0;
	2394	 3614	 0.00314	 0.02868	 0.77451	 1377.591667	 1377.591667	 1377.591667	 0.0	 0.0	 1	 -30.0	 30.0;
	2394	 980	 0.00294	 0.03326	 0.73614	 1239.360849	 1239.360849	 1239.360849	 0.0	 0.0	 1	 -30.0	 30.0;
	2394	 980	 0.00288	 0.0308	 0.72013	 1462.334228	 1462.334228	 1462.334228	 0.0	 0.0	 1	 -30.0	 30.0;
	2394	 732	 0.00088	 0.02821	 0.22351	 1098.765193	 1098.765193	 1098.765193	 0.0	 0.0	 1	 -30.0	 30.0;
	3794	 6039	 0.00152	 0.01702	 0.34786	 907.228433	 907.228433	 907.228433	 0.0	 0.0	 1	 -30.0	 30.0;
	3794	 6620	 0.00022	 0.00209	 0.05191	 1494.501425	 1494.501425	 1494.501425	 0.0	 0.0	 1	 -30.0	 30.0;
	1641	 2418	 0.00087	 0.005	 0.01298	 231.698931	 231.698931	 231.698931	 0.0	 0.0	 1	 -30.0	 30.0;
	1641	 7558	 0.000711	 0.00439	 0.01507	 396.13547	 396.13547	 396.13547	 0.0	 0.0	 1	 -30.0	 30.0;
	1641	 7558	 0.000729	 0.004289	 0.01534	 425.649026	 425.649026	 425.649026	 0.0	 0.0	 1	 -30.0	 30.0;
	4237	 5845	 0.001031	 0.00549	 0.00924	 275.158961	 275.158961	 275.158961	 0.0	 0.0	 1	 -30.0	 30.0;
	4237	 470	 0.003219	 0.01512	 0.02444	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4237	 539	 0.007271	 0.031419	 0.05502	 393.023806	 393.023806	 393.023806	 0.0	 0.0	 1	 -30.0	 30.0;
	4237	 2991	 0.02145	 0.085781	 0.16269	 450.429547	 450.429547	 450.429547	 0.0	 0.0	 1	 -30.0	 30.0;
	5569	 6805	 0.002841	 0.017771	 0.05254	 323.893501	 323.893501	 323.893501	 0.0	 0.0	 1	 -30.0	 30.0;
	5569	 2625	 0.003331	 0.017289	 0.03022	 415.082858	 415.082858	 415.082858	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 2129	 0.01524	 0.064091	 0.19686	 521.149597	 521.149597	 521.149597	 0.0	 0.0	 1	 -30.0	 30.0;
	7737	 4657	 0.000831	 0.0052	 0.00706	 530.941469	 530.941469	 530.941469	 0.0	 0.0	 1	 -30.0	 30.0;
	4657	 8208	 0.00164	 0.0103	 0.01431	 506.032153	 506.032153	 506.032153	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 3859	 0.00139	 0.00864	 0.00902	 396.870136	 396.870136	 396.870136	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 1284	 0.00143	 0.00764	 0.01541	 443.547381	 443.547381	 443.547381	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 5257	 0.000229	 0.00126	 0.00264	 260.694258	 260.694258	 260.694258	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 5257	 0.000211	 0.00143	 0.00235	 285.532698	 285.532698	 285.532698	 0.0	 0.0	 1	 -30.0	 30.0;
	886	 1413	 0.0008	 0.01072	 0.30217	 1553.3986	 1553.3986	 1553.3986	 0.0	 0.0	 1	 -30.0	 30.0;
	886	 4186	 0.00067	 0.00661	 0.22487	 1122.389881	 1122.389881	 1122.389881	 0.0	 0.0	 1	 -30.0	 30.0;
	886	 2536	 0.0003	 0.00427	 0.11118	 1394.018507	 1394.018507	 1394.018507	 0.0	 0.0	 1	 -30.0	 30.0;
	886	 2536	 0.00068	 0.00648	 0.22919	 1374.574573	 1374.574573	 1374.574573	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 7420	 0.0002	 0.001289	 0.14894	 271.333588	 271.333588	 271.333588	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 3653	 0.00013	 0.000961	 0.10653	 544.066396	 544.066396	 544.066396	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 2037	 0.00118	 0.01285	 0.28304	 1640.016972	 1640.016972	 1640.016972	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 4764	 0.00062	 0.00577	 0.14292	 1100.858203	 1100.858203	 1100.858203	 0.0	 0.0	 1	 -30.0	 30.0;
	8364	 1282	 9.1e-05	 0.000289	 0.03828	 334.969135	 334.969135	 334.969135	 0.0	 0.0	 1	 -30.0	 30.0;
	8364	 1282	 9.1e-05	 0.000271	 0.03745	 299.933384	 299.933384	 299.933384	 0.0	 0.0	 1	 -30.0	 30.0;
	8364	 5982	 0.0003	 0.002719	 0.34533	 487.052756	 487.052756	 487.052756	 0.0	 0.0	 1	 -30.0	 30.0;
	8364	 6202	 0.00049	 0.002091	 0.17448	 319.205809	 319.205809	 319.205809	 0.0	 0.0	 1	 -30.0	 30.0;
	8364	 12	 0.000159	 0.001461	 0.13821	 579.635618	 579.635618	 579.635618	 0.0	 0.0	 1	 -30.0	 30.0;
	386	 5564	 0.00301	 0.02281	 0.05603	 232.182104	 232.182104	 232.182104	 0.0	 0.0	 1	 -30.0	 30.0;
	6040	 5564	 0.0027	 0.019979	 0.05034	 250.625362	 250.625362	 250.625362	 0.0	 0.0	 1	 -30.0	 30.0;
	1310	 587	 0.00019	 0.000539	 0.055	 229.073488	 229.073488	 229.073488	 0.0	 0.0	 1	 -30.0	 30.0;
	587	 6202	 0.000169	 0.00061	 0.049	 517.135604	 517.135604	 517.135604	 0.0	 0.0	 1	 -30.0	 30.0;
	7629	 4930	 0.00163	 0.00939	 0.01781	 552.361118	 552.361118	 552.361118	 0.0	 0.0	 1	 -30.0	 30.0;
	7629	 4930	 0.001159	 0.009031	 0.02067	 528.054244	 528.054244	 528.054244	 0.0	 0.0	 1	 -30.0	 30.0;
	7629	 3697	 9.9e-05	 0.00037	 0.00051	 467.917509	 467.917509	 467.917509	 0.0	 0.0	 1	 -30.0	 30.0;
	5095	 8223	 0.003789	 0.01805	 0.05793	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5095	 1338	 0.00069	 0.00389	 0.01067	 225.31518	 225.31518	 225.31518	 0.0	 0.0	 1	 -30.0	 30.0;
	7608	 7192	 0.00201	 0.01845	 0.41995	 1284.093348	 1284.093348	 1284.093348	 0.0	 0.0	 1	 -30.0	 30.0;
	7989	 7192	 0.00121	 0.00902	 0.25097	 1294.085168	 1294.085168	 1294.085168	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 1779	 0.00155	 0.01573	 0.37795	 1303.37866	 1303.37866	 1303.37866	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 7557	 0.00031	 0.00274	 0.0767	 1345.985897	 1345.985897	 1345.985897	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 3614	 0.00047	 0.00563	 0.1564	 1214.88711	 1214.88711	 1214.88711	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 3223	 0.00066	 0.00721	 0.15865	 1161.864843	 1161.864843	 1161.864843	 0.0	 0.0	 1	 -30.0	 30.0;
	6811	 4372	 0.00326	 0.016711	 0.04153	 332.537647	 332.537647	 332.537647	 0.0	 0.0	 1	 -30.0	 30.0;
	6811	 2636	 0.002479	 0.01262	 0.1157	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	6811	 2636	 0.00243	 0.01286	 0.11329	 628.504669	 628.504669	 628.504669	 0.0	 0.0	 1	 -30.0	 30.0;
	6811	 3950	 0.004521	 0.02306	 0.04906	 476.590615	 476.590615	 476.590615	 0.0	 0.0	 1	 -30.0	 30.0;
	6811	 1167	 0.00211	 0.00899	 0.02802	 280.898735	 280.898735	 280.898735	 0.0	 0.0	 1	 -30.0	 30.0;
	6811	 7069	 0.001289	 0.005651	 0.01662	 560.047682	 560.047682	 560.047682	 0.0	 0.0	 1	 -30.0	 30.0;
	6811	 3073	 0.002479	 0.009021	 0.03307	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6811	 5858	 0.00151	 0.010521	 0.01515	 425.594536	 425.594536	 425.594536	 0.0	 0.0	 1	 -30.0	 30.0;
	4912	 7570	 0.00101	 0.004151	 0.01376	 453.739738	 453.739738	 453.739738	 0.0	 0.0	 1	 -30.0	 30.0;
	4912	 722	 0.015599	 0.079	 0.13566	 388.324301	 388.324301	 388.324301	 0.0	 0.0	 1	 -30.0	 30.0;
	4912	 7438	 0.013961	 0.067591	 0.12195	 464.507482	 464.507482	 464.507482	 0.0	 0.0	 1	 -30.0	 30.0;
	4912	 1127	 0.007099	 0.043169	 0.06179	 522.093842	 522.093842	 522.093842	 0.0	 0.0	 1	 -30.0	 30.0;
	2192	 4585	 0.00317	 0.02987	 0.7558	 993.356461	 993.356461	 993.356461	 0.0	 0.0	 1	 -30.0	 30.0;
	2192	 2505	 0.00081	 0.0088	 0.23188	 1133.532199	 1133.532199	 1133.532199	 0.0	 0.0	 1	 -30.0	 30.0;
	2192	 2505	 0.00098	 0.00961	 0.23348	 994.489845	 994.489845	 994.489845	 0.0	 0.0	 1	 -30.0	 30.0;
	2192	 159	 0.00194	 0.02225	 0.55539	 927.67214	 927.67214	 927.67214	 0.0	 0.0	 1	 -30.0	 30.0;
	8173	 4957	 0.001031	 0.006349	 0.01018	 360.673323	 360.673323	 360.673323	 0.0	 0.0	 1	 -30.0	 30.0;
	8173	 401	 0.00668	 0.0297	 0.09857	 569.022962	 569.022962	 569.022962	 0.0	 0.0	 1	 -30.0	 30.0;
	4375	 2297	 0.00439	 0.02236	 0.03336	 545.187829	 545.187829	 545.187829	 0.0	 0.0	 1	 -30.0	 30.0;
	2297	 5804	 0.00249	 0.01349	 0.01885	 592.266321	 592.266321	 592.266321	 0.0	 0.0	 1	 -30.0	 30.0;
	1899	 4145	 0.001969	 0.01205	 0.03173	 499.681555	 499.681555	 499.681555	 0.0	 0.0	 1	 -30.0	 30.0;
	1899	 4178	 0.000461	 0.003031	 0.01045	 575.218854	 575.218854	 575.218854	 0.0	 0.0	 1	 -30.0	 30.0;
	3267	 242	 0.00444	 0.023479	 0.03367	 454.188617	 454.188617	 454.188617	 0.0	 0.0	 1	 -30.0	 30.0;
	3267	 4209	 0.00175	 0.01288	 0.03245	 235.205364	 235.205364	 235.205364	 0.0	 0.0	 1	 -30.0	 30.0;
	3267	 4209	 0.001711	 0.01312	 0.03177	 291.322771	 291.322771	 291.322771	 0.0	 0.0	 1	 -30.0	 30.0;
	1413	 524	 0.0008	 0.00784	 0.18031	 1496.474647	 1496.474647	 1496.474647	 0.0	 0.0	 1	 -30.0	 30.0;
	1413	 8272	 0.00051	 0.00612	 0.11615	 1412.402113	 1412.402113	 1412.402113	 0.0	 0.0	 1	 -30.0	 30.0;
	2984	 6481	 0.00137	 0.00905	 0.02867	 347.408931	 347.408931	 347.408931	 0.0	 0.0	 1	 -30.0	 30.0;
	2984	 4418	 0.002771	 0.021409	 0.05787	 383.130193	 383.130193	 383.130193	 0.0	 0.0	 1	 -30.0	 30.0;
	2984	 4418	 0.00314	 0.020979	 0.06559	 328.130028	 328.130028	 328.130028	 0.0	 0.0	 1	 -30.0	 30.0;
	2984	 3728	 0.002	 0.01118	 0.04113	 345.462903	 345.462903	 345.462903	 0.0	 0.0	 1	 -30.0	 30.0;
	7511	 634	 0.00119	 0.00875	 0.02203	 374.989797	 374.989797	 374.989797	 0.0	 0.0	 1	 -30.0	 30.0;
	7511	 6244	 0.00031	 0.00236	 0.00669	 291.562071	 291.562071	 291.562071	 0.0	 0.0	 1	 -30.0	 30.0;
	7511	 7092	 0.000831	 0.00539	 0.01782	 224.679206	 224.679206	 224.679206	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 6664	 0.004349	 0.02394	 0.03297	 425.183763	 425.183763	 425.183763	 0.0	 0.0	 1	 -30.0	 30.0;
	1092	 7920	 0.0007	 0.00782	 0.23545	 1701.691005	 1701.691005	 1701.691005	 0.0	 0.0	 1	 -30.0	 30.0;
	1092	 1566	 0.00046	 0.00432	 0.15278	 1870.556779	 1870.556779	 1870.556779	 0.0	 0.0	 1	 -30.0	 30.0;
	1092	 2789	 0.00049	 0.00617	 0.16468	 1697.470101	 1697.470101	 1697.470101	 0.0	 0.0	 1	 -30.0	 30.0;
	1092	 980	 0.00127	 0.01514	 0.42707	 1789.232144	 1789.232144	 1789.232144	 0.0	 0.0	 1	 -30.0	 30.0;
	3228	 5935	 0.00232	 0.01843	 0.02524	 295.997506	 295.997506	 295.997506	 0.0	 0.0	 1	 -30.0	 30.0;
	3228	 1369	 0.00488	 0.032151	 0.05298	 564.130264	 564.130264	 564.130264	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 3379	 0.000229	 0.00136	 0.08924	 537.758093	 537.758093	 537.758093	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 6202	 0.0003	 0.001531	 0.16504	 494.459248	 494.459248	 494.459248	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 5345	 0.00026	 0.00126	 0.09112	 410.118524	 410.118524	 410.118524	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 5395	 0.00056	 0.002091	 0.18673	 565.11452	 565.11452	 565.11452	 0.0	 0.0	 1	 -30.0	 30.0;
	4014	 2691	 0.00103	 0.0093	 0.25567	 1711.30503	 1711.30503	 1711.30503	 0.0	 0.0	 1	 -30.0	 30.0;
	4014	 2212	 0.00183	 0.01689	 0.43755	 1331.82122	 1331.82122	 1331.82122	 0.0	 0.0	 1	 -30.0	 30.0;
	6402	 4695	 0.00324	 0.01095	 0.01848	 865.03952	 865.03952	 865.03952	 0.0	 0.0	 1	 -30.0	 30.0;
	214	 7465	 0.001419	 0.008539	 0.01475	 280.336684	 280.336684	 280.336684	 0.0	 0.0	 1	 -30.0	 30.0;
	214	 3113	 0.00068	 0.00438	 0.00621	 501.543752	 501.543752	 501.543752	 0.0	 0.0	 1	 -30.0	 30.0;
	2645	 5338	 0.00178	 0.01651	 0.53234	 1310.379055	 1310.379055	 1310.379055	 0.0	 0.0	 1	 -30.0	 30.0;
	2645	 3928	 0.00151	 0.01827	 0.50815	 1261.866633	 1261.866633	 1261.866633	 0.0	 0.0	 1	 -30.0	 30.0;
	2645	 3928	 0.00148	 0.01862	 0.49734	 1320.937567	 1320.937567	 1320.937567	 0.0	 0.0	 1	 -30.0	 30.0;
	2691	 2212	 0.00201	 0.02546	 0.67956	 1598.223902	 1598.223902	 1598.223902	 0.0	 0.0	 1	 -30.0	 30.0;
	2691	 2212	 0.00197	 0.02357	 0.66478	 1550.670447	 1550.670447	 1550.670447	 0.0	 0.0	 1	 -30.0	 30.0;
	3411	 3113	 0.001091	 0.00775	 0.02176	 270.851177	 270.851177	 270.851177	 0.0	 0.0	 1	 -30.0	 30.0;
	3411	 897	 0.000841	 0.006669	 0.01656	 280.543976	 280.543976	 280.543976	 0.0	 0.0	 1	 -30.0	 30.0;
	843	 3392	 0.00151	 0.012081	 0.08385	 515.463932	 515.463932	 515.463932	 0.0	 0.0	 1	 -30.0	 30.0;
	843	 6766	 0.00032	 0.002521	 0.01816	 439.371823	 439.371823	 439.371823	 0.0	 0.0	 1	 -30.0	 30.0;
	7334	 3035	 0.006091	 0.03019	 0.08771	 520.546393	 520.546393	 520.546393	 0.0	 0.0	 1	 -30.0	 30.0;
	7334	 6948	 0.003651	 0.016461	 0.02768	 554.305622	 554.305622	 554.305622	 0.0	 0.0	 1	 -30.0	 30.0;
	7334	 3028	 0.00076	 0.00425	 0.00591	 396.585491	 396.585491	 396.585491	 0.0	 0.0	 1	 -30.0	 30.0;
	7334	 3028	 0.00087	 0.004031	 0.00652	 352.690682	 352.690682	 352.690682	 0.0	 0.0	 1	 -30.0	 30.0;
	1494	 3392	 0.000651	 0.004729	 0.03372	 592.728155	 592.728155	 592.728155	 0.0	 0.0	 1	 -30.0	 30.0;
	1494	 8113	 0.00045	 0.00337	 0.05643	 524.480746	 524.480746	 524.480746	 0.0	 0.0	 1	 -30.0	 30.0;
	2636	 435	 0.001539	 0.00839	 0.09999	 454.016762	 454.016762	 454.016762	 0.0	 0.0	 1	 -30.0	 30.0;
	2636	 435	 0.001919	 0.010479	 0.1012	 522.023347	 522.023347	 522.023347	 0.0	 0.0	 1	 -30.0	 30.0;
	435	 8225	 0.001169	 0.007031	 0.00292	 445.141699	 445.141699	 445.141699	 0.0	 0.0	 1	 -30.0	 30.0;
	1732	 435	 0.00739	 0.034081	 0.09433	 320.036882	 320.036882	 320.036882	 0.0	 0.0	 1	 -30.0	 30.0;
	4450	 435	 0.00164	 0.00964	 0.01325	 433.618331	 433.618331	 433.618331	 0.0	 0.0	 1	 -30.0	 30.0;
	5343	 435	 0.00206	 0.012	 0.02872	 458.67054	 458.67054	 458.67054	 0.0	 0.0	 1	 -30.0	 30.0;
	4896	 435	 0.000961	 0.00531	 0.00828	 469.937462	 469.937462	 469.937462	 0.0	 0.0	 1	 -30.0	 30.0;
	3223	 6142	 6e-05	 0.00029	 0.00673	 1012.392981	 1012.392981	 1012.392981	 0.0	 0.0	 1	 -30.0	 30.0;
	1224	 4372	 0.001919	 0.013151	 0.0196	 383.256321	 383.256321	 383.256321	 0.0	 0.0	 1	 -30.0	 30.0;
	785	 4372	 0.00019	 0.00107	 0.00179	 416.157423	 416.157423	 416.157423	 0.0	 0.0	 1	 -30.0	 30.0;
	785	 4372	 0.00018	 0.001091	 0.00176	 442.898451	 442.898451	 442.898451	 0.0	 0.0	 1	 -30.0	 30.0;
	5160	 2229	 0.00147	 0.01714	 0.49579	 1539.399785	 1539.399785	 1539.399785	 0.0	 0.0	 1	 -30.0	 30.0;
	2476	 2229	 0.00143	 0.01632	 0.35893	 1297.656449	 1297.656449	 1297.656449	 0.0	 0.0	 1	 -30.0	 30.0;
	2476	 2229	 0.00142	 0.01416	 0.481	 1601.295625	 1601.295625	 1601.295625	 0.0	 0.0	 1	 -30.0	 30.0;
	2476	 2229	 0.00145	 0.01386	 0.49025	 1748.929192	 1748.929192	 1748.929192	 0.0	 0.0	 1	 -30.0	 30.0;
	2229	 8162	 0.00073	 0.00732	 0.25771	 1625.286919	 1625.286919	 1625.286919	 0.0	 0.0	 1	 -30.0	 30.0;
	1079	 1126	 0.009039	 0.05989	 0.08228	 479.598633	 479.598633	 479.598633	 0.0	 0.0	 1	 -30.0	 30.0;
	1079	 3658	 0.007919	 0.04975	 0.07193	 461.392389	 461.392389	 461.392389	 0.0	 0.0	 1	 -30.0	 30.0;
	2418	 891	 0.000521	 0.005841	 0.00779	 460.199318	 460.199318	 460.199318	 0.0	 0.0	 1	 -30.0	 30.0;
	2418	 5755	 0.000521	 0.0028	 0.00351	 329.938878	 329.938878	 329.938878	 0.0	 0.0	 1	 -30.0	 30.0;
	5952	 980	 0.0007	 0.00744	 0.16018	 900.669676	 900.669676	 900.669676	 0.0	 0.0	 1	 -30.0	 30.0;
	5952	 3668	 0.00159	 0.0148	 0.40712	 938.482736	 938.482736	 938.482736	 0.0	 0.0	 1	 -30.0	 30.0;
	3948	 3870	 0.000659	 0.005151	 0.01925	 564.699936	 564.699936	 564.699936	 0.0	 0.0	 1	 -30.0	 30.0;
	6525	 3870	 0.000729	 0.004901	 0.02146	 433.452574	 433.452574	 433.452574	 0.0	 0.0	 1	 -30.0	 30.0;
	4186	 581	 0.00064	 0.00772	 0.21455	 1139.208337	 1139.208337	 1139.208337	 0.0	 0.0	 1	 -30.0	 30.0;
	6870	 5612	 0.00018	 0.00093	 0.14315	 609.151842	 609.151842	 609.151842	 0.0	 0.0	 1	 -30.0	 30.0;
	6870	 7420	 0.00019	 0.00118	 0.14931	 509.798844	 509.798844	 509.798844	 0.0	 0.0	 1	 -30.0	 30.0;
	6719	 6870	 0.000409	 0.002341	 0.00783	 529.028211	 529.028211	 529.028211	 0.0	 0.0	 1	 -30.0	 30.0;
	7908	 932	 0.00087	 0.006591	 0.01868	 384.244387	 384.244387	 384.244387	 0.0	 0.0	 1	 -30.0	 30.0;
	7908	 2786	 0.00162	 0.0098	 0.03017	 263.343707	 263.343707	 263.343707	 0.0	 0.0	 1	 -30.0	 30.0;
	6809	 6397	 0.00096	 0.00849	 0.24256	 1564.651492	 1564.651492	 1564.651492	 0.0	 0.0	 1	 -30.0	 30.0;
	5609	 6287	 0.000341	 0.001081	 0.1269	 499.523037	 499.523037	 499.523037	 0.0	 0.0	 1	 -30.0	 30.0;
	5609	 6287	 0.0003	 0.001219	 0.11305	 527.175159	 527.175159	 527.175159	 0.0	 0.0	 1	 -30.0	 30.0;
	5609	 7319	 9.9e-05	 0.00076	 0.1008	 536.780316	 536.780316	 536.780316	 0.0	 0.0	 1	 -30.0	 30.0;
	5609	 7319	 0.00011	 0.00074	 0.10274	 566.819343	 566.819343	 566.819343	 0.0	 0.0	 1	 -30.0	 30.0;
	1460	 4418	 0.00151	 0.009039	 0.03189	 233.43881	 233.43881	 233.43881	 0.0	 0.0	 1	 -30.0	 30.0;
	1460	 2309	 0.00356	 0.02331	 0.06623	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7255	 1310	 0.000281	 0.00169	 0.00071	 359.038613	 359.038613	 359.038613	 0.0	 0.0	 1	 -30.0	 30.0;
	7255	 5982	 0.000169	 0.001531	 0.18247	 496.990571	 496.990571	 496.990571	 0.0	 0.0	 1	 -30.0	 30.0;
	7255	 7855	 0.00038	 0.00326	 0.01039	 220.978056	 220.978056	 220.978056	 0.0	 0.0	 1	 -30.0	 30.0;
	991	 6579	 0.00136	 0.01738	 0.33629	 1481.647841	 1481.647841	 1481.647841	 0.0	 0.0	 1	 -30.0	 30.0;
	5845	 470	 0.00186	 0.0133	 0.03487	 239.331386	 239.331386	 239.331386	 0.0	 0.0	 1	 -30.0	 30.0;
	5845	 470	 0.00182	 0.01356	 0.03416	 237.353349	 237.353349	 237.353349	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 5845	 0.002531	 0.015919	 0.02317	 551.810499	 551.810499	 551.810499	 0.0	 0.0	 1	 -30.0	 30.0;
	5845	 6121	 0.00289	 0.015969	 0.02583	 432.357051	 432.357051	 432.357051	 0.0	 0.0	 1	 -30.0	 30.0;
	1022	 4501	 0.001771	 0.01107	 0.01897	 415.513065	 415.513065	 415.513065	 0.0	 0.0	 1	 -30.0	 30.0;
	3829	 4501	 0.007969	 0.04238	 0.08525	 347.066366	 347.066366	 347.066366	 0.0	 0.0	 1	 -30.0	 30.0;
	2636	 6520	 0.00013	 0.00062	 0.06807	 505.315015	 505.315015	 505.315015	 0.0	 0.0	 1	 -30.0	 30.0;
	2636	 259	 0.0002	 0.00201	 0.19656	 579.571601	 579.571601	 579.571601	 0.0	 0.0	 1	 -30.0	 30.0;
	431	 8310	 0.00095	 0.01024	 0.2367	 1351.873311	 1351.873311	 1351.873311	 0.0	 0.0	 1	 -30.0	 30.0;
	1032	 8310	 0.00553	 0.04909	 1.38635	 1177.010865	 1177.010865	 1177.010865	 0.0	 0.0	 1	 -30.0	 30.0;
	2891	 5895	 0.009229	 0.03693	 0.07005	 446.296666	 446.296666	 446.296666	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 5895	 0.00451	 0.028469	 0.04079	 446.228838	 446.228838	 446.228838	 0.0	 0.0	 1	 -30.0	 30.0;
	5895	 5480	 0.003591	 0.01906	 0.02731	 403.755731	 403.755731	 403.755731	 0.0	 0.0	 1	 -30.0	 30.0;
	5895	 6705	 0.010159	 0.05169	 0.07711	 504.306754	 504.306754	 504.306754	 0.0	 0.0	 1	 -30.0	 30.0;
	65	 1938	 0.00039	 0.003099	 0.00829	 272.166185	 272.166185	 272.166185	 0.0	 0.0	 1	 -30.0	 30.0;
	65	 6231	 0.000729	 0.0048	 0.01515	 237.396789	 237.396789	 237.396789	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 6039	 0.00141	 0.01296	 0.32383	 929.505828	 929.505828	 929.505828	 0.0	 0.0	 1	 -30.0	 30.0;
	3340	 6118	 0.001969	 0.019229	 0.04229	 232.39092	 232.39092	 232.39092	 0.0	 0.0	 1	 -30.0	 30.0;
	3340	 8128	 0.001081	 0.0105	 0.02346	 282.234319	 282.234319	 282.234319	 0.0	 0.0	 1	 -30.0	 30.0;
	3340	 8128	 0.00105	 0.010711	 0.02297	 277.90291	 277.90291	 277.90291	 0.0	 0.0	 1	 -30.0	 30.0;
	5160	 2580	 0.00052	 0.00449	 0.17173	 1431.61305	 1431.61305	 1431.61305	 0.0	 0.0	 1	 -30.0	 30.0;
	3070	 5804	 0.01024	 0.056349	 0.07757	 484.295089	 484.295089	 484.295089	 0.0	 0.0	 1	 -30.0	 30.0;
	3070	 1385	 0.004599	 0.023659	 0.03518	 436.221672	 436.221672	 436.221672	 0.0	 0.0	 1	 -30.0	 30.0;
	3070	 2939	 0.010021	 0.057409	 0.07592	 443.838123	 443.838123	 443.838123	 0.0	 0.0	 1	 -30.0	 30.0;
	3070	 2991	 0.00275	 0.01525	 0.05088	 464.671334	 464.671334	 464.671334	 0.0	 0.0	 1	 -30.0	 30.0;
	628	 7469	 0.00107	 0.01122	 0.25633	 1562.137247	 1562.137247	 1562.137247	 0.0	 0.0	 1	 -30.0	 30.0;
	628	 5338	 0.00242	 0.02336	 0.60162	 1231.35344	 1231.35344	 1231.35344	 0.0	 0.0	 1	 -30.0	 30.0;
	628	 3264	 0.00165	 0.01303	 0.39323	 844.215663	 844.215663	 844.215663	 0.0	 0.0	 1	 -30.0	 30.0;
	628	 3264	 0.00155	 0.01332	 0.38611	 861.21775	 861.21775	 861.21775	 0.0	 0.0	 1	 -30.0	 30.0;
	6342	 5417	 0.00087	 0.005469	 0.00731	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6342	 5417	 0.002281	 0.011909	 0.01965	 229.463303	 229.463303	 229.463303	 0.0	 0.0	 1	 -30.0	 30.0;
	6342	 880	 0.00106	 0.01076	 0.14261	 333.020439	 333.020439	 333.020439	 0.0	 0.0	 1	 -30.0	 30.0;
	6342	 4859	 0.001409	 0.01618	 0.03782	 391.637923	 391.637923	 391.637923	 0.0	 0.0	 1	 -30.0	 30.0;
	6342	 1746	 0.00306	 0.015521	 0.02667	 470.700326	 470.700326	 470.700326	 0.0	 0.0	 1	 -30.0	 30.0;
	3498	 7737	 0.000969	 0.006831	 0.00834	 440.21204	 440.21204	 440.21204	 0.0	 0.0	 1	 -30.0	 30.0;
	3498	 8208	 0.002531	 0.016961	 0.02191	 552.437709	 552.437709	 552.437709	 0.0	 0.0	 1	 -30.0	 30.0;
	930	 234	 0.01207	 0.077901	 0.10557	 380.141609	 380.141609	 380.141609	 0.0	 0.0	 1	 -30.0	 30.0;
	930	 6291	 0.014091	 0.080581	 0.10654	 509.480286	 509.480286	 509.480286	 0.0	 0.0	 1	 -30.0	 30.0;
	930	 2676	 0.003289	 0.01481	 0.02492	 228.918019	 228.918019	 228.918019	 0.0	 0.0	 1	 -30.0	 30.0;
	930	 152	 0.003349	 0.0145	 0.0254	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7374	 3452	 0.005651	 0.026479	 0.04281	 435.338396	 435.338396	 435.338396	 0.0	 0.0	 1	 -30.0	 30.0;
	7374	 6948	 0.01193	 0.064669	 0.09039	 462.495532	 462.495532	 462.495532	 0.0	 0.0	 1	 -30.0	 30.0;
	6049	 4649	 0.004151	 0.017281	 0.03148	 433.09248	 433.09248	 433.09248	 0.0	 0.0	 1	 -30.0	 30.0;
	5002	 6481	 0.00213	 0.014091	 0.04461	 293.088562	 293.088562	 293.088562	 0.0	 0.0	 1	 -30.0	 30.0;
	3950	 1732	 0.00113	 0.00651	 0.01228	 420.163033	 420.163033	 420.163033	 0.0	 0.0	 1	 -30.0	 30.0;
	3950	 1732	 0.001159	 0.00637	 0.01252	 433.125632	 433.125632	 433.125632	 0.0	 0.0	 1	 -30.0	 30.0;
	3950	 5858	 0.00611	 0.03288	 0.06521	 474.686503	 474.686503	 474.686503	 0.0	 0.0	 1	 -30.0	 30.0;
	8121	 768	 0.00012	 0.00156	 0.05752	 1755.048944	 1755.048944	 1755.048944	 0.0	 0.0	 1	 -30.0	 30.0;
	8121	 768	 0.00013	 0.00153	 0.05863	 1662.162731	 1662.162731	 1662.162731	 0.0	 0.0	 1	 -30.0	 30.0;
	8121	 6139	 0.00285	 0.03071	 0.85138	 1674.989329	 1674.989329	 1674.989329	 0.0	 0.0	 1	 -30.0	 30.0;
	5417	 2625	 0.00676	 0.03787	 0.06371	 505.78066	 505.78066	 505.78066	 0.0	 0.0	 1	 -30.0	 30.0;
	5417	 8218	 0.004461	 0.023521	 0.03676	 449.469679	 449.469679	 449.469679	 0.0	 0.0	 1	 -30.0	 30.0;
	4845	 560	 0.00064	 0.0078	 0.24608	 1522.330562	 1522.330562	 1522.330562	 0.0	 0.0	 1	 -30.0	 30.0;
	4845	 560	 0.00065	 0.00764	 0.25072	 1528.911697	 1528.911697	 1528.911697	 0.0	 0.0	 1	 -30.0	 30.0;
	4845	 524	 0.00066	 0.00602	 0.1499	 1495.424192	 1495.424192	 1495.424192	 0.0	 0.0	 1	 -30.0	 30.0;
	4845	 4046	 0.00149	 0.01224	 0.42885	 902.087394	 902.087394	 902.087394	 0.0	 0.0	 1	 -30.0	 30.0;
	4845	 738	 0.00061	 0.00582	 0.13992	 1025.751388	 1025.751388	 1025.751388	 0.0	 0.0	 1	 -30.0	 30.0;
	3305	 6263	 0.001461	 0.00744	 0.02186	 378.383438	 378.383438	 378.383438	 0.0	 0.0	 1	 -30.0	 30.0;
	3305	 7092	 0.00386	 0.02406	 0.07282	 232.859994	 232.859994	 232.859994	 0.0	 0.0	 1	 -30.0	 30.0;
	3305	 6926	 0.00306	 0.01555	 0.04616	 275.626891	 275.626891	 275.626891	 0.0	 0.0	 1	 -30.0	 30.0;
	3305	 6926	 0.003	 0.01586	 0.04522	 296.858301	 296.858301	 296.858301	 0.0	 0.0	 1	 -30.0	 30.0;
	3301	 3742	 0.003271	 0.020651	 0.06106	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3742	 6924	 0.000849	 0.00657	 0.01589	 376.103228	 376.103228	 376.103228	 0.0	 0.0	 1	 -30.0	 30.0;
	1499	 2788	 0.000211	 0.001169	 0.00392	 486.514712	 486.514712	 486.514712	 0.0	 0.0	 1	 -30.0	 30.0;
	1499	 7234	 0.000469	 0.00345	 0.00849	 510.64554	 510.64554	 510.64554	 0.0	 0.0	 1	 -30.0	 30.0;
	4499	 6809	 0.00126	 0.0145	 0.28823	 1398.233487	 1398.233487	 1398.233487	 0.0	 0.0	 1	 -30.0	 30.0;
	1788	 5381	 0.008219	 0.04925	 0.0708	 376.625649	 376.625649	 376.625649	 0.0	 0.0	 1	 -30.0	 30.0;
	1788	 1618	 0.006771	 0.04132	 0.07479	 455.994418	 455.994418	 455.994418	 0.0	 0.0	 1	 -30.0	 30.0;
	6723	 6896	 0.000841	 0.004539	 0.02502	 591.415053	 591.415053	 591.415053	 0.0	 0.0	 1	 -30.0	 30.0;
	6723	 3452	 0.00701	 0.03161	 0.05314	 493.349246	 493.349246	 493.349246	 0.0	 0.0	 1	 -30.0	 30.0;
	6723	 6241	 0.000781	 0.004271	 0.00588	 581.766075	 581.766075	 581.766075	 0.0	 0.0	 1	 -30.0	 30.0;
	6723	 873	 0.00049	 0.0032	 0.00908	 551.849366	 551.849366	 551.849366	 0.0	 0.0	 1	 -30.0	 30.0;
	3170	 3470	 0.000331	 0.00199	 0.13889	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	1227	 3470	 0.00032	 0.002031	 0.13594	 628.950118	 628.950118	 628.950118	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 4991	 9.1e-05	 0.00057	 0.08911	 485.353268	 485.353268	 485.353268	 0.0	 0.0	 1	 -30.0	 30.0;
	3692	 785	 0.001651	 0.006789	 0.02229	 540.013154	 540.013154	 540.013154	 0.0	 0.0	 1	 -30.0	 30.0;
	3692	 3073	 0.001461	 0.007229	 0.01944	 315.337378	 315.337378	 315.337378	 0.0	 0.0	 1	 -30.0	 30.0;
	7570	 8218	 0.00437	 0.023979	 0.03915	 456.340794	 456.340794	 456.340794	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 427	 0.00781	 0.04595	 0.05746	 432.948443	 432.948443	 432.948443	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 5665	 0.0015	 0.006531	 0.01533	 471.637331	 471.637331	 471.637331	 0.0	 0.0	 1	 -30.0	 30.0;
	5233	 8225	 0.001031	 0.006469	 0.00259	 365.281375	 365.281375	 365.281375	 0.0	 0.0	 1	 -30.0	 30.0;
	2536	 2784	 0.00183	 0.01686	 0.51302	 1150.604053	 1150.604053	 1150.604053	 0.0	 0.0	 1	 -30.0	 30.0;
	2536	 560	 0.0002	 0.00294	 0.08665	 1520.326406	 1520.326406	 1520.326406	 0.0	 0.0	 1	 -30.0	 30.0;
	2536	 560	 0.00021	 0.00288	 0.08835	 1339.102	 1339.102	 1339.102	 0.0	 0.0	 1	 -30.0	 30.0;
	2536	 4585	 0.00171	 0.01889	 0.40723	 1286.700396	 1286.700396	 1286.700396	 0.0	 0.0	 1	 -30.0	 30.0;
	8051	 2505	 0.00069	 0.00565	 0.18019	 1213.322618	 1213.322618	 1213.322618	 0.0	 0.0	 1	 -30.0	 30.0;
	8051	 2505	 0.0007	 0.00553	 0.18352	 1405.196366	 1405.196366	 1405.196366	 0.0	 0.0	 1	 -30.0	 30.0;
	6436	 3907	 0.00011	 0.00115	 0.03329	 1146.788588	 1146.788588	 1146.788588	 0.0	 0.0	 1	 -30.0	 30.0;
	6436	 6058	 0.00012	 0.00126	 0.0418	 1330.072438	 1330.072438	 1330.072438	 0.0	 0.0	 1	 -30.0	 30.0;
	6436	 8148	 0.00326	 0.02919	 0.8563	 1413.556559	 1413.556559	 1413.556559	 0.0	 0.0	 1	 -30.0	 30.0;
	6436	 4603	 0.00092	 0.00876	 0.22199	 827.435381	 827.435381	 827.435381	 0.0	 0.0	 1	 -30.0	 30.0;
	5246	 6287	 0.00087	 0.005409	 0.00757	 458.188511	 458.188511	 458.188511	 0.0	 0.0	 1	 -30.0	 30.0;
	5246	 6231	 0.00131	 0.00701	 0.01131	 450.39106	 450.39106	 450.39106	 0.0	 0.0	 1	 -30.0	 30.0;
	3908	 6036	 0.002531	 0.018781	 0.04731	 278.941275	 278.941275	 278.941275	 0.0	 0.0	 1	 -30.0	 30.0;
	3908	 7918	 0.00894	 0.056909	 0.1695	 228.905444	 228.905444	 228.905444	 0.0	 0.0	 1	 -30.0	 30.0;
	5003	 4957	 0.00187	 0.010659	 0.01539	 556.269179	 556.269179	 556.269179	 0.0	 0.0	 1	 -30.0	 30.0;
	6971	 4957	 0.00286	 0.01538	 0.03108	 622.33164	 622.33164	 622.33164	 0.0	 0.0	 1	 -30.0	 30.0;
	4957	 4519	 0.0008	 0.00444	 0.00987	 426.256041	 426.256041	 426.256041	 0.0	 0.0	 1	 -30.0	 30.0;
	922	 7146	 0.00545	 0.03936	 0.10673	 272.499604	 272.499604	 272.499604	 0.0	 0.0	 1	 -30.0	 30.0;
	1590	 7146	 0.00119	 0.009031	 0.02348	 221.808366	 221.808366	 221.808366	 0.0	 0.0	 1	 -30.0	 30.0;
	43	 5146	 0.00295	 0.0162	 0.02797	 435.386027	 435.386027	 435.386027	 0.0	 0.0	 1	 -30.0	 30.0;
	43	 5602	 0.001581	 0.0087	 0.01527	 515.364478	 515.364478	 515.364478	 0.0	 0.0	 1	 -30.0	 30.0;
	43	 2279	 0.007729	 0.025401	 0.06733	 598.188238	 598.188238	 598.188238	 0.0	 0.0	 1	 -30.0	 30.0;
	7078	 3112	 0.00013	 0.001461	 0.18234	 469.188315	 469.188315	 469.188315	 0.0	 0.0	 1	 -30.0	 30.0;
	7078	 7852	 0.000341	 0.02219	 0.15864	 314.313493	 314.313493	 314.313493	 0.0	 0.0	 1	 -30.0	 30.0;
	7078	 3653	 0.00018	 0.001211	 0.14627	 603.616312	 603.616312	 603.616312	 0.0	 0.0	 1	 -30.0	 30.0;
	7078	 8199	 0.003099	 0.0147	 0.06035	 595.279293	 595.279293	 595.279293	 0.0	 0.0	 1	 -30.0	 30.0;
	7078	 8199	 0.003159	 0.014401	 0.06154	 538.539629	 538.539629	 538.539629	 0.0	 0.0	 1	 -30.0	 30.0;
	6287	 3892	 0.00281	 0.01305	 0.02407	 377.471964	 377.471964	 377.471964	 0.0	 0.0	 1	 -30.0	 30.0;
	6287	 8052	 0.002281	 0.01075	 0.02042	 513.443599	 513.443599	 513.443599	 0.0	 0.0	 1	 -30.0	 30.0;
	6287	 8052	 0.00232	 0.010521	 0.0208	 474.467779	 474.467779	 474.467779	 0.0	 0.0	 1	 -30.0	 30.0;
	6287	 3127	 0.000151	 0.000841	 0.13408	 308.465501	 308.465501	 308.465501	 0.0	 0.0	 1	 -30.0	 30.0;
	6304	 2410	 0.002771	 0.012091	 0.02504	 577.782566	 577.782566	 577.782566	 0.0	 0.0	 1	 -30.0	 30.0;
	6304	 5078	 0.00613	 0.03005	 0.05518	 471.803088	 471.803088	 471.803088	 0.0	 0.0	 1	 -30.0	 30.0;
	3035	 6948	 0.003219	 0.02486	 0.0602	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5612	 7319	 0.000211	 0.001331	 0.16723	 586.41528	 586.41528	 586.41528	 0.0	 0.0	 1	 -30.0	 30.0;
	7709	 1736	 0.00185	 0.01917	 0.4907	 1613.107311	 1613.107311	 1613.107311	 0.0	 0.0	 1	 -30.0	 30.0;
	1167	 785	 0.00082	 0.00381	 0.01084	 580.991398	 580.991398	 580.991398	 0.0	 0.0	 1	 -30.0	 30.0;
	8212	 7091	 0.00075	 0.004531	 0.00685	 387.170479	 387.170479	 387.170479	 0.0	 0.0	 1	 -30.0	 30.0;
	8212	 7091	 0.000729	 0.00419	 0.00671	 422.950422	 422.950422	 422.950422	 0.0	 0.0	 1	 -30.0	 30.0;
	8212	 27	 0.02626	 0.15576	 0.22783	 447.63949	 447.63949	 447.63949	 0.0	 0.0	 1	 -30.0	 30.0;
	8212	 6729	 0.011469	 0.03937	 0.06728	 305.627432	 305.627432	 305.627432	 0.0	 0.0	 1	 -30.0	 30.0;
	6476	 7420	 0.00011	 0.00061	 0.00193	 514.649245	 514.649245	 514.649245	 0.0	 0.0	 1	 -30.0	 30.0;
	6476	 971	 0.000531	 0.00313	 0.00962	 393.582427	 393.582427	 393.582427	 0.0	 0.0	 1	 -30.0	 30.0;
	6476	 5566	 0.001211	 0.00864	 0.02267	 328.911564	 328.911564	 328.911564	 0.0	 0.0	 1	 -30.0	 30.0;
	3948	 4226	 0.00094	 0.006289	 0.08077	 267.926228	 267.926228	 267.926228	 0.0	 0.0	 1	 -30.0	 30.0;
	662	 3662	 0.001	 0.00886	 0.2856	 845.941409	 845.941409	 845.941409	 0.0	 0.0	 1	 -30.0	 30.0;
	6140	 2891	 0.001979	 0.010469	 0.01725	 516.026364	 516.026364	 516.026364	 0.0	 0.0	 1	 -30.0	 30.0;
	6140	 2891	 0.0017	 0.00855	 0.01466	 562.010096	 562.010096	 562.010096	 0.0	 0.0	 1	 -30.0	 30.0;
	2891	 1930	 0.00757	 0.04624	 0.06619	 422.939753	 422.939753	 422.939753	 0.0	 0.0	 1	 -30.0	 30.0;
	2891	 6602	 0.001719	 0.00794	 0.01285	 509.458566	 509.458566	 509.458566	 0.0	 0.0	 1	 -30.0	 30.0;
	2891	 6602	 0.00176	 0.007781	 0.0131	 259.530909	 259.530909	 259.530909	 0.0	 0.0	 1	 -30.0	 30.0;
	2872	 828	 0.00126	 0.0053	 0.01065	 403.877286	 403.877286	 403.877286	 0.0	 0.0	 1	 -30.0	 30.0;
	2872	 1127	 0.00444	 0.022789	 0.03743	 434.649836	 434.649836	 434.649836	 0.0	 0.0	 1	 -30.0	 30.0;
	431	 2212	 0.00163	 0.0145	 0.41102	 1097.383017	 1097.383017	 1097.383017	 0.0	 0.0	 1	 -30.0	 30.0;
	6140	 234	 0.003281	 0.02124	 0.0288	 511.601597	 511.601597	 511.601597	 0.0	 0.0	 1	 -30.0	 30.0;
	6140	 6602	 0.004979	 0.025271	 0.03769	 486.379058	 486.379058	 486.379058	 0.0	 0.0	 1	 -30.0	 30.0;
	8039	 2182	 0.0072	 0.055289	 0.1441	 509.408267	 509.408267	 509.408267	 0.0	 0.0	 1	 -30.0	 30.0;
	8039	 4339	 0.00787	 0.04582	 0.16058	 284.109091	 284.109091	 284.109091	 0.0	 0.0	 1	 -30.0	 30.0;
	8039	 3658	 0.003961	 0.017711	 0.05328	 276.466728	 276.466728	 276.466728	 0.0	 0.0	 1	 -30.0	 30.0;
	2182	 6165	 0.00756	 0.04826	 0.15137	 463.376522	 463.376522	 463.376522	 0.0	 0.0	 1	 -30.0	 30.0;
	5618	 7438	 0.003401	 0.02086	 0.1519	 459.742437	 459.742437	 459.742437	 0.0	 0.0	 1	 -30.0	 30.0;
	5618	 3588	 0.001341	 0.00669	 0.05955	 428.780886	 428.780886	 428.780886	 0.0	 0.0	 1	 -30.0	 30.0;
	6957	 8048	 6e-05	 0.000581	 0.06778	 445.800918	 445.800918	 445.800918	 0.0	 0.0	 1	 -30.0	 30.0;
	6957	 5395	 9.1e-05	 0.00074	 0.09438	 530.204897	 530.204897	 530.204897	 0.0	 0.0	 1	 -30.0	 30.0;
	6699	 8115	 0.000531	 0.00175	 0.17578	 269.327353	 269.327353	 269.327353	 0.0	 0.0	 1	 -30.0	 30.0;
	1016	 4636	 0.00116	 0.01159	 0.39356	 1390.808566	 1390.808566	 1390.808566	 0.0	 0.0	 1	 -30.0	 30.0;
	1016	 3928	 0.00038	 0.00457	 0.12703	 1624.93216	 1624.93216	 1624.93216	 0.0	 0.0	 1	 -30.0	 30.0;
	2788	 7234	 0.000729	 0.00405	 0.01351	 555.896892	 555.896892	 555.896892	 0.0	 0.0	 1	 -30.0	 30.0;
	239	 6407	 0.000331	 0.001919	 0.00615	 322.723293	 322.723293	 322.723293	 0.0	 0.0	 1	 -30.0	 30.0;
	1991	 4278	 0.00086	 0.01029	 0.28608	 1923.807434	 1923.807434	 1923.807434	 0.0	 0.0	 1	 -30.0	 30.0;
	6734	 1991	 0.00027	 0.00332	 0.08843	 1718.475236	 1718.475236	 1718.475236	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 5157	 0.00012	 0.00156	 0.19385	 264.896109	 264.896109	 264.896109	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 5157	 0.00012	 0.001531	 0.19765	 356.637229	 356.637229	 356.637229	 0.0	 0.0	 1	 -30.0	 30.0;
	7944	 1882	 0.00256	 0.014211	 0.05547	 322.115516	 322.115516	 322.115516	 0.0	 0.0	 1	 -30.0	 30.0;
	7944	 7631	 0.00049	 0.00338	 0.00537	 352.431567	 352.431567	 352.431567	 0.0	 0.0	 1	 -30.0	 30.0;
	5453	 1302	 0.007531	 0.04444	 0.06788	 415.676155	 415.676155	 415.676155	 0.0	 0.0	 1	 -30.0	 30.0;
	5453	 5078	 0.007409	 0.03226	 0.06686	 295.330667	 295.330667	 295.330667	 0.0	 0.0	 1	 -30.0	 30.0;
	2866	 7383	 0.001789	 0.012841	 0.03964	 282.70225	 282.70225	 282.70225	 0.0	 0.0	 1	 -30.0	 30.0;
	2866	 3729	 0.001831	 0.01257	 0.04039	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1487	 3295	 0.000169	 0.00143	 0.00362	 371.853364	 371.853364	 371.853364	 0.0	 0.0	 1	 -30.0	 30.0;
	1487	 6231	 0.00088	 0.005099	 0.01786	 615.819095	 615.819095	 615.819095	 0.0	 0.0	 1	 -30.0	 30.0;
	2784	 6763	 0.0004	 0.00479	 0.10823	 1678.989743	 1678.989743	 1678.989743	 0.0	 0.0	 1	 -30.0	 30.0;
	2784	 6763	 0.00052	 0.00481	 0.11479	 1754.626392	 1754.626392	 1754.626392	 0.0	 0.0	 1	 -30.0	 30.0;
	2784	 7194	 0.00135	 0.01431	 0.30856	 1751.180824	 1751.180824	 1751.180824	 0.0	 0.0	 1	 -30.0	 30.0;
	2784	 738	 0.00051	 0.00549	 0.11722	 1510.168067	 1510.168067	 1510.168067	 0.0	 0.0	 1	 -30.0	 30.0;
	634	 6244	 0.00105	 0.007969	 0.02253	 492.134836	 492.134836	 492.134836	 0.0	 0.0	 1	 -30.0	 30.0;
	634	 858	 0.00339	 0.020531	 0.06318	 335.71066	 335.71066	 335.71066	 0.0	 0.0	 1	 -30.0	 30.0;
	634	 2681	 0.00169	 0.009331	 0.02372	 237.536254	 237.536254	 237.536254	 0.0	 0.0	 1	 -30.0	 30.0;
	3261	 3805	 0.00374	 0.01905	 0.0327	 455.363778	 455.363778	 455.363778	 0.0	 0.0	 1	 -30.0	 30.0;
	3261	 4796	 0.00487	 0.026341	 0.04189	 535.303743	 535.303743	 535.303743	 0.0	 0.0	 1	 -30.0	 30.0;
	4578	 7526	 0.00057	 0.004581	 0.01064	 278.960708	 278.960708	 278.960708	 0.0	 0.0	 1	 -30.0	 30.0;
	4578	 7782	 0.000409	 0.00301	 0.00633	 225.314037	 225.314037	 225.314037	 0.0	 0.0	 1	 -30.0	 30.0;
	1328	 3418	 9.1e-05	 0.00076	 0.0009	 437.858287	 437.858287	 437.858287	 0.0	 0.0	 1	 -30.0	 30.0;
	1328	 5606	 0.003919	 0.01682	 0.02779	 482.365827	 482.365827	 482.365827	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 966	 0.00117	 0.0131	 0.27951	 1535.621177	 1535.621177	 1535.621177	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 4508	 0.008271	 0.02787	 0.07459	 513.344144	 513.344144	 513.344144	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 1022	 0.016599	 0.0572	 0.08632	 433.58556	 433.58556	 433.58556	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 7132	 0.00999	 0.057	 0.09047	 378.704283	 378.704283	 378.704283	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 7132	 0.01132	 0.05586	 0.10253	 377.712026	 377.712026	 377.712026	 0.0	 0.0	 1	 -30.0	 30.0;
	6620	 4262	 4e-05	 0.00045	 0.01152	 950.048921	 950.048921	 950.048921	 0.0	 0.0	 1	 -30.0	 30.0;
	4508	 7737	 0.003281	 0.01038	 0.0295	 496.768799	 496.768799	 496.768799	 0.0	 0.0	 1	 -30.0	 30.0;
	3930	 62	 0.003711	 0.01725	 0.06426	 459.588493	 459.588493	 459.588493	 0.0	 0.0	 1	 -30.0	 30.0;
	3930	 5744	 0.00069	 0.00232	 0.01192	 463.189045	 463.189045	 463.189045	 0.0	 0.0	 1	 -30.0	 30.0;
	7892	 4502	 0.004151	 0.02436	 0.03919	 521.864068	 521.864068	 521.864068	 0.0	 0.0	 1	 -30.0	 30.0;
	4695	 4502	 0.006781	 0.028729	 0.06373	 488.481698	 488.481698	 488.481698	 0.0	 0.0	 1	 -30.0	 30.0;
	3170	 6231	 0.000331	 0.00151	 0.106	 452.161805	 452.161805	 452.161805	 0.0	 0.0	 1	 -30.0	 30.0;
	1227	 6231	 0.000331	 0.001479	 0.108	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	3354	 5331	 0.0001	 0.00144	 1.34286	 1519.210792	 1519.210792	 1519.210792	 0.0	 0.0	 1	 -30.0	 30.0;
	3354	 5370	 0.00027	 0.00221	 0.07134	 1079.016523	 1079.016523	 1079.016523	 0.0	 0.0	 1	 -30.0	 30.0;
	1119	 4174	 0.0001	 0.00141	 1.49259	 1734.150434	 1734.150434	 1734.150434	 0.0	 0.0	 1	 -30.0	 30.0;
	1119	 2505	 0.00054	 0.00546	 0.13771	 1466.755876	 1466.755876	 1466.755876	 0.0	 0.0	 1	 -30.0	 30.0;
	6734	 5331	 7e-05	 0.00053	 0.01684	 1392.9075	 1392.9075	 1392.9075	 0.0	 0.0	 1	 -30.0	 30.0;
	4174	 6734	 6e-05	 0.0006	 0.015	 1494.712042	 1494.712042	 1494.712042	 0.0	 0.0	 1	 -30.0	 30.0;
	8115	 3980	 0.000341	 0.00245	 0.00745	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8115	 7092	 0.000841	 0.006719	 0.01563	 315.042063	 315.042063	 315.042063	 0.0	 0.0	 1	 -30.0	 30.0;
	5634	 6520	 0.000401	 0.00164	 0.20126	 481.461592	 481.461592	 481.461592	 0.0	 0.0	 1	 -30.0	 30.0;
	470	 6664	 0.004409	 0.032531	 0.08197	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	386	 7148	 0.001961	 0.013581	 0.04292	 383.536012	 383.536012	 383.536012	 0.0	 0.0	 1	 -30.0	 30.0;
	1732	 4450	 0.006659	 0.03437	 0.08634	 376.243074	 376.243074	 376.243074	 0.0	 0.0	 1	 -30.0	 30.0;
	3700	 1457	 9.1e-05	 0.0007	 0.00099	 254.127603	 254.127603	 254.127603	 0.0	 0.0	 1	 -30.0	 30.0;
	3700	 7328	 0.00051	 0.004211	 0.00734	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6206	 8113	 0.00043	 0.0027	 0.00504	 367.836323	 367.836323	 367.836323	 0.0	 0.0	 1	 -30.0	 30.0;
	6206	 2322	 0.00038	 0.00306	 0.00449	 365.429985	 365.429985	 365.429985	 0.0	 0.0	 1	 -30.0	 30.0;
	7900	 1357	 0.001461	 0.009479	 0.01684	 225.682514	 225.682514	 225.682514	 0.0	 0.0	 1	 -30.0	 30.0;
	7900	 6713	 0.001841	 0.011081	 0.02137	 520.764735	 520.764735	 520.764735	 0.0	 0.0	 1	 -30.0	 30.0;
	880	 6805	 0.00094	 0.007169	 0.01761	 567.745678	 567.745678	 567.745678	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 7289	 0.00082	 0.00846	 0.22494	 1416.786903	 1416.786903	 1416.786903	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 6734	 0.00029	 0.00325	 0.07845	 1717.59525	 1717.59525	 1717.59525	 0.0	 0.0	 1	 -30.0	 30.0;
	7234	 6778	 0.000781	 0.0062	 0.01441	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7234	 2485	 8.1e-05	 0.00187	 0.15378	 508.603487	 508.603487	 508.603487	 0.0	 0.0	 1	 -30.0	 30.0;
	7234	 2088	 8.1e-05	 0.001909	 0.15058	 435.898922	 435.898922	 435.898922	 0.0	 0.0	 1	 -30.0	 30.0;
	6239	 966	 0.00113	 0.00956	 0.29493	 1201.016639	 1201.016639	 1201.016639	 0.0	 0.0	 1	 -30.0	 30.0;
	6239	 966	 0.00115	 0.00935	 0.30039	 1220.180188	 1220.180188	 1220.180188	 0.0	 0.0	 1	 -30.0	 30.0;
	8156	 4033	 0.00161	 0.02036	 0.02963	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8156	 4033	 0.00157	 0.02075	 0.029	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 3392	 0.00101	 0.007401	 0.01325	 541.916886	 541.916886	 541.916886	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 6766	 0.00087	 0.00711	 0.09328	 495.281557	 495.281557	 495.281557	 0.0	 0.0	 1	 -30.0	 30.0;
	3259	 5370	 0.00135	 0.01442	 0.32839	 1375.050437	 1375.050437	 1375.050437	 0.0	 0.0	 1	 -30.0	 30.0;
	3259	 1911	 0.00176	 0.01441	 0.42876	 1782.16988	 1782.16988	 1782.16988	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 6664	 0.00682	 0.03187	 0.06032	 428.810227	 428.810227	 428.810227	 0.0	 0.0	 1	 -30.0	 30.0;
	7289	 1273	 0.00109	 0.00987	 0.29673	 1207.630683	 1207.630683	 1207.630683	 0.0	 0.0	 1	 -30.0	 30.0;
	4227	 7289	 0.00273	 0.02829	 0.78052	 1308.324219	 1308.324219	 1308.324219	 0.0	 0.0	 1	 -30.0	 30.0;
	1601	 7117	 0.001581	 0.011289	 0.02964	 416.355569	 416.355569	 416.355569	 0.0	 0.0	 1	 -30.0	 30.0;
	1601	 3113	 0.001669	 0.013099	 0.0349	 259.23064	 259.23064	 259.23064	 0.0	 0.0	 1	 -30.0	 30.0;
	6662	 1457	 9.9e-05	 0.00069	 0.00124	 506.385388	 506.385388	 506.385388	 0.0	 0.0	 1	 -30.0	 30.0;
	6662	 7328	 9.9e-05	 0.000669	 0.00127	 517.884369	 517.884369	 517.884369	 0.0	 0.0	 1	 -30.0	 30.0;
	4455	 3400	 0.000591	 0.00382	 0.01088	 283.149985	 283.149985	 283.149985	 0.0	 0.0	 1	 -30.0	 30.0;
	4455	 6926	 0.00524	 0.02276	 0.07926	 338.924446	 338.924446	 338.924446	 0.0	 0.0	 1	 -30.0	 30.0;
	3400	 6007	 0.002719	 0.01143	 0.04139	 311.41598	 311.41598	 311.41598	 0.0	 0.0	 1	 -30.0	 30.0;
	669	 7763	 0.00294	 0.02744	 0.82496	 954.65091	 954.65091	 954.65091	 0.0	 0.0	 1	 -30.0	 30.0;
	669	 6702	 0.0011	 0.01339	 0.26522	 1023.175932	 1023.175932	 1023.175932	 0.0	 0.0	 1	 -30.0	 30.0;
	669	 5327	 0.00193	 0.01695	 0.52495	 1367.466895	 1367.466895	 1367.466895	 0.0	 0.0	 1	 -30.0	 30.0;
	669	 4406	 0.00134	 0.01054	 0.37476	 1043.956628	 1043.956628	 1043.956628	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 669	 0.00245	 0.02064	 0.57895	 1398.979204	 1398.979204	 1398.979204	 0.0	 0.0	 1	 -30.0	 30.0;
	1267	 6093	 0.001841	 0.00901	 0.02549	 470.56772	 470.56772	 470.56772	 0.0	 0.0	 1	 -30.0	 30.0;
	1267	 6093	 0.00187	 0.00882	 0.02599	 504.48318	 504.48318	 504.48318	 0.0	 0.0	 1	 -30.0	 30.0;
	7557	 732	 0.00197	 0.02312	 0.49089	 1303.574797	 1303.574797	 1303.574797	 0.0	 0.0	 1	 -30.0	 30.0;
	2037	 6702	 0.00078	 0.00887	 0.197	 1406.968843	 1406.968843	 1406.968843	 0.0	 0.0	 1	 -30.0	 30.0;
	7717	 4930	 0.003771	 0.0288	 0.0405	 456.402905	 456.402905	 456.402905	 0.0	 0.0	 1	 -30.0	 30.0;
	7717	 4232	 0.000909	 0.00737	 0.0098	 466.884861	 466.884861	 466.884861	 0.0	 0.0	 1	 -30.0	 30.0;
	7194	 6763	 0.00086	 0.00783	 0.23042	 1750.793814	 1750.793814	 1750.793814	 0.0	 0.0	 1	 -30.0	 30.0;
	7194	 6763	 0.00095	 0.00855	 0.21268	 1564.813404	 1564.813404	 1564.813404	 0.0	 0.0	 1	 -30.0	 30.0;
	272	 6763	 0.00012	 0.00157	 0.04397	 1866.864393	 1866.864393	 1866.864393	 0.0	 0.0	 1	 -30.0	 30.0;
	272	 6763	 0.00013	 0.00154	 0.04984	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4654	 5858	 0.00089	 0.004771	 0.0079	 535.698893	 535.698893	 535.698893	 0.0	 0.0	 1	 -30.0	 30.0;
	4654	 5801	 0.002	 0.00881	 0.01778	 558.068502	 558.068502	 558.068502	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 6418	 0.007711	 0.035331	 0.23617	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6418	 6291	 0.005919	 0.030419	 0.05427	 504.884808	 504.884808	 504.884808	 0.0	 0.0	 1	 -30.0	 30.0;
	6418	 2676	 0.0053	 0.031719	 0.0613	 602.012086	 602.012086	 602.012086	 0.0	 0.0	 1	 -30.0	 30.0;
	3892	 1799	 0.00025	 0.001289	 0.00214	 334.557599	 334.557599	 334.557599	 0.0	 0.0	 1	 -30.0	 30.0;
	2676	 1930	 0.0062	 0.040039	 0.05425	 370.312393	 370.312393	 370.312393	 0.0	 0.0	 1	 -30.0	 30.0;
	4636	 4958	 0.0008	 0.00707	 0.27089	 1538.720544	 1538.720544	 1538.720544	 0.0	 0.0	 1	 -30.0	 30.0;
	4636	 4510	 0.0002	 0.00207	 0.0674	 975.879826	 975.879826	 975.879826	 0.0	 0.0	 1	 -30.0	 30.0;
	4636	 4050	 0.00036	 0.00322	 0.12332	 1074.210498	 1074.210498	 1074.210498	 0.0	 0.0	 1	 -30.0	 30.0;
	1017	 5526	 0.0023	 0.0157	 0.02417	 394.094559	 394.094559	 394.094559	 0.0	 0.0	 1	 -30.0	 30.0;
	1017	 3829	 0.003479	 0.021159	 0.0367	 421.609122	 421.609122	 421.609122	 0.0	 0.0	 1	 -30.0	 30.0;
	3614	 3114	 0.00107	 0.01013	 0.35846	 1396.147058	 1396.147058	 1396.147058	 0.0	 0.0	 1	 -30.0	 30.0;
	1310	 6202	 0.00025	 0.000909	 0.08572	 526.054869	 526.054869	 526.054869	 0.0	 0.0	 1	 -30.0	 30.0;
	1310	 5345	 0.00037	 0.00188	 0.13545	 449.748227	 449.748227	 449.748227	 0.0	 0.0	 1	 -30.0	 30.0;
	8350	 3588	 0.0003	 0.00145	 0.13724	 421.279513	 421.279513	 421.279513	 0.0	 0.0	 1	 -30.0	 30.0;
	8350	 3359	 0.001419	 0.007539	 0.02769	 487.864776	 487.864776	 487.864776	 0.0	 0.0	 1	 -30.0	 30.0;
	7763	 241	 0.0012	 0.0122	 0.35023	 1279.278766	 1279.278766	 1279.278766	 0.0	 0.0	 1	 -30.0	 30.0;
	7763	 2324	 0.00397	 0.02936	 1.15862	 1256.179963	 1256.179963	 1256.179963	 0.0	 0.0	 1	 -30.0	 30.0;
	7763	 7989	 0.00092	 0.01112	 0.21917	 1190.691781	 1190.691781	 1190.691781	 0.0	 0.0	 1	 -30.0	 30.0;
	7763	 6734	 0.00387	 0.0452	 0.93392	 1467.51739	 1467.51739	 1467.51739	 0.0	 0.0	 1	 -30.0	 30.0;
	7763	 1165	 0.00432	 0.03156	 1.26373	 1100.752236	 1100.752236	 1100.752236	 0.0	 0.0	 1	 -30.0	 30.0;
	2476	 1032	 0.00407	 0.03937	 1.01194	 1252.180866	 1252.180866	 1252.180866	 0.0	 0.0	 1	 -30.0	 30.0;
	2476	 1032	 0.00415	 0.03856	 1.03178	 1168.85734	 1168.85734	 1168.85734	 0.0	 0.0	 1	 -30.0	 30.0;
	5559	 4649	 0.00869	 0.05343	 0.0754	 584.023803	 584.023803	 584.023803	 0.0	 0.0	 1	 -30.0	 30.0;
	5559	 1978	 0.0068	 0.036961	 0.05163	 462.41132	 462.41132	 462.41132	 0.0	 0.0	 1	 -30.0	 30.0;
	5559	 2410	 0.01805	 0.095469	 0.1368	 404.190891	 404.190891	 404.190891	 0.0	 0.0	 1	 -30.0	 30.0;
	6896	 6602	 0.00045	 0.00206	 0.01384	 534.902496	 534.902496	 534.902496	 0.0	 0.0	 1	 -30.0	 30.0;
	427	 6522	 0.0095	 0.037159	 0.0715	 436.258634	 436.258634	 436.258634	 0.0	 0.0	 1	 -30.0	 30.0;
	427	 4571	 0.02106	 0.0885	 0.158	 461.600824	 461.600824	 461.600824	 0.0	 0.0	 1	 -30.0	 30.0;
	6702	 5327	 0.00157	 0.02318	 0.69807	 1823.636493	 1823.636493	 1823.636493	 0.0	 0.0	 1	 -30.0	 30.0;
	6702	 3330	 0.00032	 0.00282	 0.07561	 1731.738865	 1731.738865	 1731.738865	 0.0	 0.0	 1	 -30.0	 30.0;
	6702	 4485	 0.00165	 0.01605	 0.39059	 920.139936	 920.139936	 920.139936	 0.0	 0.0	 1	 -30.0	 30.0;
	4930	 442	 0.00107	 0.00714	 0.01154	 413.129971	 413.129971	 413.129971	 0.0	 0.0	 1	 -30.0	 30.0;
	4930	 442	 0.000961	 0.00555	 0.0143	 400.434489	 400.434489	 400.434489	 0.0	 0.0	 1	 -30.0	 30.0;
	4930	 7732	 0.00074	 0.00461	 0.01388	 278.756846	 278.756846	 278.756846	 0.0	 0.0	 1	 -30.0	 30.0;
	4930	 6407	 0.00076	 0.00451	 0.01414	 275.574687	 275.574687	 275.574687	 0.0	 0.0	 1	 -30.0	 30.0;
	4930	 3697	 0.001419	 0.01093	 0.0155	 548.127639	 548.127639	 548.127639	 0.0	 0.0	 1	 -30.0	 30.0;
	4930	 4232	 0.003729	 0.024599	 0.04002	 485.837203	 485.837203	 485.837203	 0.0	 0.0	 1	 -30.0	 30.0;
	2212	 6374	 0.00233	 0.01992	 0.57451	 1701.785783	 1701.785783	 1701.785783	 0.0	 0.0	 1	 -30.0	 30.0;
	2212	 6374	 0.00238	 0.01949	 0.58514	 1655.247899	 1655.247899	 1655.247899	 0.0	 0.0	 1	 -30.0	 30.0;
	2212	 4361	 0.00217	 0.0253	 0.73216	 1775.045089	 1775.045089	 1775.045089	 0.0	 0.0	 1	 -30.0	 30.0;
	2212	 4361	 0.00212	 0.02579	 0.71691	 1873.080897	 1873.080897	 1873.080897	 0.0	 0.0	 1	 -30.0	 30.0;
	2212	 1032	 0.00458	 0.04138	 1.1569	 1106.325699	 1106.325699	 1106.325699	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 496	 0.01555	 0.089841	 0.13668	 396.967685	 396.967685	 396.967685	 0.0	 0.0	 1	 -30.0	 30.0;
	5714	 3452	 0.00274	 0.0168	 0.02382	 476.83868	 476.83868	 476.83868	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 6241	 0.005831	 0.032211	 0.04427	 442.122631	 442.122631	 442.122631	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 3809	 0.006669	 0.031341	 0.058	 478.727169	 478.727169	 478.727169	 0.0	 0.0	 1	 -30.0	 30.0;
	7892	 4695	 0.01081	 0.0538	 0.10162	 481.652118	 481.652118	 481.652118	 0.0	 0.0	 1	 -30.0	 30.0;
	7892	 7132	 0.005581	 0.02457	 0.0523	 510.418434	 510.418434	 510.418434	 0.0	 0.0	 1	 -30.0	 30.0;
	7892	 7132	 0.00569	 0.024039	 0.05327	 543.95208	 543.95208	 543.95208	 0.0	 0.0	 1	 -30.0	 30.0;
	868	 6750	 0.002081	 0.01294	 0.01872	 468.776399	 468.776399	 468.776399	 0.0	 0.0	 1	 -30.0	 30.0;
	868	 4456	 0.001599	 0.00919	 0.01439	 279.460266	 279.460266	 279.460266	 0.0	 0.0	 1	 -30.0	 30.0;
	4764	 5327	 0.00083	 0.00768	 0.19377	 1760.275545	 1760.275545	 1760.275545	 0.0	 0.0	 1	 -30.0	 30.0;
	7648	 7383	 0.004979	 0.024099	 0.06968	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7648	 7383	 0.005081	 0.023591	 0.07102	 477.75587	 477.75587	 477.75587	 0.0	 0.0	 1	 -30.0	 30.0;
	3907	 241	 0.00412	 0.03917	 1.14425	 1291.035165	 1291.035165	 1291.035165	 0.0	 0.0	 1	 -30.0	 30.0;
	241	 4406	 0.00086	 0.00798	 0.24791	 1120.920167	 1120.920167	 1120.920167	 0.0	 0.0	 1	 -30.0	 30.0;
	2977	 241	 0.00087	 0.00961	 0.1919	 1248.485189	 1248.485189	 1248.485189	 0.0	 0.0	 1	 -30.0	 30.0;
	7477	 241	 0.00095	 0.01034	 0.27472	 1252.386218	 1252.386218	 1252.386218	 0.0	 0.0	 1	 -30.0	 30.0;
	7589	 241	 0.00211	 0.0196	 0.61015	 1123.293561	 1123.293561	 1123.293561	 0.0	 0.0	 1	 -30.0	 30.0;
	6522	 4571	 0.00963	 0.05281	 0.072	 352.763843	 352.763843	 352.763843	 0.0	 0.0	 1	 -30.0	 30.0;
	970	 3398	 0.00018	 0.001349	 0.00342	 560.865799	 560.865799	 560.865799	 0.0	 0.0	 1	 -30.0	 30.0;
	970	 5858	 0.000961	 0.006021	 0.01061	 397.97366	 397.97366	 397.97366	 0.0	 0.0	 1	 -30.0	 30.0;
	970	 5858	 0.000979	 0.00589	 0.01081	 395.263624	 395.263624	 395.263624	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 2786	 0.000461	 0.002729	 0.00843	 622.201702	 622.201702	 622.201702	 0.0	 0.0	 1	 -30.0	 30.0;
	895	 3059	 0.005039	 0.01901	 0.04421	 399.944838	 399.944838	 399.944838	 0.0	 0.0	 1	 -30.0	 30.0;
	895	 4189	 0.00812	 0.028919	 0.07492	 429.533843	 429.533843	 429.533843	 0.0	 0.0	 1	 -30.0	 30.0;
	6579	 6320	 0.00106	 0.01005	 0.26163	 956.834749	 956.834749	 956.834749	 0.0	 0.0	 1	 -30.0	 30.0;
	5327	 6139	 0.00074	 0.0081	 0.17958	 1228.371888	 1228.371888	 1228.371888	 0.0	 0.0	 1	 -30.0	 30.0;
	7383	 5602	 0.012961	 0.03605	 0.11124	 259.560631	 259.560631	 259.560631	 0.0	 0.0	 1	 -30.0	 30.0;
	7383	 5602	 0.00844	 0.0378	 0.1234	 414.25331	 414.25331	 414.25331	 0.0	 0.0	 1	 -30.0	 30.0;
	7383	 4694	 0.000591	 0.004169	 0.00667	 557.673352	 557.673352	 557.673352	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 5480	 0.003091	 0.012289	 0.0233	 461.482317	 461.482317	 461.482317	 0.0	 0.0	 1	 -30.0	 30.0;
	4145	 4178	 0.000969	 0.0053	 0.01476	 555.910228	 555.910228	 555.910228	 0.0	 0.0	 1	 -30.0	 30.0;
	2189	 2435	 0.00161	 0.012919	 0.033	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2189	 2435	 0.003219	 0.01795	 0.06745	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2189	 3314	 0.004331	 0.025	 0.09024	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2189	 3314	 0.004409	 0.02445	 0.09192	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4418	 2309	 0.00425	 0.02014	 0.05893	 237.546542	 237.546542	 237.546542	 0.0	 0.0	 1	 -30.0	 30.0;
	4418	 6263	 0.009531	 0.060979	 0.10839	 510.70727	 510.70727	 510.70727	 0.0	 0.0	 1	 -30.0	 30.0;
	4418	 1735	 0.002409	 0.0135	 0.045	 234.363241	 234.363241	 234.363241	 0.0	 0.0	 1	 -30.0	 30.0;
	2972	 7441	 0.0006	 0.00662	 0.1499	 1693.565782	 1693.565782	 1693.565782	 0.0	 0.0	 1	 -30.0	 30.0;
	2972	 2580	 0.00173	 0.01701	 0.43536	 1704.893048	 1704.893048	 1704.893048	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 1067	 0.004289	 0.018531	 0.03245	 444.093428	 444.093428	 444.093428	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 6291	 0.006919	 0.039789	 0.05258	 423.086076	 423.086076	 423.086076	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 6291	 0.007591	 0.035539	 0.05742	 505.188506	 505.188506	 505.188506	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 4320	 0.00961	 0.05225	 0.07296	 435.949221	 435.949221	 435.949221	 0.0	 0.0	 1	 -30.0	 30.0;
	3332	 5935	 0.000581	 0.004599	 0.00619	 226.443092	 226.443092	 226.443092	 0.0	 0.0	 1	 -30.0	 30.0;
	3332	 5935	 0.00057	 0.00469	 0.00605	 266.938925	 266.938925	 266.938925	 0.0	 0.0	 1	 -30.0	 30.0;
	3332	 5935	 0.00087	 0.003159	 0.00447	 605.053637	 605.053637	 605.053637	 0.0	 0.0	 1	 -30.0	 30.0;
	5838	 4745	 0.00018	 0.001419	 0.00423	 233.727266	 233.727266	 233.727266	 0.0	 0.0	 1	 -30.0	 30.0;
	5838	 6093	 0.00195	 0.018841	 0.04532	 356.312954	 356.312954	 356.312954	 0.0	 0.0	 1	 -30.0	 30.0;
	62	 5529	 0.00293	 0.01293	 0.05088	 402.793577	 402.793577	 402.793577	 0.0	 0.0	 1	 -30.0	 30.0;
	1385	 2939	 0.001969	 0.010599	 0.01484	 453.574743	 453.574743	 453.574743	 0.0	 0.0	 1	 -30.0	 30.0;
	6333	 772	 3.9e-05	 0.000591	 0.06673	 275.229074	 275.229074	 275.229074	 0.0	 0.0	 1	 -30.0	 30.0;
	6333	 373	 0.00364	 0.02431	 0.14332	 292.454874	 292.454874	 292.454874	 0.0	 0.0	 1	 -30.0	 30.0;
	6333	 1367	 0.00114	 0.007211	 0.09227	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	442	 3859	 0.001271	 0.008659	 0.01417	 388.868443	 388.868443	 388.868443	 0.0	 0.0	 1	 -30.0	 30.0;
	442	 1284	 0.00105	 0.00668	 0.01789	 366.259152	 366.259152	 366.259152	 0.0	 0.0	 1	 -30.0	 30.0;
	3907	 6058	 0.00011	 0.00122	 0.04059	 1009.510814	 1009.510814	 1009.510814	 0.0	 0.0	 1	 -30.0	 30.0;
	3907	 3264	 0.00117	 0.0124	 0.32387	 1350.161387	 1350.161387	 1350.161387	 0.0	 0.0	 1	 -30.0	 30.0;
	3907	 7589	 0.00168	 0.01891	 0.46934	 1191.170277	 1191.170277	 1191.170277	 0.0	 0.0	 1	 -30.0	 30.0;
	722	 7091	 0.00132	 0.008281	 0.01107	 573.39057	 573.39057	 573.39057	 0.0	 0.0	 1	 -30.0	 30.0;
	722	 7593	 0.004531	 0.01924	 0.06299	 280.680392	 280.680392	 280.680392	 0.0	 0.0	 1	 -30.0	 30.0;
	722	 1127	 0.007841	 0.041909	 0.11339	 422.303016	 422.303016	 422.303016	 0.0	 0.0	 1	 -30.0	 30.0;
	7194	 7034	 0.00113	 0.01235	 0.2836	 1794.324477	 1794.324477	 1794.324477	 0.0	 0.0	 1	 -30.0	 30.0;
	7194	 7034	 0.00128	 0.0121	 0.32141	 1776.483869	 1776.483869	 1776.483869	 0.0	 0.0	 1	 -30.0	 30.0;
	7194	 7822	 0.0015	 0.01792	 0.35784	 1421.783142	 1421.783142	 1421.783142	 0.0	 0.0	 1	 -30.0	 30.0;
	4178	 1338	 0.00111	 0.005281	 0.01707	 282.694629	 282.694629	 282.694629	 0.0	 0.0	 1	 -30.0	 30.0;
	4178	 1338	 0.00113	 0.005169	 0.01739	 265.731755	 265.731755	 265.731755	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 2830	 0.00563	 0.03255	 0.0444	 494.024469	 494.024469	 494.024469	 0.0	 0.0	 1	 -30.0	 30.0;
	1069	 2830	 0.005289	 0.022539	 0.04082	 355.215527	 355.215527	 355.215527	 0.0	 0.0	 1	 -30.0	 30.0;
	2830	 5661	 0.007159	 0.05086	 0.13337	 408.47886	 408.47886	 408.47886	 0.0	 0.0	 1	 -30.0	 30.0;
	2830	 3356	 0.009669	 0.05649	 0.13532	 324.375531	 324.375531	 324.375531	 0.0	 0.0	 1	 -30.0	 30.0;
	2830	 5606	 0.0092	 0.052169	 0.06528	 554.467188	 554.467188	 554.467188	 0.0	 0.0	 1	 -30.0	 30.0;
	7608	 4631	 0.00197	 0.01594	 0.38068	 1324.855709	 1324.855709	 1324.855709	 0.0	 0.0	 1	 -30.0	 30.0;
	7608	 7989	 0.00343	 0.02573	 0.71559	 1267.155761	 1267.155761	 1267.155761	 0.0	 0.0	 1	 -30.0	 30.0;
	7608	 7477	 0.00151	 0.01485	 0.36026	 1191.923234	 1191.923234	 1191.923234	 0.0	 0.0	 1	 -30.0	 30.0;
	7608	 4603	 0.00092	 0.01042	 0.2249	 1037.437362	 1037.437362	 1037.437362	 0.0	 0.0	 1	 -30.0	 30.0;
	7608	 7267	 0.00029	 0.00336	 0.07002	 1548.006137	 1548.006137	 1548.006137	 0.0	 0.0	 1	 -30.0	 30.0;
	1357	 4085	 0.001711	 0.01255	 0.03159	 293.674237	 293.674237	 293.674237	 0.0	 0.0	 1	 -30.0	 30.0;
	1357	 1369	 0.005	 0.03962	 0.05923	 571.522657	 571.522657	 571.522657	 0.0	 0.0	 1	 -30.0	 30.0;
	768	 1063	 0.0014	 0.01687	 0.34391	 1255.656711	 1255.656711	 1255.656711	 0.0	 0.0	 1	 -30.0	 30.0;
	768	 1063	 0.00067	 0.00678	 0.17127	 1943.770671	 1943.770671	 1943.770671	 0.0	 0.0	 1	 -30.0	 30.0;
	768	 1063	 0.00065	 0.00692	 0.16778	 1700.868281	 1700.868281	 1700.868281	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 768	 0.00137	 0.01524	 0.32277	 1231.358705	 1231.358705	 1231.358705	 0.0	 0.0	 1	 -30.0	 30.0;
	3495	 622	 0.00424	 0.02376	 0.06041	 235.143252	 235.143252	 235.143252	 0.0	 0.0	 1	 -30.0	 30.0;
	3495	 5282	 0.005591	 0.031711	 0.05037	 483.788672	 483.788672	 483.788672	 0.0	 0.0	 1	 -30.0	 30.0;
	3495	 2027	 0.00138	 0.00649	 0.01411	 435.897398	 435.897398	 435.897398	 0.0	 0.0	 1	 -30.0	 30.0;
	3495	 2027	 0.00107	 0.00544	 0.01489	 527.999754	 527.999754	 527.999754	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 3997	 3e-05	 0.00041	 0.01153	 1777.887765	 1777.887765	 1777.887765	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 3997	 3e-05	 0.00041	 0.01129	 1629.613131	 1629.613131	 1629.613131	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 4510	 0.00044	 0.00342	 0.09556	 1334.650733	 1334.650733	 1334.650733	 0.0	 0.0	 1	 -30.0	 30.0;
	6750	 2268	 0.003841	 0.01737	 0.03461	 446.137767	 446.137767	 446.137767	 0.0	 0.0	 1	 -30.0	 30.0;
	1590	 1749	 0.001771	 0.01337	 0.01926	 505.359979	 505.359979	 505.359979	 0.0	 0.0	 1	 -30.0	 30.0;
	437	 2410	 0.00139	 0.007349	 0.01217	 534.679962	 534.679962	 534.679962	 0.0	 0.0	 1	 -30.0	 30.0;
	437	 5078	 0.00625	 0.03463	 0.05639	 542.392057	 542.392057	 542.392057	 0.0	 0.0	 1	 -30.0	 30.0;
	4649	 3970	 0.00055	 0.00255	 0.00485	 360.858895	 360.858895	 360.858895	 0.0	 0.0	 1	 -30.0	 30.0;
	5981	 3192	 0.00489	 0.043331	 0.10534	 258.732225	 258.732225	 258.732225	 0.0	 0.0	 1	 -30.0	 30.0;
	7891	 7438	 0.00145	 0.013099	 0.03507	 397.691683	 397.691683	 397.691683	 0.0	 0.0	 1	 -30.0	 30.0;
	7891	 1156	 0.004039	 0.02881	 0.09804	 330.849971	 330.849971	 330.849971	 0.0	 0.0	 1	 -30.0	 30.0;
	2038	 4519	 0.002219	 0.00988	 0.03167	 447.281302	 447.281302	 447.281302	 0.0	 0.0	 1	 -30.0	 30.0;
	7776	 7117	 0.001919	 0.0153	 0.03557	 416.696229	 416.696229	 416.696229	 0.0	 0.0	 1	 -30.0	 30.0;
	7858	 1273	 0.00189	 0.01319	 0.32109	 1410.033325	 1410.033325	 1410.033325	 0.0	 0.0	 1	 -30.0	 30.0;
	4731	 8113	 0.00011	 0.000659	 0.00129	 498.042272	 498.042272	 498.042272	 0.0	 0.0	 1	 -30.0	 30.0;
	4731	 2322	 0.00011	 0.00064	 0.00132	 467.091771	 467.091771	 467.091771	 0.0	 0.0	 1	 -30.0	 30.0;
	4731	 2753	 0.000211	 0.00111	 0.00191	 260.18403	 260.18403	 260.18403	 0.0	 0.0	 1	 -30.0	 30.0;
	6202	 5634	 0.000469	 0.001669	 0.24078	 406.630381	 406.630381	 406.630381	 0.0	 0.0	 1	 -30.0	 30.0;
	5372	 772	 6e-05	 0.000849	 0.11043	 279.394726	 279.394726	 279.394726	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 6627	 0.00051	 0.00597	 0.13001	 1593.067067	 1593.067067	 1593.067067	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 6320	 0.00119	 0.01087	 0.29433	 1218.453784	 1218.453784	 1218.453784	 0.0	 0.0	 1	 -30.0	 30.0;
	5291	 6474	 0.00219	 0.01922	 0.55346	 1402.92104	 1402.92104	 1402.92104	 0.0	 0.0	 1	 -30.0	 30.0;
	5370	 2505	 0.00051	 0.00465	 0.12608	 1583.960498	 1583.960498	 1583.960498	 0.0	 0.0	 1	 -30.0	 30.0;
	8052	 8001	 0.00055	 0.0067	 0.01252	 284.39869	 284.39869	 284.39869	 0.0	 0.0	 1	 -30.0	 30.0;
	2268	 4842	 0.005099	 0.027349	 0.04815	 564.960575	 564.960575	 564.960575	 0.0	 0.0	 1	 -30.0	 30.0;
	2939	 2575	 0.000599	 0.003961	 0.01127	 489.098239	 489.098239	 489.098239	 0.0	 0.0	 1	 -30.0	 30.0;
	2939	 2991	 0.005461	 0.032719	 0.04907	 488.871133	 488.871133	 488.871133	 0.0	 0.0	 1	 -30.0	 30.0;
	7385	 2625	 0.00349	 0.02256	 0.0383	 478.105675	 478.105675	 478.105675	 0.0	 0.0	 1	 -30.0	 30.0;
	7385	 1648	 0.00132	 0.00861	 0.01366	 401.775027	 401.775027	 401.775027	 0.0	 0.0	 1	 -30.0	 30.0;
	5288	 396	 0.0045	 0.01838	 0.03264	 356.165487	 356.165487	 356.165487	 0.0	 0.0	 1	 -30.0	 30.0;
	5288	 1265	 0.004289	 0.019719	 0.03123	 409.1095	 409.1095	 409.1095	 0.0	 0.0	 1	 -30.0	 30.0;
	7465	 2753	 0.001409	 0.00881	 0.01461	 496.965422	 496.965422	 496.965422	 0.0	 0.0	 1	 -30.0	 30.0;
	1063	 5992	 0.00212	 0.01857	 0.51971	 1423.37462	 1423.37462	 1423.37462	 0.0	 0.0	 1	 -30.0	 30.0;
	1063	 6961	 0.00049	 0.00574	 0.11994	 1628.943105	 1628.943105	 1628.943105	 0.0	 0.0	 1	 -30.0	 30.0;
	1063	 684	 0.00184	 0.021	 0.45843	 1566.552314	 1566.552314	 1566.552314	 0.0	 0.0	 1	 -30.0	 30.0;
	2435	 4340	 0.00593	 0.037409	 0.12416	 437.053126	 437.053126	 437.053126	 0.0	 0.0	 1	 -30.0	 30.0;
	2027	 3805	 0.00514	 0.024169	 0.03245	 439.603121	 439.603121	 439.603121	 0.0	 0.0	 1	 -30.0	 30.0;
	3458	 2642	 0.00041	 0.00492	 0.10366	 1258.387497	 1258.387497	 1258.387497	 0.0	 0.0	 1	 -30.0	 30.0;
	3223	 2642	 0.00296	 0.02677	 0.7466	 1349.709876	 1349.709876	 1349.709876	 0.0	 0.0	 1	 -30.0	 30.0;
	4463	 496	 0.0072	 0.03406	 0.06334	 398.857318	 398.857318	 398.857318	 0.0	 0.0	 1	 -30.0	 30.0;
	3113	 6302	 0.00043	 0.00276	 0.00814	 424.753556	 424.753556	 424.753556	 0.0	 0.0	 1	 -30.0	 30.0;
	3113	 8199	 0.001789	 0.013469	 0.01352	 551.683228	 551.683228	 551.683228	 0.0	 0.0	 1	 -30.0	 30.0;
	4450	 6713	 0.00163	 0.011091	 0.01944	 471.43766	 471.43766	 471.43766	 0.0	 0.0	 1	 -30.0	 30.0;
	4450	 5760	 0.00036	 0.002651	 0.00698	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8048	 12	 0.00013	 0.00132	 0.11865	 525.679533	 525.679533	 525.679533	 0.0	 0.0	 1	 -30.0	 30.0;
	8048	 259	 0.000169	 0.001659	 0.18764	 460.038133	 460.038133	 460.038133	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 7737	 0.00136	 0.012831	 0.02471	 267.426289	 267.426289	 267.426289	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 7737	 0.00139	 0.01256	 0.02517	 255.973034	 255.973034	 255.973034	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 4796	 0.00126	 0.009521	 0.02337	 225.265644	 225.265644	 225.265644	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 4796	 0.00143	 0.009331	 0.02649	 225.565531	 225.565531	 225.565531	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 4033	 0.00164	 0.012961	 0.034	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 4033	 0.001599	 0.012	 0.03326	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6291	 2686	 0.001271	 0.00524	 0.00955	 438.762141	 438.762141	 438.762141	 0.0	 0.0	 1	 -30.0	 30.0;
	7469	 8148	 0.00226	 0.02465	 0.6298	 1528.460844	 1528.460844	 1528.460844	 0.0	 0.0	 1	 -30.0	 30.0;
	5934	 3379	 0.00032	 0.0015	 0.11985	 530.036472	 530.036472	 530.036472	 0.0	 0.0	 1	 -30.0	 30.0;
	5934	 5395	 0.00032	 0.00112	 0.10237	 432.587968	 432.587968	 432.587968	 0.0	 0.0	 1	 -30.0	 30.0;
	2977	 4485	 0.00075	 0.00817	 0.16312	 1059.388958	 1059.388958	 1059.388958	 0.0	 0.0	 1	 -30.0	 30.0;
	7398	 3112	 0.00037	 0.0027	 0.32698	 557.541508	 557.541508	 557.541508	 0.0	 0.0	 1	 -30.0	 30.0;
	3112	 6152	 3.9e-05	 0.000219	 0.00076	 353.272547	 353.272547	 353.272547	 0.0	 0.0	 1	 -30.0	 30.0;
	1978	 539	 0.012781	 0.05762	 0.0969	 348.456822	 348.456822	 348.456822	 0.0	 0.0	 1	 -30.0	 30.0;
	7852	 971	 0.00036	 0.001289	 0.17186	 353.167377	 353.167377	 353.167377	 0.0	 0.0	 1	 -30.0	 30.0;
	5526	 1069	 0.006771	 0.039349	 0.07095	 322.173436	 322.173436	 322.173436	 0.0	 0.0	 1	 -30.0	 30.0;
	2825	 6961	 0.00292	 0.02831	 0.72728	 1432.39036	 1432.39036	 1432.39036	 0.0	 0.0	 1	 -30.0	 30.0;
	2825	 1911	 0.00134	 0.01229	 0.31832	 1533.890166	 1533.890166	 1533.890166	 0.0	 0.0	 1	 -30.0	 30.0;
	7398	 4991	 0.00011	 0.00063	 0.10373	 584.791621	 584.791621	 584.791621	 0.0	 0.0	 1	 -30.0	 30.0;
	6571	 7438	 0.0003	 0.003331	 0.0085	 283.934569	 283.934569	 283.934569	 0.0	 0.0	 1	 -30.0	 30.0;
	6571	 3359	 0.001289	 0.01555	 0.03654	 222.195514	 222.195514	 222.195514	 0.0	 0.0	 1	 -30.0	 30.0;
	6152	 5372	 0.00011	 0.0017	 0.16068	 556.383113	 556.383113	 556.383113	 0.0	 0.0	 1	 -30.0	 30.0;
	6152	 7776	 0.00043	 0.00249	 0.00828	 534.30234	 534.30234	 534.30234	 0.0	 0.0	 1	 -30.0	 30.0;
	1022	 4231	 0.002651	 0.016771	 0.02821	 237.954267	 237.954267	 237.954267	 0.0	 0.0	 1	 -30.0	 30.0;
	3168	 1022	 0.0082	 0.025081	 0.04994	 403.271034	 403.271034	 403.271034	 0.0	 0.0	 1	 -30.0	 30.0;
	3127	 8001	 0.00037	 0.002781	 0.007	 594.054213	 594.054213	 594.054213	 0.0	 0.0	 1	 -30.0	 30.0;
	4419	 4463	 0.010719	 0.054719	 0.09428	 413.481681	 413.481681	 413.481681	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 4463	 0.006469	 0.04074	 0.12044	 406.865109	 406.865109	 406.865109	 0.0	 0.0	 1	 -30.0	 30.0;
	5338	 8148	 0.00101	 0.01274	 0.24051	 1312.950561	 1312.950561	 1312.950561	 0.0	 0.0	 1	 -30.0	 30.0;
	7438	 5408	 9.1e-05	 0.05076	 0.06756	 437.183446	 437.183446	 437.183446	 0.0	 0.0	 1	 -30.0	 30.0;
	7438	 3301	 0.00588	 0.03938	 0.05157	 473.029311	 473.029311	 473.029311	 0.0	 0.0	 1	 -30.0	 30.0;
	7438	 3359	 0.003591	 0.022099	 0.03114	 446.585883	 446.585883	 446.585883	 0.0	 0.0	 1	 -30.0	 30.0;
	7438	 6924	 0.00555	 0.032521	 0.04324	 268.765303	 268.765303	 268.765303	 0.0	 0.0	 1	 -30.0	 30.0;
	6239	 7034	 0.00116	 0.01347	 0.30147	 1526.623208	 1526.623208	 1526.623208	 0.0	 0.0	 1	 -30.0	 30.0;
	6239	 7034	 0.00113	 0.01247	 0.29492	 1571.75917	 1571.75917	 1571.75917	 0.0	 0.0	 1	 -30.0	 30.0;
	4585	 159	 0.00107	 0.00871	 0.30588	 984.906097	 984.906097	 984.906097	 0.0	 0.0	 1	 -30.0	 30.0;
	4585	 4046	 0.00078	 0.00609	 0.22253	 1384.287325	 1384.287325	 1384.287325	 0.0	 0.0	 1	 -30.0	 30.0;
	2324	 6139	 0.00075	 0.00604	 0.21992	 1146.038922	 1146.038922	 1146.038922	 0.0	 0.0	 1	 -30.0	 30.0;
	4456	 6093	 0.00224	 0.011091	 0.02035	 298.994093	 298.994093	 298.994093	 0.0	 0.0	 1	 -30.0	 30.0;
	6778	 6302	 0.001961	 0.013969	 0.03661	 418.120979	 418.120979	 418.120979	 0.0	 0.0	 1	 -30.0	 30.0;
	1177	 4694	 0.001271	 0.00761	 0.01431	 486.446504	 486.446504	 486.446504	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 7989	 0.00374	 0.03581	 0.90723	 1396.776936	 1396.776936	 1396.776936	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 7989	 0.00385	 0.03284	 1.01893	 1334.340072	 1334.340072	 1334.340072	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 7989	 0.00392	 0.03216	 1.03852	 1190.958343	 1190.958343	 1190.958343	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 8148	 0.00307	 0.03131	 0.81414	 1302.919909	 1302.919909	 1302.919909	 0.0	 0.0	 1	 -30.0	 30.0;
	7091	 27	 0.027	 0.131289	 0.23246	 453.439851	 453.439851	 453.439851	 0.0	 0.0	 1	 -30.0	 30.0;
	5744	 5003	 0.005539	 0.0195	 0.09625	 242.757417	 242.757417	 242.757417	 0.0	 0.0	 1	 -30.0	 30.0;
	7737	 8208	 0.003099	 0.017849	 0.02707	 506.488272	 506.488272	 506.488272	 0.0	 0.0	 1	 -30.0	 30.0;
	7737	 4796	 0.002831	 0.014099	 0.02429	 534.598417	 534.598417	 534.598417	 0.0	 0.0	 1	 -30.0	 30.0;
	3668	 2059	 0.0	 0.01368	 0.0	 1611.013642	 1611.013642	 1611.013642	 0.0	 0.0	 1	 -30.0	 30.0;
	3829	 4231	 0.01082	 0.079719	 0.11605	 377.953994	 377.953994	 377.953994	 0.0	 0.0	 1	 -30.0	 30.0;
	662	 2505	 0.00102	 0.00941	 0.25147	 1250.561087	 1250.561087	 1250.561087	 0.0	 0.0	 1	 -30.0	 30.0;
	662	 541	 0.00183	 0.01819	 0.6177	 1806.078243	 1806.078243	 1806.078243	 0.0	 0.0	 1	 -30.0	 30.0;
	662	 346	 0.00028	 0.00346	 0.07481	 1268.363521	 1268.363521	 1268.363521	 0.0	 0.0	 1	 -30.0	 30.0;
	3392	 2322	 0.0012	 0.00982	 0.01289	 237.7706	 237.7706	 237.7706	 0.0	 0.0	 1	 -30.0	 30.0;
	2505	 2376	 0.00027	 0.0032	 0.09026	 1838.646272	 1838.646272	 1838.646272	 0.0	 0.0	 1	 -30.0	 30.0;
	2505	 6974	 0.00064	 0.00679	 0.15697	 1158.394264	 1158.394264	 1158.394264	 0.0	 0.0	 1	 -30.0	 30.0;
	2505	 7487	 0.00047	 0.00442	 0.15628	 1735.902508	 1735.902508	 1735.902508	 0.0	 0.0	 1	 -30.0	 30.0;
	373	 3059	 0.00493	 0.017599	 0.04325	 499.905994	 499.905994	 499.905994	 0.0	 0.0	 1	 -30.0	 30.0;
	373	 3716	 0.00207	 0.0153	 0.04117	 277.720006	 277.720006	 277.720006	 0.0	 0.0	 1	 -30.0	 30.0;
	6606	 7034	 0.00094	 0.0092	 0.31227	 1909.950127	 1909.950127	 1909.950127	 0.0	 0.0	 1	 -30.0	 30.0;
	6606	 7034	 0.00095	 0.00901	 0.31828	 1717.486651	 1717.486651	 1717.486651	 0.0	 0.0	 1	 -30.0	 30.0;
	858	 2523	 0.00101	 0.00719	 0.01887	 340.716148	 340.716148	 340.716148	 0.0	 0.0	 1	 -30.0	 30.0;
	3398	 6034	 0.000419	 0.00331	 0.00803	 573.547563	 573.547563	 573.547563	 0.0	 0.0	 1	 -30.0	 30.0;
	2309	 1735	 0.002099	 0.015599	 0.03927	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7989	 7858	 0.00163	 0.01283	 0.27543	 1312.010023	 1312.010023	 1312.010023	 0.0	 0.0	 1	 -30.0	 30.0;
	7989	 6734	 0.00445	 0.03788	 1.27074	 1531.011947	 1531.011947	 1531.011947	 0.0	 0.0	 1	 -30.0	 30.0;
	7989	 4227	 0.00092	 0.00703	 0.1816	 1218.876993	 1218.876993	 1218.876993	 0.0	 0.0	 1	 -30.0	 30.0;
	227	 27	 9.1e-05	 0.000961	 0.00046	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1590	 227	 0.00387	 0.028599	 0.07207	 303.707315	 303.707315	 303.707315	 0.0	 0.0	 1	 -30.0	 30.0;
	227	 4807	 0.00949	 0.06625	 0.18391	 309.626945	 309.626945	 309.626945	 0.0	 0.0	 1	 -30.0	 30.0;
	227	 4065	 0.00414	 0.035331	 0.08022	 267.958237	 267.958237	 267.958237	 0.0	 0.0	 1	 -30.0	 30.0;
	227	 4807	 0.009781	 0.065581	 0.18949	 296.815623	 296.815623	 296.815623	 0.0	 0.0	 1	 -30.0	 30.0;
	1265	 27	 0.02818	 0.116099	 0.20127	 387.059593	 387.059593	 387.059593	 0.0	 0.0	 1	 -30.0	 30.0;
	27	 1952	 0.00324	 0.01912	 0.08909	 397.676059	 397.676059	 397.676059	 0.0	 0.0	 1	 -30.0	 30.0;
	2734	 6139	 0.00135	 0.01609	 0.454	 1616.367931	 1616.367931	 1616.367931	 0.0	 0.0	 1	 -30.0	 30.0;
	5602	 5146	 0.00294	 0.0182	 0.02782	 444.711493	 444.711493	 444.711493	 0.0	 0.0	 1	 -30.0	 30.0;
	7317	 5408	 0.000711	 0.00649	 0.01737	 458.21709	 458.21709	 458.21709	 0.0	 0.0	 1	 -30.0	 30.0;
	398	 7317	 0.002651	 0.01375	 0.02404	 296.32521	 296.32521	 296.32521	 0.0	 0.0	 1	 -30.0	 30.0;
	1156	 5408	 0.00105	 0.008469	 0.02555	 437.408266	 437.408266	 437.408266	 0.0	 0.0	 1	 -30.0	 30.0;
	785	 4085	 0.002229	 0.016461	 0.02693	 500.815182	 500.815182	 500.815182	 0.0	 0.0	 1	 -30.0	 30.0;
	785	 4085	 0.002281	 0.01613	 0.02746	 505.352358	 505.352358	 505.352358	 0.0	 0.0	 1	 -30.0	 30.0;
	546	 4085	 0.003341	 0.012651	 0.01616	 274.338557	 274.338557	 274.338557	 0.0	 0.0	 1	 -30.0	 30.0;
	546	 4085	 0.003271	 0.012901	 0.01583	 261.584775	 261.584775	 261.584775	 0.0	 0.0	 1	 -30.0	 30.0;
	5882	 7185	 0.00101	 0.01218	 0.33876	 1855.391012	 1855.391012	 1855.391012	 0.0	 0.0	 1	 -30.0	 30.0;
	5882	 6740	 0.0009	 0.0095	 0.24781	 1980.894616	 1980.894616	 1980.894616	 0.0	 0.0	 1	 -30.0	 30.0;
	7185	 4262	 0.00098	 0.01241	 0.33155	 2041.821617	 2041.821617	 2041.821617	 0.0	 0.0	 1	 -30.0	 30.0;
	5002	 1774	 0.001219	 0.00951	 0.02586	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5002	 7631	 0.001789	 0.01382	 0.03345	 225.44207	 225.44207	 225.44207	 0.0	 0.0	 1	 -30.0	 30.0;
	5002	 7631	 0.00175	 0.014081	 0.03273	 242.635862	 242.635862	 242.635862	 0.0	 0.0	 1	 -30.0	 30.0;
	6907	 3073	 9.1e-05	 0.00087	 0.12315	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6907	 3073	 9.1e-05	 0.00086	 0.12543	 217.164877	 217.164877	 217.164877	 0.0	 0.0	 1	 -30.0	 30.0;
	6907	 7140	 0.000229	 0.00236	 0.32841	 409.066441	 409.066441	 409.066441	 0.0	 0.0	 1	 -30.0	 30.0;
	622	 4703	 0.00125	 0.00557	 0.01779	 594.916532	 594.916532	 594.916532	 0.0	 0.0	 1	 -30.0	 30.0;
	1978	 4721	 0.00757	 0.04013	 0.0575	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1547	 159	 0.00157	 0.01604	 0.39323	 1411.218048	 1411.218048	 1411.218048	 0.0	 0.0	 1	 -30.0	 30.0;
	1547	 159	 0.00154	 0.01634	 0.38504	 1298.380446	 1298.380446	 1298.380446	 0.0	 0.0	 1	 -30.0	 30.0;
	159	 1911	 0.00169	 0.02383	 0.71005	 1563.199548	 1563.199548	 1563.199548	 0.0	 0.0	 1	 -30.0	 30.0;
	1578	 159	 0.00068	 0.0089	 0.28329	 1552.479124	 1552.479124	 1552.479124	 0.0	 0.0	 1	 -30.0	 30.0;
	1691	 4189	 0.010289	 0.036651	 0.09501	 486.001055	 486.001055	 486.001055	 0.0	 0.0	 1	 -30.0	 30.0;
	1691	 4189	 0.00563	 0.03395	 0.10451	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 5198	 0.003591	 0.02763	 0.06689	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 5198	 0.00351	 0.028159	 0.06547	 255.015452	 255.015452	 255.015452	 0.0	 0.0	 1	 -30.0	 30.0;
	5198	 4340	 0.00143	 0.00838	 0.03016	 318.870865	 318.870865	 318.870865	 0.0	 0.0	 1	 -30.0	 30.0;
	6948	 6241	 0.01213	 0.06156	 0.09183	 495.321948	 495.321948	 495.321948	 0.0	 0.0	 1	 -30.0	 30.0;
	5602	 4703	 0.004789	 0.022849	 0.06926	 560.253831	 560.253831	 560.253831	 0.0	 0.0	 1	 -30.0	 30.0;
	477	 7471	 0.00019	 0.00211	 0.00538	 469.661581	 469.661581	 469.661581	 0.0	 0.0	 1	 -30.0	 30.0;
	477	 7732	 0.000331	 0.002349	 0.00731	 285.04419	 285.04419	 285.04419	 0.0	 0.0	 1	 -30.0	 30.0;
	477	 7733	 9.1e-05	 0.000539	 0.00112	 398.927051	 398.927051	 398.927051	 0.0	 0.0	 1	 -30.0	 30.0;
	5893	 5992	 0.00088	 0.00776	 0.29732	 1394.745795	 1394.745795	 1394.745795	 0.0	 0.0	 1	 -30.0	 30.0;
	4227	 4278	 0.00039	 0.00368	 0.13016	 1979.357768	 1979.357768	 1979.357768	 0.0	 0.0	 1	 -30.0	 30.0;
	6036	 1906	 0.00275	 0.01268	 0.02402	 411.958239	 411.958239	 411.958239	 0.0	 0.0	 1	 -30.0	 30.0;
	6036	 8167	 0.00205	 0.00874	 0.02813	 284.521007	 284.521007	 284.521007	 0.0	 0.0	 1	 -30.0	 30.0;
	6036	 1127	 0.00082	 0.00519	 0.01536	 595.667965	 595.667965	 595.667965	 0.0	 0.0	 1	 -30.0	 30.0;
	2410	 733	 0.00519	 0.02355	 0.04694	 465.913942	 465.913942	 465.913942	 0.0	 0.0	 1	 -30.0	 30.0;
	2991	 6121	 0.016711	 0.08874	 0.14919	 430.909438	 430.909438	 430.909438	 0.0	 0.0	 1	 -30.0	 30.0;
	6713	 4004	 0.005099	 0.022659	 0.03759	 495.229734	 495.229734	 495.229734	 0.0	 0.0	 1	 -30.0	 30.0;
	6713	 1618	 0.001469	 0.01213	 0.01502	 601.622271	 601.622271	 601.622271	 0.0	 0.0	 1	 -30.0	 30.0;
	6713	 1618	 0.001659	 0.01189	 0.01702	 552.155731	 552.155731	 552.155731	 0.0	 0.0	 1	 -30.0	 30.0;
	922	 4065	 0.000521	 0.00374	 0.01092	 421.39078	 421.39078	 421.39078	 0.0	 0.0	 1	 -30.0	 30.0;
	922	 4571	 0.006461	 0.048349	 0.12384	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7185	 6627	 0.00293	 0.0257	 0.74111	 1316.598849	 1316.598849	 1316.598849	 0.0	 0.0	 1	 -30.0	 30.0;
	7185	 5089	 0.00178	 0.0157	 0.44951	 1415.926663	 1415.926663	 1415.926663	 0.0	 0.0	 1	 -30.0	 30.0;
	5291	 7185	 0.00115	 0.01332	 0.28982	 1089.131423	 1089.131423	 1089.131423	 0.0	 0.0	 1	 -30.0	 30.0;
	7185	 2005	 0.00078	 0.00752	 0.19838	 1687.742211	 1687.742211	 1687.742211	 0.0	 0.0	 1	 -30.0	 30.0;
	67	 6040	 3.9e-05	 0.00037	 0.01462	 375.978624	 375.978624	 375.978624	 0.0	 0.0	 1	 -30.0	 30.0;
	7363	 7631	 0.0012	 0.006729	 0.02243	 550.894071	 550.894071	 550.894071	 0.0	 0.0	 1	 -30.0	 30.0;
	28	 3028	 0.000211	 0.001659	 0.00497	 365.53706	 365.53706	 365.53706	 0.0	 0.0	 1	 -30.0	 30.0;
	5887	 7526	 0.001659	 0.011919	 0.03316	 513.100653	 513.100653	 513.100653	 0.0	 0.0	 1	 -30.0	 30.0;
	5887	 6231	 0.002	 0.0133	 0.04009	 444.65243	 444.65243	 444.65243	 0.0	 0.0	 1	 -30.0	 30.0;
	3980	 7092	 0.00105	 0.00837	 0.02095	 228.351777	 228.351777	 228.351777	 0.0	 0.0	 1	 -30.0	 30.0;
	2625	 4859	 0.00138	 0.014979	 0.037	 359.210086	 359.210086	 359.210086	 0.0	 0.0	 1	 -30.0	 30.0;
	5233	 6202	 0.0	 0.0003	 0.03478	 254.555523	 254.555523	 254.555523	 0.0	 0.0	 1	 -30.0	 30.0;
	2707	 6202	 0.0	 0.0003	 0.03546	 434.697849	 434.697849	 434.697849	 0.0	 0.0	 1	 -30.0	 30.0;
	2707	 4896	 0.00164	 0.00782	 0.01408	 403.082795	 403.082795	 403.082795	 0.0	 0.0	 1	 -30.0	 30.0;
	3301	 209	 0.007099	 0.04044	 0.0622	 522.240546	 522.240546	 522.240546	 0.0	 0.0	 1	 -30.0	 30.0;
	8208	 7132	 0.00181	 0.00914	 0.01575	 583.331433	 583.331433	 583.331433	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 6658	 0.00027	 0.00247	 0.09082	 1943.296782	 1943.296782	 1943.296782	 0.0	 0.0	 1	 -30.0	 30.0;
	6658	 4510	 0.00266	 0.03206	 1.13637	 1676.320168	 1676.320168	 1676.320168	 0.0	 0.0	 1	 -30.0	 30.0;
	7558	 891	 0.000591	 0.005081	 0.00898	 412.018826	 412.018826	 412.018826	 0.0	 0.0	 1	 -30.0	 30.0;
	7558	 681	 0.002229	 0.016099	 0.04517	 435.74231	 435.74231	 435.74231	 0.0	 0.0	 1	 -30.0	 30.0;
	3668	 4878	 0.00205	 0.02585	 0.06907	 1110.268851	 1110.268851	 1110.268851	 0.0	 0.0	 1	 -30.0	 30.0;
	7093	 581	 0.00101	 0.0091	 0.2532	 1335.850594	 1335.850594	 1335.850594	 0.0	 0.0	 1	 -30.0	 30.0;
	7093	 5089	 0.001	 0.00871	 0.25243	 1318.5543	 1318.5543	 1318.5543	 0.0	 0.0	 1	 -30.0	 30.0;
	8256	 1379	 0.00112	 0.00895	 0.02078	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8256	 1379	 0.001099	 0.008289	 0.02033	 220.59548	 220.59548	 220.59548	 0.0	 0.0	 1	 -30.0	 30.0;
	8256	 2844	 0.001289	 0.0095	 0.02391	 231.229095	 231.229095	 231.229095	 0.0	 0.0	 1	 -30.0	 30.0;
	8256	 2844	 0.00126	 0.00968	 0.02342	 231.911176	 231.911176	 231.911176	 0.0	 0.0	 1	 -30.0	 30.0;
	3928	 4958	 0.00065	 0.00723	 0.21781	 1551.523447	 1551.523447	 1551.523447	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 3728	 0.001781	 0.012669	 0.03664	 309.734401	 309.734401	 309.734401	 0.0	 0.0	 1	 -30.0	 30.0;
	3614	 980	 0.00086	 0.00956	 0.21021	 1066.623665	 1066.623665	 1066.623665	 0.0	 0.0	 1	 -30.0	 30.0;
	3614	 732	 0.00248	 0.02429	 0.63341	 1307.253361	 1307.253361	 1307.253361	 0.0	 0.0	 1	 -30.0	 30.0;
	3614	 4103	 0.00151	 0.01699	 0.3774	 1347.545124	 1347.545124	 1347.545124	 0.0	 0.0	 1	 -30.0	 30.0;
	5343	 3356	 0.003159	 0.01537	 0.04444	 255.341251	 255.341251	 255.341251	 0.0	 0.0	 1	 -30.0	 30.0;
	7441	 2832	 0.00075	 0.00683	 0.18112	 1377.877975	 1377.877975	 1377.877975	 0.0	 0.0	 1	 -30.0	 30.0;
	7441	 2580	 0.00223	 0.02524	 0.55052	 1639.504908	 1639.504908	 1639.504908	 0.0	 0.0	 1	 -30.0	 30.0;
	581	 5089	 0.00191	 0.0208	 0.46218	 993.197181	 993.197181	 993.197181	 0.0	 0.0	 1	 -30.0	 30.0;
	1547	 581	 0.00074	 0.00784	 0.18584	 935.02532	 935.02532	 935.02532	 0.0	 0.0	 1	 -30.0	 30.0;
	1547	 581	 0.00073	 0.00799	 0.18188	 1104.622989	 1104.622989	 1104.622989	 0.0	 0.0	 1	 -30.0	 30.0;
	1293	 3295	 0.000789	 0.00482	 0.01619	 529.719057	 529.719057	 529.719057	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 1293	 0.000789	 0.004409	 0.01467	 386.72503	 386.72503	 386.72503	 0.0	 0.0	 1	 -30.0	 30.0;
	2575	 2991	 0.005461	 0.03161	 0.05048	 547.037833	 547.037833	 547.037833	 0.0	 0.0	 1	 -30.0	 30.0;
	1493	 7776	 6e-05	 0.00087	 0.09273	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2878	 1284	 0.00593	 0.040961	 0.1172	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2878	 4571	 0.003771	 0.030841	 0.0752	 268.225734	 268.225734	 268.225734	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 7772	 0.00038	 0.001461	 0.16307	 548.742656	 548.742656	 548.742656	 0.0	 0.0	 1	 -30.0	 30.0;
	7772	 3716	 0.00149	 0.00938	 0.02776	 304.793311	 304.793311	 304.793311	 0.0	 0.0	 1	 -30.0	 30.0;
	7772	 3716	 0.001521	 0.00918	 0.02829	 350.298823	 350.298823	 350.298823	 0.0	 0.0	 1	 -30.0	 30.0;
	1906	 396	 0.00407	 0.015469	 0.02869	 357.367323	 357.367323	 357.367323	 0.0	 0.0	 1	 -30.0	 30.0;
	4507	 1293	 0.00082	 0.006219	 0.01525	 275.399023	 275.399023	 275.399023	 0.0	 0.0	 1	 -30.0	 30.0;
	2417	 1799	 0.00161	 0.00888	 0.0144	 445.381381	 445.381381	 445.381381	 0.0	 0.0	 1	 -30.0	 30.0;
	2417	 8199	 0.00118	 0.006461	 0.01047	 523.997573	 523.997573	 523.997573	 0.0	 0.0	 1	 -30.0	 30.0;
	8001	 5566	 0.00082	 0.009091	 0.01791	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	681	 4089	 0.01893	 0.0848	 0.26385	 460.390605	 460.390605	 460.390605	 0.0	 0.0	 1	 -30.0	 30.0;
	681	 4089	 0.01313	 0.082409	 0.2672	 451.384461	 451.384461	 451.384461	 0.0	 0.0	 1	 -30.0	 30.0;
	681	 5755	 0.000281	 0.00149	 0.00187	 243.959252	 243.959252	 243.959252	 0.0	 0.0	 1	 -30.0	 30.0;
	4806	 2832	 0.00019	 0.00199	 0.05042	 1351.769977	 1351.769977	 1351.769977	 0.0	 0.0	 1	 -30.0	 30.0;
	2832	 4806	 0.0002	 0.00188	 0.05312	 1398.935106	 1398.935106	 1398.935106	 0.0	 0.0	 1	 -30.0	 30.0;
	152	 2676	 0.003159	 0.025331	 0.05892	 233.139304	 233.139304	 233.139304	 0.0	 0.0	 1	 -30.0	 30.0;
	6971	 5801	 0.00445	 0.01886	 0.03964	 616.123554	 616.123554	 616.123554	 0.0	 0.0	 1	 -30.0	 30.0;
	5282	 4842	 0.00461	 0.02205	 0.04378	 525.746979	 525.746979	 525.746979	 0.0	 0.0	 1	 -30.0	 30.0;
	6602	 7444	 0.00061	 0.00494	 0.01145	 248.684668	 248.684668	 248.684668	 0.0	 0.0	 1	 -30.0	 30.0;
	6602	 873	 0.00082	 0.00462	 0.02449	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3150	 7855	 0.000331	 0.003271	 0.00943	 560.796829	 560.796829	 560.796829	 0.0	 0.0	 1	 -30.0	 30.0;
	3150	 1618	 0.00056	 0.004081	 0.01565	 604.571607	 604.571607	 604.571607	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 8223	 0.00163	 0.007521	 0.02413	 299.494794	 299.494794	 299.494794	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 1338	 0.001659	 0.00736	 0.02459	 228.445897	 228.445897	 228.445897	 0.0	 0.0	 1	 -30.0	 30.0;
	5935	 1369	 0.00719	 0.049211	 0.07788	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6766	 1799	 6e-05	 0.00039	 0.00056	 452.721569	 452.721569	 452.721569	 0.0	 0.0	 1	 -30.0	 30.0;
	938	 5465	 0.00288	 0.018	 0.02583	 547.767927	 547.767927	 547.767927	 0.0	 0.0	 1	 -30.0	 30.0;
	938	 7962	 0.00288	 0.0182	 0.02628	 506.247066	 506.247066	 506.247066	 0.0	 0.0	 1	 -30.0	 30.0;
	938	 4807	 0.00111	 0.008531	 0.01377	 455.463614	 455.463614	 455.463614	 0.0	 0.0	 1	 -30.0	 30.0;
	938	 3896	 0.00307	 0.022289	 0.13473	 519.69703	 519.69703	 519.69703	 0.0	 0.0	 1	 -30.0	 30.0;
	2789	 4103	 0.00091	 0.00868	 0.30687	 1547.696135	 1547.696135	 1547.696135	 0.0	 0.0	 1	 -30.0	 30.0;
	5089	 8272	 0.00098	 0.0118	 0.22347	 1498.155636	 1498.155636	 1498.155636	 0.0	 0.0	 1	 -30.0	 30.0;
	5089	 6740	 0.00053	 0.00591	 0.14433	 1678.345385	 1678.345385	 1678.345385	 0.0	 0.0	 1	 -30.0	 30.0;
	5089	 2005	 0.00086	 0.00991	 0.21418	 1370.212161	 1370.212161	 1370.212161	 0.0	 0.0	 1	 -30.0	 30.0;
	6350	 3028	 0.00545	 0.034099	 0.05137	 496.737172	 496.737172	 496.737172	 0.0	 0.0	 1	 -30.0	 30.0;
	1882	 3176	 0.00095	 0.006091	 0.02027	 557.962189	 557.962189	 557.962189	 0.0	 0.0	 1	 -30.0	 30.0;
	3223	 732	 0.00305	 0.0272	 0.76729	 1317.233334	 1317.233334	 1317.233334	 0.0	 0.0	 1	 -30.0	 30.0;
	785	 4467	 0.000281	 0.001841	 0.00299	 444.160874	 444.160874	 444.160874	 0.0	 0.0	 1	 -30.0	 30.0;
	785	 5858	 0.004531	 0.02451	 0.03616	 328.684457	 328.684457	 328.684457	 0.0	 0.0	 1	 -30.0	 30.0;
	4004	 1369	 0.00618	 0.02961	 0.05724	 551.631024	 551.631024	 551.631024	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 6118	 0.00064	 0.004461	 0.0135	 307.600896	 307.600896	 307.600896	 0.0	 0.0	 1	 -30.0	 30.0;
	828	 3847	 0.00143	 0.00513	 0.01209	 570.250327	 570.250327	 570.250327	 0.0	 0.0	 1	 -30.0	 30.0;
	828	 1127	 0.0052	 0.021841	 0.04386	 473.866099	 473.866099	 473.866099	 0.0	 0.0	 1	 -30.0	 30.0;
	546	 4467	 0.00138	 0.008669	 0.01594	 452.285647	 452.285647	 452.285647	 0.0	 0.0	 1	 -30.0	 30.0;
	5858	 546	 0.00314	 0.013169	 0.015	 373.931999	 373.931999	 373.931999	 0.0	 0.0	 1	 -30.0	 30.0;
	3847	 1746	 0.002479	 0.01331	 0.02234	 491.930211	 491.930211	 491.930211	 0.0	 0.0	 1	 -30.0	 30.0;
	2088	 2485	 7e-05	 0.00194	 0.14737	 369.585729	 369.585729	 369.585729	 0.0	 0.0	 1	 -30.0	 30.0;
	8313	 7631	 0.001159	 0.00931	 0.02166	 216.314751	 216.314751	 216.314751	 0.0	 0.0	 1	 -30.0	 30.0;
	4896	 5760	 0.00062	 0.003669	 0.01131	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2279	 4695	 0.015969	 0.056711	 0.13475	 635.211932	 635.211932	 635.211932	 0.0	 0.0	 1	 -30.0	 30.0;
	4695	 3418	 0.0085	 0.03719	 0.0693	 419.618511	 419.618511	 419.618511	 0.0	 0.0	 1	 -30.0	 30.0;
	2523	 8223	 0.001531	 0.00732	 0.02343	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2523	 8223	 0.00205	 0.01062	 0.03022	 221.707388	 221.707388	 221.707388	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 4958	 0.00091	 0.01056	 0.22032	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	732	 7822	 0.00167	 0.02069	 0.39692	 1558.894397	 1558.894397	 1558.894397	 0.0	 0.0	 1	 -30.0	 30.0;
	5714	 6241	 0.002719	 0.016219	 0.0236	 530.822962	 530.822962	 530.822962	 0.0	 0.0	 1	 -30.0	 30.0;
	7477	 3997	 0.002	 0.02376	 0.67032	 1736.843046	 1736.843046	 1736.843046	 0.0	 0.0	 1	 -30.0	 30.0;
	7477	 3997	 0.00226	 0.02328	 0.7597	 1664.454511	 1664.454511	 1664.454511	 0.0	 0.0	 1	 -30.0	 30.0;
	6924	 398	 0.004151	 0.02119	 0.03874	 544.293121	 544.293121	 544.293121	 0.0	 0.0	 1	 -30.0	 30.0;
	8167	 7593	 0.001841	 0.010909	 0.02506	 229.497598	 229.497598	 229.497598	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 3809	 0.000669	 0.00399	 0.00581	 481.73633	 481.73633	 481.73633	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 1341	 8e-05	 0.00098	 0.0192	 1637.629097	 1637.629097	 1637.629097	 0.0	 0.0	 1	 -30.0	 30.0;
	7471	 7733	 0.0002	 0.0025	 0.01729	 312.997343	 312.997343	 312.997343	 0.0	 0.0	 1	 -30.0	 30.0;
	4985	 4807	 0.006219	 0.031599	 0.055	 535.941241	 535.941241	 535.941241	 0.0	 0.0	 1	 -30.0	 30.0;
	4985	 1308	 0.00438	 0.023169	 0.03876	 545.127623	 545.127623	 545.127623	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 3896	 0.00581	 0.03088	 0.06283	 516.022934	 516.022934	 516.022934	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 3896	 0.0065	 0.02637	 0.07223	 438.647825	 438.647825	 438.647825	 0.0	 0.0	 1	 -30.0	 30.0;
	4227	 541	 0.00198	 0.02208	 0.66516	 1693.343317	 1693.343317	 1693.343317	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 4842	 0.00093	 0.006659	 0.01743	 328.529751	 328.529751	 328.529751	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 4842	 0.000909	 0.006789	 0.01708	 297.063688	 297.063688	 297.063688	 0.0	 0.0	 1	 -30.0	 30.0;
	3668	 980	 0.00244	 0.01919	 0.6083	 864.403996	 864.403996	 864.403996	 0.0	 0.0	 1	 -30.0	 30.0;
	2139	 7782	 0.00194	 0.01549	 0.03601	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 3697	 0.0002	 0.001479	 0.00229	 519.71875	 519.71875	 519.71875	 0.0	 0.0	 1	 -30.0	 30.0;
	4089	 1379	 0.001091	 0.009461	 0.02148	 617.911065	 617.911065	 617.911065	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 5989	 0.003081	 0.00899	 0.01672	 499.655643	 499.655643	 499.655643	 0.0	 0.0	 1	 -30.0	 30.0;
	5989	 1325	 0.00357	 0.0138	 0.01939	 470.841315	 470.841315	 470.841315	 0.0	 0.0	 1	 -30.0	 30.0;
	3176	 6923	 0.001229	 0.00986	 0.02292	 493.872429	 493.872429	 493.872429	 0.0	 0.0	 1	 -30.0	 30.0;
	1812	 8262	 0.001211	 0.00913	 0.02242	 577.845058	 577.845058	 577.845058	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 7267	 0.00116	 0.01053	 0.28682	 1582.646114	 1582.646114	 1582.646114	 0.0	 0.0	 1	 -30.0	 30.0;
	4226	 5157	 0.0017	 0.009781	 0.03441	 248.831754	 248.831754	 248.831754	 0.0	 0.0	 1	 -30.0	 30.0;
	4226	 5157	 0.001521	 0.011091	 0.03062	 220.763143	 220.763143	 220.763143	 0.0	 0.0	 1	 -30.0	 30.0;
	7069	 401	 0.0043	 0.0233	 0.06331	 573.180611	 573.180611	 573.180611	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 4050	 0.00019	 0.0016	 0.06168	 991.811056	 991.811056	 991.811056	 0.0	 0.0	 1	 -30.0	 30.0;
	4339	 7526	 0.00838	 0.072479	 0.17676	 229.296022	 229.296022	 229.296022	 0.0	 0.0	 1	 -30.0	 30.0;
	4339	 897	 0.00787	 0.049211	 0.15585	 353.351043	 353.351043	 353.351043	 0.0	 0.0	 1	 -30.0	 30.0;
	398	 209	 0.00557	 0.03376	 0.05029	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3859	 6629	 0.01213	 0.06564	 0.13833	 340.04626	 340.04626	 340.04626	 0.0	 0.0	 1	 -30.0	 30.0;
	6678	 2844	 0.003531	 0.01086	 0.0176	 400.38762	 400.38762	 400.38762	 0.0	 0.0	 1	 -30.0	 30.0;
	6678	 6729	 0.0158	 0.057031	 0.07883	 338.373827	 338.373827	 338.373827	 0.0	 0.0	 1	 -30.0	 30.0;
	684	 1911	 0.00289	 0.0244	 0.70742	 1292.962314	 1292.962314	 1292.962314	 0.0	 0.0	 1	 -30.0	 30.0;
	1457	 3729	 0.000521	 0.00413	 0.00749	 553.25354	 553.25354	 553.25354	 0.0	 0.0	 1	 -30.0	 30.0;
	7328	 3729	 0.000531	 0.004039	 0.00763	 509.045506	 509.045506	 509.045506	 0.0	 0.0	 1	 -30.0	 30.0;
	209	 1648	 0.00431	 0.02226	 0.04491	 419.196306	 419.196306	 419.196306	 0.0	 0.0	 1	 -30.0	 30.0;
	2753	 3716	 0.00163	 0.00899	 0.01424	 558.003724	 558.003724	 558.003724	 0.0	 0.0	 1	 -30.0	 30.0;
	4227	 1165	 0.00274	 0.02428	 0.78775	 1430.67317	 1430.67317	 1430.67317	 0.0	 0.0	 1	 -30.0	 30.0;
	5729	 5465	 0.0093	 0.056979	 0.08381	 526.04458	 526.04458	 526.04458	 0.0	 0.0	 1	 -30.0	 30.0;
	5729	 7918	 0.011281	 0.080039	 0.20991	 253.337684	 253.337684	 253.337684	 0.0	 0.0	 1	 -30.0	 30.0;
	5729	 5109	 0.00449	 0.02376	 0.07508	 450.476797	 450.476797	 450.476797	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 7487	 0.00014	 0.00148	 0.04807	 1754.010995	 1754.010995	 1754.010995	 0.0	 0.0	 1	 -30.0	 30.0;
	6165	 7526	 0.0055	 0.033659	 0.10993	 429.020567	 429.020567	 429.020567	 0.0	 0.0	 1	 -30.0	 30.0;
	4065	 4959	 0.00249	 0.02082	 0.05329	 471.233798	 471.233798	 471.233798	 0.0	 0.0	 1	 -30.0	 30.0;
	1578	 1911	 0.00164	 0.02252	 0.68801	 1606.120079	 1606.120079	 1606.120079	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 1956	 0.000961	 0.0047	 0.00912	 262.218463	 262.218463	 262.218463	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 1956	 0.000979	 0.004599	 0.00929	 270.097839	 270.097839	 270.097839	 0.0	 0.0	 1	 -30.0	 30.0;
	6974	 346	 0.00057	 0.00515	 0.14926	 1270.952798	 1270.952798	 1270.952798	 0.0	 0.0	 1	 -30.0	 30.0;
	7526	 6231	 0.00143	 0.011651	 0.03006	 382.701891	 382.701891	 382.701891	 0.0	 0.0	 1	 -30.0	 30.0;
	1367	 3716	 0.00126	 0.009211	 0.02652	 279.618022	 279.618022	 279.618022	 0.0	 0.0	 1	 -30.0	 30.0;
	5465	 630	 9.1e-05	 0.000211	 0.00044	 396.181577	 396.181577	 396.181577	 0.0	 0.0	 1	 -30.0	 30.0;
	7962	 630	 0.000211	 0.000711	 0.0012	 374.560733	 374.560733	 374.560733	 0.0	 0.0	 1	 -30.0	 30.0;
	7962	 5109	 0.01095	 0.07062	 0.09816	 464.957885	 464.957885	 464.957885	 0.0	 0.0	 1	 -30.0	 30.0;
	1952	 5109	 0.00125	 0.007281	 0.01067	 300.864292	 300.864292	 300.864292	 0.0	 0.0	 1	 -30.0	 30.0;
	1952	 5109	 0.001	 0.0045	 0.0089	 311.965837	 311.965837	 311.965837	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 4571	 0.00282	 0.026419	 0.05997	 303.581949	 303.581949	 303.581949	 0.0	 0.0	 1	 -30.0	 30.0;
	6926	 6007	 0.003479	 0.01456	 0.05279	 224.454005	 224.454005	 224.454005	 0.0	 0.0	 1	 -30.0	 30.0;
	4807	 3896	 0.005521	 0.03418	 0.05866	 460.549123	 460.549123	 460.549123	 0.0	 0.0	 1	 -30.0	 30.0;
	4807	 3896	 0.00563	 0.033461	 0.05978	 490.825544	 490.825544	 490.825544	 0.0	 0.0	 1	 -30.0	 30.0;
	4571	 4322	 0.00095	 0.0072	 0.02091	 425.181096	 425.181096	 425.181096	 0.0	 0.0	 1	 -30.0	 30.0;
	4571	 6629	 0.00093	 0.007159	 0.01053	 523.959468	 523.959468	 523.959468	 0.0	 0.0	 1	 -30.0	 30.0;
	1308	 3896	 0.00988	 0.058651	 0.1092	 586.366506	 586.366506	 586.366506	 0.0	 0.0	 1	 -30.0	 30.0;
	6034	 7140	 3.9e-05	 0.00044	 0.06158	 606.884588	 606.884588	 606.884588	 0.0	 0.0	 1	 -30.0	 30.0;
	6034	 7140	 3.9e-05	 0.00043	 0.06272	 544.680269	 544.680269	 544.680269	 0.0	 0.0	 1	 -30.0	 30.0;
	6665	 4936	 0.00018	 0.000781	 0.00101	 379.143635	 379.143635	 379.143635	 0.0	 0.0	 1	 -30.0	 30.0;
	3927	 6868	 0.002961	 0.01669	 0.03408	 434.588868	 434.588868	 434.588868	 0.0	 0.0	 1	 -30.0	 30.0;
	5266	 3567	 0.00056	 0.00432	 0.00697	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6128	 5478	 0.0002	 0.00246	 0.05268	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6128	 6279	 0.0003	 0.00377	 0.07873	 1447.11778	 1447.11778	 1447.11778	 0.0	 0.0	 1	 -30.0	 30.0;
	4566	 8268	 0.00014	 0.00057	 0.00095	 351.41759	 351.41759	 351.41759	 0.0	 0.0	 1	 -30.0	 30.0;
	2659	 8268	 0.00013	 0.000729	 0.00089	 359.459294	 359.459294	 359.459294	 0.0	 0.0	 1	 -30.0	 30.0;
	1307	 8268	 0.00012	 0.000581	 0.00093	 378.117084	 378.117084	 378.117084	 0.0	 0.0	 1	 -30.0	 30.0;
	1692	 8268	 0.00011	 0.00064	 0.00091	 280.599609	 280.599609	 280.599609	 0.0	 0.0	 1	 -30.0	 30.0;
	7551	 8268	 0.00019	 0.00056	 0.00107	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5644	 7976	 0.00062	 0.004909	 0.00728	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	8352	 7114	 7e-05	 0.00076	 0.01698	 1000.370019	 1000.370019	 1000.370019	 0.0	 0.0	 1	 -30.0	 30.0;
	8352	 8169	 0.00066	 0.00622	 0.11119	 1733.803574	 1733.803574	 1733.803574	 0.0	 0.0	 1	 -30.0	 30.0;
	8352	 1941	 0.00054	 0.00752	 0.26021	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	8352	 24	 0.00105	 0.00877	 0.19663	 1434.038441	 1434.038441	 1434.038441	 0.0	 0.0	 1	 -30.0	 30.0;
	105	 8083	 8e-05	 0.00091	 0.0182	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	105	 4184	 0.00056	 0.00719	 0.26685	 1080.229547	 1080.229547	 1080.229547	 0.0	 0.0	 1	 -30.0	 30.0;
	2202	 5023	 0.000531	 0.002039	 0.0042	 435.108622	 435.108622	 435.108622	 0.0	 0.0	 1	 -30.0	 30.0;
	2202	 4395	 0.008659	 0.03769	 0.0546	 403.161291	 403.161291	 403.161291	 0.0	 0.0	 1	 -30.0	 30.0;
	2202	 8136	 0.003849	 0.021099	 0.03049	 378.911575	 378.911575	 378.911575	 0.0	 0.0	 1	 -30.0	 30.0;
	2202	 7726	 0.00688	 0.035969	 0.04966	 414.189674	 414.189674	 414.189674	 0.0	 0.0	 1	 -30.0	 30.0;
	2202	 6250	 0.006729	 0.03713	 0.04898	 240.178081	 240.178081	 240.178081	 0.0	 0.0	 1	 -30.0	 30.0;
	2202	 3091	 0.00111	 0.006651	 0.01236	 526.441255	 526.441255	 526.441255	 0.0	 0.0	 1	 -30.0	 30.0;
	2202	 580	 0.0023	 0.008909	 0.01481	 360.931294	 360.931294	 360.931294	 0.0	 0.0	 1	 -30.0	 30.0;
	2202	 2356	 0.000841	 0.00313	 0.00503	 377.327927	 377.327927	 377.327927	 0.0	 0.0	 1	 -30.0	 30.0;
	2202	 4861	 0.003521	 0.017479	 0.02439	 409.168563	 409.168563	 409.168563	 0.0	 0.0	 1	 -30.0	 30.0;
	2775	 651	 3.9e-05	 0.00025	 0.0	 620.730082	 620.730082	 620.730082	 0.0	 0.0	 1	 -30.0	 30.0;
	2761	 2114	 0.000159	 0.000729	 0.06691	 457.491568	 457.491568	 457.491568	 0.0	 0.0	 1	 -30.0	 30.0;
	7847	 6776	 0.005281	 0.032099	 0.05218	 509.751594	 509.751594	 509.751594	 0.0	 0.0	 1	 -30.0	 30.0;
	7847	 6776	 0.005651	 0.029419	 0.05541	 485.345266	 485.345266	 485.345266	 0.0	 0.0	 1	 -30.0	 30.0;
	816	 3323	 0.000271	 0.00036	 0.02718	 318.400267	 318.400267	 318.400267	 0.0	 0.0	 1	 -30.0	 30.0;
	7921	 6394	 0.00044	 0.00143	 0.19132	 582.640587	 582.640587	 582.640587	 0.0	 0.0	 1	 -30.0	 30.0;
	7921	 3563	 0.000159	 0.00074	 0.06733	 564.796723	 564.796723	 564.796723	 0.0	 0.0	 1	 -30.0	 30.0;
	2068	 1803	 0.00019	 0.000591	 0.14587	 441.4516	 441.4516	 441.4516	 0.0	 0.0	 1	 -30.0	 30.0;
	4664	 2657	 0.00019	 0.00087	 0.15682	 299.879275	 299.879275	 299.879275	 0.0	 0.0	 1	 -30.0	 30.0;
	6011	 4474	 0.002591	 0.013659	 0.0182	 429.504502	 429.504502	 429.504502	 0.0	 0.0	 1	 -30.0	 30.0;
	6011	 6626	 0.00305	 0.01168	 0.02236	 280.555788	 280.555788	 280.555788	 0.0	 0.0	 1	 -30.0	 30.0;
	371	 1005	 0.000159	 0.000599	 0.06412	 538.327384	 538.327384	 538.327384	 0.0	 0.0	 1	 -30.0	 30.0;
	371	 1005	 0.000159	 0.00062	 0.06278	 503.836537	 503.836537	 503.836537	 0.0	 0.0	 1	 -30.0	 30.0;
	2954	 4474	 0.00101	 0.004229	 0.00593	 573.509839	 573.509839	 573.509839	 0.0	 0.0	 1	 -30.0	 30.0;
	2954	 3898	 0.00319	 0.018651	 0.11399	 566.230618	 566.230618	 566.230618	 0.0	 0.0	 1	 -30.0	 30.0;
	2954	 6626	 0.000729	 0.00337	 0.00402	 274.904037	 274.904037	 274.904037	 0.0	 0.0	 1	 -30.0	 30.0;
	1044	 1080	 0.002961	 0.012831	 0.01603	 390.3393	 390.3393	 390.3393	 0.0	 0.0	 1	 -30.0	 30.0;
	1044	 7210	 0.000591	 0.00339	 0.0122	 378.609783	 378.609783	 378.609783	 0.0	 0.0	 1	 -30.0	 30.0;
	8080	 2197	 0.00024	 0.001219	 0.00175	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 2701	 0.006219	 0.036341	 0.07005	 485.907317	 485.907317	 485.907317	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 5473	 0.001841	 0.01193	 0.02173	 580.651119	 580.651119	 580.651119	 0.0	 0.0	 1	 -30.0	 30.0;
	2992	 6585	 0.001409	 0.01113	 0.01514	 518.798511	 518.798511	 518.798511	 0.0	 0.0	 1	 -30.0	 30.0;
	2992	 258	 0.00151	 0.00768	 0.01116	 482.193973	 482.193973	 482.193973	 0.0	 0.0	 1	 -30.0	 30.0;
	2992	 2791	 0.00599	 0.03313	 0.04364	 501.005707	 501.005707	 501.005707	 0.0	 0.0	 1	 -30.0	 30.0;
	2992	 3080	 0.001771	 0.010151	 0.02023	 470.454929	 470.454929	 470.454929	 0.0	 0.0	 1	 -30.0	 30.0;
	4261	 4490	 0.00074	 0.00311	 0.31301	 238.895844	 238.895844	 238.895844	 0.0	 0.0	 1	 -30.0	 30.0;
	4261	 4490	 0.000729	 0.003159	 0.30635	 299.358759	 299.358759	 299.358759	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 7082	 0.005271	 0.01906	 0.03513	 383.731111	 383.731111	 383.731111	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 4949	 0.00906	 0.053151	 0.07992	 436.824114	 436.824114	 436.824114	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 1698	 0.00405	 0.0153	 0.02875	 364.175945	 364.175945	 364.175945	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 4913	 0.00055	 0.003961	 0.02467	 507.257614	 507.257614	 507.257614	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 4913	 0.00055	 0.003729	 0.01897	 451.015603	 451.015603	 451.015603	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 1467	 0.00107	 0.007789	 0.01233	 526.277402	 526.277402	 526.277402	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 1467	 0.00112	 0.00775	 0.01328	 580.409914	 580.409914	 580.409914	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 1467	 0.001031	 0.00775	 0.0122	 284.016495	 284.016495	 284.016495	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 2213	 0.00062	 0.003219	 0.00455	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 865	 0.00068	 0.002659	 0.00532	 520.876002	 520.876002	 520.876002	 0.0	 0.0	 1	 -30.0	 30.0;
	8292	 454	 0.00193	 0.012479	 0.02215	 593.787478	 593.787478	 593.787478	 0.0	 0.0	 1	 -30.0	 30.0;
	8292	 2739	 0.001159	 0.007229	 0.01333	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8292	 2679	 0.00137	 0.008729	 0.0151	 499.489505	 499.489505	 499.489505	 0.0	 0.0	 1	 -30.0	 30.0;
	8292	 2679	 0.001401	 0.00855	 0.01539	 545.544112	 545.544112	 545.544112	 0.0	 0.0	 1	 -30.0	 30.0;
	8292	 2679	 0.001331	 0.008521	 0.0151	 541.137636	 541.137636	 541.137636	 0.0	 0.0	 1	 -30.0	 30.0;
	6413	 2011	 0.00031	 0.00081	 0.05914	 392.237316	 392.237316	 392.237316	 0.0	 0.0	 1	 -30.0	 30.0;
	6413	 7312	 0.000341	 0.00119	 0.1412	 399.770317	 399.770317	 399.770317	 0.0	 0.0	 1	 -30.0	 30.0;
	6413	 4080	 0.00031	 0.001281	 0.13155	 495.071978	 495.071978	 495.071978	 0.0	 0.0	 1	 -30.0	 30.0;
	6413	 3860	 0.00094	 0.0035	 0.15159	 543.601132	 543.601132	 543.601132	 0.0	 0.0	 1	 -30.0	 30.0;
	7738	 6391	 7e-05	 0.000651	 0.06234	 217.31844	 217.31844	 217.31844	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 3326	 0.00019	 0.00124	 0.13922	 602.279203	 602.279203	 602.279203	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 2657	 0.000331	 0.002539	 0.22112	 541.255	 541.255	 541.255	 0.0	 0.0	 1	 -30.0	 30.0;
	2861	 2647	 0.0016	 0.02113	 0.39058	 1980.272637	 1980.272637	 1980.272637	 0.0	 0.0	 1	 -30.0	 30.0;
	7048	 4831	 0.000909	 0.004711	 0.08412	 469.242805	 469.242805	 469.242805	 0.0	 0.0	 1	 -30.0	 30.0;
	7048	 4831	 0.00088	 0.004969	 0.08209	 433.9769	 433.9769	 433.9769	 0.0	 0.0	 1	 -30.0	 30.0;
	2	 7870	 0.001841	 0.0088	 0.01539	 325.213843	 325.213843	 325.213843	 0.0	 0.0	 1	 -30.0	 30.0;
	2	 7423	 0.01013	 0.04238	 0.07841	 498.251088	 498.251088	 498.251088	 0.0	 0.0	 1	 -30.0	 30.0;
	6588	 2667	 0.00059	 0.00802	 0.26604	 825.882736	 825.882736	 825.882736	 0.0	 0.0	 1	 -30.0	 30.0;
	6588	 2667	 0.00054	 0.0079	 0.24432	 784.505636	 784.505636	 784.505636	 0.0	 0.0	 1	 -30.0	 30.0;
	6588	 3569	 0.00171	 0.02128	 0.77791	 1111.911008	 1111.911008	 1111.911008	 0.0	 0.0	 1	 -30.0	 30.0;
	6588	 3569	 0.00174	 0.02084	 0.79287	 975.494133	 975.494133	 975.494133	 0.0	 0.0	 1	 -30.0	 30.0;
	6588	 5968	 0.00086	 0.01433	 0.53318	 1265.566258	 1265.566258	 1265.566258	 0.0	 0.0	 1	 -30.0	 30.0;
	6588	 5968	 0.00087	 0.01404	 0.54364	 845.928903	 845.928903	 845.928903	 0.0	 0.0	 1	 -30.0	 30.0;
	6588	 3485	 0.00126	 0.01447	 0.5739	 1225.455495	 1225.455495	 1225.455495	 0.0	 0.0	 1	 -30.0	 30.0;
	6588	 5126	 0.00122	 0.01509	 0.55265	 1173.867401	 1173.867401	 1173.867401	 0.0	 0.0	 1	 -30.0	 30.0;
	6588	 5126	 0.00154	 0.019	 0.37428	 1384.1807	 1384.1807	 1384.1807	 0.0	 0.0	 1	 -30.0	 30.0;
	4474	 4464	 0.00474	 0.03564	 0.05389	 584.214329	 584.214329	 584.214329	 0.0	 0.0	 1	 -30.0	 30.0;
	4474	 5404	 0.006	 0.047849	 0.07097	 544.097261	 544.097261	 544.097261	 0.0	 0.0	 1	 -30.0	 30.0;
	4474	 4758	 0.008039	 0.03375	 0.09851	 398.687369	 398.687369	 398.687369	 0.0	 0.0	 1	 -30.0	 30.0;
	6217	 6626	 2.1e-05	 0.000211	 0.0	 614.640122	 614.640122	 614.640122	 0.0	 0.0	 1	 -30.0	 30.0;
	7534	 3347	 0.00045	 0.002341	 0.0364	 298.342114	 298.342114	 298.342114	 0.0	 0.0	 1	 -30.0	 30.0;
	2509	 7987	 0.000669	 0.004281	 0.00705	 537.199091	 537.199091	 537.199091	 0.0	 0.0	 1	 -30.0	 30.0;
	8387	 7987	 0.00068	 0.00419	 0.00719	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2804	 6463	 0.000729	 0.00431	 0.00836	 619.478329	 619.478329	 619.478329	 0.0	 0.0	 1	 -30.0	 30.0;
	2804	 6463	 0.000591	 0.004651	 0.00697	 569.23635	 569.23635	 569.23635	 0.0	 0.0	 1	 -30.0	 30.0;
	2804	 8054	 0.00099	 0.005081	 0.00637	 451.722072	 451.722072	 451.722072	 0.0	 0.0	 1	 -30.0	 30.0;
	1427	 6878	 0.00212	 0.013031	 0.02462	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1427	 3220	 0.002159	 0.01275	 0.02509	 246.765313	 246.765313	 246.765313	 0.0	 0.0	 1	 -30.0	 30.0;
	7874	 3363	 0.00025	 0.00095	 0.20339	 278.753035	 278.753035	 278.753035	 0.0	 0.0	 1	 -30.0	 30.0;
	7874	 3363	 0.000271	 0.00089	 0.1299	 288.927864	 288.927864	 288.927864	 0.0	 0.0	 1	 -30.0	 30.0;
	7874	 2537	 0.001961	 0.012409	 0.02493	 392.856143	 392.856143	 392.856143	 0.0	 0.0	 1	 -30.0	 30.0;
	7874	 7548	 0.00044	 0.00207	 0.12342	 572.216551	 572.216551	 572.216551	 0.0	 0.0	 1	 -30.0	 30.0;
	7874	 7716	 0.000469	 0.00143	 0.19912	 640.334403	 640.334403	 640.334403	 0.0	 0.0	 1	 -30.0	 30.0;
	7874	 5958	 0.001271	 0.01406	 0.03741	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	7874	 5958	 0.00124	 0.013021	 0.03746	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	7874	 8150	 0.000409	 0.00239	 0.22086	 364.053628	 364.053628	 364.053628	 0.0	 0.0	 1	 -30.0	 30.0;
	7874	 195	 0.00094	 0.005	 0.02509	 457.229405	 457.229405	 457.229405	 0.0	 0.0	 1	 -30.0	 30.0;
	7874	 2690	 0.000219	 0.0007	 0.08927	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	7874	 6144	 6e-05	 0.00025	 0.04364	 276.368417	 276.368417	 276.368417	 0.0	 0.0	 1	 -30.0	 30.0;
	7874	 4797	 5e-05	 0.000229	 0.04008	 253.611279	 253.611279	 253.611279	 0.0	 0.0	 1	 -30.0	 30.0;
	3430	 2493	 0.00019	 0.000909	 0.00107	 357.480495	 357.480495	 357.480495	 0.0	 0.0	 1	 -30.0	 30.0;
	2071	 5034	 0.001711	 0.00782	 0.01092	 343.350355	 343.350355	 343.350355	 0.0	 0.0	 1	 -30.0	 30.0;
	2071	 6183	 0.002651	 0.01176	 0.01876	 437.907062	 437.907062	 437.907062	 0.0	 0.0	 1	 -30.0	 30.0;
	7045	 400	 0.001409	 0.010599	 0.0158	 229.347083	 229.347083	 229.347083	 0.0	 0.0	 1	 -30.0	 30.0;
	7045	 4847	 0.001419	 0.010219	 0.01613	 371.786299	 371.786299	 371.786299	 0.0	 0.0	 1	 -30.0	 30.0;
	759	 3569	 0.00013	 0.00212	 0.05846	 871.539976	 871.539976	 871.539976	 0.0	 0.0	 1	 -30.0	 30.0;
	759	 734	 0.00026	 0.00313	 0.12476	 1412.074339	 1412.074339	 1412.074339	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 2079	 0.0047	 0.0318	 0.04833	 479.263308	 479.263308	 479.263308	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 6170	 0.00136	 0.00768	 0.01491	 445.006045	 445.006045	 445.006045	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 3200	 0.005669	 0.027789	 0.04732	 414.465555	 414.465555	 414.465555	 0.0	 0.0	 1	 -30.0	 30.0;
	6594	 5690	 0.004409	 0.033091	 0.05018	 386.592424	 386.592424	 386.592424	 0.0	 0.0	 1	 -30.0	 30.0;
	6594	 1306	 0.01056	 0.044469	 0.07696	 252.950155	 252.950155	 252.950155	 0.0	 0.0	 1	 -30.0	 30.0;
	6594	 6483	 0.01963	 0.07736	 0.14113	 441.642125	 441.642125	 441.642125	 0.0	 0.0	 1	 -30.0	 30.0;
	6594	 6741	 0.01157	 0.04694	 0.08944	 467.568848	 467.568848	 467.568848	 0.0	 0.0	 1	 -30.0	 30.0;
	5540	 787	 0.000479	 0.00255	 0.00356	 459.609451	 459.609451	 459.609451	 0.0	 0.0	 1	 -30.0	 30.0;
	6877	 787	 0.000469	 0.00236	 0.00348	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1081	 1403	 0.01237	 0.067039	 0.08816	 389.154231	 389.154231	 389.154231	 0.0	 0.0	 1	 -30.0	 30.0;
	1081	 7720	 0.0132	 0.056229	 0.09362	 392.730777	 392.730777	 392.730777	 0.0	 0.0	 1	 -30.0	 30.0;
	3619	 3719	 0.00026	 0.001711	 0.00302	 346.036004	 346.036004	 346.036004	 0.0	 0.0	 1	 -30.0	 30.0;
	3619	 3719	 0.000271	 0.001669	 0.00307	 351.000339	 351.000339	 351.000339	 0.0	 0.0	 1	 -30.0	 30.0;
	6210	 4852	 0.000211	 0.000401	 0.02316	 295.64732	 295.64732	 295.64732	 0.0	 0.0	 1	 -30.0	 30.0;
	7520	 5276	 0.00105	 0.005159	 0.00759	 297.145995	 297.145995	 297.145995	 0.0	 0.0	 1	 -30.0	 30.0;
	6454	 6175	 0.00212	 0.00931	 0.01208	 428.374686	 428.374686	 428.374686	 0.0	 0.0	 1	 -30.0	 30.0;
	561	 6160	 0.000151	 0.00068	 0.05924	 377.209801	 377.209801	 377.209801	 0.0	 0.0	 1	 -30.0	 30.0;
	4919	 4465	 0.00019	 0.00082	 0.07926	 284.535106	 284.535106	 284.535106	 0.0	 0.0	 1	 -30.0	 30.0;
	4656	 6183	 0.003219	 0.01405	 0.02045	 402.455584	 402.455584	 402.455584	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 8309	 0.007271	 0.033159	 0.04367	 386.889263	 386.889263	 386.889263	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 7290	 0.006659	 0.03132	 0.04937	 415.800378	 415.800378	 415.800378	 0.0	 0.0	 1	 -30.0	 30.0;
	3130	 2579	 0.00057	 0.00668	 0.14718	 1581.858273	 1581.858273	 1581.858273	 0.0	 0.0	 1	 -30.0	 30.0;
	3130	 6400	 0.00057	 0.00758	 0.14879	 1516.303614	 1516.303614	 1516.303614	 0.0	 0.0	 1	 -30.0	 30.0;
	3130	 6400	 0.00039	 0.00607	 0.904	 952.215647	 952.215647	 952.215647	 0.0	 0.0	 1	 -30.0	 30.0;
	3130	 1496	 0.00155	 0.0179	 0.48657	 2132.72671	 2132.72671	 2132.72671	 0.0	 0.0	 1	 -30.0	 30.0;
	3130	 4180	 0.00036	 0.00485	 0.10754	 1652.592804	 1652.592804	 1652.592804	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 1543	 0.000581	 0.004229	 0.00651	 445.6565	 445.6565	 445.6565	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 7424	 0.00056	 0.00431	 0.00637	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 5296	 0.003099	 0.020531	 0.03456	 582.983915	 582.983915	 582.983915	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 2904	 0.00118	 0.016919	 0.02406	 619.811749	 619.811749	 619.811749	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 4814	 0.00188	 0.01407	 0.02137	 278.789235	 278.789235	 278.789235	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 4449	 0.00545	 0.04082	 0.0826	 470.621449	 470.621449	 470.621449	 0.0	 0.0	 1	 -30.0	 30.0;
	6585	 400	 0.00214	 0.01639	 0.02509	 571.156848	 571.156848	 571.156848	 0.0	 0.0	 1	 -30.0	 30.0;
	6585	 4318	 0.002479	 0.01549	 0.02818	 279.059401	 279.059401	 279.059401	 0.0	 0.0	 1	 -30.0	 30.0;
	7242	 8183	 0.000159	 0.001229	 0.10737	 577.843915	 577.843915	 577.843915	 0.0	 0.0	 1	 -30.0	 30.0;
	7242	 6054	 0.00026	 0.00162	 0.16913	 556.787408	 556.787408	 556.787408	 0.0	 0.0	 1	 -30.0	 30.0;
	7242	 6268	 0.000159	 0.00113	 0.09293	 477.695283	 477.695283	 477.695283	 0.0	 0.0	 1	 -30.0	 30.0;
	7242	 8016	 0.000461	 0.003219	 0.28994	 581.150296	 581.150296	 581.150296	 0.0	 0.0	 1	 -30.0	 30.0;
	7242	 3814	 0.000159	 0.001229	 0.10129	 306.802975	 306.802975	 306.802975	 0.0	 0.0	 1	 -30.0	 30.0;
	1462	 454	 0.000229	 0.00139	 0.00313	 490.444493	 490.444493	 490.444493	 0.0	 0.0	 1	 -30.0	 30.0;
	2573	 454	 0.0002	 0.00156	 0.00182	 448.297946	 448.297946	 448.297946	 0.0	 0.0	 1	 -30.0	 30.0;
	1232	 464	 0.00145	 0.00824	 0.01704	 384.616292	 384.616292	 384.616292	 0.0	 0.0	 1	 -30.0	 30.0;
	1232	 454	 0.00069	 0.005	 0.00759	 608.363828	 608.363828	 608.363828	 0.0	 0.0	 1	 -30.0	 30.0;
	806	 3362	 0.00036	 0.00455	 0.12014	 1915.50187	 1915.50187	 1915.50187	 0.0	 0.0	 1	 -30.0	 30.0;
	806	 3362	 0.00036	 0.00453	 0.12014	 1890.265959	 1890.265959	 1890.265959	 0.0	 0.0	 1	 -30.0	 30.0;
	7535	 6841	 0.00066	 0.00997	 0.29862	 1462.661343	 1462.661343	 1462.661343	 0.0	 0.0	 1	 -30.0	 30.0;
	7535	 6841	 0.00064	 0.01016	 0.29227	 1094.773994	 1094.773994	 1094.773994	 0.0	 0.0	 1	 -30.0	 30.0;
	5720	 4390	 9.9e-05	 0.00044	 0.04269	 634.586246	 634.586246	 634.586246	 0.0	 0.0	 1	 -30.0	 30.0;
	4390	 4024	 6e-05	 0.000469	 0.00093	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4390	 1463	 3.9e-05	 0.000341	 0.00093	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4390	 6303	 0.002531	 0.01943	 0.06916	 547.744683	 547.744683	 547.744683	 0.0	 0.0	 1	 -30.0	 30.0;
	4390	 6463	 0.00945	 0.06418	 0.11059	 527.278805	 527.278805	 527.278805	 0.0	 0.0	 1	 -30.0	 30.0;
	8282	 196	 0.000591	 0.002831	 0.00379	 467.647725	 467.647725	 467.647725	 0.0	 0.0	 1	 -30.0	 30.0;
	6360	 196	 0.00087	 0.00387	 0.00593	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	653	 4860	 0.0015	 0.01785	 0.25472	 1295.827368	 1295.827368	 1295.827368	 0.0	 0.0	 1	 -30.0	 30.0;
	653	 4860	 0.00147	 0.0182	 0.24952	 1271.237131	 1271.237131	 1271.237131	 0.0	 0.0	 1	 -30.0	 30.0;
	1561	 578	 0.00151	 0.0113	 0.01672	 488.702327	 488.702327	 488.702327	 0.0	 0.0	 1	 -30.0	 30.0;
	1561	 578	 0.001479	 0.011521	 0.01637	 506.530949	 506.530949	 506.530949	 0.0	 0.0	 1	 -30.0	 30.0;
	1561	 8283	 0.00174	 0.010341	 0.02091	 532.042326	 532.042326	 532.042326	 0.0	 0.0	 1	 -30.0	 30.0;
	1561	 8283	 0.001659	 0.01206	 0.01949	 558.33219	 558.33219	 558.33219	 0.0	 0.0	 1	 -30.0	 30.0;
	7440	 1824	 0.00069	 0.000479	 0.05645	 230.537487	 230.537487	 230.537487	 0.0	 0.0	 1	 -30.0	 30.0;
	7440	 7235	 0.00044	 0.00139	 0.27226	 357.169938	 357.169938	 357.169938	 0.0	 0.0	 1	 -30.0	 30.0;
	943	 7414	 0.002039	 0.01601	 0.02457	 314.629004	 314.629004	 314.629004	 0.0	 0.0	 1	 -30.0	 30.0;
	943	 6769	 0.01349	 0.05662	 0.09953	 463.637543	 463.637543	 463.637543	 0.0	 0.0	 1	 -30.0	 30.0;
	943	 277	 0.00082	 0.00438	 0.00637	 400.643305	 400.643305	 400.643305	 0.0	 0.0	 1	 -30.0	 30.0;
	943	 277	 0.0008	 0.004461	 0.00624	 384.346889	 384.346889	 384.346889	 0.0	 0.0	 1	 -30.0	 30.0;
	943	 4644	 0.001091	 0.00888	 0.01336	 554.856241	 554.856241	 554.856241	 0.0	 0.0	 1	 -30.0	 30.0;
	943	 4644	 0.00111	 0.007039	 0.01308	 601.67257	 601.67257	 601.67257	 0.0	 0.0	 1	 -30.0	 30.0;
	2287	 7673	 0.000849	 0.00537	 0.01283	 545.608129	 545.608129	 545.608129	 0.0	 0.0	 1	 -30.0	 30.0;
	7863	 8074	 0.00061	 0.00275	 0.25927	 474.049385	 474.049385	 474.049385	 0.0	 0.0	 1	 -30.0	 30.0;
	5631	 6976	 0.00141	 0.0188	 0.36135	 1445.266322	 1445.266322	 1445.266322	 0.0	 0.0	 1	 -30.0	 30.0;
	5631	 6006	 0.00121	 0.01427	 0.30849	 1673.467618	 1673.467618	 1673.467618	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 7393	 0.001711	 0.007159	 0.01232	 456.156746	 456.156746	 456.156746	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 7979	 0.00545	 0.02381	 0.03439	 403.801076	 403.801076	 403.801076	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 3772	 0.000771	 0.004331	 0.01597	 332.685495	 332.685495	 332.685495	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 2533	 0.00414	 0.03282	 0.04631	 554.014499	 554.014499	 554.014499	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 5742	 0.00264	 0.011521	 0.01913	 450.519094	 450.519094	 450.519094	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 5793	 0.00261	 0.011	 0.02509	 483.29483	 483.29483	 483.29483	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 6824	 0.00239	 0.00919	 0.01704	 421.977217	 421.977217	 421.977217	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 2618	 0.000539	 0.00226	 0.00732	 379.86649	 379.86649	 379.86649	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 6249	 0.00325	 0.017979	 0.03513	 584.910509	 584.910509	 584.910509	 0.0	 0.0	 1	 -30.0	 30.0;
	1134	 4131	 0.00076	 0.0071	 0.18714	 1328.519135	 1328.519135	 1328.519135	 0.0	 0.0	 1	 -30.0	 30.0;
	743	 6824	 0.000651	 0.00343	 0.00436	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2094	 3964	 0.001219	 0.00812	 0.0158	 453.481004	 453.481004	 453.481004	 0.0	 0.0	 1	 -30.0	 30.0;
	2094	 4381	 0.00243	 0.01439	 0.04077	 600.419292	 600.419292	 600.419292	 0.0	 0.0	 1	 -30.0	 30.0;
	8325	 5668	 0.0006	 0.00839	 0.63239	 1277.476013	 1277.476013	 1277.476013	 0.0	 0.0	 1	 -30.0	 30.0;
	8325	 5668	 0.00059	 0.00856	 0.61949	 1217.217065	 1217.217065	 1217.217065	 0.0	 0.0	 1	 -30.0	 30.0;
	8325	 5135	 0.00087	 0.01328	 0.40029	 1778.511719	 1778.511719	 1778.511719	 0.0	 0.0	 1	 -30.0	 30.0;
	8325	 5135	 0.00073	 0.01595	 0.33479	 1366.674447	 1366.674447	 1366.674447	 0.0	 0.0	 1	 -30.0	 30.0;
	2653	 3315	 0.00163	 0.002039	 0.17114	 333.829792	 333.829792	 333.829792	 0.0	 0.0	 1	 -30.0	 30.0;
	2653	 3315	 0.001659	 0.002	 0.17443	 333.026155	 333.026155	 333.026155	 0.0	 0.0	 1	 -30.0	 30.0;
	50	 5231	 0.00339	 0.019669	 0.03869	 577.18965	 577.18965	 577.18965	 0.0	 0.0	 1	 -30.0	 30.0;
	50	 2144	 0.00239	 0.017281	 0.02751	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	5905	 8203	 0.00032	 0.00112	 0.1323	 502.03988	 502.03988	 502.03988	 0.0	 0.0	 1	 -30.0	 30.0;
	5905	 5369	 0.0018	 0.01401	 0.02092	 507.550261	 507.550261	 507.550261	 0.0	 0.0	 1	 -30.0	 30.0;
	5905	 5369	 0.00212	 0.012469	 0.02509	 548.880596	 548.880596	 548.880596	 0.0	 0.0	 1	 -30.0	 30.0;
	1160	 2581	 0.00063	 0.00411	 0.00692	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5828	 3740	 0.009729	 0.03505	 0.05018	 312.522934	 312.522934	 312.522934	 0.0	 0.0	 1	 -30.0	 30.0;
	5828	 3237	 0.01007	 0.03056	 0.04174	 307.175262	 307.175262	 307.175262	 0.0	 0.0	 1	 -30.0	 30.0;
	1607	 2550	 0.00042	 0.00623	 0.262	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	1607	 317	 0.00036	 0.00722	 0.22052	 1864.829961	 1864.829961	 1864.829961	 0.0	 0.0	 1	 -30.0	 30.0;
	1607	 5968	 0.00053	 0.0078	 0.3275	 959.934774	 959.934774	 959.934774	 0.0	 0.0	 1	 -30.0	 30.0;
	1607	 1760	 0.00109	 0.0173	 0.4942	 832.524423	 832.524423	 832.524423	 0.0	 0.0	 1	 -30.0	 30.0;
	1607	 5297	 0.00071	 0.01144	 0.2579	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	1607	 3485	 0.00157	 0.01884	 0.71634	 1260.333733	 1260.333733	 1260.333733	 0.0	 0.0	 1	 -30.0	 30.0;
	1607	 3254	 0.00032	 0.00384	 0.14694	 857.689909	 857.689909	 857.689909	 0.0	 0.0	 1	 -30.0	 30.0;
	7285	 1642	 0.00041	 0.00649	 0.24929	 1565.717742	 1565.717742	 1565.717742	 0.0	 0.0	 1	 -30.0	 30.0;
	7285	 7081	 0.0004	 0.00658	 0.24449	 2196.770189	 2196.770189	 2196.770189	 0.0	 0.0	 1	 -30.0	 30.0;
	7285	 5968	 0.00054	 0.00763	 0.33356	 974.889924	 974.889924	 974.889924	 0.0	 0.0	 1	 -30.0	 30.0;
	7285	 1760	 0.00107	 0.01602	 0.48345	 929.910608	 929.910608	 929.910608	 0.0	 0.0	 1	 -30.0	 30.0;
	7285	 5297	 0.0007	 0.01165	 0.25241	 2195.721709	 2195.721709	 2195.721709	 0.0	 0.0	 1	 -30.0	 30.0;
	7285	 5126	 0.0016	 0.01844	 0.72985	 1350.248924	 1350.248924	 1350.248924	 0.0	 0.0	 1	 -30.0	 30.0;
	7285	 3254	 0.00032	 0.00376	 0.14971	 956.064021	 956.064021	 956.064021	 0.0	 0.0	 1	 -30.0	 30.0;
	4197	 151	 0.00212	 0.01207	 0.02395	 497.713806	 497.713806	 497.713806	 0.0	 0.0	 1	 -30.0	 30.0;
	2856	 2127	 5e-05	 0.00037	 0.0006	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5690	 7973	 0.00355	 0.024651	 0.0389	 433.725787	 433.725787	 433.725787	 0.0	 0.0	 1	 -30.0	 30.0;
	5674	 8290	 0.00675	 0.04145	 0.07349	 536.098997	 536.098997	 536.098997	 0.0	 0.0	 1	 -30.0	 30.0;
	5023	 6471	 0.00195	 0.014341	 0.02547	 456.865501	 456.865501	 456.865501	 0.0	 0.0	 1	 -30.0	 30.0;
	7578	 3966	 0.00018	 0.00043	 0.0273	 385.686284	 385.686284	 385.686284	 0.0	 0.0	 1	 -30.0	 30.0;
	7578	 2657	 0.00037	 0.000969	 0.22368	 458.323022	 458.323022	 458.323022	 0.0	 0.0	 1	 -30.0	 30.0;
	552	 1221	 0.00257	 0.017169	 0.02962	 492.175989	 492.175989	 492.175989	 0.0	 0.0	 1	 -30.0	 30.0;
	552	 4920	 0.00076	 0.00399	 0.00546	 510.629917	 510.629917	 510.629917	 0.0	 0.0	 1	 -30.0	 30.0;
	552	 4920	 0.00075	 0.00406	 0.00535	 496.374411	 496.374411	 496.374411	 0.0	 0.0	 1	 -30.0	 30.0;
	552	 1897	 0.003901	 0.023961	 0.04412	 586.979617	 586.979617	 586.979617	 0.0	 0.0	 1	 -30.0	 30.0;
	552	 701	 0.00249	 0.019211	 0.02875	 458.231569	 458.231569	 458.231569	 0.0	 0.0	 1	 -30.0	 30.0;
	3323	 2657	 0.00025	 0.001159	 0.10555	 490.205574	 490.205574	 490.205574	 0.0	 0.0	 1	 -30.0	 30.0;
	1233	 6601	 0.00195	 0.02924	 0.88633	 1991.761815	 1991.761815	 1991.761815	 0.0	 0.0	 1	 -30.0	 30.0;
	1233	 2000	 0.00152	 0.01527	 0.38572	 1513.143037	 1513.143037	 1513.143037	 0.0	 0.0	 1	 -30.0	 30.0;
	1233	 6933	 0.00149	 0.01558	 0.37844	 1632.938911	 1632.938911	 1632.938911	 0.0	 0.0	 1	 -30.0	 30.0;
	1233	 986	 0.00253	 0.0276	 0.64512	 1386.806836	 1386.806836	 1386.806836	 0.0	 0.0	 1	 -30.0	 30.0;
	1233	 986	 0.00263	 0.02648	 0.67042	 1582.074156	 1582.074156	 1582.074156	 0.0	 0.0	 1	 -30.0	 30.0;
	1233	 2143	 0.00077	 0.0092	 0.34898	 1426.817556	 1426.817556	 1426.817556	 0.0	 0.0	 1	 -30.0	 30.0;
	1233	 3823	 0.00112	 0.01705	 0.50766	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 7748	 0.00226	 0.01101	 0.01547	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 5434	 0.004531	 0.029039	 0.05939	 514.207606	 514.207606	 514.207606	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 7261	 0.002081	 0.030409	 0.30294	 267.782953	 267.782953	 267.782953	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 3576	 0.0053	 0.03257	 0.05951	 450.112893	 450.112893	 450.112893	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 3018	 0.00513	 0.041901	 0.05878	 557.505309	 557.505309	 557.505309	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 4319	 0.001461	 0.01056	 0.01707	 471.822522	 471.822522	 471.822522	 0.0	 0.0	 1	 -30.0	 30.0;
	7491	 4381	 0.0005	 0.002591	 0.01692	 371.718091	 371.718091	 371.718091	 0.0	 0.0	 1	 -30.0	 30.0;
	5580	 5727	 0.00055	 0.0033	 0.00616	 463.255348	 463.255348	 463.255348	 0.0	 0.0	 1	 -30.0	 30.0;
	3648	 5925	 0.002289	 0.01763	 0.0	 494.234428	 494.234428	 494.234428	 0.0	 0.0	 1	 -30.0	 30.0;
	3648	 1983	 0.0075	 0.043531	 0.0	 469.966803	 469.966803	 469.966803	 0.0	 0.0	 1	 -30.0	 30.0;
	5195	 1897	 0.00138	 0.019961	 0.07928	 270.022772	 270.022772	 270.022772	 0.0	 0.0	 1	 -30.0	 30.0;
	5195	 715	 0.00126	 0.018729	 0.07188	 605.776491	 605.776491	 605.776491	 0.0	 0.0	 1	 -30.0	 30.0;
	2114	 8338	 0.00038	 0.001331	 0.161	 512.857542	 512.857542	 512.857542	 0.0	 0.0	 1	 -30.0	 30.0;
	2114	 3090	 0.00019	 0.001461	 0.12342	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	186	 4318	 0.002151	 0.013401	 0.0182	 481.394527	 481.394527	 481.394527	 0.0	 0.0	 1	 -30.0	 30.0;
	186	 7066	 0.000789	 0.005669	 0.00854	 581.834283	 581.834283	 581.834283	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 6109	 3e-05	 0.00042	 0.00797	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 603	 0.00079	 0.00899	 0.35869	 1386.46919	 1386.46919	 1386.46919	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 603	 0.0008	 0.00879	 0.36533	 1579.509232	 1579.509232	 1579.509232	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 4039	 0.00334	 0.03393	 0.96124	 1384.396583	 1384.396583	 1384.396583	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 1498	 0.00063	 0.00789	 0.28834	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 3164	 0.0006	 0.00842	 0.27454	 1326.310285	 1326.310285	 1326.310285	 0.0	 0.0	 1	 -30.0	 30.0;
	4256	 7246	 0.00011	 0.00125	 0.00546	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4256	 5911	 0.00012	 0.001091	 0.00604	 367.910247	 367.910247	 367.910247	 0.0	 0.0	 1	 -30.0	 30.0;
	4256	 6982	 9.9e-05	 0.00125	 0.00372	 363.490434	 363.490434	 363.490434	 0.0	 0.0	 1	 -30.0	 30.0;
	4256	 374	 0.00294	 0.02443	 0.03473	 637.16863	 637.16863	 637.16863	 0.0	 0.0	 1	 -30.0	 30.0;
	4256	 2578	 0.00144	 0.011151	 0.01637	 507.419942	 507.419942	 507.419942	 0.0	 0.0	 1	 -30.0	 30.0;
	4256	 2321	 0.001831	 0.010849	 0.02013	 609.471163	 609.471163	 609.471163	 0.0	 0.0	 1	 -30.0	 30.0;
	4256	 2321	 0.001599	 0.01055	 0.01777	 576.22521	 576.22521	 576.22521	 0.0	 0.0	 1	 -30.0	 30.0;
	4256	 2723	 0.00144	 0.019591	 0.04186	 395.572657	 395.572657	 395.572657	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 910	 0.0133	 0.09551	 0.14988	 614.413016	 614.413016	 614.413016	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 4031	 0.009591	 0.073961	 0.10803	 531.827413	 531.827413	 531.827413	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 2467	 0.0007	 0.00671	 0.0537	 1578.303447	 1578.303447	 1578.303447	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 2467	 0.00072	 0.00658	 0.05476	 1608.901545	 1608.901545	 1608.901545	 0.0	 0.0	 1	 -30.0	 30.0;
	2145	 4490	 0.001901	 0.00964	 0.26659	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	2145	 4711	 0.001711	 0.01189	 0.23511	 613.612808	 613.612808	 613.612808	 0.0	 0.0	 1	 -30.0	 30.0;
	1867	 4319	 0.00025	 0.00187	 0.0027	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3824	 5012	 0.00043	 0.002211	 0.01278	 225.206962	 225.206962	 225.206962	 0.0	 0.0	 1	 -30.0	 30.0;
	5173	 7864	 0.000401	 0.00243	 0.01185	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7082	 4648	 0.00336	 0.017	 0.02562	 460.561316	 460.561316	 460.561316	 0.0	 0.0	 1	 -30.0	 30.0;
	6548	 4381	 0.005521	 0.031031	 0.10009	 262.687918	 262.687918	 262.687918	 0.0	 0.0	 1	 -30.0	 30.0;
	4009	 3474	 9.9e-05	 0.00026	 0.02045	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 2478	 0.00045	 0.00718	 0.20724	 1116.51234	 1116.51234	 1116.51234	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 4140	 0.00044	 0.00665	 0.20273	 949.136684	 949.136684	 949.136684	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 3951	 0.00103	 0.01516	 0.47132	 1314.725013	 1314.725013	 1314.725013	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 6814	 0.00101	 0.01546	 0.4615	 983.090838	 983.090838	 983.090838	 0.0	 0.0	 1	 -30.0	 30.0;
	4563	 21	 0.00045	 0.00608	 0.1116	 1516.193699	 1516.193699	 1516.193699	 0.0	 0.0	 1	 -30.0	 30.0;
	4563	 8361	 0.0004	 0.00501	 0.10045	 1373.039699	 1373.039699	 1373.039699	 0.0	 0.0	 1	 -30.0	 30.0;
	5547	 8174	 0.001729	 0.01337	 0.02702	 598.324654	 598.324654	 598.324654	 0.0	 0.0	 1	 -30.0	 30.0;
	5547	 5654	 0.00264	 0.01489	 0.04259	 520.051407	 520.051407	 520.051407	 0.0	 0.0	 1	 -30.0	 30.0;
	5547	 798	 0.002341	 0.018961	 0.02582	 524.119891	 524.119891	 524.119891	 0.0	 0.0	 1	 -30.0	 30.0;
	5547	 5209	 0.001841	 0.01363	 0.06215	 479.954154	 479.954154	 479.954154	 0.0	 0.0	 1	 -30.0	 30.0;
	8041	 6985	 0.001219	 0.00949	 0.28237	 506.666223	 506.666223	 506.666223	 0.0	 0.0	 1	 -30.0	 30.0;
	8041	 8174	 0.002271	 0.01151	 0.02881	 501.392474	 501.392474	 501.392474	 0.0	 0.0	 1	 -30.0	 30.0;
	8041	 5437	 0.010781	 0.05775	 0.0906	 273.24837	 273.24837	 273.24837	 0.0	 0.0	 1	 -30.0	 30.0;
	8041	 5852	 0.00251	 0.013919	 0.0187	 408.129055	 408.129055	 408.129055	 0.0	 0.0	 1	 -30.0	 30.0;
	8041	 7010	 0.00101	 0.007331	 0.02277	 522.067549	 522.067549	 522.067549	 0.0	 0.0	 1	 -30.0	 30.0;
	2256	 3740	 0.00061	 0.003909	 0.01185	 635.597556	 635.597556	 635.597556	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 5786	 0.004289	 0.019331	 0.04391	 370.029653	 370.029653	 370.029653	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 3740	 0.0008	 0.004401	 0.0098	 638.189847	 638.189847	 638.189847	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 4393	 0.008099	 0.03519	 0.06156	 617.404648	 617.404648	 617.404648	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 7128	 0.00063	 0.004591	 0.00854	 520.749874	 520.749874	 520.749874	 0.0	 0.0	 1	 -30.0	 30.0;
	2542	 7128	 0.000651	 0.00456	 0.00789	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2256	 8184	 0.00114	 0.00581	 0.01044	 317.036485	 317.036485	 317.036485	 0.0	 0.0	 1	 -30.0	 30.0;
	2256	 2033	 0.001211	 0.00538	 0.00906	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	595	 3453	 0.00418	 0.030159	 0.04743	 582.277446	 582.277446	 582.277446	 0.0	 0.0	 1	 -30.0	 30.0;
	595	 7702	 0.00324	 0.02413	 0.03531	 621.966212	 621.966212	 621.966212	 0.0	 0.0	 1	 -30.0	 30.0;
	595	 7702	 0.003169	 0.024591	 0.03457	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	3182	 8174	 0.000219	 0.00088	 0.09293	 508.315031	 508.315031	 508.315031	 0.0	 0.0	 1	 -30.0	 30.0;
	3182	 8174	 0.000289	 0.00095	 0.12545	 526.658835	 526.658835	 526.658835	 0.0	 0.0	 1	 -30.0	 30.0;
	5727	 37	 0.0035	 0.022211	 0.04027	 557.795289	 557.795289	 557.795289	 0.0	 0.0	 1	 -30.0	 30.0;
	5727	 6878	 0.00313	 0.02256	 0.03439	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5391	 7991	 0.000831	 0.00162	 0.19258	 362.505036	 362.505036	 362.505036	 0.0	 0.0	 1	 -30.0	 30.0;
	2896	 7720	 0.002099	 0.01068	 0.0158	 400.868506	 400.868506	 400.868506	 0.0	 0.0	 1	 -30.0	 30.0;
	914	 7720	 0.00224	 0.00976	 0.01611	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7973	 1316	 0.00169	 0.01231	 0.03531	 637.28104	 637.28104	 637.28104	 0.0	 0.0	 1	 -30.0	 30.0;
	6018	 8220	 0.00011	 0.00076	 0.00616	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8265	 8220	 0.00011	 0.00068	 0.00627	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6312	 5786	 0.005479	 0.021909	 0.04153	 358.18201	 358.18201	 358.18201	 0.0	 0.0	 1	 -30.0	 30.0;
	6312	 8000	 0.003331	 0.017039	 0.02416	 447.086585	 447.086585	 447.086585	 0.0	 0.0	 1	 -30.0	 30.0;
	4972	 3964	 0.000479	 0.001271	 0.08906	 326.475885	 326.475885	 326.475885	 0.0	 0.0	 1	 -30.0	 30.0;
	6774	 4765	 0.00109	 0.01629	 0.693	 852.85624	 852.85624	 852.85624	 0.0	 0.0	 1	 -30.0	 30.0;
	6774	 7433	 4e-05	 0.00063	 0.02356	 1825.936171	 1825.936171	 1825.936171	 0.0	 0.0	 1	 -30.0	 30.0;
	495	 5706	 0.0053	 0.024531	 0.04347	 587.628928	 587.628928	 587.628928	 0.0	 0.0	 1	 -30.0	 30.0;
	495	 2082	 0.004659	 0.021919	 0.03899	 436.834022	 436.834022	 436.834022	 0.0	 0.0	 1	 -30.0	 30.0;
	495	 3325	 0.001659	 0.01043	 0.02052	 579.903116	 579.903116	 579.903116	 0.0	 0.0	 1	 -30.0	 30.0;
	4550	 3773	 0.006961	 0.053539	 0.08688	 513.689377	 513.689377	 513.689377	 0.0	 0.0	 1	 -30.0	 30.0;
	1727	 4936	 0.00036	 0.00288	 0.00465	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	1727	 4936	 0.00038	 0.003	 0.00455	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	4981	 4522	 0.00048	 0.00643	 0.16791	 2139.013639	 2139.013639	 2139.013639	 0.0	 0.0	 1	 -30.0	 30.0;
	4981	 4522	 0.00051	 0.0066	 0.18021	 2128.0306	 2128.0306	 2128.0306	 0.0	 0.0	 1	 -30.0	 30.0;
	4981	 4522	 0.00046	 0.00729	 0.16288	 1880.022056	 1880.022056	 1880.022056	 0.0	 0.0	 1	 -30.0	 30.0;
	4981	 4955	 0.0006	 0.00868	 0.19685	 1842.049717	 1842.049717	 1842.049717	 0.0	 0.0	 1	 -30.0	 30.0;
	4981	 7056	 0.00068	 0.01076	 0.24161	 1957.468698	 1957.468698	 1957.468698	 0.0	 0.0	 1	 -30.0	 30.0;
	4981	 6257	 0.00066	 0.01096	 0.23647	 1936.001522	 1936.001522	 1936.001522	 0.0	 0.0	 1	 -30.0	 30.0;
	850	 4151	 0.00101	 0.005099	 0.00651	 412.391875	 412.391875	 412.391875	 0.0	 0.0	 1	 -30.0	 30.0;
	509	 7681	 0.003901	 0.02437	 0.04617	 244.344495	 244.344495	 244.344495	 0.0	 0.0	 1	 -30.0	 30.0;
	509	 2051	 0.00276	 0.016461	 0.03136	 567.99298	 567.99298	 567.99298	 0.0	 0.0	 1	 -30.0	 30.0;
	509	 7172	 0.00588	 0.047081	 0.07007	 302.721917	 302.721917	 302.721917	 0.0	 0.0	 1	 -30.0	 30.0;
	3943	 1698	 3.9e-05	 0.000219	 0.0	 309.975226	 309.975226	 309.975226	 0.0	 0.0	 1	 -30.0	 30.0;
	2607	 3341	 0.00131	 0.00538	 0.00923	 372.542686	 372.542686	 372.542686	 0.0	 0.0	 1	 -30.0	 30.0;
	2585	 986	 0.00679	 0.04679	 1.05162	 1020.252958	 1020.252958	 1020.252958	 0.0	 0.0	 1	 -30.0	 30.0;
	2585	 7493	 0.00138	 0.01466	 0.33876	 1089.139321	 1089.139321	 1089.139321	 0.0	 0.0	 1	 -30.0	 30.0;
	8268	 8327	 0.003531	 0.01724	 0.02562	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8268	 1294	 0.01324	 0.06936	 0.0967	 493.246362	 493.246362	 493.246362	 0.0	 0.0	 1	 -30.0	 30.0;
	8268	 7720	 0.00363	 0.01743	 0.02562	 446.307335	 446.307335	 446.307335	 0.0	 0.0	 1	 -30.0	 30.0;
	8268	 7720	 0.00257	 0.01662	 0.02863	 533.502514	 533.502514	 533.502514	 0.0	 0.0	 1	 -30.0	 30.0;
	8268	 4595	 0.01399	 0.056289	 0.1035	 436.503269	 436.503269	 436.503269	 0.0	 0.0	 1	 -30.0	 30.0;
	8268	 958	 0.00343	 0.01751	 0.02509	 459.191437	 459.191437	 459.191437	 0.0	 0.0	 1	 -30.0	 30.0;
	8268	 1271	 0.00301	 0.015409	 0.02178	 325.259569	 325.259569	 325.259569	 0.0	 0.0	 1	 -30.0	 30.0;
	8268	 1444	 0.00857	 0.033091	 0.06282	 483.864882	 483.864882	 483.864882	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 6250	 0.003341	 0.01689	 0.02366	 353.368191	 353.368191	 353.368191	 0.0	 0.0	 1	 -30.0	 30.0;
	6944	 2745	 3.9e-05	 0.000219	 0.0	 380.255162	 380.255162	 380.255162	 0.0	 0.0	 1	 -30.0	 30.0;
	6656	 6438	 0.00087	 0.00714	 0.01336	 466.796076	 466.796076	 466.796076	 0.0	 0.0	 1	 -30.0	 30.0;
	4273	 7493	 0.00011	 0.001	 0.06775	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1524	 4873	 0.000219	 0.00101	 0.0019	 345.435467	 345.435467	 345.435467	 0.0	 0.0	 1	 -30.0	 30.0;
	3532	 4873	 0.000219	 0.001031	 0.00186	 345.389741	 345.389741	 345.389741	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 4873	 0.000271	 0.00101	 0.00206	 332.11087	 332.11087	 332.11087	 0.0	 0.0	 1	 -30.0	 30.0;
	3284	 4873	 0.000271	 0.000979	 0.0021	 326.313176	 326.313176	 326.313176	 0.0	 0.0	 1	 -30.0	 30.0;
	2520	 4873	 0.000289	 0.00107	 0.00206	 342.432784	 342.432784	 342.432784	 0.0	 0.0	 1	 -30.0	 30.0;
	1687	 4873	 0.000289	 0.00105	 0.0021	 347.149435	 347.149435	 347.149435	 0.0	 0.0	 1	 -30.0	 30.0;
	3964	 5493	 0.001591	 0.012289	 0.0182	 381.91845	 381.91845	 381.91845	 0.0	 0.0	 1	 -30.0	 30.0;
	1973	 4762	 0.000271	 0.001901	 0.00284	 507.504154	 507.504154	 507.504154	 0.0	 0.0	 1	 -30.0	 30.0;
	1973	 2615	 0.00186	 0.010711	 0.0213	 515.012387	 515.012387	 515.012387	 0.0	 0.0	 1	 -30.0	 30.0;
	951	 3193	 1e-05	 0.0002	 0.00566	 2097.179104	 2097.179104	 2097.179104	 0.0	 0.0	 1	 -30.0	 30.0;
	3689	 798	 0.000169	 0.000271	 0.01777	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4113	 798	 0.000169	 0.00031	 0.0187	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1554	 5276	 0.00526	 0.03787	 0.05976	 553.117885	 553.117885	 553.117885	 0.0	 0.0	 1	 -30.0	 30.0;
	7350	 1352	 0.000229	 0.000599	 0.06709	 371.510418	 371.510418	 371.510418	 0.0	 0.0	 1	 -30.0	 30.0;
	5141	 5012	 0.00089	 0.004091	 0.01086	 446.509673	 446.509673	 446.509673	 0.0	 0.0	 1	 -30.0	 30.0;
	4078	 7864	 0.00093	 0.004	 0.01007	 415.857154	 415.857154	 415.857154	 0.0	 0.0	 1	 -30.0	 30.0;
	7979	 6824	 0.00289	 0.013099	 0.02074	 405.591255	 405.591255	 405.591255	 0.0	 0.0	 1	 -30.0	 30.0;
	2123	 5832	 0.002599	 0.016479	 0.02818	 543.649907	 543.649907	 543.649907	 0.0	 0.0	 1	 -30.0	 30.0;
	410	 7053	 0.00369	 0.02712	 0.04364	 557.24124	 557.24124	 557.24124	 0.0	 0.0	 1	 -30.0	 30.0;
	410	 3511	 0.0062	 0.04864	 0.07007	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	410	 300	 0.008021	 0.059031	 0.09486	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	410	 6295	 0.004979	 0.0295	 0.05645	 573.836019	 573.836019	 573.836019	 0.0	 0.0	 1	 -30.0	 30.0;
	7456	 3325	 0.001159	 0.005281	 0.00888	 303.235574	 303.235574	 303.235574	 0.0	 0.0	 1	 -30.0	 30.0;
	4915	 7032	 0.00361	 0.01824	 0.02602	 371.390006	 371.390006	 371.390006	 0.0	 0.0	 1	 -30.0	 30.0;
	4915	 1773	 0.001521	 0.01075	 0.02372	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4915	 3856	 0.00868	 0.041711	 0.06166	 377.427762	 377.427762	 377.427762	 0.0	 0.0	 1	 -30.0	 30.0;
	2348	 6194	 0.01118	 0.05986	 0.08642	 370.230848	 370.230848	 370.230848	 0.0	 0.0	 1	 -30.0	 30.0;
	2348	 6868	 0.003229	 0.02543	 0.03746	 601.102898	 601.102898	 601.102898	 0.0	 0.0	 1	 -30.0	 30.0;
	2348	 6868	 0.00218	 0.01869	 0.06377	 336.0296	 336.0296	 336.0296	 0.0	 0.0	 1	 -30.0	 30.0;
	2348	 6868	 0.001901	 0.021909	 0.05343	 589.012525	 589.012525	 589.012525	 0.0	 0.0	 1	 -30.0	 30.0;
	2348	 7251	 0.00974	 0.043969	 0.07405	 408.998995	 408.998995	 408.998995	 0.0	 0.0	 1	 -30.0	 30.0;
	2348	 6551	 0.003461	 0.01814	 0.02526	 464.665238	 464.665238	 464.665238	 0.0	 0.0	 1	 -30.0	 30.0;
	2348	 1418	 0.00487	 0.027669	 0.07401	 435.802897	 435.802897	 435.802897	 0.0	 0.0	 1	 -30.0	 30.0;
	8183	 1052	 0.000651	 0.003961	 0.15054	 624.16221	 624.16221	 624.16221	 0.0	 0.0	 1	 -30.0	 30.0;
	7880	 4993	 0.00169	 0.00887	 0.0	 409.462353	 409.462353	 409.462353	 0.0	 0.0	 1	 -30.0	 30.0;
	2806	 8054	 0.001711	 0.01336	 0.02912	 520.834086	 520.834086	 520.834086	 0.0	 0.0	 1	 -30.0	 30.0;
	1429	 890	 0.00031	 0.000539	 0.0331	 414.850798	 414.850798	 414.850798	 0.0	 0.0	 1	 -30.0	 30.0;
	2915	 3025	 0.0027	 0.01157	 0.01913	 270.193102	 270.193102	 270.193102	 0.0	 0.0	 1	 -30.0	 30.0;
	3236	 578	 0.000909	 0.006901	 0.0546	 521.660586	 521.660586	 521.660586	 0.0	 0.0	 1	 -30.0	 30.0;
	3236	 4490	 0.001729	 0.01214	 0.0645	 528.719941	 528.719941	 528.719941	 0.0	 0.0	 1	 -30.0	 30.0;
	374	 3173	 0.00614	 0.03106	 0.05643	 453.491674	 453.491674	 453.491674	 0.0	 0.0	 1	 -30.0	 30.0;
	374	 7202	 0.00418	 0.02388	 0.04792	 515.124797	 515.124797	 515.124797	 0.0	 0.0	 1	 -30.0	 30.0;
	2960	 1147	 0.00238	 0.017771	 0.02788	 217.997473	 217.997473	 217.997473	 0.0	 0.0	 1	 -30.0	 30.0;
	2960	 1649	 8.1e-05	 0.00063	 0.00095	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6683	 330	 0.001599	 0.01618	 0.0362	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3872	 1944	 0.00532	 0.026961	 0.03985	 433.594706	 433.594706	 433.594706	 0.0	 0.0	 1	 -30.0	 30.0;
	3872	 1944	 0.00361	 0.02814	 0.04531	 558.62941	 558.62941	 558.62941	 0.0	 0.0	 1	 -30.0	 30.0;
	3872	 5055	 0.002469	 0.01025	 0.023	 538.21726	 538.21726	 538.21726	 0.0	 0.0	 1	 -30.0	 30.0;
	5786	 1653	 0.005229	 0.02675	 0.0381	 403.025637	 403.025637	 403.025637	 0.0	 0.0	 1	 -30.0	 30.0;
	5786	 1653	 0.00512	 0.02726	 0.03731	 421.280275	 421.280275	 421.280275	 0.0	 0.0	 1	 -30.0	 30.0;
	5786	 7128	 0.00355	 0.01694	 0.03078	 403.389922	 403.389922	 403.389922	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 6607	 0.00139	 0.007659	 0.29899	 474.404525	 474.404525	 474.404525	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 3643	 0.000169	 0.000669	 0.07109	 516.39827	 516.39827	 516.39827	 0.0	 0.0	 1	 -30.0	 30.0;
	7849	 2093	 0.00111	 0.00712	 0.01208	 490.060774	 490.060774	 490.060774	 0.0	 0.0	 1	 -30.0	 30.0;
	821	 5873	 0.00031	 0.001901	 0.0041	 536.780697	 536.780697	 536.780697	 0.0	 0.0	 1	 -30.0	 30.0;
	6375	 5873	 0.000281	 0.002091	 0.00379	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3830	 5944	 0.000281	 0.001651	 0.00836	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6642	 5944	 0.000271	 0.00169	 0.00819	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5312	 3081	 0.001521	 0.00843	 0.01069	 384.486735	 384.486735	 384.486735	 0.0	 0.0	 1	 -30.0	 30.0;
	5312	 3423	 0.000841	 0.0062	 0.00871	 537.806106	 537.806106	 537.806106	 0.0	 0.0	 1	 -30.0	 30.0;
	3372	 7953	 0.00019	 0.00126	 0.00198	 517.991445	 517.991445	 517.991445	 0.0	 0.0	 1	 -30.0	 30.0;
	813	 6002	 0.000219	 0.00143	 0.00302	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2647	 7352	 0.00121	 0.01796	 0.33479	 1899.188895	 1899.188895	 1899.188895	 0.0	 0.0	 1	 -30.0	 30.0;
	2647	 7352	 0.0014	 0.01512	 0.39301	 1985.796736	 1985.796736	 1985.796736	 0.0	 0.0	 1	 -30.0	 30.0;
	5925	 1983	 0.008409	 0.063651	 0.10454	 365.876196	 365.876196	 365.876196	 0.0	 0.0	 1	 -30.0	 30.0;
	5925	 4831	 0.00918	 0.07344	 0.10919	 624.859153	 624.859153	 624.859153	 0.0	 0.0	 1	 -30.0	 30.0;
	5925	 551	 0.004219	 0.0345	 0.04809	 518.067274	 518.067274	 518.067274	 0.0	 0.0	 1	 -30.0	 30.0;
	5925	 551	 0.0042	 0.031651	 0.0474	 469.815906	 469.815906	 469.815906	 0.0	 0.0	 1	 -30.0	 30.0;
	4090	 7951	 0.00121	 0.01381	 0.56889	 1572.448942	 1572.448942	 1572.448942	 0.0	 0.0	 1	 -30.0	 30.0;
	4090	 6400	 0.00107	 0.01326	 0.54567	 1600.153684	 1600.153684	 1600.153684	 0.0	 0.0	 1	 -30.0	 30.0;
	6194	 5276	 0.003401	 0.02607	 0.03833	 317.336753	 317.336753	 317.336753	 0.0	 0.0	 1	 -30.0	 30.0;
	3337	 16	 0.000289	 0.00138	 0.12648	 421.657896	 421.657896	 421.657896	 0.0	 0.0	 1	 -30.0	 30.0;
	4669	 6987	 0.001031	 0.006039	 0.0115	 363.614276	 363.614276	 363.614276	 0.0	 0.0	 1	 -30.0	 30.0;
	1215	 6987	 0.00105	 0.005909	 0.01171	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7656	 6918	 0.001091	 0.007901	 0.01208	 424.945606	 424.945606	 424.945606	 0.0	 0.0	 1	 -30.0	 30.0;
	7656	 1029	 0.00332	 0.024021	 0.03795	 565.090513	 565.090513	 565.090513	 0.0	 0.0	 1	 -30.0	 30.0;
	7656	 2792	 0.00344	 0.021419	 0.03825	 414.303228	 414.303228	 414.303228	 0.0	 0.0	 1	 -30.0	 30.0;
	7656	 278	 0.00095	 0.010419	 0.02788	 519.894795	 519.894795	 519.894795	 0.0	 0.0	 1	 -30.0	 30.0;
	7656	 278	 0.00093	 0.01062	 0.02639	 476.77352	 476.77352	 476.77352	 0.0	 0.0	 1	 -30.0	 30.0;
	7656	 6793	 0.00474	 0.025409	 0.03549	 365.289758	 365.289758	 365.289758	 0.0	 0.0	 1	 -30.0	 30.0;
	4258	 1905	 0.000271	 0.000841	 0.20316	 393.073342	 393.073342	 393.073342	 0.0	 0.0	 1	 -30.0	 30.0;
	6787	 5675	 0.000271	 0.00119	 0.12102	 392.802415	 392.802415	 392.802415	 0.0	 0.0	 1	 -30.0	 30.0;
	6787	 1424	 0.000289	 0.00076	 0.05343	 358.512382	 358.512382	 358.512382	 0.0	 0.0	 1	 -30.0	 30.0;
	7054	 1498	 0.00031	 0.00454	 0.19026	 1952.561972	 1952.561972	 1952.561972	 0.0	 0.0	 1	 -30.0	 30.0;
	5418	 3164	 0.00032	 0.0044	 0.19061	 2042.148074	 2042.148074	 2042.148074	 0.0	 0.0	 1	 -30.0	 30.0;
	2524	 1498	 0.00028	 0.00494	 0.16981	 1982.570341	 1982.570341	 1982.570341	 0.0	 0.0	 1	 -30.0	 30.0;
	882	 3164	 0.00028	 0.00508	 0.17265	 2227.307076	 2227.307076	 2227.307076	 0.0	 0.0	 1	 -30.0	 30.0;
	8086	 835	 0.000531	 0.00093	 0.0969	 306.723335	 306.723335	 306.723335	 0.0	 0.0	 1	 -30.0	 30.0;
	8086	 4471	 0.0003	 0.001031	 0.12778	 501.41267	 501.41267	 501.41267	 0.0	 0.0	 1	 -30.0	 30.0;
	2408	 8259	 0.00139	 0.02163	 0.64598	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2408	 6497	 0.00164	 0.02321	 0.75001	 1890.202115	 1890.202115	 1890.202115	 0.0	 0.0	 1	 -30.0	 30.0;
	3199	 8259	 0.00136	 0.02205	 0.63253	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3199	 6497	 0.0016	 0.02367	 0.73193	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1623	 8290	 0.002091	 0.01174	 0.01603	 386.824484	 386.824484	 386.824484	 0.0	 0.0	 1	 -30.0	 30.0;
	1623	 8290	 0.001719	 0.00961	 0.01679	 567.360435	 567.360435	 567.360435	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 934	 0.012341	 0.076781	 0.10241	 437.741305	 437.741305	 437.741305	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 8290	 0.00176	 0.009419	 0.01712	 607.733189	 607.733189	 607.733189	 0.0	 0.0	 1	 -30.0	 30.0;
	1000	 2618	 0.00031	 0.00182	 0.00313	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6688	 2478	 0.00386	 0.02348	 0.34569	 1284.413223	 1284.413223	 1284.413223	 0.0	 0.0	 1	 -30.0	 30.0;
	6688	 4353	 0.00017	 0.00104	 0.01531	 1164.705545	 1164.705545	 1164.705545	 0.0	 0.0	 1	 -30.0	 30.0;
	3222	 4822	 0.00061	 0.00808	 0.1541	 1635.040478	 1635.040478	 1635.040478	 0.0	 0.0	 1	 -30.0	 30.0;
	3222	 3485	 0.00059	 0.0067	 0.14151	 2032.347784	 2032.347784	 2032.347784	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 935	 0.00059	 0.00748	 0.15075	 1495.708526	 1495.708526	 1495.708526	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 5126	 0.00061	 0.0063	 0.15018	 2205.964296	 2205.964296	 2205.964296	 0.0	 0.0	 1	 -30.0	 30.0;
	330	 1066	 0.001031	 0.008789	 0.0345	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	330	 8340	 0.00051	 0.006169	 0.01423	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	330	 7911	 0.0005	 0.00619	 0.01208	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	1676	 3285	 0.00049	 0.00376	 0.0061	 586.801285	 586.801285	 586.801285	 0.0	 0.0	 1	 -30.0	 30.0;
	1676	 3285	 0.000539	 0.003229	 0.00627	 536.059367	 536.059367	 536.059367	 0.0	 0.0	 1	 -30.0	 30.0;
	1676	 3610	 0.001031	 0.00882	 0.03869	 372.316342	 372.316342	 372.316342	 0.0	 0.0	 1	 -30.0	 30.0;
	1676	 1681	 0.000711	 0.00463	 0.00789	 459.750439	 459.750439	 459.750439	 0.0	 0.0	 1	 -30.0	 30.0;
	1676	 2032	 0.000711	 0.004539	 0.00805	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3624	 2237	 0.00206	 0.015341	 0.02323	 515.145754	 515.145754	 515.145754	 0.0	 0.0	 1	 -30.0	 30.0;
	3624	 2237	 0.002021	 0.01564	 0.02275	 525.266474	 525.266474	 525.266474	 0.0	 0.0	 1	 -30.0	 30.0;
	5546	 8034	 0.00094	 0.005781	 0.0115	 611.138262	 611.138262	 611.138262	 0.0	 0.0	 1	 -30.0	 30.0;
	5546	 910	 0.002219	 0.016969	 0.02602	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	6879	 1653	 0.00238	 0.01187	 0.02013	 396.173194	 396.173194	 396.173194	 0.0	 0.0	 1	 -30.0	 30.0;
	6879	 2618	 0.00707	 0.03095	 0.05336	 384.746612	 384.746612	 384.746612	 0.0	 0.0	 1	 -30.0	 30.0;
	21	 6006	 0.00256	 0.03401	 0.6483	 1658.802067	 1658.802067	 1658.802067	 0.0	 0.0	 1	 -30.0	 30.0;
	21	 2248	 0.00203	 0.02416	 0.53208	 1161.192842	 1161.192842	 1161.192842	 0.0	 0.0	 1	 -30.0	 30.0;
	21	 4184	 0.001	 0.01459	 0.45469	 2047.421406	 2047.421406	 2047.421406	 0.0	 0.0	 1	 -30.0	 30.0;
	21	 3853	 0.00103	 0.00987	 0.262	 1625.624565	 1625.624565	 1625.624565	 0.0	 0.0	 1	 -30.0	 30.0;
	21	 4676	 0.00038	 0.00483	 0.09617	 1476.727293	 1476.727293	 1476.727293	 0.0	 0.0	 1	 -30.0	 30.0;
	21	 4676	 0.00041	 0.00398	 0.10605	 1335.019972	 1335.019972	 1335.019972	 0.0	 0.0	 1	 -30.0	 30.0;
	6976	 2248	 0.00167	 0.01721	 0.48923	 1402.085152	 1402.085152	 1402.085152	 0.0	 0.0	 1	 -30.0	 30.0;
	6976	 1941	 0.00098	 0.01487	 0.44521	 1003.400935	 1003.400935	 1003.400935	 0.0	 0.0	 1	 -30.0	 30.0;
	6976	 8361	 0.00042	 0.00342	 0.06654	 1354.020292	 1354.020292	 1354.020292	 0.0	 0.0	 1	 -30.0	 30.0;
	6976	 8361	 0.00019	 0.00248	 0.08543	 1612.095031	 1612.095031	 1612.095031	 0.0	 0.0	 1	 -30.0	 30.0;
	6976	 3853	 0.00105	 0.00966	 0.26685	 1910.215373	 1910.215373	 1910.215373	 0.0	 0.0	 1	 -30.0	 30.0;
	6976	 3193	 0.00043	 0.00473	 0.109	 1408.256241	 1408.256241	 1408.256241	 0.0	 0.0	 1	 -30.0	 30.0;
	6976	 3193	 0.00041	 0.00397	 0.10605	 1330.174456	 1330.174456	 1330.174456	 0.0	 0.0	 1	 -30.0	 30.0;
	1717	 3558	 0.00051	 0.00514	 0.12858	 1243.093384	 1243.093384	 1243.093384	 0.0	 0.0	 1	 -30.0	 30.0;
	101	 3558	 0.00053	 0.00503	 0.13411	 1417.789969	 1417.789969	 1417.789969	 0.0	 0.0	 1	 -30.0	 30.0;
	7032	 3421	 0.00455	 0.022771	 0.03136	 409.944002	 409.944002	 409.944002	 0.0	 0.0	 1	 -30.0	 30.0;
	7032	 3421	 0.00557	 0.02055	 0.0394	 393.584332	 393.584332	 393.584332	 0.0	 0.0	 1	 -30.0	 30.0;
	7032	 3421	 0.00339	 0.02026	 0.05227	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 8151	 0.00237	 0.01068	 0.01986	 452.121033	 452.121033	 452.121033	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 7423	 0.0037	 0.019479	 0.02701	 391.486645	 391.486645	 391.486645	 0.0	 0.0	 1	 -30.0	 30.0;
	5554	 7157	 0.01407	 0.056849	 0.07303	 372.569741	 372.569741	 372.569741	 0.0	 0.0	 1	 -30.0	 30.0;
	5554	 4134	 0.001669	 0.015409	 0.0453	 618.888843	 618.888843	 618.888843	 0.0	 0.0	 1	 -30.0	 30.0;
	5554	 4134	 0.001711	 0.015091	 0.04617	 269.92065	 269.92065	 269.92065	 0.0	 0.0	 1	 -30.0	 30.0;
	7174	 3362	 0.00172	 0.01619	 0.44793	 1681.097891	 1681.097891	 1681.097891	 0.0	 0.0	 1	 -30.0	 30.0;
	7174	 6841	 0.00029	 0.00447	 0.13019	 1007.19863	 1007.19863	 1007.19863	 0.0	 0.0	 1	 -30.0	 30.0;
	7174	 6841	 0.00033	 0.00387	 0.15	 1146.92878	 1146.92878	 1146.92878	 0.0	 0.0	 1	 -30.0	 30.0;
	7174	 3770	 0.00079	 0.01154	 0.36042	 1008.68085	 1008.68085	 1008.68085	 0.0	 0.0	 1	 -30.0	 30.0;
	7174	 3770	 0.00077	 0.01177	 0.35291	 1009.146182	 1009.146182	 1009.146182	 0.0	 0.0	 1	 -30.0	 30.0;
	7174	 2748	 0.00127	 0.01498	 0.32548	 1548.043653	 1548.043653	 1548.043653	 0.0	 0.0	 1	 -30.0	 30.0;
	1617	 144	 0.00214	 0.012599	 0.023	 505.428568	 505.428568	 505.428568	 0.0	 0.0	 1	 -30.0	 30.0;
	3866	 2201	 0.000159	 0.00125	 0.00178	 462.409034	 462.409034	 462.409034	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 4811	 0.000211	 0.000669	 0.09264	 464.493765	 464.493765	 464.493765	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 7548	 0.000341	 0.001169	 0.14397	 526.245394	 526.245394	 526.245394	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 786	 0.00024	 0.001469	 0.15805	 590.382023	 590.382023	 590.382023	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 2690	 0.00018	 0.000669	 0.07063	 542.037679	 542.037679	 542.037679	 0.0	 0.0	 1	 -30.0	 30.0;
	3180	 7245	 0.00033	 0.00683	 0.16895	 952.97716	 952.97716	 952.97716	 0.0	 0.0	 1	 -30.0	 30.0;
	3180	 2000	 0.00121	 0.01211	 0.30613	 1422.268879	 1422.268879	 1422.268879	 0.0	 0.0	 1	 -30.0	 30.0;
	3180	 6933	 0.00123	 0.01185	 0.3119	 1476.857612	 1476.857612	 1476.857612	 0.0	 0.0	 1	 -30.0	 30.0;
	3180	 3853	 0.00058	 0.0097	 0.3	 1204.930832	 1204.930832	 1204.930832	 0.0	 0.0	 1	 -30.0	 30.0;
	3180	 4676	 0.00103	 0.01292	 0.25992	 1266.520618	 1266.520618	 1266.520618	 0.0	 0.0	 1	 -30.0	 30.0;
	3180	 3193	 0.00116	 0.01266	 0.29458	 947.275353	 947.275353	 947.275353	 0.0	 0.0	 1	 -30.0	 30.0;
	6607	 3643	 0.0013	 0.006841	 0.23104	 474.73642	 474.73642	 474.73642	 0.0	 0.0	 1	 -30.0	 30.0;
	2744	 958	 6e-05	 0.000349	 0.00091	 456.894461	 456.894461	 456.894461	 0.0	 0.0	 1	 -30.0	 30.0;
	2450	 3121	 0.000169	 0.0007	 0.12981	 407.520517	 407.520517	 407.520517	 0.0	 0.0	 1	 -30.0	 30.0;
	8284	 1844	 0.000169	 0.000719	 0.13243	 298.105482	 298.105482	 298.105482	 0.0	 0.0	 1	 -30.0	 30.0;
	5722	 6061	 0.000271	 0.001031	 0.00095	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 3347	 0.008271	 0.036841	 0.04987	 335.54757	 335.54757	 335.54757	 0.0	 0.0	 1	 -30.0	 30.0;
	4913	 2493	 0.002969	 0.02299	 0.06006	 436.880129	 436.880129	 436.880129	 0.0	 0.0	 1	 -30.0	 30.0;
	2803	 4205	 0.00124	 0.01273	 0.30035	 1220.382907	 1220.382907	 1220.382907	 0.0	 0.0	 1	 -30.0	 30.0;
	2803	 3951	 0.00106	 0.00989	 0.26367	 1507.901297	 1507.901297	 1507.901297	 0.0	 0.0	 1	 -30.0	 30.0;
	2803	 4805	 7e-05	 0.00029	 0.06127	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2803	 4922	 9e-05	 0.00079	 0.01837	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2803	 5874	 0.00196	 0.02049	 0.48657	 1638.538701	 1638.538701	 1638.538701	 0.0	 0.0	 1	 -30.0	 30.0;
	2803	 7675	 0.00158	 0.01519	 0.393	 1308.138612	 1308.138612	 1308.138612	 0.0	 0.0	 1	 -30.0	 30.0;
	5648	 2478	 0.00172	 0.01811	 0.44152	 1622.95828	 1622.95828	 1622.95828	 0.0	 0.0	 1	 -30.0	 30.0;
	5648	 6814	 0.00096	 0.01121	 0.23491	 1765.565991	 1765.565991	 1765.565991	 0.0	 0.0	 1	 -30.0	 30.0;
	5648	 5874	 0.00147	 0.01707	 0.53053	 1979.450571	 1979.450571	 1979.450571	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 4205	 0.00129	 0.0129	 0.31837	 1316.707449	 1316.707449	 1316.707449	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 4140	 0.00179	 0.01737	 0.4585	 1672.004486	 1672.004486	 1672.004486	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 5874	 0.00131	 0.01935	 0.47265	 1797.877987	 1797.877987	 1797.877987	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 8377	 0.003901	 0.01614	 0.02771	 435.064039	 435.064039	 435.064039	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 8377	 0.002591	 0.014771	 0.04495	 555.123739	 555.123739	 555.123739	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 8377	 0.00224	 0.0173	 0.03912	 493.213592	 493.213592	 493.213592	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 3693	 0.00012	 0.000849	 0.0543	 225.829218	 225.829218	 225.829218	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 3162	 0.00394	 0.03039	 0.04531	 505.185839	 505.185839	 505.185839	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 3277	 0.00189	 0.01	 0.02672	 380.840075	 380.840075	 380.840075	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 2530	 0.00032	 0.00257	 0.00356	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 2530	 0.00038	 0.00224	 0.00418	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 7674	 0.00751	 0.03955	 0.05488	 513.304515	 513.304515	 513.304515	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 1034	 0.00086	 0.006531	 0.01425	 252.079072	 252.079072	 252.079072	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 17	 0.00087	 0.006591	 0.01692	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8034	 910	 0.003031	 0.02276	 0.03624	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	8034	 4504	 0.006331	 0.03911	 0.07286	 267.036855	 267.036855	 267.036855	 0.0	 0.0	 1	 -30.0	 30.0;
	8034	 4017	 0.00605	 0.02986	 0.0554	 399.046701	 399.046701	 399.046701	 0.0	 0.0	 1	 -30.0	 30.0;
	8034	 6074	 0.003919	 0.01612	 0.02767	 443.995879	 443.995879	 443.995879	 0.0	 0.0	 1	 -30.0	 30.0;
	8034	 1054	 0.002039	 0.0108	 0.01547	 455.825993	 455.825993	 455.825993	 0.0	 0.0	 1	 -30.0	 30.0;
	8034	 6498	 0.006289	 0.026271	 0.04617	 519.987772	 519.987772	 519.987772	 0.0	 0.0	 1	 -30.0	 30.0;
	2667	 2579	 0.00042	 0.00547	 0.19147	 885.670428	 885.670428	 885.670428	 0.0	 0.0	 1	 -30.0	 30.0;
	2667	 2579	 0.00043	 0.00536	 0.19523	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2667	 6823	 0.00147	 0.01373	 0.37804	 1791.123751	 1791.123751	 1791.123751	 0.0	 0.0	 1	 -30.0	 30.0;
	2667	 6823	 0.00131	 0.01555	 0.3368	 1577.742678	 1577.742678	 1577.742678	 0.0	 0.0	 1	 -30.0	 30.0;
	2667	 1496	 0.00221	 0.02217	 0.56327	 1812.359249	 1812.359249	 1812.359249	 0.0	 0.0	 1	 -30.0	 30.0;
	2667	 734	 0.00224	 0.0217	 0.57078	 1832.204671	 1832.204671	 1832.204671	 0.0	 0.0	 1	 -30.0	 30.0;
	8338	 6160	 0.00095	 0.003289	 0.30482	 403.975217	 403.975217	 403.975217	 0.0	 0.0	 1	 -30.0	 30.0;
	8338	 3090	 0.000229	 0.00082	 0.09827	 283.554661	 283.554661	 283.554661	 0.0	 0.0	 1	 -30.0	 30.0;
	8338	 6433	 0.00068	 0.00306	 0.40342	 311.307762	 311.307762	 311.307762	 0.0	 0.0	 1	 -30.0	 30.0;
	8338	 3382	 0.00049	 0.00256	 0.01274	 437.917731	 437.917731	 437.917731	 0.0	 0.0	 1	 -30.0	 30.0;
	8338	 3366	 0.000531	 0.0022	 0.00851	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8338	 6808	 0.00136	 0.00956	 0.02771	 522.183389	 522.183389	 522.183389	 0.0	 0.0	 1	 -30.0	 30.0;
	8338	 6808	 0.0012	 0.010729	 0.02457	 479.382577	 479.382577	 479.382577	 0.0	 0.0	 1	 -30.0	 30.0;
	8338	 6808	 0.00105	 0.00861	 0.03764	 311.548967	 311.548967	 311.548967	 0.0	 0.0	 1	 -30.0	 30.0;
	8338	 2184	 0.000591	 0.006969	 0.02405	 275.48133	 275.48133	 275.48133	 0.0	 0.0	 1	 -30.0	 30.0;
	2537	 7716	 0.00025	 0.0008	 0.19912	 302.121761	 302.121761	 302.121761	 0.0	 0.0	 1	 -30.0	 30.0;
	2537	 195	 0.00113	 0.00632	 0.01917	 400.690174	 400.690174	 400.690174	 0.0	 0.0	 1	 -30.0	 30.0;
	409	 1941	 0.0003	 0.00275	 0.07942	 975.0288	 975.0288	 975.0288	 0.0	 0.0	 1	 -30.0	 30.0;
	7882	 6303	 0.00836	 0.051659	 0.10261	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	7882	 6303	 0.01338	 0.073469	 0.12588	 605.624832	 605.624832	 605.624832	 0.0	 0.0	 1	 -30.0	 30.0;
	7882	 1077	 0.0027	 0.02089	 0.03049	 229.070059	 229.070059	 229.070059	 0.0	 0.0	 1	 -30.0	 30.0;
	7882	 4017	 0.003419	 0.02636	 0.03833	 617.015976	 617.015976	 617.015976	 0.0	 0.0	 1	 -30.0	 30.0;
	7882	 7931	 0.009531	 0.033711	 0.05135	 459.208966	 459.208966	 459.208966	 0.0	 0.0	 1	 -30.0	 30.0;
	2220	 7951	 0.0004	 0.00707	 0.3152	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	2380	 7951	 0.00035	 0.00701	 0.20632	 2138.833297	 2138.833297	 2138.833297	 0.0	 0.0	 1	 -30.0	 30.0;
	4505	 6154	 0.00194	 0.01751	 0.0607	 551.93053	 551.93053	 551.93053	 0.0	 0.0	 1	 -30.0	 30.0;
	4505	 6154	 0.00156	 0.01936	 0.0543	 519.458873	 519.458873	 519.458873	 0.0	 0.0	 1	 -30.0	 30.0;
	4205	 875	 0.00078	 0.00941	 0.35817	 1359.604285	 1359.604285	 1359.604285	 0.0	 0.0	 1	 -30.0	 30.0;
	4205	 875	 0.00074	 0.00969	 0.34171	 1582.906095	 1582.906095	 1582.906095	 0.0	 0.0	 1	 -30.0	 30.0;
	4205	 7566	 0.00042	 0.00532	 0.09503	 1694.374026	 1694.374026	 1694.374026	 0.0	 0.0	 1	 -30.0	 30.0;
	4205	 7566	 0.0004	 0.00473	 0.09906	 1860.193746	 1860.193746	 1860.193746	 0.0	 0.0	 1	 -30.0	 30.0;
	4205	 7566	 0.0006	 0.00499	 0.10813	 1572.811599	 1572.811599	 1572.811599	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 5941	 0.00086	 0.00638	 0.02875	 610.541155	 610.541155	 610.541155	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 5941	 0.000969	 0.00625	 0.03258	 616.423442	 616.423442	 616.423442	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 8171	 0.002781	 0.01725	 0.03181	 466.837229	 466.837229	 466.837229	 0.0	 0.0	 1	 -30.0	 30.0;
	3978	 4381	 0.005031	 0.028081	 0.15972	 564.321933	 564.321933	 564.321933	 0.0	 0.0	 1	 -30.0	 30.0;
	4973	 871	 1e-05	 0.00021	 0.00555	 2257.804473	 2257.804473	 2257.804473	 0.0	 0.0	 1	 -30.0	 30.0;
	7180	 871	 1e-05	 0.00025	 0.00953	 2266.564181	 2266.564181	 2266.564181	 0.0	 0.0	 1	 -30.0	 30.0;
	457	 871	 2e-05	 0.00031	 0.00797	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2708	 871	 3e-05	 0.0004	 0.00831	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4143	 5791	 0.000841	 0.00474	 0.00958	 533.507849	 533.507849	 533.507849	 0.0	 0.0	 1	 -30.0	 30.0;
	4143	 5791	 0.00082	 0.00487	 0.00941	 537.122881	 537.122881	 537.122881	 0.0	 0.0	 1	 -30.0	 30.0;
	6209	 1453	 0.00186	 0.011979	 0.02074	 237.236366	 237.236366	 237.236366	 0.0	 0.0	 1	 -30.0	 30.0;
	3339	 4847	 0.00056	 0.003021	 0.00455	 394.227165	 394.227165	 394.227165	 0.0	 0.0	 1	 -30.0	 30.0;
	5643	 4847	 0.00055	 0.003081	 0.00445	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8169	 5582	 0.00114	 0.01063	 0.17472	 2006.22728	 2006.22728	 2006.22728	 0.0	 0.0	 1	 -30.0	 30.0;
	1693	 5382	 0.003719	 0.02295	 0.0431	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	1693	 5169	 0.006669	 0.04288	 0.07651	 527.460947	 527.460947	 527.460947	 0.0	 0.0	 1	 -30.0	 30.0;
	2660	 5263	 0.00243	 0.0198	 0.02761	 260.820767	 260.820767	 260.820767	 0.0	 0.0	 1	 -30.0	 30.0;
	2660	 6463	 0.00845	 0.04339	 0.06356	 537.431533	 537.431533	 537.431533	 0.0	 0.0	 1	 -30.0	 30.0;
	2355	 3341	 0.00219	 0.015169	 0.04925	 387.959636	 387.959636	 387.959636	 0.0	 0.0	 1	 -30.0	 30.0;
	2355	 1944	 0.00357	 0.0302	 0.11918	 420.597812	 420.597812	 420.597812	 0.0	 0.0	 1	 -30.0	 30.0;
	2316	 6868	 0.005849	 0.032419	 0.04367	 434.355284	 434.355284	 434.355284	 0.0	 0.0	 1	 -30.0	 30.0;
	8015	 1029	 0.00406	 0.01688	 0.03032	 218.208957	 218.208957	 218.208957	 0.0	 0.0	 1	 -30.0	 30.0;
	6687	 3018	 0.00113	 0.0065	 0.01259	 228.513724	 228.513724	 228.513724	 0.0	 0.0	 1	 -30.0	 30.0;
	1150	 4031	 0.0068	 0.04613	 0.07998	 532.165024	 532.165024	 532.165024	 0.0	 0.0	 1	 -30.0	 30.0;
	1150	 1795	 0.00337	 0.02011	 0.03869	 431.695928	 431.695928	 431.695928	 0.0	 0.0	 1	 -30.0	 30.0;
	7312	 6495	 0.00011	 0.0005	 0.04966	 246.960411	 246.960411	 246.960411	 0.0	 0.0	 1	 -30.0	 30.0;
	6280	 4626	 0.003711	 0.018521	 0.02962	 447.562518	 447.562518	 447.562518	 0.0	 0.0	 1	 -30.0	 30.0;
	6280	 1178	 0.000271	 0.00145	 0.00851	 458.417522	 458.417522	 458.417522	 0.0	 0.0	 1	 -30.0	 30.0;
	7584	 4282	 0.00326	 0.01824	 0.02457	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8136	 6471	 0.00118	 0.00712	 0.01134	 427.11493	 427.11493	 427.11493	 0.0	 0.0	 1	 -30.0	 30.0;
	8136	 6250	 0.00482	 0.02232	 0.03949	 389.630545	 389.630545	 389.630545	 0.0	 0.0	 1	 -30.0	 30.0;
	3813	 6365	 0.00013	 0.000469	 0.0575	 387.018058	 387.018058	 387.018058	 0.0	 0.0	 1	 -30.0	 30.0;
	3813	 5675	 0.000229	 0.00075	 0.09304	 437.840378	 437.840378	 437.840378	 0.0	 0.0	 1	 -30.0	 30.0;
	7164	 3081	 0.004591	 0.035021	 0.05924	 534.846862	 534.846862	 534.846862	 0.0	 0.0	 1	 -30.0	 30.0;
	7164	 1316	 0.005469	 0.03924	 0.06166	 625.749288	 625.749288	 625.749288	 0.0	 0.0	 1	 -30.0	 30.0;
	7164	 1316	 0.00536	 0.0403	 0.05914	 331.373155	 331.373155	 331.373155	 0.0	 0.0	 1	 -30.0	 30.0;
	7164	 102	 0.00424	 0.033031	 0.0472	 344.061397	 344.061397	 344.061397	 0.0	 0.0	 1	 -30.0	 30.0;
	5076	 3920	 2e-05	 0.00024	 0.00601	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5076	 1612	 1e-05	 0.00021	 0.00566	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5076	 3362	 0.00286	 0.03653	 0.72754	 1647.759793	 1647.759793	 1647.759793	 0.0	 0.0	 1	 -30.0	 30.0;
	5076	 3454	 0.00117	 0.01183	 0.3	 1745.749528	 1745.749528	 1745.749528	 0.0	 0.0	 1	 -30.0	 30.0;
	5076	 3287	 0.00103	 0.01336	 0.26604	 1504.566303	 1504.566303	 1504.566303	 0.0	 0.0	 1	 -30.0	 30.0;
	5076	 1368	 0.00156	 0.01969	 0.39888	 1566.264031	 1566.264031	 1566.264031	 0.0	 0.0	 1	 -30.0	 30.0;
	5076	 5943	 0.00449	 0.05772	 1.14558	 1777.871969	 1777.871969	 1777.871969	 0.0	 0.0	 1	 -30.0	 30.0;
	5076	 3283	 0.00259	 0.03469	 0.66158	 1615.595228	 1615.595228	 1615.595228	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 3764	 0.000219	 0.00118	 0.00175	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 1808	 6e-05	 0.00095	 0.00284	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 467	 6e-05	 0.000651	 0.00101	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 3257	 8.1e-05	 0.000841	 0.00202	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 3466	 0.00274	 0.020831	 0.06273	 528.696696	 528.696696	 528.696696	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 5094	 0.004781	 0.027729	 0.03822	 564.360419	 564.360419	 564.360419	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 5094	 0.002849	 0.02093	 0.03415	 577.417138	 577.417138	 577.417138	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 6074	 0.00513	 0.03014	 0.04617	 529.463371	 529.463371	 529.463371	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 6498	 0.00113	 0.00651	 0.01278	 363.113575	 363.113575	 363.113575	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 4899	 0.00125	 0.00707	 0.06377	 586.228946	 586.228946	 586.228946	 0.0	 0.0	 1	 -30.0	 30.0;
	6742	 4847	 0.003349	 0.01463	 0.02668	 356.974459	 356.974459	 356.974459	 0.0	 0.0	 1	 -30.0	 30.0;
	6742	 1391	 0.00245	 0.0122	 0.02114	 498.752933	 498.752933	 498.752933	 0.0	 0.0	 1	 -30.0	 30.0;
	1184	 6303	 0.00587	 0.036521	 0.06544	 404.413044	 404.413044	 404.413044	 0.0	 0.0	 1	 -30.0	 30.0;
	1184	 6303	 0.00569	 0.03774	 0.06418	 374.869003	 374.869003	 374.869003	 0.0	 0.0	 1	 -30.0	 30.0;
	1184	 6303	 0.006031	 0.03545	 0.06795	 638.255388	 638.255388	 638.255388	 0.0	 0.0	 1	 -30.0	 30.0;
	1184	 7154	 0.000531	 0.00301	 0.00639	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1184	 5832	 0.00076	 0.006099	 0.00958	 520.134095	 520.134095	 520.134095	 0.0	 0.0	 1	 -30.0	 30.0;
	705	 6537	 0.008841	 0.028919	 0.03903	 307.92136	 307.92136	 307.92136	 0.0	 0.0	 1	 -30.0	 30.0;
	705	 1747	 0.00169	 0.007091	 0.01232	 324.126323	 324.126323	 324.126323	 0.0	 0.0	 1	 -30.0	 30.0;
	705	 6187	 0.001031	 0.00361	 0.00593	 321.822107	 321.822107	 321.822107	 0.0	 0.0	 1	 -30.0	 30.0;
	705	 2793	 0.00813	 0.030961	 0.04182	 359.110632	 359.110632	 359.110632	 0.0	 0.0	 1	 -30.0	 30.0;
	4811	 5688	 0.00013	 0.00068	 0.06097	 548.819628	 548.819628	 548.819628	 0.0	 0.0	 1	 -30.0	 30.0;
	3326	 3509	 0.000211	 0.000729	 0.67953	 638.278251	 638.278251	 638.278251	 0.0	 0.0	 1	 -30.0	 30.0;
	3326	 3509	 0.000169	 0.000669	 0.53409	 603.583541	 603.583541	 603.583541	 0.0	 0.0	 1	 -30.0	 30.0;
	3326	 2657	 0.000669	 0.00251	 0.48	 500.108332	 500.108332	 500.108332	 0.0	 0.0	 1	 -30.0	 30.0;
	3326	 2657	 0.000711	 0.00238	 0.50939	 481.263065	 481.263065	 481.263065	 0.0	 0.0	 1	 -30.0	 30.0;
	3326	 1066	 0.000229	 0.00238	 0.01132	 593.590474	 593.590474	 593.590474	 0.0	 0.0	 1	 -30.0	 30.0;
	3326	 8340	 0.0007	 0.0065	 0.02873	 557.808625	 557.808625	 557.808625	 0.0	 0.0	 1	 -30.0	 30.0;
	3326	 7911	 0.00061	 0.006031	 0.02656	 526.635972	 526.635972	 526.635972	 0.0	 0.0	 1	 -30.0	 30.0;
	5872	 4870	 0.000281	 0.0018	 0.18523	 632.602494	 632.602494	 632.602494	 0.0	 0.0	 1	 -30.0	 30.0;
	5872	 3610	 0.000211	 0.002409	 0.01336	 275.072081	 275.072081	 275.072081	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 1223	 0.00056	 0.00773	 0.26327	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 24	 0.0023	 0.01581	 0.35639	 1219.117887	 1219.117887	 1219.117887	 0.0	 0.0	 1	 -30.0	 30.0;
	6776	 3347	 0.005039	 0.032151	 0.05529	 363.985039	 363.985039	 363.985039	 0.0	 0.0	 1	 -30.0	 30.0;
	6776	 85	 0.00364	 0.01713	 0.03513	 460.479009	 460.479009	 460.479009	 0.0	 0.0	 1	 -30.0	 30.0;
	6776	 1709	 0.002169	 0.012409	 0.0236	 344.619637	 344.619637	 344.619637	 0.0	 0.0	 1	 -30.0	 30.0;
	312	 2897	 0.00113	 0.004719	 0.00616	 344.538092	 344.538092	 344.538092	 0.0	 0.0	 1	 -30.0	 30.0;
	312	 5958	 0.00113	 0.004979	 0.00805	 494.122018	 494.122018	 494.122018	 0.0	 0.0	 1	 -30.0	 30.0;
	2897	 4299	 0.00264	 0.01174	 0.02215	 231.266819	 231.266819	 231.266819	 0.0	 0.0	 1	 -30.0	 30.0;
	2406	 7157	 0.00494	 0.03181	 0.05638	 484.388447	 484.388447	 484.388447	 0.0	 0.0	 1	 -30.0	 30.0;
	2406	 1944	 0.003711	 0.023961	 0.04229	 626.278568	 626.278568	 626.278568	 0.0	 0.0	 1	 -30.0	 30.0;
	3773	 8055	 0.001409	 0.01101	 0.01655	 462.44409	 462.44409	 462.44409	 0.0	 0.0	 1	 -30.0	 30.0;
	3773	 1481	 0.001169	 0.00593	 0.01022	 382.408863	 382.408863	 382.408863	 0.0	 0.0	 1	 -30.0	 30.0;
	3773	 1481	 0.00118	 0.00587	 0.00819	 324.072214	 324.072214	 324.072214	 0.0	 0.0	 1	 -30.0	 30.0;
	3773	 3446	 0.00264	 0.012469	 0.02555	 538.831896	 538.831896	 538.831896	 0.0	 0.0	 1	 -30.0	 30.0;
	3773	 3446	 0.002349	 0.01414	 0.02277	 513.432167	 513.432167	 513.432167	 0.0	 0.0	 1	 -30.0	 30.0;
	3110	 3732	 0.00014	 0.0007	 0.00099	 286.096273	 286.096273	 286.096273	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 4025	 3e-05	 0.00054	 0.01386	 1889.224061	 1889.224061	 1889.224061	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 6492	 3e-05	 0.00055	 0.01357	 1830.691517	 1830.691517	 1830.691517	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 3329	 4e-05	 0.00058	 0.01328	 1778.917158	 1778.917158	 1778.917158	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 4977	 4e-05	 0.00054	 0.013	 1879.592923	 1879.592923	 1879.592923	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 3853	 0.00171	 0.02197	 0.43707	 1392.212463	 1392.212463	 1392.212463	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 3853	 0.00164	 0.02064	 0.41847	 1658.37096	 1658.37096	 1658.37096	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 6279	 0.00136	 0.01756	 0.3502	 1718.20604	 1718.20604	 1718.20604	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 389	 0.00097	 0.00942	 0.25264	 1505.895167	 1505.895167	 1505.895167	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 389	 0.00086	 0.01109	 0.21989	 1497.826547	 1497.826547	 1497.826547	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 389	 0.00085	 0.0113	 0.21521	 1452.037671	 1452.037671	 1452.037671	 0.0	 0.0	 1	 -30.0	 30.0;
	3045	 6249	 0.000979	 0.0058	 0.01045	 415.127822	 415.127822	 415.127822	 0.0	 0.0	 1	 -30.0	 30.0;
	2248	 1872	 0.00052	 0.00593	 0.18425	 1925.839892	 1925.839892	 1925.839892	 0.0	 0.0	 1	 -30.0	 30.0;
	2248	 1872	 0.00046	 0.00672	 0.16415	 1933.091053	 1933.091053	 1933.091053	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 7894	 0.001151	 0.00636	 0.01278	 574.538677	 574.538677	 574.538677	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 7894	 0.001031	 0.007211	 0.01143	 591.22186	 591.22186	 591.22186	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 4282	 0.002341	 0.02286	 0.06464	 534.216604	 534.216604	 534.216604	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 1178	 0.002281	 0.02518	 0.01143	 405.589349	 405.589349	 405.589349	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 1747	 0.005479	 0.02114	 0.04046	 386.46401	 386.46401	 386.46401	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 2713	 0.011159	 0.08856	 0.13269	 485.3647	 485.3647	 485.3647	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 5308	 0.000669	 0.00249	 0.01673	 409.147224	 409.147224	 409.147224	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 7096	 0.00193	 0.01643	 0.03825	 582.544181	 582.544181	 582.544181	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 2793	 0.00024	 0.0017	 0.01301	 451.808952	 451.808952	 451.808952	 0.0	 0.0	 1	 -30.0	 30.0;
	4116	 175	 0.010159	 0.065849	 0.12243	 340.040926	 340.040926	 340.040926	 0.0	 0.0	 1	 -30.0	 30.0;
	8233	 6679	 0.00294	 0.02131	 0.00308	 518.803465	 518.803465	 518.803465	 0.0	 0.0	 1	 -30.0	 30.0;
	8233	 8306	 0.018841	 0.07469	 0.10019	 241.746107	 241.746107	 241.746107	 0.0	 0.0	 1	 -30.0	 30.0;
	8233	 5768	 0.015599	 0.052169	 0.08256	 411.186229	 411.186229	 411.186229	 0.0	 0.0	 1	 -30.0	 30.0;
	7157	 2845	 0.005831	 0.03969	 0.06912	 507.534257	 507.534257	 507.534257	 0.0	 0.0	 1	 -30.0	 30.0;
	7157	 7765	 0.00087	 0.00661	 0.01046	 466.691668	 466.691668	 466.691668	 0.0	 0.0	 1	 -30.0	 30.0;
	7157	 5055	 0.00637	 0.024659	 0.04685	 394.024446	 394.024446	 394.024446	 0.0	 0.0	 1	 -30.0	 30.0;
	5818	 2791	 0.0027	 0.020419	 0.03159	 557.430242	 557.430242	 557.430242	 0.0	 0.0	 1	 -30.0	 30.0;
	5818	 3528	 0.000409	 0.00314	 0.00436	 454.361995	 454.361995	 454.361995	 0.0	 0.0	 1	 -30.0	 30.0;
	5818	 7987	 0.001669	 0.01301	 0.01911	 495.212586	 495.212586	 495.212586	 0.0	 0.0	 1	 -30.0	 30.0;
	5818	 7987	 0.00164	 0.01325	 0.0187	 514.358884	 514.358884	 514.358884	 0.0	 0.0	 1	 -30.0	 30.0;
	7103	 4140	 0.00089	 0.00556	 0.14036	 1297.626172	 1297.626172	 1297.626172	 0.0	 0.0	 1	 -30.0	 30.0;
	7103	 3755	 0.00186	 0.01809	 0.45613	 1635.838191	 1635.838191	 1635.838191	 0.0	 0.0	 1	 -30.0	 30.0;
	7103	 3038	 0.00381	 0.02853	 0.59152	 1022.120871	 1022.120871	 1022.120871	 0.0	 0.0	 1	 -30.0	 30.0;
	5015	 2158	 0.012419	 0.072151	 0.1028	 418.417437	 418.417437	 418.417437	 0.0	 0.0	 1	 -30.0	 30.0;
	5015	 1275	 0.0042	 0.02556	 0.03659	 417.244943	 417.244943	 417.244943	 0.0	 0.0	 1	 -30.0	 30.0;
	5015	 2581	 0.010771	 0.0493	 0.06783	 486.41983	 486.41983	 486.41983	 0.0	 0.0	 1	 -30.0	 30.0;
	5015	 2206	 0.010159	 0.04995	 0.07399	 416.372336	 416.372336	 416.372336	 0.0	 0.0	 1	 -30.0	 30.0;
	5015	 8315	 0.013169	 0.05113	 0.09304	 500.51377	 500.51377	 500.51377	 0.0	 0.0	 1	 -30.0	 30.0;
	7716	 941	 0.000469	 0.001159	 0.08625	 410.57769	 410.57769	 410.57769	 0.0	 0.0	 1	 -30.0	 30.0;
	7716	 5605	 0.000229	 0.00105	 0.18562	 472.456591	 472.456591	 472.456591	 0.0	 0.0	 1	 -30.0	 30.0;
	3090	 890	 0.000271	 0.001271	 0.12465	 537.160986	 537.160986	 537.160986	 0.0	 0.0	 1	 -30.0	 30.0;
	1916	 4184	 0.00099	 0.01194	 0.35557	 1658.715846	 1658.715846	 1658.715846	 0.0	 0.0	 1	 -30.0	 30.0;
	1916	 4131	 0.00077	 0.01184	 0.28834	 2054.01373	 2054.01373	 2054.01373	 0.0	 0.0	 1	 -30.0	 30.0;
	1916	 4676	 0.00034	 0.00426	 0.12245	 2224.49336	 2224.49336	 2224.49336	 0.0	 0.0	 1	 -30.0	 30.0;
	3570	 1941	 0.00101	 0.01168	 0.36215	 1765.082229	 1765.082229	 1765.082229	 0.0	 0.0	 1	 -30.0	 30.0;
	3570	 4131	 0.00086	 0.01046	 0.3119	 1826.82603	 1826.82603	 1826.82603	 0.0	 0.0	 1	 -30.0	 30.0;
	3570	 3193	 0.00035	 0.00417	 0.12476	 2277.38794	 2277.38794	 2277.38794	 0.0	 0.0	 1	 -30.0	 30.0;
	6054	 1352	 0.000159	 0.00069	 0.06858	 542.66527	 542.66527	 542.66527	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 5296	 0.000781	 0.00488	 0.0082	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 520	 0.000781	 0.00511	 0.00888	 545.698819	 545.698819	 545.698819	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 7445	 0.00064	 0.003539	 0.01491	 469.574701	 469.574701	 469.574701	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 7445	 0.00057	 0.003781	 0.00593	 455.148484	 455.148484	 455.148484	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 2747	 0.000531	 0.00111	 0.12193	 352.546263	 352.546263	 352.546263	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 7228	 0.000521	 0.00113	 0.11933	 279.864562	 279.864562	 279.864562	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 5440	 0.00176	 0.00843	 0.0151	 454.605868	 454.605868	 454.605868	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 7987	 0.002461	 0.01975	 0.02761	 577.443049	 577.443049	 577.443049	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 6197	 0.000591	 0.00105	 0.06273	 349.130521	 349.130521	 349.130521	 0.0	 0.0	 1	 -30.0	 30.0;
	1866	 1294	 0.00012	 0.00064	 0.00093	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6090	 1653	 0.000581	 0.004419	 0.0061	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 1653	 0.000651	 0.004331	 0.00692	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	464	 2597	 0.001289	 0.008289	 0.0151	 507.579221	 507.579221	 507.579221	 0.0	 0.0	 1	 -30.0	 30.0;
	4522	 8369	 0.00233	 0.03502	 1.06047	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4522	 8369	 0.00238	 0.03781	 1.08404	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4522	 1891	 0.00052	 0.00605	 0.10447	 1395.819943	 1395.819943	 1395.819943	 0.0	 0.0	 1	 -30.0	 30.0;
	4522	 4955	 0.00023	 0.00275	 0.06481	 1525.776789	 1525.776789	 1525.776789	 0.0	 0.0	 1	 -30.0	 30.0;
	4522	 7352	 0.00134	 0.01343	 0.3398	 1721.558148	 1721.558148	 1721.558148	 0.0	 0.0	 1	 -30.0	 30.0;
	4522	 7352	 0.00116	 0.01552	 0.29758	 1483.368322	 1483.368322	 1483.368322	 0.0	 0.0	 1	 -30.0	 30.0;
	7218	 641	 0.004169	 0.027919	 0.04838	 527.405314	 527.405314	 527.405314	 0.0	 0.0	 1	 -30.0	 30.0;
	7218	 4381	 0.00063	 0.008	 0.01742	 235.022459	 235.022459	 235.022459	 0.0	 0.0	 1	 -30.0	 30.0;
	7218	 1707	 0.004841	 0.028581	 0.05233	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	7218	 4979	 0.007419	 0.05787	 0.20563	 602.967763	 602.967763	 602.967763	 0.0	 0.0	 1	 -30.0	 30.0;
	4633	 2237	 0.002719	 0.020331	 0.02974	 510.876457	 510.876457	 510.876457	 0.0	 0.0	 1	 -30.0	 30.0;
	2115	 6510	 0.000789	 0.005	 0.00805	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8331	 175	 0.00238	 0.013219	 0.02271	 462.355305	 462.355305	 462.355305	 0.0	 0.0	 1	 -30.0	 30.0;
	8331	 2852	 0.003771	 0.02701	 0.04182	 508.356185	 508.356185	 508.356185	 0.0	 0.0	 1	 -30.0	 30.0;
	266	 4134	 0.001271	 0.00939	 0.01394	 352.713164	 352.713164	 352.713164	 0.0	 0.0	 1	 -30.0	 30.0;
	8174	 6111	 0.000841	 0.00131	 0.19486	 304.552486	 304.552486	 304.552486	 0.0	 0.0	 1	 -30.0	 30.0;
	7649	 3421	 0.005711	 0.043039	 0.07248	 599.481144	 599.481144	 599.481144	 0.0	 0.0	 1	 -30.0	 30.0;
	7649	 3421	 0.00562	 0.041901	 0.0697	 514.029274	 514.029274	 514.029274	 0.0	 0.0	 1	 -30.0	 30.0;
	4525	 2669	 0.00356	 0.019781	 0.0394	 551.192053	 551.192053	 551.192053	 0.0	 0.0	 1	 -30.0	 30.0;
	4525	 144	 0.004841	 0.03149	 0.0543	 541.485536	 541.485536	 541.485536	 0.0	 0.0	 1	 -30.0	 30.0;
	167	 7712	 0.00057	 0.00107	 0.06055	 330.262771	 330.262771	 330.262771	 0.0	 0.0	 1	 -30.0	 30.0;
	6268	 4471	 0.000539	 0.00213	 0.22396	 521.885788	 521.885788	 521.885788	 0.0	 0.0	 1	 -30.0	 30.0;
	400	 4318	 0.0007	 0.00425	 0.0082	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1327	 5892	 0.0012	 0.009531	 0.02761	 280.25552	 280.25552	 280.25552	 0.0	 0.0	 1	 -30.0	 30.0;
	1327	 2493	 0.00206	 0.015901	 0.04003	 307.333779	 307.333779	 307.333779	 0.0	 0.0	 1	 -30.0	 30.0;
	3276	 4299	 0.00063	 0.00312	 0.00465	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1136	 5874	 3e-05	 0.00041	 0.01132	 1496.554286	 1496.554286	 1496.554286	 0.0	 0.0	 1	 -30.0	 30.0;
	997	 5874	 2e-05	 0.00043	 0.01063	 2122.412382	 2122.412382	 2122.412382	 0.0	 0.0	 1	 -30.0	 30.0;
	5181	 5874	 3e-05	 0.00039	 0.0104	 1284.402034	 1284.402034	 1284.402034	 0.0	 0.0	 1	 -30.0	 30.0;
	3481	 5874	 3e-05	 0.00038	 0.01178	 2081.138616	 2081.138616	 2081.138616	 0.0	 0.0	 1	 -30.0	 30.0;
	1288	 3183	 0.0008	 0.004151	 0.0061	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4139	 3183	 0.000901	 0.00381	 0.00604	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2794	 578	 0.000591	 0.004341	 0.04704	 478.85787	 478.85787	 478.85787	 0.0	 0.0	 1	 -30.0	 30.0;
	2794	 578	 0.000591	 0.00405	 0.0575	 513.876092	 513.876092	 513.876092	 0.0	 0.0	 1	 -30.0	 30.0;
	4555	 4131	 0.00218	 0.0275	 0.43052	 1169.574756	 1169.574756	 1169.574756	 0.0	 0.0	 1	 -30.0	 30.0;
	4555	 7429	 0.00184	 0.01677	 0.39127	 1108.786631	 1108.786631	 1108.786631	 0.0	 0.0	 1	 -30.0	 30.0;
	686	 875	 0.00058	 0.00807	 0.26039	 1091.574584	 1091.574584	 1091.574584	 0.0	 0.0	 1	 -30.0	 30.0;
	686	 875	 0.00056	 0.00823	 0.25784	 952.801426	 952.801426	 952.801426	 0.0	 0.0	 1	 -30.0	 30.0;
	686	 3558	 0.00123	 0.01146	 0.31768	 1434.222073	 1434.222073	 1434.222073	 0.0	 0.0	 1	 -30.0	 30.0;
	686	 3558	 0.0011	 0.01298	 0.28302	 1500.80415	 1500.80415	 1500.80415	 0.0	 0.0	 1	 -30.0	 30.0;
	686	 7566	 0.00156	 0.01585	 0.40103	 1783.568511	 1783.568511	 1783.568511	 0.0	 0.0	 1	 -30.0	 30.0;
	686	 2648	 0.00226	 0.02781	 0.57667	 1487.683346	 1487.683346	 1487.683346	 0.0	 0.0	 1	 -30.0	 30.0;
	3421	 168	 0.00614	 0.02831	 0.06602	 418.694842	 418.694842	 418.694842	 0.0	 0.0	 1	 -30.0	 30.0;
	3421	 2043	 0.00513	 0.03401	 0.05522	 239.49257	 239.49257	 239.49257	 0.0	 0.0	 1	 -30.0	 30.0;
	3555	 3744	 0.013219	 0.0597	 0.08728	 236.263162	 236.263162	 236.263162	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 6338	 0.012969	 0.06087	 0.0855	 240.085867	 240.085867	 240.085867	 0.0	 0.0	 1	 -30.0	 30.0;
	7823	 8107	 0.00437	 0.032831	 0.05018	 555.161463	 555.161463	 555.161463	 0.0	 0.0	 1	 -30.0	 30.0;
	7823	 2237	 0.005651	 0.033229	 0.07114	 596.715094	 596.715094	 596.715094	 0.0	 0.0	 1	 -30.0	 30.0;
	1969	 4979	 0.008969	 0.03625	 0.06691	 453.103383	 453.103383	 453.103383	 0.0	 0.0	 1	 -30.0	 30.0;
	1969	 7050	 0.012409	 0.05645	 0.09084	 421.345053	 421.345053	 421.345053	 0.0	 0.0	 1	 -30.0	 30.0;
	4551	 5791	 0.00038	 0.002271	 0.00426	 409.452827	 409.452827	 409.452827	 0.0	 0.0	 1	 -30.0	 30.0;
	5873	 3719	 0.00138	 0.01089	 0.01547	 574.794363	 574.794363	 574.794363	 0.0	 0.0	 1	 -30.0	 30.0;
	5873	 3719	 0.001539	 0.012521	 0.01692	 606.634237	 606.634237	 606.634237	 0.0	 0.0	 1	 -30.0	 30.0;
	5873	 45	 0.00205	 0.014229	 0.10055	 550.448241	 550.448241	 550.448241	 0.0	 0.0	 1	 -30.0	 30.0;
	5873	 6581	 0.00026	 0.00164	 0.00307	 511.214068	 511.214068	 511.214068	 0.0	 0.0	 1	 -30.0	 30.0;
	5873	 2245	 0.000289	 0.00169	 0.00418	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4847	 6874	 0.003349	 0.051211	 0.02405	 463.160848	 463.160848	 463.160848	 0.0	 0.0	 1	 -30.0	 30.0;
	7224	 2080	 0.00038	 0.001479	 0.16032	 379.885923	 379.885923	 379.885923	 0.0	 0.0	 1	 -30.0	 30.0;
	1451	 6438	 0.00082	 0.00625	 0.01022	 558.063549	 558.063549	 558.063549	 0.0	 0.0	 1	 -30.0	 30.0;
	2900	 1897	 0.00275	 0.015581	 0.03088	 572.708488	 572.708488	 572.708488	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 5375	 0.000909	 0.00739	 0.01069	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3362	 7692	 0.00082	 0.01038	 0.20794	 1565.174086	 1565.174086	 1565.174086	 0.0	 0.0	 1	 -30.0	 30.0;
	3362	 6830	 0.00093	 0.01017	 0.23566	 1410.850126	 1410.850126	 1410.850126	 0.0	 0.0	 1	 -30.0	 30.0;
	3362	 1368	 0.00137	 0.01431	 0.34902	 1878.217328	 1878.217328	 1878.217328	 0.0	 0.0	 1	 -30.0	 30.0;
	3362	 1416	 0.00215	 0.02021	 0.55912	 1685.372108	 1685.372108	 1685.372108	 0.0	 0.0	 1	 -30.0	 30.0;
	6303	 3453	 0.01189	 0.058841	 0.08822	 469.297677	 469.297677	 469.297677	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 2286	 0.00104	 0.01241	 0.47144	 1270.53617	 1270.53617	 1270.53617	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 2286	 0.00092	 0.014	 0.41807	 1274.774845	 1274.774845	 1274.774845	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 2149	 0.00055	 0.00845	 0.25004	 1171.182029	 1171.182029	 1171.182029	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 2149	 0.00054	 0.00861	 0.24472	 1003.754377	 1003.754377	 1003.754377	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 3454	 0.00105	 0.01057	 0.26634	 1831.444474	 1831.444474	 1831.444474	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 3287	 0.00089	 0.01122	 0.22613	 1630.410186	 1630.410186	 1630.410186	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 6261	 0.00223	 0.02584	 0.56605	 1794.352779	 1794.352779	 1794.352779	 0.0	 0.0	 1	 -30.0	 30.0;
	7414	 4644	 0.00101	 0.007841	 0.01092	 564.002993	 564.002993	 564.002993	 0.0	 0.0	 1	 -30.0	 30.0;
	7414	 4644	 0.001081	 0.008099	 0.01208	 578.823598	 578.823598	 578.823598	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 6498	 0.011081	 0.068479	 0.12621	 351.984213	 351.984213	 351.984213	 0.0	 0.0	 1	 -30.0	 30.0;
	8369	 7910	 2e-05	 0.00033	 0.01132	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	8369	 8053	 1e-05	 0.00029	 0.00901	 1798.151132	 1798.151132	 1798.151132	 0.0	 0.0	 1	 -30.0	 30.0;
	8369	 7866	 0.00071	 0.00892	 0.32438	 1601.747136	 1601.747136	 1601.747136	 0.0	 0.0	 1	 -30.0	 30.0;
	8369	 6497	 0.00136	 0.01526	 0.62583	 1467.106028	 1467.106028	 1467.106028	 0.0	 0.0	 1	 -30.0	 30.0;
	5382	 7050	 0.005401	 0.036021	 0.07207	 598.54795	 598.54795	 598.54795	 0.0	 0.0	 1	 -30.0	 30.0;
	2853	 3116	 0.00437	 0.033719	 0.05924	 470.166092	 470.166092	 470.166092	 0.0	 0.0	 1	 -30.0	 30.0;
	2853	 958	 0.005151	 0.034919	 0.04987	 522.354481	 522.354481	 522.354481	 0.0	 0.0	 1	 -30.0	 30.0;
	258	 725	 0.00038	 0.00139	 0.00213	 358.391588	 358.391588	 358.391588	 0.0	 0.0	 1	 -30.0	 30.0;
	258	 983	 0.00037	 0.0015	 0.00206	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	258	 4318	 0.00069	 0.004461	 0.00805	 547.833468	 547.833468	 547.833468	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 4741	 0.00688	 0.040591	 0.07696	 395.436241	 395.436241	 395.436241	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 102	 0.001341	 0.008349	 0.01642	 484.090465	 484.090465	 484.090465	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 102	 0.001229	 0.009669	 0.01425	 643.406819	 643.406819	 643.406819	 0.0	 0.0	 1	 -30.0	 30.0;
	4430	 5222	 0.00137	 0.006039	 0.00987	 436.028479	 436.028479	 436.028479	 0.0	 0.0	 1	 -30.0	 30.0;
	6839	 5944	 0.001919	 0.01261	 0.02271	 487.725312	 487.725312	 487.725312	 0.0	 0.0	 1	 -30.0	 30.0;
	6839	 787	 0.00163	 0.0095	 0.01881	 536.910636	 536.910636	 536.910636	 0.0	 0.0	 1	 -30.0	 30.0;
	8074	 8055	 0.00488	 0.0497	 0.0558	 583.316572	 583.316572	 583.316572	 0.0	 0.0	 1	 -30.0	 30.0;
	8074	 4101	 0.001289	 0.0087	 0.08728	 564.532273	 564.532273	 564.532273	 0.0	 0.0	 1	 -30.0	 30.0;
	8074	 3122	 0.00211	 0.01524	 0.02467	 576.331142	 576.331142	 576.331142	 0.0	 0.0	 1	 -30.0	 30.0;
	8074	 3122	 0.00206	 0.015539	 0.02416	 605.628643	 605.628643	 605.628643	 0.0	 0.0	 1	 -30.0	 30.0;
	8074	 3122	 0.00276	 0.01631	 0.02582	 516.448568	 516.448568	 516.448568	 0.0	 0.0	 1	 -30.0	 30.0;
	8074	 5944	 0.00305	 0.019521	 0.03322	 618.800058	 618.800058	 618.800058	 0.0	 0.0	 1	 -30.0	 30.0;
	8074	 7953	 0.000409	 0.0023	 0.00426	 509.545445	 509.545445	 509.545445	 0.0	 0.0	 1	 -30.0	 30.0;
	8074	 6002	 0.00036	 0.00268	 0.00372	 516.486674	 516.486674	 516.486674	 0.0	 0.0	 1	 -30.0	 30.0;
	7400	 6108	 0.00032	 0.00049	 0.04838	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	984	 6108	 0.00013	 0.000349	 0.09477	 288.756391	 288.756391	 288.756391	 0.0	 0.0	 1	 -30.0	 30.0;
	7245	 3853	 0.0002	 0.00327	 0.10102	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	729	 1951	 0.000919	 0.00561	 0.01949	 543.29591	 543.29591	 543.29591	 0.0	 0.0	 1	 -30.0	 30.0;
	729	 1951	 0.00094	 0.00549	 0.023	 539.357365	 539.357365	 539.357365	 0.0	 0.0	 1	 -30.0	 30.0;
	729	 6820	 0.00175	 0.01976	 0.05187	 541.369696	 541.369696	 541.369696	 0.0	 0.0	 1	 -30.0	 30.0;
	729	 6117	 0.001729	 0.019331	 0.05096	 484.208209	 484.208209	 484.208209	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 6170	 0.00406	 0.02581	 0.04631	 574.671283	 574.671283	 574.671283	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 698	 0.00526	 0.025961	 0.0389	 524.353475	 524.353475	 524.353475	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 986	 0.00179	 0.02098	 0.43586	 1360.138727	 1360.138727	 1360.138727	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 5430	 0.00162	 0.02148	 0.39854	 1411.555694	 1411.555694	 1411.555694	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 7493	 0.00492	 0.04991	 1.20141	 1060.166926	 1060.166926	 1060.166926	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 871	 0.00109	 0.01361	 0.49859	 1095.990309	 1095.990309	 1095.990309	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 871	 0.00097	 0.0153	 0.44106	 911.008357	 911.008357	 911.008357	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 3558	 0.00322	 0.03022	 0.78911	 1502.622699	 1502.622699	 1502.622699	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 6674	 0.032831	 0.074151	 0.14161	 257.629463	 257.629463	 257.629463	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 6215	 0.01411	 0.058711	 0.11286	 518.404123	 518.404123	 518.404123	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 7720	 0.02725	 0.102979	 0.19486	 438.393664	 438.393664	 438.393664	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 2880	 0.012229	 0.04049	 0.08781	 403.924918	 403.924918	 403.924918	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 2426	 0.01994	 0.066719	 0.10772	 357.425624	 357.425624	 357.425624	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 3453	 0.018591	 0.07462	 0.13591	 441.049972	 441.049972	 441.049972	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 4120	 0.008979	 0.03251	 0.0607	 356.029071	 356.029071	 356.029071	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 3856	 0.016531	 0.086031	 0.11738	 384.357178	 384.357178	 384.357178	 0.0	 0.0	 1	 -30.0	 30.0;
	7825	 37	 0.003591	 0.02137	 0.04002	 607.969059	 607.969059	 607.969059	 0.0	 0.0	 1	 -30.0	 30.0;
	7825	 6012	 0.00124	 0.008	 0.01283	 411.000276	 411.000276	 411.000276	 0.0	 0.0	 1	 -30.0	 30.0;
	7825	 6012	 0.001271	 0.007831	 0.01308	 455.553923	 455.553923	 455.553923	 0.0	 0.0	 1	 -30.0	 30.0;
	7825	 1409	 0.000469	 0.00294	 0.00906	 509.439132	 509.439132	 509.439132	 0.0	 0.0	 1	 -30.0	 30.0;
	7825	 3839	 0.000841	 0.003289	 0.3457	 500.49205	 500.49205	 500.49205	 0.0	 0.0	 1	 -30.0	 30.0;
	6496	 1754	 0.00219	 0.016539	 0.02547	 402.576378	 402.576378	 402.576378	 0.0	 0.0	 1	 -30.0	 30.0;
	6496	 5010	 0.002901	 0.020901	 0.03252	 403.514145	 403.514145	 403.514145	 0.0	 0.0	 1	 -30.0	 30.0;
	6938	 204	 0.0002	 0.001211	 0.00202	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 1271	 9.1e-05	 0.000479	 0.00091	 335.513276	 335.513276	 335.513276	 0.0	 0.0	 1	 -30.0	 30.0;
	6367	 6458	 0.005461	 0.029469	 0.04274	 432.413447	 432.413447	 432.413447	 0.0	 0.0	 1	 -30.0	 30.0;
	6367	 3018	 0.001979	 0.011289	 0.02236	 595.247666	 595.247666	 595.247666	 0.0	 0.0	 1	 -30.0	 30.0;
	1133	 144	 0.0023	 0.01289	 0.02345	 252.431925	 252.431925	 252.431925	 0.0	 0.0	 1	 -30.0	 30.0;
	8214	 2227	 0.000159	 0.00037	 0.02912	 342.807738	 342.807738	 342.807738	 0.0	 0.0	 1	 -30.0	 30.0;
	8055	 3446	 0.002789	 0.01562	 0.44832	 543.451379	 543.451379	 543.451379	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 5062	 0.002531	 0.012331	 0.01975	 385.621887	 385.621887	 385.621887	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 6952	 0.00357	 0.023289	 0.037	 416.91762	 416.91762	 416.91762	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 4449	 0.00076	 0.006039	 0.0091	 527.690721	 527.690721	 527.690721	 0.0	 0.0	 1	 -30.0	 30.0;
	3641	 1391	 0.000469	 0.00075	 0.04743	 322.237072	 322.237072	 322.237072	 0.0	 0.0	 1	 -30.0	 30.0;
	164	 1391	 0.00044	 0.00069	 0.04838	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2701	 1904	 0.00561	 0.035521	 0.06342	 604.27553	 604.27553	 604.27553	 0.0	 0.0	 1	 -30.0	 30.0;
	7870	 844	 0.004539	 0.03468	 0.04898	 373.025859	 373.025859	 373.025859	 0.0	 0.0	 1	 -30.0	 30.0;
	7870	 844	 0.00175	 0.0067	 0.0362	 424.735266	 424.735266	 424.735266	 0.0	 0.0	 1	 -30.0	 30.0;
	7870	 3313	 0.007461	 0.031419	 0.05235	 401.11276	 401.11276	 401.11276	 0.0	 0.0	 1	 -30.0	 30.0;
	7894	 6099	 0.00224	 0.012909	 0.02509	 620.534984	 620.534984	 620.534984	 0.0	 0.0	 1	 -30.0	 30.0;
	6391	 16	 0.0003	 0.000961	 0.24277	 430.731868	 430.731868	 430.731868	 0.0	 0.0	 1	 -30.0	 30.0;
	6391	 16	 0.00032	 0.001409	 0.14589	 219.786509	 219.786509	 219.786509	 0.0	 0.0	 1	 -30.0	 30.0;
	6391	 1415	 0.002031	 0.0157	 0.04269	 568.47882	 568.47882	 568.47882	 0.0	 0.0	 1	 -30.0	 30.0;
	6391	 3735	 0.00038	 0.00306	 0.02547	 520.966692	 520.966692	 520.966692	 0.0	 0.0	 1	 -30.0	 30.0;
	6391	 7133	 0.00118	 0.0083	 0.0351	 552.860676	 552.860676	 552.860676	 0.0	 0.0	 1	 -30.0	 30.0;
	6391	 4952	 0.001229	 0.00787	 0.02416	 579.77051	 579.77051	 579.77051	 0.0	 0.0	 1	 -30.0	 30.0;
	5062	 5143	 0.00301	 0.01538	 0.02137	 525.66734	 525.66734	 525.66734	 0.0	 0.0	 1	 -30.0	 30.0;
	6115	 4952	 0.00063	 0.00114	 0.14515	 395.387847	 395.387847	 395.387847	 0.0	 0.0	 1	 -30.0	 30.0;
	4790	 7133	 0.00064	 0.00111	 0.14799	 266.970933	 266.970933	 266.970933	 0.0	 0.0	 1	 -30.0	 30.0;
	7053	 3511	 0.004919	 0.03837	 0.05642	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	5706	 3122	 0.001831	 0.008349	 0.02919	 438.960287	 438.960287	 438.960287	 0.0	 0.0	 1	 -30.0	 30.0;
	3116	 362	 0.00536	 0.03188	 0.06168	 538.304521	 538.304521	 538.304521	 0.0	 0.0	 1	 -30.0	 30.0;
	2696	 8151	 0.00038	 0.001461	 0.0021	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2696	 8151	 0.000289	 0.001521	 0.00182	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8151	 2250	 0.00305	 0.016841	 0.02366	 487.972614	 487.972614	 487.972614	 0.0	 0.0	 1	 -30.0	 30.0;
	8151	 8264	 0.001781	 0.012729	 0.02941	 459.923437	 459.923437	 459.923437	 0.0	 0.0	 1	 -30.0	 30.0;
	1878	 6821	 0.00041	 0.00461	 0.09908	 985.302979	 985.302979	 985.302979	 0.0	 0.0	 1	 -30.0	 30.0;
	1878	 6821	 0.0004	 0.0047	 0.09706	 1044.369964	 1044.369964	 1044.369964	 0.0	 0.0	 1	 -30.0	 30.0;
	3719	 4852	 0.00213	 0.01401	 0.02369	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	3719	 2108	 0.001271	 0.00887	 0.01301	 441.903145	 441.903145	 441.903145	 0.0	 0.0	 1	 -30.0	 30.0;
	3719	 2608	 0.00462	 0.02743	 0.05227	 544.428775	 544.428775	 544.428775	 0.0	 0.0	 1	 -30.0	 30.0;
	2354	 6728	 0.001539	 0.00776	 0.01436	 328.636826	 328.636826	 328.636826	 0.0	 0.0	 1	 -30.0	 30.0;
	6514	 8108	 0.00025	 0.00478	 0.15203	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	4884	 8108	 0.00025	 0.00487	 0.14879	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	7367	 8108	 0.00025	 0.00435	 0.16202	 843.64897	 843.64897	 843.64897	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 8108	 0.00026	 0.00426	 0.16519	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1123	 8108	 0.00025	 0.00479	 0.152	 2267.925954	 2267.925954	 2267.925954	 0.0	 0.0	 1	 -30.0	 30.0;
	3757	 8324	 0.000169	 0.00076	 0.07144	 449.317258	 449.317258	 449.317258	 0.0	 0.0	 1	 -30.0	 30.0;
	3757	 7235	 0.00039	 0.00126	 0.16212	 501.885173	 501.885173	 501.885173	 0.0	 0.0	 1	 -30.0	 30.0;
	2208	 4381	 0.011229	 0.074659	 0.12737	 629.055669	 629.055669	 629.055669	 0.0	 0.0	 1	 -30.0	 30.0;
	2208	 1707	 0.014521	 0.058081	 0.07643	 408.713969	 408.713969	 408.713969	 0.0	 0.0	 1	 -30.0	 30.0;
	2208	 7992	 0.00064	 0.003919	 0.01013	 533.867561	 533.867561	 533.867561	 0.0	 0.0	 1	 -30.0	 30.0;
	2208	 4678	 0.014789	 0.07768	 0.1089	 443.074497	 443.074497	 443.074497	 0.0	 0.0	 1	 -30.0	 30.0;
	2208	 6295	 0.00938	 0.05355	 0.10755	 580.516608	 580.516608	 580.516608	 0.0	 0.0	 1	 -30.0	 30.0;
	2208	 1591	 0.00124	 0.004289	 0.00673	 423.443883	 423.443883	 423.443883	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 7824	 0.00968	 0.04388	 0.08518	 248.199209	 248.199209	 248.199209	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 154	 0.008531	 0.067151	 0.10106	 465.063817	 465.063817	 465.063817	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 6741	 0.00731	 0.04106	 0.05699	 438.740421	 438.740421	 438.740421	 0.0	 0.0	 1	 -30.0	 30.0;
	6657	 5387	 0.004349	 0.02555	 0.04344	 536.298286	 536.298286	 536.298286	 0.0	 0.0	 1	 -30.0	 30.0;
	6657	 6797	 0.00599	 0.03462	 0.06122	 488.955726	 488.955726	 488.955726	 0.0	 0.0	 1	 -30.0	 30.0;
	7991	 4381	 0.002961	 0.021591	 0.04182	 564.023951	 564.023951	 564.023951	 0.0	 0.0	 1	 -30.0	 30.0;
	7991	 4381	 0.002901	 0.02206	 0.04186	 579.598656	 579.598656	 579.598656	 0.0	 0.0	 1	 -30.0	 30.0;
	7991	 5493	 0.002979	 0.016969	 0.03301	 490.70818	 490.70818	 490.70818	 0.0	 0.0	 1	 -30.0	 30.0;
	5231	 3817	 0.00312	 0.020021	 0.03524	 490.765719	 490.765719	 490.765719	 0.0	 0.0	 1	 -30.0	 30.0;
	7712	 1803	 0.000219	 0.000909	 0.09676	 342.38782	 342.38782	 342.38782	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 1803	 0.000219	 0.00093	 0.09386	 462.401031	 462.401031	 462.401031	 0.0	 0.0	 1	 -30.0	 30.0;
	2627	 1940	 0.000151	 0.000289	 0.0236	 375.192135	 375.192135	 375.192135	 0.0	 0.0	 1	 -30.0	 30.0;
	4496	 7483	 0.00563	 0.043599	 0.06447	 364.539468	 364.539468	 364.539468	 0.0	 0.0	 1	 -30.0	 30.0;
	4496	 4319	 0.000969	 0.00612	 0.01007	 523.535358	 523.535358	 523.535358	 0.0	 0.0	 1	 -30.0	 30.0;
	3167	 3269	 0.005021	 0.020719	 0.046	 441.499993	 441.499993	 441.499993	 0.0	 0.0	 1	 -30.0	 30.0;
	3167	 4252	 0.00988	 0.041039	 0.12342	 348.969336	 348.969336	 348.969336	 0.0	 0.0	 1	 -30.0	 30.0;
	4230	 3857	 0.003159	 0.02011	 0.03624	 480.934218	 480.934218	 480.934218	 0.0	 0.0	 1	 -30.0	 30.0;
	4230	 3857	 0.003219	 0.01969	 0.03694	 479.265976	 479.265976	 479.265976	 0.0	 0.0	 1	 -30.0	 30.0;
	6467	 4936	 0.00049	 0.00238	 0.00379	 307.409227	 307.409227	 307.409227	 0.0	 0.0	 1	 -30.0	 30.0;
	6467	 4936	 0.000479	 0.002419	 0.00372	 305.538266	 305.538266	 305.538266	 0.0	 0.0	 1	 -30.0	 30.0;
	7479	 5193	 0.00264	 0.019729	 0.03903	 544.554903	 544.554903	 544.554903	 0.0	 0.0	 1	 -30.0	 30.0;
	7479	 5193	 0.002581	 0.02011	 0.03822	 505.24414	 505.24414	 505.24414	 0.0	 0.0	 1	 -30.0	 30.0;
	6197	 6099	 0.00037	 0.002831	 0.00455	 570.722069	 570.722069	 570.722069	 0.0	 0.0	 1	 -30.0	 30.0;
	6197	 5161	 0.00213	 0.012789	 0.01992	 520.785312	 520.785312	 520.785312	 0.0	 0.0	 1	 -30.0	 30.0;
	2158	 730	 0.018669	 0.092281	 0.16007	 442.954085	 442.954085	 442.954085	 0.0	 0.0	 1	 -30.0	 30.0;
	820	 8251	 3.9e-05	 0.000401	 0.00095	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3695	 8251	 6e-05	 0.00044	 0.00089	 399.734117	 399.734117	 399.734117	 0.0	 0.0	 1	 -30.0	 30.0;
	6203	 1951	 6e-05	 0.0005	 0.00093	 520.109327	 520.109327	 520.109327	 0.0	 0.0	 1	 -30.0	 30.0;
	5143	 2393	 0.001271	 0.007031	 0.0098	 489.004882	 489.004882	 489.004882	 0.0	 0.0	 1	 -30.0	 30.0;
	5143	 6874	 0.00055	 0.003159	 0.00532	 616.945101	 616.945101	 616.945101	 0.0	 0.0	 1	 -30.0	 30.0;
	5143	 6874	 0.00055	 0.00338	 0.00616	 609.551565	 609.551565	 609.551565	 0.0	 0.0	 1	 -30.0	 30.0;
	5143	 6874	 0.00105	 0.004771	 0.00941	 495.662608	 495.662608	 495.662608	 0.0	 0.0	 1	 -30.0	 30.0;
	5143	 1484	 0.003289	 0.015039	 0.02091	 395.285725	 395.285725	 395.285725	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 623	 0.00036	 0.004349	 0.01069	 617.130673	 617.130673	 617.130673	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 623	 0.00038	 0.003669	 0.0151	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 2201	 0.00118	 0.00701	 0.01359	 300.927928	 300.927928	 300.927928	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 2201	 0.001229	 0.00686	 0.01384	 538.729774	 538.729774	 538.729774	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 5358	 0.00301	 0.0217	 0.03159	 285.137548	 285.137548	 285.137548	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 5358	 0.003409	 0.01924	 0.03833	 314.544029	 314.544029	 314.544029	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 5358	 0.003409	 0.01938	 0.03764	 573.819634	 573.819634	 573.819634	 0.0	 0.0	 1	 -30.0	 30.0;
	7119	 8365	 0.002719	 0.02131	 0.03094	 269.041946	 269.041946	 269.041946	 0.0	 0.0	 1	 -30.0	 30.0;
	2709	 1316	 0.00295	 0.01956	 0.03357	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4648	 5161	 0.001091	 0.00831	 0.03284	 489.757458	 489.757458	 489.757458	 0.0	 0.0	 1	 -30.0	 30.0;
	2697	 5358	 0.00111	 0.008211	 0.03252	 556.130476	 556.130476	 556.130476	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 1963	 0.002469	 0.015271	 0.02873	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 7354	 0.00212	 0.01601	 0.02416	 242.804667	 242.804667	 242.804667	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 2294	 0.00037	 0.0028	 0.00364	 547.55149	 547.55149	 547.55149	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 6438	 0.00162	 0.01238	 0.0183	 234.559482	 234.559482	 234.559482	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 6438	 0.001909	 0.01162	 0.02155	 318.573264	 318.573264	 318.573264	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 6438	 0.001909	 0.010729	 0.02236	 561.117293	 561.117293	 561.117293	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 3401	 0.00089	 0.00526	 0.00743	 419.94088	 419.94088	 419.94088	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 5019	 0.00087	 0.00536	 0.00728	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 5222	 0.001521	 0.01176	 0.01742	 548.813912	 548.813912	 548.813912	 0.0	 0.0	 1	 -30.0	 30.0;
	8191	 5951	 0.00014	 0.000591	 0.09775	 491.532013	 491.532013	 491.532013	 0.0	 0.0	 1	 -30.0	 30.0;
	1221	 1004	 0.003531	 0.028781	 0.04097	 266.599789	 266.599789	 266.599789	 0.0	 0.0	 1	 -30.0	 30.0;
	2533	 7517	 0.004599	 0.03657	 0.05077	 554.684768	 554.684768	 554.684768	 0.0	 0.0	 1	 -30.0	 30.0;
	2533	 7582	 0.00307	 0.019159	 0.03322	 603.388062	 603.388062	 603.388062	 0.0	 0.0	 1	 -30.0	 30.0;
	2533	 1003	 0.000581	 0.004461	 0.00637	 518.963125	 518.963125	 518.963125	 0.0	 0.0	 1	 -30.0	 30.0;
	2533	 6249	 0.00164	 0.01161	 0.01707	 609.086682	 609.086682	 609.086682	 0.0	 0.0	 1	 -30.0	 30.0;
	4493	 6242	 0.00057	 0.003281	 0.00746	 551.546049	 551.546049	 551.546049	 0.0	 0.0	 1	 -30.0	 30.0;
	7020	 6330	 0.020419	 0.063669	 0.10465	 322.593354	 322.593354	 322.593354	 0.0	 0.0	 1	 -30.0	 30.0;
	5953	 2840	 0.01424	 0.04751	 0.08106	 224.301584	 224.301584	 224.301584	 0.0	 0.0	 1	 -30.0	 30.0;
	7897	 255	 0.00157	 0.008849	 0.03194	 566.540794	 566.540794	 566.540794	 0.0	 0.0	 1	 -30.0	 30.0;
	7897	 2273	 0.01218	 0.07524	 0.13852	 339.407238	 339.407238	 339.407238	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 695	 0.00037	 0.00151	 0.15705	 364.999016	 364.999016	 364.999016	 0.0	 0.0	 1	 -30.0	 30.0;
	7623	 5655	 0.000219	 0.000531	 0.03604	 328.605199	 328.605199	 328.605199	 0.0	 0.0	 1	 -30.0	 30.0;
	3600	 1271	 0.002849	 0.0137	 0.01992	 341.119301	 341.119301	 341.119301	 0.0	 0.0	 1	 -30.0	 30.0;
	875	 6601	 0.00116	 0.01692	 0.524	 1293.388156	 1293.388156	 1293.388156	 0.0	 0.0	 1	 -30.0	 30.0;
	875	 6601	 0.00133	 0.01462	 0.60359	 1428.157609	 1428.157609	 1428.157609	 0.0	 0.0	 1	 -30.0	 30.0;
	875	 5874	 0.00063	 0.00821	 0.28868	 1019.484205	 1019.484205	 1019.484205	 0.0	 0.0	 1	 -30.0	 30.0;
	875	 5874	 0.00064	 0.00804	 0.29434	 1284.082159	 1284.082159	 1284.082159	 0.0	 0.0	 1	 -30.0	 30.0;
	5135	 4921	 0.00126	 0.01272	 0.32143	 1399.529442	 1399.529442	 1399.529442	 0.0	 0.0	 1	 -30.0	 30.0;
	5135	 7493	 0.00337	 0.0494	 0.82527	 1768.207264	 1768.207264	 1768.207264	 0.0	 0.0	 1	 -30.0	 30.0;
	5135	 6644	 0.0014	 0.0214	 0.51846	 2057.141398	 2057.141398	 2057.141398	 0.0	 0.0	 1	 -30.0	 30.0;
	5135	 6644	 0.00137	 0.02182	 0.50766	 2166.353749	 2166.353749	 2166.353749	 0.0	 0.0	 1	 -30.0	 30.0;
	5135	 6497	 0.00212	 0.02063	 0.53959	 1247.652592	 1247.652592	 1247.652592	 0.0	 0.0	 1	 -30.0	 30.0;
	5038	 369	 0.00186	 0.01045	 0.08518	 613.25462	 613.25462	 613.25462	 0.0	 0.0	 1	 -30.0	 30.0;
	5038	 6876	 0.00426	 0.021771	 0.03066	 454.707227	 454.707227	 454.707227	 0.0	 0.0	 1	 -30.0	 30.0;
	5038	 6876	 0.002659	 0.020539	 0.03049	 497.562148	 497.562148	 497.562148	 0.0	 0.0	 1	 -30.0	 30.0;
	5038	 3817	 0.00606	 0.049919	 0.07035	 462.840002	 462.840002	 462.840002	 0.0	 0.0	 1	 -30.0	 30.0;
	6601	 3823	 0.00109	 0.01192	 0.48923	 918.297693	 918.297693	 918.297693	 0.0	 0.0	 1	 -30.0	 30.0;
	1391	 3567	 0.013021	 0.049219	 0.09157	 453.632282	 453.632282	 453.632282	 0.0	 0.0	 1	 -30.0	 30.0;
	1391	 4318	 0.00236	 0.01239	 0.02114	 446.600744	 446.600744	 446.600744	 0.0	 0.0	 1	 -30.0	 30.0;
	1391	 4318	 0.0027	 0.015169	 0.02091	 431.264197	 431.264197	 431.264197	 0.0	 0.0	 1	 -30.0	 30.0;
	4131	 3038	 0.00285	 0.03283	 1.0134	 1517.032219	 1517.032219	 1517.032219	 0.0	 0.0	 1	 -30.0	 30.0;
	4131	 3038	 0.00529	 0.03969	 0.82926	 1039.841032	 1039.841032	 1039.841032	 0.0	 0.0	 1	 -30.0	 30.0;
	1223	 3038	 0.00254	 0.03721	 0.90285	 1573.658676	 1573.658676	 1573.658676	 0.0	 0.0	 1	 -30.0	 30.0;
	3347	 2465	 0.000159	 0.00069	 0.00465	 339.032664	 339.032664	 339.032664	 0.0	 0.0	 1	 -30.0	 30.0;
	3347	 2465	 0.000229	 0.000979	 0.01781	 314.355028	 314.355028	 314.355028	 0.0	 0.0	 1	 -30.0	 30.0;
	3347	 2465	 0.00024	 0.00082	 0.01642	 295.264745	 295.264745	 295.264745	 0.0	 0.0	 1	 -30.0	 30.0;
	3347	 720	 0.000169	 0.00075	 0.00789	 349.338193	 349.338193	 349.338193	 0.0	 0.0	 1	 -30.0	 30.0;
	3347	 4442	 0.00368	 0.01756	 0.02439	 338.946166	 338.946166	 338.946166	 0.0	 0.0	 1	 -30.0	 30.0;
	3347	 1709	 0.002599	 0.020659	 0.03562	 370.929696	 370.929696	 370.929696	 0.0	 0.0	 1	 -30.0	 30.0;
	6767	 5052	 0.00018	 0.00064	 0.00616	 336.905256	 336.905256	 336.905256	 0.0	 0.0	 1	 -30.0	 30.0;
	6767	 6380	 0.000159	 0.000771	 0.00651	 381.663908	 381.663908	 381.663908	 0.0	 0.0	 1	 -30.0	 30.0;
	6767	 5387	 0.00357	 0.01981	 0.04617	 485.920653	 485.920653	 485.920653	 0.0	 0.0	 1	 -30.0	 30.0;
	6767	 6797	 0.006021	 0.03205	 0.05839	 534.361022	 534.361022	 534.361022	 0.0	 0.0	 1	 -30.0	 30.0;
	4413	 2615	 0.001781	 0.01164	 0.02114	 536.38288	 536.38288	 536.38288	 0.0	 0.0	 1	 -30.0	 30.0;
	4413	 6393	 0.002781	 0.018831	 0.03654	 517.809302	 517.809302	 517.809302	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 5575	 0.000349	 0.00281	 0.00436	 266.219119	 266.219119	 266.219119	 0.0	 0.0	 1	 -30.0	 30.0;
	79	 1701	 0.00313	 0.02444	 0.0364	 620.69655	 620.69655	 620.69655	 0.0	 0.0	 1	 -30.0	 30.0;
	79	 1701	 0.00368	 0.02074	 0.04259	 604.304109	 604.304109	 604.304109	 0.0	 0.0	 1	 -30.0	 30.0;
	1951	 2978	 9.1e-05	 0.001539	 0.00267	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1951	 3224	 0.00251	 0.01111	 0.01777	 331.855946	 331.855946	 331.855946	 0.0	 0.0	 1	 -30.0	 30.0;
	1951	 6207	 0.003081	 0.017961	 0.03113	 436.032671	 436.032671	 436.032671	 0.0	 0.0	 1	 -30.0	 30.0;
	1951	 6117	 0.005341	 0.030419	 0.05551	 439.689238	 439.689238	 439.689238	 0.0	 0.0	 1	 -30.0	 30.0;
	1951	 6928	 9.9e-05	 0.00126	 0.0019	 518.000209	 518.000209	 518.000209	 0.0	 0.0	 1	 -30.0	 30.0;
	8251	 948	 0.002169	 0.017901	 0.07124	 431.883024	 431.883024	 431.883024	 0.0	 0.0	 1	 -30.0	 30.0;
	2227	 5605	 0.00011	 0.00038	 0.02582	 358.43922	 358.43922	 358.43922	 0.0	 0.0	 1	 -30.0	 30.0;
	1294	 1329	 0.00212	 0.00494	 0.00836	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1294	 7050	 0.018901	 0.077349	 0.13545	 483.138218	 483.138218	 483.138218	 0.0	 0.0	 1	 -30.0	 30.0;
	7152	 4873	 0.00957	 0.0395	 0.0622	 462.209744	 462.209744	 462.209744	 0.0	 0.0	 1	 -30.0	 30.0;
	7152	 6330	 0.02324	 0.063469	 0.09766	 407.673699	 407.673699	 407.673699	 0.0	 0.0	 1	 -30.0	 30.0;
	6284	 3021	 0.000531	 0.004331	 0.01069	 611.731559	 611.731559	 611.731559	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 557	 0.002581	 0.006229	 0.01007	 328.587289	 328.587289	 328.587289	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 1147	 0.00031	 0.002211	 0.00348	 429.794863	 429.794863	 429.794863	 0.0	 0.0	 1	 -30.0	 30.0;
	728	 6330	 0.01087	 0.06114	 0.08104	 448.355866	 448.355866	 448.355866	 0.0	 0.0	 1	 -30.0	 30.0;
	728	 5369	 0.011581	 0.061099	 0.09202	 430.563443	 430.563443	 430.563443	 0.0	 0.0	 1	 -30.0	 30.0;
	6918	 2792	 0.002099	 0.016271	 0.02366	 411.256723	 411.256723	 411.256723	 0.0	 0.0	 1	 -30.0	 30.0;
	452	 1411	 0.00093	 0.005461	 0.02048	 230.666663	 230.666663	 230.666663	 0.0	 0.0	 1	 -30.0	 30.0;
	452	 4762	 0.009591	 0.037039	 0.07028	 429.603576	 429.603576	 429.603576	 0.0	 0.0	 1	 -30.0	 30.0;
	452	 701	 0.002591	 0.017211	 0.02962	 558.3722	 558.3722	 558.3722	 0.0	 0.0	 1	 -30.0	 30.0;
	452	 8125	 0.00164	 0.013651	 0.03295	 505.145066	 505.145066	 505.145066	 0.0	 0.0	 1	 -30.0	 30.0;
	2496	 1897	 0.003219	 0.014719	 0.02771	 469.450097	 469.450097	 469.450097	 0.0	 0.0	 1	 -30.0	 30.0;
	2496	 3140	 0.00401	 0.022229	 0.02938	 473.398931	 473.398931	 473.398931	 0.0	 0.0	 1	 -30.0	 30.0;
	2496	 6393	 0.00126	 0.010211	 0.01729	 602.962428	 602.962428	 602.962428	 0.0	 0.0	 1	 -30.0	 30.0;
	3748	 7144	 0.009169	 0.03993	 0.06745	 349.170531	 349.170531	 349.170531	 0.0	 0.0	 1	 -30.0	 30.0;
	3748	 3519	 0.001349	 0.006081	 0.00987	 298.792898	 298.792898	 298.792898	 0.0	 0.0	 1	 -30.0	 30.0;
	1603	 7692	 0.00156	 0.01931	 0.40201	 1598.235091	 1598.235091	 1598.235091	 0.0	 0.0	 1	 -30.0	 30.0;
	1603	 6830	 0.00152	 0.01968	 0.39363	 1508.874745	 1508.874745	 1508.874745	 0.0	 0.0	 1	 -30.0	 30.0;
	1603	 7056	 0.00094	 0.01433	 0.33547	 1687.669153	 1687.669153	 1687.669153	 0.0	 0.0	 1	 -30.0	 30.0;
	1603	 6257	 0.00092	 0.01461	 0.32848	 1451.117536	 1451.117536	 1451.117536	 0.0	 0.0	 1	 -30.0	 30.0;
	1603	 871	 0.00137	 0.02012	 0.62381	 1134.946626	 1134.946626	 1134.946626	 0.0	 0.0	 1	 -30.0	 30.0;
	1603	 871	 0.00134	 0.02051	 0.61081	 953.339817	 953.339817	 953.339817	 0.0	 0.0	 1	 -30.0	 30.0;
	3511	 4087	 0.00314	 0.042151	 0.0351	 582.150937	 582.150937	 582.150937	 0.0	 0.0	 1	 -30.0	 30.0;
	3511	 5454	 0.000651	 0.00494	 0.02695	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3511	 6295	 0.003961	 0.02426	 0.04515	 591.024475	 591.024475	 591.024475	 0.0	 0.0	 1	 -30.0	 30.0;
	776	 1496	 0.00013	 0.0015	 0.04679	 1993.323674	 1993.323674	 1993.323674	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 734	 0.00013	 0.00147	 0.04765	 1889.27869	 1889.27869	 1889.27869	 0.0	 0.0	 1	 -30.0	 30.0;
	4383	 1496	 0.00011	 0.00172	 0.04072	 1879.099288	 1879.099288	 1879.099288	 0.0	 0.0	 1	 -30.0	 30.0;
	1858	 734	 0.00012	 0.00166	 0.04245	 1992.378529	 1992.378529	 1992.378529	 0.0	 0.0	 1	 -30.0	 30.0;
	3523	 1496	 0.00012	 0.00168	 0.04245	 1911.249373	 1911.249373	 1911.249373	 0.0	 0.0	 1	 -30.0	 30.0;
	3405	 734	 0.00012	 0.00172	 0.04159	 1924.768376	 1924.768376	 1924.768376	 0.0	 0.0	 1	 -30.0	 30.0;
	672	 623	 0.00093	 0.005669	 0.05669	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2639	 6438	 0.00105	 0.00506	 0.0575	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5163	 5654	 0.00113	 0.006539	 0.02875	 347.635276	 347.635276	 347.635276	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 4949	 0.00037	 0.002919	 0.00364	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	641	 5169	 0.005169	 0.03738	 0.05882	 477.636601	 477.636601	 477.636601	 0.0	 0.0	 1	 -30.0	 30.0;
	3471	 865	 0.00125	 0.006669	 0.00801	 465.157175	 465.157175	 465.157175	 0.0	 0.0	 1	 -30.0	 30.0;
	2103	 2213	 0.001281	 0.00661	 0.00819	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	175	 2713	 0.00226	 0.0138	 0.02517	 460.281625	 460.281625	 460.281625	 0.0	 0.0	 1	 -30.0	 30.0;
	2280	 3193	 0.00213	 0.02677	 0.52763	 1641.584096	 1641.584096	 1641.584096	 0.0	 0.0	 1	 -30.0	 30.0;
	2280	 3038	 0.00154	 0.01919	 0.37948	 1375.765878	 1375.765878	 1375.765878	 0.0	 0.0	 1	 -30.0	 30.0;
	4134	 545	 0.00687	 0.04413	 0.07852	 353.562908	 353.562908	 353.562908	 0.0	 0.0	 1	 -30.0	 30.0;
	4134	 2947	 0.0045	 0.04725	 0.09322	 475.193301	 475.193301	 475.193301	 0.0	 0.0	 1	 -30.0	 30.0;
	4134	 6653	 0.00138	 0.00837	 0.01539	 339.727702	 339.727702	 339.727702	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 1402	 0.000419	 0.001901	 0.00296	 323.609999	 323.609999	 323.609999	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 1402	 0.00043	 0.00186	 0.00302	 353.76677	 353.76677	 353.76677	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 4300	 0.003331	 0.015099	 0.02369	 603.009297	 603.009297	 603.009297	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 6001	 0.002099	 0.01631	 0.02457	 535.447399	 535.447399	 535.447399	 0.0	 0.0	 1	 -30.0	 30.0;
	3466	 5094	 0.001331	 0.01082	 0.01514	 593.612575	 593.612575	 593.612575	 0.0	 0.0	 1	 -30.0	 30.0;
	3466	 6068	 0.00199	 0.00818	 0.01333	 395.060524	 395.060524	 395.060524	 0.0	 0.0	 1	 -30.0	 30.0;
	3466	 6068	 0.00169	 0.008831	 0.01183	 380.35614	 380.35614	 380.35614	 0.0	 0.0	 1	 -30.0	 30.0;
	1208	 4899	 0.001771	 0.014281	 0.0196	 257.908393	 257.908393	 257.908393	 0.0	 0.0	 1	 -30.0	 30.0;
	545	 558	 0.003099	 0.01844	 0.03554	 501.494215	 501.494215	 501.494215	 0.0	 0.0	 1	 -30.0	 30.0;
	3177	 1415	 0.003409	 0.01819	 0.03764	 446.494431	 446.494431	 446.494431	 0.0	 0.0	 1	 -30.0	 30.0;
	4480	 2032	 0.00057	 0.00369	 0.00593	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7309	 5358	 0.001081	 0.00468	 0.07341	 352.494059	 352.494059	 352.494059	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 5358	 0.00105	 0.004771	 0.07188	 358.066552	 358.066552	 358.066552	 0.0	 0.0	 1	 -30.0	 30.0;
	3341	 558	 0.001979	 0.01549	 0.02275	 605.871372	 605.871372	 605.871372	 0.0	 0.0	 1	 -30.0	 30.0;
	3341	 6653	 0.001469	 0.015151	 0.04429	 348.592095	 348.592095	 348.592095	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 4624	 0.000711	 0.003969	 0.00692	 421.504714	 421.504714	 421.504714	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 6873	 0.00051	 0.00274	 0.01001	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 2904	 0.000521	 0.00306	 0.00523	 495.490373	 495.490373	 495.490373	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 3169	 0.00188	 0.011841	 0.02656	 365.418172	 365.418172	 365.418172	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 1438	 0.002469	 0.010539	 0.02769	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	520	 4814	 0.00045	 0.00351	 0.00455	 523.680539	 523.680539	 523.680539	 0.0	 0.0	 1	 -30.0	 30.0;
	3580	 8324	 0.00037	 0.000659	 0.04003	 283.755094	 283.755094	 283.755094	 0.0	 0.0	 1	 -30.0	 30.0;
	1905	 3475	 0.000401	 0.0007	 0.04458	 339.768093	 339.768093	 339.768093	 0.0	 0.0	 1	 -30.0	 30.0;
	1905	 5655	 0.00014	 0.000531	 0.1096	 363.368879	 363.368879	 363.368879	 0.0	 0.0	 1	 -30.0	 30.0;
	1905	 1497	 0.000289	 0.0013	 0.12557	 512.03752	 512.03752	 512.03752	 0.0	 0.0	 1	 -30.0	 30.0;
	1905	 5675	 7e-05	 0.000289	 0.03049	 241.734294	 241.734294	 241.734294	 0.0	 0.0	 1	 -30.0	 30.0;
	1905	 6061	 0.00051	 0.002151	 0.16622	 396.553864	 396.553864	 396.553864	 0.0	 0.0	 1	 -30.0	 30.0;
	1905	 7386	 0.00037	 0.00157	 0.257	 534.993186	 534.993186	 534.993186	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 405	 0.00022	 0.00277	 0.05526	 1476.188902	 1476.188902	 1476.188902	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 405	 0.00025	 0.00271	 0.06263	 1563.93276	 1563.93276	 1563.93276	 0.0	 0.0	 1	 -30.0	 30.0;
	6934	 2762	 0.000271	 0.002081	 0.00851	 586.035372	 586.035372	 586.035372	 0.0	 0.0	 1	 -30.0	 30.0;
	6934	 2762	 0.00025	 0.00231	 0.00789	 536.218266	 536.218266	 536.218266	 0.0	 0.0	 1	 -30.0	 30.0;
	2904	 2126	 0.00095	 0.00331	 0.07953	 364.054009	 364.054009	 364.054009	 0.0	 0.0	 1	 -30.0	 30.0;
	2904	 7901	 0.00093	 0.00336	 0.078	 218.280213	 218.280213	 218.280213	 0.0	 0.0	 1	 -30.0	 30.0;
	7349	 7911	 0.000341	 0.002211	 0.00395	 605.829076	 605.829076	 605.829076	 0.0	 0.0	 1	 -30.0	 30.0;
	2396	 8340	 0.00032	 0.00232	 0.00379	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3758	 7726	 3.9e-05	 0.000271	 0.0	 517.282308	 517.282308	 517.282308	 0.0	 0.0	 1	 -30.0	 30.0;
	548	 6823	 0.00075	 0.0101	 0.19131	 1622.90431	 1622.90431	 1622.90431	 0.0	 0.0	 1	 -30.0	 30.0;
	548	 3644	 0.00118	 0.01455	 0.29942	 1557.529992	 1557.529992	 1557.529992	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 8193	 0.0017	 0.0098	 0.02023	 515.883088	 515.883088	 515.883088	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 8193	 0.001521	 0.01111	 0.01802	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 1865	 0.000169	 0.001401	 0.00178	 218.591913	 218.591913	 218.591913	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 623	 0.002591	 0.01725	 0.02962	 618.957432	 618.957432	 618.957432	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 3200	 0.000169	 0.001159	 0.00198	 445.855789	 445.855789	 445.855789	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 4300	 0.00307	 0.01339	 0.02215	 550.866635	 550.866635	 550.866635	 0.0	 0.0	 1	 -30.0	 30.0;
	2393	 4449	 0.002591	 0.013521	 0.02462	 525.987041	 525.987041	 525.987041	 0.0	 0.0	 1	 -30.0	 30.0;
	8234	 8220	 0.000581	 0.005031	 0.03056	 564.422531	 564.422531	 564.422531	 0.0	 0.0	 1	 -30.0	 30.0;
	6319	 5061	 0.001419	 0.00595	 0.00854	 398.682416	 398.682416	 398.682416	 0.0	 0.0	 1	 -30.0	 30.0;
	603	 1360	 0.00205	 0.02664	 0.49385	 1480.243287	 1480.243287	 1480.243287	 0.0	 0.0	 1	 -30.0	 30.0;
	603	 2478	 0.00295	 0.03721	 0.75117	 1538.170306	 1538.170306	 1538.170306	 0.0	 0.0	 1	 -30.0	 30.0;
	603	 4140	 0.00335	 0.03648	 0.85132	 1502.229108	 1502.229108	 1502.229108	 0.0	 0.0	 1	 -30.0	 30.0;
	603	 1465	 0.00022	 0.00251	 0.05377	 1270.426254	 1270.426254	 1270.426254	 0.0	 0.0	 1	 -30.0	 30.0;
	603	 1908	 0.00059	 0.00651	 0.14434	 1660.629831	 1660.629831	 1660.629831	 0.0	 0.0	 1	 -30.0	 30.0;
	3243	 1983	 0.008539	 0.041979	 0.06261	 396.943298	 396.943298	 396.943298	 0.0	 0.0	 1	 -30.0	 30.0;
	3243	 2572	 0.001349	 0.0052	 0.00888	 408.121053	 408.121053	 408.121053	 0.0	 0.0	 1	 -30.0	 30.0;
	3286	 7233	 0.00245	 0.013909	 0.02875	 521.510071	 521.510071	 521.510071	 0.0	 0.0	 1	 -30.0	 30.0;
	3286	 2250	 0.001469	 0.008419	 0.01811	 563.429511	 563.429511	 563.429511	 0.0	 0.0	 1	 -30.0	 30.0;
	4921	 6497	 0.00084	 0.00836	 0.20816	 1380.21517	 1380.21517	 1380.21517	 0.0	 0.0	 1	 -30.0	 30.0;
	6458	 1896	 0.002591	 0.017789	 0.02846	 525.183024	 525.183024	 525.183024	 0.0	 0.0	 1	 -30.0	 30.0;
	6458	 7144	 0.009651	 0.05968	 0.1067	 434.687941	 434.687941	 434.687941	 0.0	 0.0	 1	 -30.0	 30.0;
	6728	 6820	 0.00143	 0.00799	 0.01069	 381.993898	 381.993898	 381.993898	 0.0	 0.0	 1	 -30.0	 30.0;
	6728	 6117	 0.001969	 0.014909	 0.02184	 572.3865	 572.3865	 572.3865	 0.0	 0.0	 1	 -30.0	 30.0;
	934	 1701	 0.01039	 0.06406	 0.09099	 498.481624	 498.481624	 498.481624	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 3021	 0.000719	 0.005331	 0.00854	 452.599252	 452.599252	 452.599252	 0.0	 0.0	 1	 -30.0	 30.0;
	5478	 6279	 0.00052	 0.00565	 0.13551	 1444.271155	 1444.271155	 1444.271155	 0.0	 0.0	 1	 -30.0	 30.0;
	7864	 6412	 0.002409	 0.019479	 0.03117	 502.097038	 502.097038	 502.097038	 0.0	 0.0	 1	 -30.0	 30.0;
	7864	 6412	 0.00256	 0.019151	 0.03249	 421.832037	 421.832037	 421.832037	 0.0	 0.0	 1	 -30.0	 30.0;
	7864	 2597	 0.00656	 0.02288	 0.03949	 392.086039	 392.086039	 392.086039	 0.0	 0.0	 1	 -30.0	 30.0;
	3674	 5852	 0.0027	 0.014901	 0.0196	 418.322174	 418.322174	 418.322174	 0.0	 0.0	 1	 -30.0	 30.0;
	3674	 5209	 0.003591	 0.01362	 0.01742	 419.048458	 419.048458	 419.048458	 0.0	 0.0	 1	 -30.0	 30.0;
	6643	 2250	 0.002211	 0.01188	 0.01568	 362.22001	 362.22001	 362.22001	 0.0	 0.0	 1	 -30.0	 30.0;
	6643	 7423	 0.00068	 0.00357	 0.00445	 408.790179	 408.790179	 408.790179	 0.0	 0.0	 1	 -30.0	 30.0;
	6777	 1444	 0.000211	 0.000969	 0.0019	 405.95211	 405.95211	 405.95211	 0.0	 0.0	 1	 -30.0	 30.0;
	8122	 3080	 9.9e-05	 0.000539	 0.00093	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1653	 5793	 0.00645	 0.0263	 0.04809	 423.549053	 423.549053	 423.549053	 0.0	 0.0	 1	 -30.0	 30.0;
	4206	 5473	 0.00063	 0.001901	 0.00178	 369.861991	 369.861991	 369.861991	 0.0	 0.0	 1	 -30.0	 30.0;
	1571	 3237	 0.000281	 0.000669	 0.00101	 290.966107	 290.966107	 290.966107	 0.0	 0.0	 1	 -30.0	 30.0;
	6979	 3519	 0.000219	 0.00064	 0.00087	 277.002867	 277.002867	 277.002867	 0.0	 0.0	 1	 -30.0	 30.0;
	8332	 6099	 0.00014	 0.00105	 0.0019	 238.797152	 238.797152	 238.797152	 0.0	 0.0	 1	 -30.0	 30.0;
	7588	 7936	 0.003219	 0.020729	 0.03725	 546.289067	 546.289067	 546.289067	 0.0	 0.0	 1	 -30.0	 30.0;
	7588	 7681	 0.00051	 0.003151	 0.00593	 573.621868	 573.621868	 573.621868	 0.0	 0.0	 1	 -30.0	 30.0;
	7588	 7681	 0.000409	 0.00331	 0.00558	 521.764994	 521.764994	 521.764994	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 6021	 0.002289	 0.017479	 0.02547	 593.966572	 593.966572	 593.966572	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 1080	 0.002831	 0.01895	 0.03357	 552.422848	 552.422848	 552.422848	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 6595	 0.006289	 0.036521	 0.07454	 364.589767	 364.589767	 364.589767	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 8166	 0.005651	 0.032169	 0.06495	 456.164367	 456.164367	 456.164367	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 6587	 0.00414	 0.02262	 0.03185	 489.37755	 489.37755	 489.37755	 0.0	 0.0	 1	 -30.0	 30.0;
	3173	 6108	 0.01095	 0.05814	 0.08102	 471.398412	 471.398412	 471.398412	 0.0	 0.0	 1	 -30.0	 30.0;
	3173	 924	 0.009	 0.0368	 0.06691	 510.461492	 510.461492	 510.461492	 0.0	 0.0	 1	 -30.0	 30.0;
	3173	 7533	 0.000229	 0.00181	 0.00364	 562.286739	 562.286739	 562.286739	 0.0	 0.0	 1	 -30.0	 30.0;
	1809	 5958	 0.00119	 0.00726	 0.01394	 616.286263	 616.286263	 616.286263	 0.0	 0.0	 1	 -30.0	 30.0;
	8290	 679	 0.011771	 0.051669	 0.08658	 638.394472	 638.394472	 638.394472	 0.0	 0.0	 1	 -30.0	 30.0;
	6823	 1987	 0.00209	 0.02279	 0.53024	 1719.740915	 1719.740915	 1719.740915	 0.0	 0.0	 1	 -30.0	 30.0;
	6868	 3567	 0.002031	 0.01443	 0.02751	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6868	 6252	 0.00145	 0.008479	 0.01811	 559.915838	 559.915838	 559.915838	 0.0	 0.0	 1	 -30.0	 30.0;
	2286	 5624	 0.00124	 0.01433	 0.80471	 1536.493265	 1536.493265	 1536.493265	 0.0	 0.0	 1	 -30.0	 30.0;
	2286	 5624	 0.00127	 0.01402	 0.81961	 1882.401374	 1882.401374	 1882.401374	 0.0	 0.0	 1	 -30.0	 30.0;
	1349	 3319	 0.013039	 0.052841	 0.09722	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 5624	 0.00235	 0.02739	 0.47138	 980.011217	 980.011217	 980.011217	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 5624	 0.0024	 0.02681	 0.48028	 1234.294843	 1234.294843	 1234.294843	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 3770	 0.00135	 0.02056	 0.5311	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 1194	 0.00087	 0.01124	 0.39362	 974.360748	 974.360748	 974.360748	 0.0	 0.0	 1	 -30.0	 30.0;
	7539	 154	 0.0012	 0.00818	 0.01433	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	154	 5832	 0.006961	 0.05561	 0.0828	 497.197482	 497.197482	 497.197482	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 7162	 0.00105	 0.00763	 0.01044	 492.936949	 492.936949	 492.936949	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 506	 0.000219	 0.00182	 0.00649	 273.047175	 273.047175	 273.047175	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 8024	 3.9e-05	 0.0002	 0.03439	 316.639049	 316.639049	 316.639049	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 8024	 3.9e-05	 0.000169	 0.03456	 309.608654	 309.608654	 309.608654	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 3860	 0.0035	 0.022651	 0.04027	 539.832155	 539.832155	 539.832155	 0.0	 0.0	 1	 -30.0	 30.0;
	3520	 1701	 0.004281	 0.02319	 0.03185	 474.715081	 474.715081	 474.715081	 0.0	 0.0	 1	 -30.0	 30.0;
	3520	 807	 0.003729	 0.014021	 0.02555	 433.553933	 433.553933	 433.553933	 0.0	 0.0	 1	 -30.0	 30.0;
	6386	 1983	 0.00212	 0.01582	 0.02323	 590.356874	 590.356874	 590.356874	 0.0	 0.0	 1	 -30.0	 30.0;
	7866	 6497	 0.00056	 0.00784	 0.25472	 786.395927	 786.395927	 786.395927	 0.0	 0.0	 1	 -30.0	 30.0;
	1701	 7050	 0.004401	 0.01813	 0.0345	 352.596181	 352.596181	 352.596181	 0.0	 0.0	 1	 -30.0	 30.0;
	1701	 7050	 0.005021	 0.02144	 0.03624	 356.565591	 356.565591	 356.565591	 0.0	 0.0	 1	 -30.0	 30.0;
	4446	 2657	 0.00018	 0.000219	 0.02462	 387.420067	 387.420067	 387.420067	 0.0	 0.0	 1	 -30.0	 30.0;
	3786	 2657	 0.000151	 0.000211	 0.02404	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4036	 2657	 0.000151	 0.000211	 0.01597	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1891	 5430	 0.00282	 0.02591	 0.66429	 1483.151123	 1483.151123	 1483.151123	 0.0	 0.0	 1	 -30.0	 30.0;
	3135	 5941	 0.00131	 0.008539	 0.03949	 548.193942	 548.193942	 548.193942	 0.0	 0.0	 1	 -30.0	 30.0;
	3605	 6808	 0.002159	 0.015969	 0.02353	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4804	 1681	 0.00019	 0.000281	 0.01975	 280.605325	 280.605325	 280.605325	 0.0	 0.0	 1	 -30.0	 30.0;
	5059	 2032	 0.0002	 0.000281	 0.02013	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1896	 7261	 0.00139	 0.00774	 0.01597	 590.386977	 590.386977	 590.386977	 0.0	 0.0	 1	 -30.0	 30.0;
	578	 5762	 0.01101	 0.06739	 0.02052	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	578	 2492	 0.00063	 0.00463	 0.02178	 438.563994	 438.563994	 438.563994	 0.0	 0.0	 1	 -30.0	 30.0;
	578	 8283	 0.002341	 0.009599	 0.01778	 491.232126	 491.232126	 491.232126	 0.0	 0.0	 1	 -30.0	 30.0;
	369	 3817	 0.00375	 0.021659	 0.04366	 493.700575	 493.700575	 493.700575	 0.0	 0.0	 1	 -30.0	 30.0;
	1360	 5247	 0.00056	 0.00749	 0.14347	 1295.941892	 1295.941892	 1295.941892	 0.0	 0.0	 1	 -30.0	 30.0;
	527	 6001	 0.00118	 0.00926	 0.01336	 549.824841	 549.824841	 549.824841	 0.0	 0.0	 1	 -30.0	 30.0;
	527	 5473	 0.002039	 0.013081	 0.02074	 518.538253	 518.538253	 518.538253	 0.0	 0.0	 1	 -30.0	 30.0;
	1595	 6808	 0.00155	 0.010961	 0.03717	 265.812918	 265.812918	 265.812918	 0.0	 0.0	 1	 -30.0	 30.0;
	2978	 6928	 3.9e-05	 0.00036	 0.0	 434.100361	 434.100361	 434.100361	 0.0	 0.0	 1	 -30.0	 30.0;
	1008	 176	 0.00024	 0.000409	 0.12981	 394.351388	 394.351388	 394.351388	 0.0	 0.0	 1	 -30.0	 30.0;
	7726	 6470	 0.000341	 0.001659	 0.00319	 566.951948	 566.951948	 566.951948	 0.0	 0.0	 1	 -30.0	 30.0;
	7726	 4861	 0.005461	 0.024919	 0.04048	 461.446117	 461.446117	 461.446117	 0.0	 0.0	 1	 -30.0	 30.0;
	7951	 6400	 0.00158	 0.02413	 0.72211	 974.381151	 974.381151	 974.381151	 0.0	 0.0	 1	 -30.0	 30.0;
	7951	 8006	 0.00155	 0.02458	 0.70675	 872.353486	 872.353486	 872.353486	 0.0	 0.0	 1	 -30.0	 30.0;
	7951	 6251	 0.00021	 0.00256	 0.05545	 1418.638362	 1418.638362	 1418.638362	 0.0	 0.0	 1	 -30.0	 30.0;
	7951	 6251	 0.00024	 0.00243	 0.06735	 1535.21903	 1535.21903	 1535.21903	 0.0	 0.0	 1	 -30.0	 30.0;
	7951	 8068	 0.00144	 0.02266	 0.65096	 1530.335339	 1530.335339	 1530.335339	 0.0	 0.0	 1	 -30.0	 30.0;
	7951	 8068	 0.0014	 0.02098	 0.6368	 1577.09503	 1577.09503	 1577.09503	 0.0	 0.0	 1	 -30.0	 30.0;
	7951	 7693	 0.00086	 0.01074	 0.22093	 2104.80806	 2104.80806	 2104.80806	 0.0	 0.0	 1	 -30.0	 30.0;
	7936	 7681	 0.003341	 0.02611	 0.03822	 554.079277	 554.079277	 554.079277	 0.0	 0.0	 1	 -30.0	 30.0;
	196	 6154	 0.00387	 0.02063	 0.0313	 516.222224	 516.222224	 516.222224	 0.0	 0.0	 1	 -30.0	 30.0;
	196	 6154	 0.00405	 0.018271	 0.03181	 515.374766	 515.374766	 515.374766	 0.0	 0.0	 1	 -30.0	 30.0;
	196	 1073	 0.00101	 0.00462	 0.00789	 417.640474	 417.640474	 417.640474	 0.0	 0.0	 1	 -30.0	 30.0;
	196	 2333	 0.00088	 0.00389	 0.00604	 426.348636	 426.348636	 426.348636	 0.0	 0.0	 1	 -30.0	 30.0;
	196	 6595	 0.005081	 0.039	 0.0604	 516.994615	 516.994615	 516.994615	 0.0	 0.0	 1	 -30.0	 30.0;
	7233	 7423	 0.00257	 0.0208	 0.0285	 566.961856	 566.961856	 566.961856	 0.0	 0.0	 1	 -30.0	 30.0;
	7233	 7423	 0.00251	 0.01926	 0.02701	 529.555205	 529.555205	 529.555205	 0.0	 0.0	 1	 -30.0	 30.0;
	7233	 947	 0.002531	 0.01314	 0.0182	 378.841462	 378.841462	 378.841462	 0.0	 0.0	 1	 -30.0	 30.0;
	6575	 7112	 0.00132	 0.00869	 0.0	 270.245687	 270.245687	 270.245687	 0.0	 0.0	 1	 -30.0	 30.0;
	4002	 8091	 0.00082	 0.004021	 0.00705	 434.432256	 434.432256	 434.432256	 0.0	 0.0	 1	 -30.0	 30.0;
	4002	 4415	 0.00143	 0.007479	 0.01022	 442.307441	 442.307441	 442.307441	 0.0	 0.0	 1	 -30.0	 30.0;
	2531	 1077	 0.000659	 0.005771	 0.0205	 363.512916	 363.512916	 363.512916	 0.0	 0.0	 1	 -30.0	 30.0;
	2531	 1077	 0.000591	 0.006539	 0.01827	 298.275049	 298.275049	 298.275049	 0.0	 0.0	 1	 -30.0	 30.0;
	1188	 5707	 0.00589	 0.025599	 0.04328	 477.416353	 477.416353	 477.416353	 0.0	 0.0	 1	 -30.0	 30.0;
	1188	 6330	 0.00614	 0.02343	 0.04366	 456.83235	 456.83235	 456.83235	 0.0	 0.0	 1	 -30.0	 30.0;
	2478	 1646	 0.00155	 0.01994	 0.37729	 1496.866921	 1496.866921	 1496.866921	 0.0	 0.0	 1	 -30.0	 30.0;
	2478	 3038	 0.00205	 0.03218	 0.73298	 1598.86431	 1598.86431	 1598.86431	 0.0	 0.0	 1	 -30.0	 30.0;
	4140	 3038	 0.00233	 0.03154	 0.83071	 1589.447739	 1589.447739	 1589.447739	 0.0	 0.0	 1	 -30.0	 30.0;
	4296	 5209	 0.002341	 0.01982	 0.08305	 259.809838	 259.809838	 259.809838	 0.0	 0.0	 1	 -30.0	 30.0;
	988	 7533	 8.1e-05	 0.000521	 0.00101	 548.968619	 548.968619	 548.968619	 0.0	 0.0	 1	 -30.0	 30.0;
	1272	 5055	 9.9e-05	 0.00069	 0.00202	 595.847821	 595.847821	 595.847821	 0.0	 0.0	 1	 -30.0	 30.0;
	3898	 4167	 0.00276	 0.016419	 0.11399	 566.049619	 566.049619	 566.049619	 0.0	 0.0	 1	 -30.0	 30.0;
	6394	 4465	 0.00036	 0.001229	 0.15202	 463.966771	 463.966771	 463.966771	 0.0	 0.0	 1	 -30.0	 30.0;
	6394	 3404	 0.000229	 0.000711	 0.0969	 520.140573	 520.140573	 520.140573	 0.0	 0.0	 1	 -30.0	 30.0;
	5951	 786	 0.00013	 0.00099	 0.08102	 514.944178	 514.944178	 514.944178	 0.0	 0.0	 1	 -30.0	 30.0;
	8171	 5892	 0.001159	 0.00689	 0.01642	 437.868957	 437.868957	 437.868957	 0.0	 0.0	 1	 -30.0	 30.0;
	6250	 5441	 0.008531	 0.03045	 0.04181	 383.38283	 383.38283	 383.38283	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 7261	 0.000781	 0.004531	 0.00836	 528.552659	 528.552659	 528.552659	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 7261	 0.00075	 0.00474	 0.00805	 542.558195	 542.558195	 542.558195	 0.0	 0.0	 1	 -30.0	 30.0;
	5335	 3673	 0.002159	 0.008349	 0.01597	 342.991024	 342.991024	 342.991024	 0.0	 0.0	 1	 -30.0	 30.0;
	7429	 7554	 0.00162	 0.01651	 0.39946	 1556.784275	 1556.784275	 1556.784275	 0.0	 0.0	 1	 -30.0	 30.0;
	844	 5768	 0.01236	 0.044211	 0.07249	 402.038714	 402.038714	 402.038714	 0.0	 0.0	 1	 -30.0	 30.0;
	844	 5768	 0.00825	 0.03989	 0.07773	 431.034423	 431.034423	 431.034423	 0.0	 0.0	 1	 -30.0	 30.0;
	844	 3437	 0.02187	 0.066961	 0.12564	 343.021127	 343.021127	 343.021127	 0.0	 0.0	 1	 -30.0	 30.0;
	844	 3623	 0.01212	 0.06661	 0.09409	 352.017364	 352.017364	 352.017364	 0.0	 0.0	 1	 -30.0	 30.0;
	3569	 1496	 0.00036	 0.00534	 0.16115	 905.377633	 905.377633	 905.377633	 0.0	 0.0	 1	 -30.0	 30.0;
	6170	 1050	 0.000229	 0.00063	 0.04453	 272.782726	 272.782726	 272.782726	 0.0	 0.0	 1	 -30.0	 30.0;
	6170	 6895	 0.000219	 0.000581	 0.04269	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3667	 3638	 0.000281	 0.00063	 0.05332	 363.773555	 363.773555	 363.773555	 0.0	 0.0	 1	 -30.0	 30.0;
	1453	 1287	 0.005021	 0.035659	 0.05597	 424.62438	 424.62438	 424.62438	 0.0	 0.0	 1	 -30.0	 30.0;
	2833	 3325	 0.00174	 0.007901	 0.01283	 374.491763	 374.491763	 374.491763	 0.0	 0.0	 1	 -30.0	 30.0;
	4762	 3140	 0.003919	 0.020581	 0.02875	 498.957557	 498.957557	 498.957557	 0.0	 0.0	 1	 -30.0	 30.0;
	4762	 8264	 0.003341	 0.016349	 0.02467	 509.523344	 509.523344	 509.523344	 0.0	 0.0	 1	 -30.0	 30.0;
	4762	 1344	 0.003271	 0.016669	 0.02416	 467.086056	 467.086056	 467.086056	 0.0	 0.0	 1	 -30.0	 30.0;
	2535	 7720	 0.000151	 0.000659	 0.00103	 437.813323	 437.813323	 437.813323	 0.0	 0.0	 1	 -30.0	 30.0;
	5809	 7144	 0.00736	 0.035659	 0.04732	 346.277971	 346.277971	 346.277971	 0.0	 0.0	 1	 -30.0	 30.0;
	5809	 3546	 0.00944	 0.042169	 0.06071	 350.2832	 350.2832	 350.2832	 0.0	 0.0	 1	 -30.0	 30.0;
	4039	 4305	 0.00068	 0.00652	 0.31132	 887.849001	 887.849001	 887.849001	 0.0	 0.0	 1	 -30.0	 30.0;
	4039	 3164	 0.00188	 0.02281	 0.832	 1387.04049	 1387.04049	 1387.04049	 0.0	 0.0	 1	 -30.0	 30.0;
	1897	 6396	 0.00168	 0.00956	 0.01916	 540.883094	 540.883094	 540.883094	 0.0	 0.0	 1	 -30.0	 30.0;
	1897	 6396	 0.001669	 0.00981	 0.02509	 524.000241	 524.000241	 524.000241	 0.0	 0.0	 1	 -30.0	 30.0;
	1897	 701	 0.002229	 0.01599	 0.02562	 599.663668	 599.663668	 599.663668	 0.0	 0.0	 1	 -30.0	 30.0;
	1897	 701	 0.00218	 0.01631	 0.02695	 614.721286	 614.721286	 614.721286	 0.0	 0.0	 1	 -30.0	 30.0;
	986	 5874	 0.00238	 0.02124	 0.39058	 1080.251267	 1080.251267	 1080.251267	 0.0	 0.0	 1	 -30.0	 30.0;
	986	 5874	 0.00194	 0.02023	 0.48056	 1257.92348	 1257.92348	 1257.92348	 0.0	 0.0	 1	 -30.0	 30.0;
	6674	 2880	 0.013831	 0.05955	 0.07917	 370.667914	 370.667914	 370.667914	 0.0	 0.0	 1	 -30.0	 30.0;
	6674	 383	 0.00876	 0.04875	 0.06501	 437.639945	 437.639945	 437.639945	 0.0	 0.0	 1	 -30.0	 30.0;
	2594	 1698	 0.0002	 0.00099	 0.00186	 404.126113	 404.126113	 404.126113	 0.0	 0.0	 1	 -30.0	 30.0;
	1241	 2206	 0.00105	 0.00826	 0.01183	 477.848846	 477.848846	 477.848846	 0.0	 0.0	 1	 -30.0	 30.0;
	1983	 679	 0.0172	 0.06637	 0.12564	 486.474702	 486.474702	 486.474702	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 2581	 0.00305	 0.015781	 0.02048	 477.069597	 477.069597	 477.069597	 0.0	 0.0	 1	 -30.0	 30.0;
	5943	 3283	 0.00208	 0.02105	 0.53266	 1485.150013	 1485.150013	 1485.150013	 0.0	 0.0	 1	 -30.0	 30.0;
	7681	 1795	 0.00614	 0.043729	 0.06831	 482.722491	 482.722491	 482.722491	 0.0	 0.0	 1	 -30.0	 30.0;
	7681	 5375	 0.000229	 0.001849	 0.00267	 556.787408	 556.787408	 556.787408	 0.0	 0.0	 1	 -30.0	 30.0;
	5206	 5493	 0.00386	 0.025789	 0.04344	 455.592409	 455.592409	 455.592409	 0.0	 0.0	 1	 -30.0	 30.0;
	5206	 2127	 0.002031	 0.012	 0.04412	 592.643181	 592.643181	 592.643181	 0.0	 0.0	 1	 -30.0	 30.0;
	2382	 6808	 0.000591	 0.004	 0.01278	 513.172671	 513.172671	 513.172671	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 2184	 9.1e-05	 0.00051	 0.00091	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6874	 5276	 0.00732	 0.039969	 0.0546	 434.795398	 434.795398	 434.795398	 0.0	 0.0	 1	 -30.0	 30.0;
	6874	 2937	 0.004581	 0.02031	 0.03423	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	6952	 5276	 0.00132	 0.00537	 0.00958	 458.280725	 458.280725	 458.280725	 0.0	 0.0	 1	 -30.0	 30.0;
	1077	 1054	 0.007521	 0.0387	 0.06443	 491.79913	 491.79913	 491.79913	 0.0	 0.0	 1	 -30.0	 30.0;
	6215	 4595	 0.005159	 0.031281	 0.04553	 535.914187	 535.914187	 535.914187	 0.0	 0.0	 1	 -30.0	 30.0;
	7531	 7990	 9.9e-05	 0.001159	 0.00284	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6300	 7990	 9.9e-05	 0.00113	 0.00302	 283.453683	 283.453683	 283.453683	 0.0	 0.0	 1	 -30.0	 30.0;
	4101	 3968	 0.00019	 0.000909	 0.08276	 383.390451	 383.390451	 383.390451	 0.0	 0.0	 1	 -30.0	 30.0;
	6480	 7066	 0.00107	 0.00413	 0.00746	 269.057569	 269.057569	 269.057569	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 1902	 9e-05	 0.00058	 0.01132	 1255.798878	 1255.798878	 1255.798878	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 3666	 9e-05	 0.00059	 0.01109	 1177.671019	 1177.671019	 1177.671019	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 8232	 8e-05	 0.00053	 0.01178	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 598	 8e-05	 0.00052	 0.01201	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5997	 8045	 0.000271	 0.00151	 0.07926	 497.671128	 497.671128	 497.671128	 0.0	 0.0	 1	 -30.0	 30.0;
	8108	 5624	 0.00053	 0.00585	 0.34309	 1910.459558	 1910.459558	 1910.459558	 0.0	 0.0	 1	 -30.0	 30.0;
	8108	 5624	 0.00047	 0.00663	 0.30566	 1450.876642	 1450.876642	 1450.876642	 0.0	 0.0	 1	 -30.0	 30.0;
	8108	 5624	 0.00046	 0.00676	 0.29942	 1282.818454	 1282.818454	 1282.818454	 0.0	 0.0	 1	 -30.0	 30.0;
	8108	 5624	 0.00045	 0.00689	 0.29319	 1277.637267	 1277.637267	 1277.637267	 0.0	 0.0	 1	 -30.0	 30.0;
	8108	 7699	 0.00028	 0.00338	 0.06931	 1598.810998	 1598.810998	 1598.810998	 0.0	 0.0	 1	 -30.0	 30.0;
	8108	 7699	 0.0003	 0.00319	 0.07364	 1355.15236	 1355.15236	 1355.15236	 0.0	 0.0	 1	 -30.0	 30.0;
	1497	 4107	 0.00025	 0.00101	 0.10191	 491.671478	 491.671478	 491.671478	 0.0	 0.0	 1	 -30.0	 30.0;
	176	 1803	 0.000281	 0.00119	 0.11988	 254.631734	 254.631734	 254.631734	 0.0	 0.0	 1	 -30.0	 30.0;
	2631	 5061	 0.00018	 0.00063	 0.00105	 333.399204	 333.399204	 333.399204	 0.0	 0.0	 1	 -30.0	 30.0;
	4504	 4017	 0.00382	 0.02868	 0.80483	 325.516779	 325.516779	 325.516779	 0.0	 0.0	 1	 -30.0	 30.0;
	4504	 300	 0.00361	 0.0235	 0.04229	 573.380282	 573.380282	 573.380282	 0.0	 0.0	 1	 -30.0	 30.0;
	4504	 6267	 0.00538	 0.03569	 0.06023	 280.664769	 280.664769	 280.664769	 0.0	 0.0	 1	 -30.0	 30.0;
	3069	 7010	 6e-05	 0.000409	 0.00093	 523.830673	 523.830673	 523.830673	 0.0	 0.0	 1	 -30.0	 30.0;
	935	 2949	 9e-05	 0.00102	 0.02356	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	935	 2228	 0.0014	 0.01649	 0.35378	 1722.598729	 1722.598729	 1722.598729	 0.0	 0.0	 1	 -30.0	 30.0;
	935	 2648	 0.00034	 0.00427	 0.08872	 1149.599672	 1149.599672	 1149.599672	 0.0	 0.0	 1	 -30.0	 30.0;
	4822	 7762	 0.0001	 0.00109	 0.02218	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4822	 5829	 0.00137	 0.01682	 0.34656	 1808.575376	 1808.575376	 1808.575376	 0.0	 0.0	 1	 -30.0	 30.0;
	4822	 7566	 0.00131	 0.01262	 0.33062	 1518.968583	 1518.968583	 1518.968583	 0.0	 0.0	 1	 -30.0	 30.0;
	6483	 5091	 0.00262	 0.019669	 0.02875	 538.882575	 538.882575	 538.882575	 0.0	 0.0	 1	 -30.0	 30.0;
	6483	 2197	 0.00082	 0.00526	 0.00906	 479.019435	 479.019435	 479.019435	 0.0	 0.0	 1	 -30.0	 30.0;
	6483	 2197	 0.000841	 0.005151	 0.00923	 471.132057	 471.132057	 471.132057	 0.0	 0.0	 1	 -30.0	 30.0;
	6483	 2197	 0.000669	 0.005081	 0.00784	 480.371024	 480.371024	 480.371024	 0.0	 0.0	 1	 -30.0	 30.0;
	6483	 6337	 0.001919	 0.012669	 0.02173	 483.122213	 483.122213	 483.122213	 0.0	 0.0	 1	 -30.0	 30.0;
	37	 1409	 0.002659	 0.02	 0.03224	 303.44439	 303.44439	 303.44439	 0.0	 0.0	 1	 -30.0	 30.0;
	37	 3220	 0.003031	 0.02343	 0.03295	 577.874018	 577.874018	 577.874018	 0.0	 0.0	 1	 -30.0	 30.0;
	5654	 4282	 0.01176	 0.059159	 0.0827	 408.323392	 408.323392	 408.323392	 0.0	 0.0	 1	 -30.0	 30.0;
	5654	 7582	 0.002469	 0.017531	 0.02751	 512.560703	 512.560703	 512.560703	 0.0	 0.0	 1	 -30.0	 30.0;
	5654	 2080	 0.000669	 0.005729	 0.04838	 268.815602	 268.815602	 268.815602	 0.0	 0.0	 1	 -30.0	 30.0;
	7517	 7679	 0.000781	 0.00876	 0.02265	 386.075718	 386.075718	 386.075718	 0.0	 0.0	 1	 -30.0	 30.0;
	7517	 4949	 0.00062	 0.00482	 0.02184	 554.258372	 554.258372	 554.258372	 0.0	 0.0	 1	 -30.0	 30.0;
	7517	 6928	 0.001349	 0.012599	 0.03524	 543.338969	 543.338969	 543.338969	 0.0	 0.0	 1	 -30.0	 30.0;
	6207	 7679	 0.000979	 0.0082	 0.02823	 232.278128	 232.278128	 232.278128	 0.0	 0.0	 1	 -30.0	 30.0;
	6207	 798	 0.008091	 0.028831	 0.04443	 360.986547	 360.986547	 360.986547	 0.0	 0.0	 1	 -30.0	 30.0;
	6207	 2080	 0.000711	 0.005969	 0.01611	 530.452961	 530.452961	 530.452961	 0.0	 0.0	 1	 -30.0	 30.0;
	3617	 7010	 0.00145	 0.00857	 0.01673	 235.331492	 235.331492	 235.331492	 0.0	 0.0	 1	 -30.0	 30.0;
	994	 1029	 0.00869	 0.03768	 0.06567	 403.390684	 403.390684	 403.390684	 0.0	 0.0	 1	 -30.0	 30.0;
	994	 2792	 0.001719	 0.00837	 0.01913	 461.329135	 461.329135	 461.329135	 0.0	 0.0	 1	 -30.0	 30.0;
	7720	 4873	 0.01582	 0.067349	 0.11276	 442.79671	 442.79671	 442.79671	 0.0	 0.0	 1	 -30.0	 30.0;
	7720	 4873	 0.01457	 0.06469	 0.10367	 413.739272	 413.739272	 413.739272	 0.0	 0.0	 1	 -30.0	 30.0;
	7720	 4120	 0.021711	 0.090539	 0.14218	 386.852682	 386.852682	 386.852682	 0.0	 0.0	 1	 -30.0	 30.0;
	7720	 3056	 0.00019	 0.000729	 0.00107	 408.507058	 408.507058	 408.507058	 0.0	 0.0	 1	 -30.0	 30.0;
	846	 4888	 0.001271	 0.00638	 0.18923	 411.992533	 411.992533	 411.992533	 0.0	 0.0	 1	 -30.0	 30.0;
	832	 5958	 3.9e-05	 0.0002	 0.02215	 402.111495	 402.111495	 402.111495	 0.0	 0.0	 1	 -30.0	 30.0;
	6044	 4031	 0.000281	 0.00236	 0.21362	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	3951	 1987	 0.00019	 0.00329	 0.12078	 1766.170857	 1766.170857	 1766.170857	 0.0	 0.0	 1	 -30.0	 30.0;
	6814	 3644	 0.00035	 0.00324	 0.08578	 2009.07588	 2009.07588	 2009.07588	 0.0	 0.0	 1	 -30.0	 30.0;
	5958	 7745	 0.00049	 0.00349	 0.21656	 426.31358	 426.31358	 426.31358	 0.0	 0.0	 1	 -30.0	 30.0;
	5958	 7745	 0.000469	 0.00331	 0.20996	 435.139487	 435.139487	 435.139487	 0.0	 0.0	 1	 -30.0	 30.0;
	5958	 1515	 0.00313	 0.01324	 0.07773	 309.786605	 309.786605	 309.786605	 0.0	 0.0	 1	 -30.0	 30.0;
	5958	 8274	 0.001031	 0.006719	 0.01481	 486.696474	 486.696474	 486.696474	 0.0	 0.0	 1	 -30.0	 30.0;
	5958	 1049	 0.00038	 0.00401	 0.01044	 235.003406	 235.003406	 235.003406	 0.0	 0.0	 1	 -30.0	 30.0;
	454	 3266	 0.00037	 0.002849	 0.00436	 500.823946	 500.823946	 500.823946	 0.0	 0.0	 1	 -30.0	 30.0;
	7679	 948	 0.00032	 0.00256	 0.00465	 478.152544	 478.152544	 478.152544	 0.0	 0.0	 1	 -30.0	 30.0;
	7679	 129	 0.00037	 0.00118	 0.15288	 395.767755	 395.767755	 395.767755	 0.0	 0.0	 1	 -30.0	 30.0;
	7679	 3885	 0.00068	 0.001151	 0.15801	 352.787469	 352.787469	 352.787469	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 4711	 0.00168	 0.009841	 0.0213	 504.366579	 504.366579	 504.366579	 0.0	 0.0	 1	 -30.0	 30.0;
	4831	 8035	 0.000599	 0.002401	 0.25184	 402.198375	 402.198375	 402.198375	 0.0	 0.0	 1	 -30.0	 30.0;
	8190	 3	 0.002169	 0.00911	 0.01539	 416.96487	 416.96487	 416.96487	 0.0	 0.0	 1	 -30.0	 30.0;
	8190	 4393	 0.002849	 0.01282	 0.023	 458.201085	 458.201085	 458.201085	 0.0	 0.0	 1	 -30.0	 30.0;
	5675	 4888	 0.001229	 0.01207	 0.14032	 558.268935	 558.268935	 558.268935	 0.0	 0.0	 1	 -30.0	 30.0;
	5675	 6808	 0.001289	 0.01089	 0.15	 623.369624	 623.369624	 623.369624	 0.0	 0.0	 1	 -30.0	 30.0;
	8068	 1498	 0.00093	 0.01036	 0.42887	 877.90457	 877.90457	 877.90457	 0.0	 0.0	 1	 -30.0	 30.0;
	8068	 3164	 0.00083	 0.01174	 0.38208	 843.22971	 843.22971	 843.22971	 0.0	 0.0	 1	 -30.0	 30.0;
	6021	 7112	 0.00118	 0.009469	 0.01613	 307.332636	 307.332636	 307.332636	 0.0	 0.0	 1	 -30.0	 30.0;
	6021	 7112	 0.001151	 0.009651	 0.01578	 297.698519	 297.698519	 297.698519	 0.0	 0.0	 1	 -30.0	 30.0;
	4955	 7352	 0.00101	 0.01327	 0.24444	 1605.522452	 1605.522452	 1605.522452	 0.0	 0.0	 1	 -30.0	 30.0;
	5707	 3817	 0.00364	 0.02486	 0.04515	 585.492756	 585.492756	 585.492756	 0.0	 0.0	 1	 -30.0	 30.0;
	7617	 4318	 0.00056	 0.00425	 0.00651	 551.668367	 551.668367	 551.668367	 0.0	 0.0	 1	 -30.0	 30.0;
	7617	 4167	 0.00369	 0.02681	 0.04553	 534.696728	 534.696728	 534.696728	 0.0	 0.0	 1	 -30.0	 30.0;
	304	 7096	 0.000531	 0.00276	 0.00364	 403.617409	 403.617409	 403.617409	 0.0	 0.0	 1	 -30.0	 30.0;
	2238	 7096	 0.000521	 0.00281	 0.00356	 395.824913	 395.824913	 395.824913	 0.0	 0.0	 1	 -30.0	 30.0;
	4779	 7096	 0.000419	 0.00232	 0.00364	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1992	 7096	 0.000409	 0.00237	 0.00356	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7666	 7493	 0.00014	 0.00193	 0.02599	 1539.966477	 1539.966477	 1539.966477	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 5434	 0.003211	 0.01481	 0.02091	 420.029284	 420.029284	 420.029284	 0.0	 0.0	 1	 -30.0	 30.0;
	1080	 5184	 0.00381	 0.01175	 0.02091	 378.080503	 378.080503	 378.080503	 0.0	 0.0	 1	 -30.0	 30.0;
	1080	 5915	 0.003781	 0.02676	 0.04364	 428.42346	 428.42346	 428.42346	 0.0	 0.0	 1	 -30.0	 30.0;
	2144	 7833	 0.000919	 0.005461	 0.01045	 557.507976	 557.507976	 557.507976	 0.0	 0.0	 1	 -30.0	 30.0;
	2144	 8010	 0.000271	 0.001211	 0.11488	 384.666591	 384.666591	 384.666591	 0.0	 0.0	 1	 -30.0	 30.0;
	2144	 3857	 0.002229	 0.017401	 0.04964	 575.610574	 575.610574	 575.610574	 0.0	 0.0	 1	 -30.0	 30.0;
	2144	 3857	 0.00243	 0.017659	 0.05406	 619.558731	 619.558731	 619.558731	 0.0	 0.0	 1	 -30.0	 30.0;
	2144	 3857	 0.002531	 0.01705	 0.02818	 593.40414	 593.40414	 593.40414	 0.0	 0.0	 1	 -30.0	 30.0;
	8000	 4638	 0.012531	 0.05451	 0.09161	 348.590571	 348.590571	 348.590571	 0.0	 0.0	 1	 -30.0	 30.0;
	5247	 4305	 0.00087	 0.01212	 0.21989	 1355.84279	 1355.84279	 1355.84279	 0.0	 0.0	 1	 -30.0	 30.0;
	5247	 818	 0.0006	 0.00802	 0.1541	 1740.994183	 1740.994183	 1740.994183	 0.0	 0.0	 1	 -30.0	 30.0;
	5247	 7554	 0.00072	 0.00667	 0.18108	 1870.485696	 1870.485696	 1870.485696	 0.0	 0.0	 1	 -30.0	 30.0;
	5247	 1908	 0.00234	 0.02626	 0.57442	 1436.325614	 1436.325614	 1436.325614	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 6337	 0.00038	 0.002969	 0.00445	 528.229909	 528.229909	 528.229909	 0.0	 0.0	 1	 -30.0	 30.0;
	7156	 3563	 0.00024	 0.00045	 0.04833	 347.961455	 347.961455	 347.961455	 0.0	 0.0	 1	 -30.0	 30.0;
	6105	 3563	 0.000229	 0.000409	 0.04367	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3917	 3563	 0.000281	 0.000401	 0.04542	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4870	 5091	 0.001211	 0.005271	 0.51029	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4870	 315	 0.000281	 0.00107	 0.11244	 443.519184	 443.519184	 443.519184	 0.0	 0.0	 1	 -30.0	 30.0;
	4870	 6134	 0.00025	 0.001091	 0.10919	 283.210572	 283.210572	 283.210572	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 1803	 0.00019	 0.00081	 0.54263	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 1803	 0.00045	 0.00136	 0.18846	 609.337414	 609.337414	 609.337414	 0.0	 0.0	 1	 -30.0	 30.0;
	3162	 499	 0.003461	 0.023289	 0.03949	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4954	 7453	 0.0013	 0.01609	 0.3327	 1849.188988	 1849.188988	 1849.188988	 0.0	 0.0	 1	 -30.0	 30.0;
	4954	 7453	 0.00128	 0.0164	 0.32305	 1719.661275	 1719.661275	 1719.661275	 0.0	 0.0	 1	 -30.0	 30.0;
	4954	 2467	 0.00089	 0.01082	 0.07679	 1595.64713	 1595.64713	 1595.64713	 0.0	 0.0	 1	 -30.0	 30.0;
	4954	 2467	 0.00087	 0.01102	 0.07519	 1664.865873	 1664.865873	 1664.865873	 0.0	 0.0	 1	 -30.0	 30.0;
	3446	 7778	 0.003349	 0.02514	 0.04275	 538.659279	 538.659279	 538.659279	 0.0	 0.0	 1	 -30.0	 30.0;
	443	 2405	 0.0003	 0.00061	 0.05537	 330.986007	 330.986007	 330.986007	 0.0	 0.0	 1	 -30.0	 30.0;
	132	 6412	 0.000289	 0.001211	 0.12193	 518.223505	 518.223505	 518.223505	 0.0	 0.0	 1	 -30.0	 30.0;
	6578	 7931	 0.01301	 0.044091	 0.07285	 451.41304	 451.41304	 451.41304	 0.0	 0.0	 1	 -30.0	 30.0;
	6578	 1591	 0.02162	 0.065969	 0.11626	 403.948543	 403.948543	 403.948543	 0.0	 0.0	 1	 -30.0	 30.0;
	8107	 285	 0.006461	 0.05275	 0.07391	 530.840871	 530.840871	 530.840871	 0.0	 0.0	 1	 -30.0	 30.0;
	6305	 7235	 0.0002	 0.000271	 0.02052	 293.923445	 293.923445	 293.923445	 0.0	 0.0	 1	 -30.0	 30.0;
	3019	 7235	 0.00018	 0.00026	 0.01812	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5105	 1591	 0.00032	 0.00188	 0.01052	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5091	 6337	 0.00105	 0.006591	 0.01208	 480.451045	 480.451045	 480.451045	 0.0	 0.0	 1	 -30.0	 30.0;
	16	 5592	 0.00013	 0.00055	 0.09918	 305.308873	 305.308873	 305.308873	 0.0	 0.0	 1	 -30.0	 30.0;
	3413	 4873	 0.006151	 0.04013	 0.07249	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	3413	 6330	 0.007159	 0.040591	 0.08093	 549.135901	 549.135901	 549.135901	 0.0	 0.0	 1	 -30.0	 30.0;
	2082	 2852	 0.00874	 0.048461	 0.06824	 416.264879	 416.264879	 416.264879	 0.0	 0.0	 1	 -30.0	 30.0;
	2082	 4309	 0.004159	 0.01606	 0.03088	 355.628967	 355.628967	 355.628967	 0.0	 0.0	 1	 -30.0	 30.0;
	2082	 3325	 0.002919	 0.01912	 0.03423	 538.050741	 538.050741	 538.050741	 0.0	 0.0	 1	 -30.0	 30.0;
	285	 3916	 0.00094	 0.00394	 0.00719	 436.962055	 436.962055	 436.962055	 0.0	 0.0	 1	 -30.0	 30.0;
	285	 5253	 0.000901	 0.00395	 0.00705	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	285	 2237	 0.003159	 0.017789	 0.0362	 588.924883	 588.924883	 588.924883	 0.0	 0.0	 1	 -30.0	 30.0;
	285	 2237	 0.002419	 0.018331	 0.02701	 308.880847	 308.880847	 308.880847	 0.0	 0.0	 1	 -30.0	 30.0;
	285	 4778	 0.00375	 0.018281	 0.0607	 419.420745	 419.420745	 419.420745	 0.0	 0.0	 1	 -30.0	 30.0;
	2911	 2405	 0.00025	 0.001031	 0.10861	 423.288033	 423.288033	 423.288033	 0.0	 0.0	 1	 -30.0	 30.0;
	4252	 4415	 0.00264	 0.01238	 0.13103	 429.510218	 429.510218	 429.510218	 0.0	 0.0	 1	 -30.0	 30.0;
	4252	 4415	 0.001289	 0.00795	 0.35592	 472.714944	 472.714944	 472.714944	 0.0	 0.0	 1	 -30.0	 30.0;
	4252	 1049	 0.00087	 0.003081	 0.35051	 480.110766	 480.110766	 480.110766	 0.0	 0.0	 1	 -30.0	 30.0;
	7769	 4743	 0.000401	 0.00224	 0.00267	 435.786893	 435.786893	 435.786893	 0.0	 0.0	 1	 -30.0	 30.0;
	49	 200	 0.0003	 0.00385	 0.04615	 2012.21737	 2012.21737	 2012.21737	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 770	 0.00126	 0.008219	 0.0122	 542.336423	 542.336423	 542.336423	 0.0	 0.0	 1	 -30.0	 30.0;
	134	 4638	 0.01905	 0.055729	 0.09514	 323.754036	 323.754036	 323.754036	 0.0	 0.0	 1	 -30.0	 30.0;
	134	 3237	 0.00201	 0.00444	 0.00732	 309.078231	 309.078231	 309.078231	 0.0	 0.0	 1	 -30.0	 30.0;
	6537	 2663	 0.00101	 0.00324	 0.00513	 247.014902	 247.014902	 247.014902	 0.0	 0.0	 1	 -30.0	 30.0;
	1332	 4353	 0.00105	 0.00677	 0.12858	 1234.390279	 1234.390279	 1234.390279	 0.0	 0.0	 1	 -30.0	 30.0;
	1332	 3485	 0.00039	 0.00502	 0.17675	 1159.209748	 1159.209748	 1159.209748	 0.0	 0.0	 1	 -30.0	 30.0;
	1332	 5126	 0.0004	 0.00492	 0.18021	 980.27054	 980.27054	 980.27054	 0.0	 0.0	 1	 -30.0	 30.0;
	1332	 3644	 0.00051	 0.00617	 0.12199	 1360.254566	 1360.254566	 1360.254566	 0.0	 0.0	 1	 -30.0	 30.0;
	6837	 3166	 0.0003	 0.00314	 0.07364	 1607.760262	 1607.760262	 1607.760262	 0.0	 0.0	 1	 -30.0	 30.0;
	6837	 3485	 0.00051	 0.00668	 0.15203	 1647.374758	 1647.374758	 1647.374758	 0.0	 0.0	 1	 -30.0	 30.0;
	6837	 5126	 0.0005	 0.00678	 0.15145	 1795.226183	 1795.226183	 1795.226183	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 2200	 0.002909	 0.017	 0.04617	 312.695169	 312.695169	 312.695169	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 1052	 0.00245	 0.011281	 0.02052	 476.917557	 476.917557	 476.917557	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 4471	 0.0027	 0.01532	 0.02974	 469.898213	 469.898213	 469.898213	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 4471	 0.00105	 0.011151	 0.04174	 323.558938	 323.558938	 323.558938	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 3489	 0.00036	 0.002669	 0.00379	 344.477505	 344.477505	 344.477505	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 501	 0.0018	 0.011169	 0.01637	 474.073772	 474.073772	 474.073772	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 2745	 0.000711	 0.007771	 0.02091	 269.049948	 269.049948	 269.049948	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 7190	 0.00036	 0.00257	 0.00379	 283.414053	 283.414053	 283.414053	 0.0	 0.0	 1	 -30.0	 30.0;
	1415	 3735	 0.00201	 0.01195	 0.02258	 617.614227	 617.614227	 617.614227	 0.0	 0.0	 1	 -30.0	 30.0;
	1415	 7133	 0.001091	 0.00731	 0.01185	 571.792823	 571.792823	 571.792823	 0.0	 0.0	 1	 -30.0	 30.0;
	1415	 4952	 0.00105	 0.007591	 0.01233	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	1415	 1681	 0.00299	 0.02256	 0.03276	 487.232231	 487.232231	 487.232231	 0.0	 0.0	 1	 -30.0	 30.0;
	2792	 2617	 0.00036	 0.00288	 0.00445	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 4100	 0.00589	 0.045599	 0.06709	 561.660291	 561.660291	 561.660291	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 3256	 0.00157	 0.0127	 0.01781	 485.475967	 485.475967	 485.475967	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 3256	 0.00168	 0.011969	 0.01897	 250.692046	 250.692046	 250.692046	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 7172	 0.00289	 0.021031	 0.0332	 443.547762	 443.547762	 443.547762	 0.0	 0.0	 1	 -30.0	 30.0;
	5779	 1005	 0.00395	 0.025211	 0.04328	 575.397567	 575.397567	 575.397567	 0.0	 0.0	 1	 -30.0	 30.0;
	5779	 8365	 0.002771	 0.021659	 0.06187	 494.959949	 494.959949	 494.959949	 0.0	 0.0	 1	 -30.0	 30.0;
	5779	 5130	 0.002979	 0.016901	 0.03301	 566.903555	 566.903555	 566.903555	 0.0	 0.0	 1	 -30.0	 30.0;
	7684	 5358	 0.007419	 0.034021	 0.06023	 220.611866	 220.611866	 220.611866	 0.0	 0.0	 1	 -30.0	 30.0;
	4765	 6279	 0.00056	 0.00813	 0.7392	 920.340681	 920.340681	 920.340681	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 1657	 0.00361	 0.015211	 0.02668	 439.459083	 439.459083	 439.459083	 0.0	 0.0	 1	 -30.0	 30.0;
	8125	 6393	 0.000409	 0.003331	 0.00535	 645.433249	 645.433249	 645.433249	 0.0	 0.0	 1	 -30.0	 30.0;
	6211	 7974	 0.004091	 0.019599	 0.03488	 481.922664	 481.922664	 481.922664	 0.0	 0.0	 1	 -30.0	 30.0;
	6211	 6108	 0.00294	 0.012841	 0.0302	 507.799469	 507.799469	 507.799469	 0.0	 0.0	 1	 -30.0	 30.0;
	4031	 5094	 0.020771	 0.080479	 0.15227	 571.341658	 571.341658	 571.341658	 0.0	 0.0	 1	 -30.0	 30.0;
	4031	 1795	 0.00662	 0.0513	 0.0758	 566.839538	 566.839538	 566.839538	 0.0	 0.0	 1	 -30.0	 30.0;
	4031	 1616	 0.00607	 0.04581	 0.06876	 548.965952	 548.965952	 548.965952	 0.0	 0.0	 1	 -30.0	 30.0;
	2762	 1005	 0.000669	 0.0042	 0.00705	 491.441323	 491.441323	 491.441323	 0.0	 0.0	 1	 -30.0	 30.0;
	2762	 7691	 0.001271	 0.007419	 0.12617	 485.072814	 485.072814	 485.072814	 0.0	 0.0	 1	 -30.0	 30.0;
	2762	 5130	 0.001599	 0.012271	 0.01742	 588.349496	 588.349496	 588.349496	 0.0	 0.0	 1	 -30.0	 30.0;
	807	 4235	 0.009599	 0.05024	 0.06824	 430.740632	 430.740632	 430.740632	 0.0	 0.0	 1	 -30.0	 30.0;
	807	 471	 0.00149	 0.009219	 0.02771	 450.548054	 450.548054	 450.548054	 0.0	 0.0	 1	 -30.0	 30.0;
	807	 6183	 0.01488	 0.06724	 0.10762	 401.72549	 401.72549	 401.72549	 0.0	 0.0	 1	 -30.0	 30.0;
	807	 5369	 0.003599	 0.024031	 0.05233	 430.77607	 430.77607	 430.77607	 0.0	 0.0	 1	 -30.0	 30.0;
	807	 5369	 0.00519	 0.024	 0.04495	 447.119355	 447.119355	 447.119355	 0.0	 0.0	 1	 -30.0	 30.0;
	7833	 1255	 0.003461	 0.013349	 0.02173	 414.40916	 414.40916	 414.40916	 0.0	 0.0	 1	 -30.0	 30.0;
	3122	 3860	 0.00105	 0.01236	 0.02416	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3122	 3860	 0.00199	 0.012331	 0.02258	 503.398709	 503.398709	 503.398709	 0.0	 0.0	 1	 -30.0	 30.0;
	3122	 3325	 0.00711	 0.044711	 0.06055	 444.324345	 444.324345	 444.324345	 0.0	 0.0	 1	 -30.0	 30.0;
	5628	 6463	 0.006729	 0.02543	 0.04685	 336.250229	 336.250229	 336.250229	 0.0	 0.0	 1	 -30.0	 30.0;
	8227	 6463	 0.005771	 0.02999	 0.04003	 242.309301	 242.309301	 242.309301	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 85	 0.0048	 0.021771	 0.03456	 359.174649	 359.174649	 359.174649	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 278	 0.00286	 0.02212	 0.04095	 549.653368	 549.653368	 549.653368	 0.0	 0.0	 1	 -30.0	 30.0;
	651	 7609	 0.00351	 0.02175	 0.02462	 522.491278	 522.491278	 522.491278	 0.0	 0.0	 1	 -30.0	 30.0;
	651	 6330	 0.008401	 0.0448	 0.08155	 580.324558	 580.324558	 580.324558	 0.0	 0.0	 1	 -30.0	 30.0;
	6531	 7990	 0.0018	 0.01187	 0.01975	 272.935527	 272.935527	 272.935527	 0.0	 0.0	 1	 -30.0	 30.0;
	6531	 7990	 0.001831	 0.01163	 0.02013	 267.590522	 267.590522	 267.590522	 0.0	 0.0	 1	 -30.0	 30.0;
	7791	 2723	 0.00075	 0.00538	 0.00854	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5968	 746	 2e-05	 0.00033	 0.00831	 2061.617676	 2061.617676	 2061.617676	 0.0	 0.0	 1	 -30.0	 30.0;
	5968	 1532	 1e-05	 0.00034	 0.00814	 1835.36459	 1835.36459	 1835.36459	 0.0	 0.0	 1	 -30.0	 30.0;
	5624	 864	 0.00023	 0.00258	 0.33685	 854.127185	 854.127185	 854.127185	 0.0	 0.0	 1	 -30.0	 30.0;
	5624	 1661	 0.00023	 0.00252	 0.34309	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2937	 1370	 0.002031	 0.008531	 0.03689	 233.326781	 233.326781	 233.326781	 0.0	 0.0	 1	 -30.0	 30.0;
	2937	 6551	 0.005349	 0.020789	 0.03833	 426.951459	 426.951459	 426.951459	 0.0	 0.0	 1	 -30.0	 30.0;
	2657	 7136	 0.0002	 0.00082	 0.08642	 512.896028	 512.896028	 512.896028	 0.0	 0.0	 1	 -30.0	 30.0;
	3567	 6252	 0.002091	 0.011219	 0.02048	 353.414298	 353.414298	 353.414298	 0.0	 0.0	 1	 -30.0	 30.0;
	5493	 151	 0.00262	 0.016979	 0.0302	 547.989318	 547.989318	 547.989318	 0.0	 0.0	 1	 -30.0	 30.0;
	5493	 151	 0.002669	 0.01663	 0.02975	 604.444717	 604.444717	 604.444717	 0.0	 0.0	 1	 -30.0	 30.0;
	8010	 2769	 0.00025	 0.00118	 0.10419	 520.156196	 520.156196	 520.156196	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 1086	 0.00056	 0.00715	 0.14388	 1668.819556	 1668.819556	 1668.819556	 0.0	 0.0	 1	 -30.0	 30.0;
	3563	 3404	 0.0007	 0.00455	 0.16386	 442.938462	 442.938462	 442.938462	 0.0	 0.0	 1	 -30.0	 30.0;
	3563	 2443	 0.000331	 0.001711	 0.0061	 391.613154	 391.613154	 391.613154	 0.0	 0.0	 1	 -30.0	 30.0;
	3563	 2443	 0.00011	 0.000781	 0.00637	 557.364701	 557.364701	 557.364701	 0.0	 0.0	 1	 -30.0	 30.0;
	3563	 8058	 0.00111	 0.00664	 0.01365	 441.296131	 441.296131	 441.296131	 0.0	 0.0	 1	 -30.0	 30.0;
	6821	 7453	 0.00066	 0.00838	 0.05678	 1566.771487	 1566.771487	 1566.771487	 0.0	 0.0	 1	 -30.0	 30.0;
	6821	 7453	 0.00064	 0.00854	 0.05557	 1560.76231	 1560.76231	 1560.76231	 0.0	 0.0	 1	 -30.0	 30.0;
	2197	 3285	 0.003091	 0.017091	 0.03301	 572.922258	 572.922258	 572.922258	 0.0	 0.0	 1	 -30.0	 30.0;
	2197	 1287	 0.00643	 0.03687	 0.07109	 635.399409	 635.399409	 635.399409	 0.0	 0.0	 1	 -30.0	 30.0;
	8060	 3285	 0.00275	 0.01937	 0.02941	 225.056066	 225.056066	 225.056066	 0.0	 0.0	 1	 -30.0	 30.0;
	7609	 5369	 0.00357	 0.021289	 0.05645	 523.489632	 523.489632	 523.489632	 0.0	 0.0	 1	 -30.0	 30.0;
	1751	 6330	 0.000289	 0.002789	 0.00356	 333.769966	 333.769966	 333.769966	 0.0	 0.0	 1	 -30.0	 30.0;
	7144	 6020	 0.002531	 0.01345	 0.0182	 383.060079	 383.060079	 383.060079	 0.0	 0.0	 1	 -30.0	 30.0;
	4151	 6987	 0.00162	 0.012159	 0.01859	 530.693405	 530.693405	 530.693405	 0.0	 0.0	 1	 -30.0	 30.0;
	4151	 6987	 0.00262	 0.01168	 0.02013	 437.524867	 437.524867	 437.524867	 0.0	 0.0	 1	 -30.0	 30.0;
	8016	 1052	 0.00099	 0.006081	 0.01129	 261.344712	 261.344712	 261.344712	 0.0	 0.0	 1	 -30.0	 30.0;
	8016	 1120	 0.000909	 0.005979	 0.00987	 291.366972	 291.366972	 291.366972	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 368	 0.00011	 0.0008	 0.00089	 262.890256	 262.890256	 262.890256	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 6555	 0.00011	 0.00068	 0.00103	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 5440	 0.00207	 0.008341	 0.01568	 505.112677	 505.112677	 505.112677	 0.0	 0.0	 1	 -30.0	 30.0;
	1747	 2308	 0.00019	 0.001031	 0.00089	 341.744987	 341.744987	 341.744987	 0.0	 0.0	 1	 -30.0	 30.0;
	3623	 6667	 0.014039	 0.0667	 0.09478	 332.583754	 332.583754	 332.583754	 0.0	 0.0	 1	 -30.0	 30.0;
	2845	 6797	 0.004961	 0.03043	 0.0543	 457.185584	 457.185584	 457.185584	 0.0	 0.0	 1	 -30.0	 30.0;
	2438	 5222	 0.00056	 0.003531	 0.00906	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1093	 3857	 0.001461	 0.00889	 0.02155	 525.122817	 525.122817	 525.122817	 0.0	 0.0	 1	 -30.0	 30.0;
	6920	 6419	 6e-05	 0.000419	 0.00089	 514.119584	 514.119584	 514.119584	 0.0	 0.0	 1	 -30.0	 30.0;
	4387	 3699	 0.00139	 0.005169	 0.0	 253.936315	 253.936315	 253.936315	 0.0	 0.0	 1	 -30.0	 30.0;
	3770	 1194	 0.00069	 0.00825	 0.31259	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6463	 4155	 0.004969	 0.030781	 0.05643	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6463	 8054	 0.00012	 0.000969	 0.00186	 609.674644	 609.674644	 609.674644	 0.0	 0.0	 1	 -30.0	 30.0;
	6061	 4888	 0.001091	 0.010159	 0.02962	 583.218642	 583.218642	 583.218642	 0.0	 0.0	 1	 -30.0	 30.0;
	7386	 4888	 0.000969	 0.00887	 0.02764	 558.36115	 558.36115	 558.36115	 0.0	 0.0	 1	 -30.0	 30.0;
	3968	 6002	 0.00099	 0.006789	 0.20656	 525.394507	 525.394507	 525.394507	 0.0	 0.0	 1	 -30.0	 30.0;
	7425	 7953	 0.001031	 0.00586	 0.22751	 387.443692	 387.443692	 387.443692	 0.0	 0.0	 1	 -30.0	 30.0;
	6769	 4962	 0.00401	 0.03345	 0.0472	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	3091	 4861	 9.1e-05	 0.000349	 0.00087	 372.741976	 372.741976	 372.741976	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 204	 0.00125	 0.00745	 0.01463	 608.173303	 608.173303	 608.173303	 0.0	 0.0	 1	 -30.0	 30.0;
	45	 3673	 0.003711	 0.024219	 0.04229	 520.227834	 520.227834	 520.227834	 0.0	 0.0	 1	 -30.0	 30.0;
	7453	 6279	 0.00169	 0.02156	 0.43164	 1709.904425	 1709.904425	 1709.904425	 0.0	 0.0	 1	 -30.0	 30.0;
	7453	 6279	 0.00171	 0.02114	 0.43805	 1801.062259	 1801.062259	 1801.062259	 0.0	 0.0	 1	 -30.0	 30.0;
	5944	 3860	 0.00088	 0.00562	 0.01007	 543.182357	 543.182357	 543.182357	 0.0	 0.0	 1	 -30.0	 30.0;
	5944	 3860	 0.0008	 0.00618	 0.00958	 579.429088	 579.429088	 579.429088	 0.0	 0.0	 1	 -30.0	 30.0;
	2669	 6510	 0.00161	 0.01014	 0.01812	 247.961814	 247.961814	 247.961814	 0.0	 0.0	 1	 -30.0	 30.0;
	3579	 2321	 0.00032	 0.002031	 0.00402	 546.704794	 546.704794	 546.704794	 0.0	 0.0	 1	 -30.0	 30.0;
	3579	 5915	 0.00011	 0.000659	 0.00105	 509.395311	 509.395311	 509.395311	 0.0	 0.0	 1	 -30.0	 30.0;
	1760	 3485	 0.00042	 0.00505	 0.1898	 1115.741612	 1115.741612	 1115.741612	 0.0	 0.0	 1	 -30.0	 30.0;
	1760	 5126	 0.00043	 0.00494	 0.19339	 1282.655226	 1282.655226	 1282.655226	 0.0	 0.0	 1	 -30.0	 30.0;
	2549	 4471	 0.00038	 0.000711	 0.04097	 230.929969	 230.929969	 230.929969	 0.0	 0.0	 1	 -30.0	 30.0;
	2549	 4471	 0.00037	 0.000659	 0.04008	 254.570384	 254.570384	 254.570384	 0.0	 0.0	 1	 -30.0	 30.0;
	3755	 1498	 0.00248	 0.03096	 0.61625	 1863.235193	 1863.235193	 1863.235193	 0.0	 0.0	 1	 -30.0	 30.0;
	144	 3179	 0.00375	 0.019729	 0.02788	 511.803936	 511.803936	 511.803936	 0.0	 0.0	 1	 -30.0	 30.0;
	144	 2206	 0.00518	 0.020021	 0.03833	 450.908909	 450.908909	 450.908909	 0.0	 0.0	 1	 -30.0	 30.0;
	7208	 8264	 0.000771	 0.003711	 0.00569	 499.351945	 499.351945	 499.351945	 0.0	 0.0	 1	 -30.0	 30.0;
	7208	 1344	 0.00076	 0.003789	 0.00558	 466.410071	 466.410071	 466.410071	 0.0	 0.0	 1	 -30.0	 30.0;
	2098	 3220	 0.000781	 0.00574	 0.00871	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3214	 6878	 0.00089	 0.00562	 0.00987	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1843	 7745	 0.000331	 0.001401	 0.14375	 343.170118	 343.170118	 343.170118	 0.0	 0.0	 1	 -30.0	 30.0;
	4706	 7745	 0.000401	 0.00137	 0.16389	 285.980052	 285.980052	 285.980052	 0.0	 0.0	 1	 -30.0	 30.0;
	7210	 4743	 0.00051	 0.003349	 0.00455	 373.358898	 373.358898	 373.358898	 0.0	 0.0	 1	 -30.0	 30.0;
	1879	 8283	 0.000461	 0.00168	 0.19747	 253.946223	 253.946223	 253.946223	 0.0	 0.0	 1	 -30.0	 30.0;
	1879	 8283	 0.000469	 0.00164	 0.20134	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4235	 6183	 0.006081	 0.03114	 0.04269	 469.423043	 469.423043	 469.423043	 0.0	 0.0	 1	 -30.0	 30.0;
	6820	 704	 0.005831	 0.02218	 0.03797	 512.94366	 512.94366	 512.94366	 0.0	 0.0	 1	 -30.0	 30.0;
	8163	 3121	 0.00013	 0.000461	 0.04458	 340.200205	 340.200205	 340.200205	 0.0	 0.0	 1	 -30.0	 30.0;
	7071	 1844	 0.00013	 0.000461	 0.04186	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	787	 3673	 0.00262	 0.020289	 0.02962	 528.662021	 528.662021	 528.662021	 0.0	 0.0	 1	 -30.0	 30.0;
	787	 2608	 0.00164	 0.01194	 0.01897	 565.655993	 565.655993	 565.655993	 0.0	 0.0	 1	 -30.0	 30.0;
	6667	 8315	 0.006479	 0.02845	 0.04553	 531.941728	 531.941728	 531.941728	 0.0	 0.0	 1	 -30.0	 30.0;
	7235	 1836	 0.00294	 0.014419	 0.18523	 505.390082	 505.390082	 505.390082	 0.0	 0.0	 1	 -30.0	 30.0;
	7235	 1836	 0.00238	 0.01463	 0.1682	 513.540386	 513.540386	 513.540386	 0.0	 0.0	 1	 -30.0	 30.0;
	7235	 1599	 0.002219	 0.00993	 0.19393	 485.859685	 485.859685	 485.859685	 0.0	 0.0	 1	 -30.0	 30.0;
	1275	 2093	 0.008651	 0.04886	 0.06882	 404.672921	 404.672921	 404.672921	 0.0	 0.0	 1	 -30.0	 30.0;
	4100	 7172	 0.00464	 0.030979	 0.05233	 239.809605	 239.809605	 239.809605	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 405	 0.00092	 0.00889	 0.23317	 1563.433202	 1563.433202	 1563.433202	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 405	 0.00093	 0.00869	 0.23749	 1460.379435	 1460.379435	 1460.379435	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 1661	 0.0022	 0.03485	 0.78184	 1710.604069	 1710.604069	 1710.604069	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 2228	 0.00074	 0.00941	 0.18974	 1860.996067	 1860.996067	 1860.996067	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 5829	 0.00087	 0.00884	 0.22347	 1683.003978	 1683.003978	 1683.003978	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 1580	 0.00139	 0.01662	 0.4928	 2148.207087	 2148.207087	 2148.207087	 0.0	 0.0	 1	 -30.0	 30.0;
	8365	 538	 0.002781	 0.022979	 0.03384	 412.593832	 412.593832	 412.593832	 0.0	 0.0	 1	 -30.0	 30.0;
	5762	 4898	 0.000521	 0.00407	 0.01742	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	5620	 6987	 0.008479	 0.032841	 0.06282	 222.503023	 222.503023	 222.503023	 0.0	 0.0	 1	 -30.0	 30.0;
	2267	 6793	 0.005669	 0.02901	 0.04182	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3673	 2603	 0.001031	 0.004099	 0.00732	 302.678477	 302.678477	 302.678477	 0.0	 0.0	 1	 -30.0	 30.0;
	3673	 7297	 0.00301	 0.018719	 0.03322	 489.924739	 489.924739	 489.924739	 0.0	 0.0	 1	 -30.0	 30.0;
	1657	 2597	 0.00257	 0.01713	 0.02962	 439.123377	 439.123377	 439.123377	 0.0	 0.0	 1	 -30.0	 30.0;
	4873	 4918	 0.010461	 0.03836	 0.06141	 350.440193	 350.440193	 350.440193	 0.0	 0.0	 1	 -30.0	 30.0;
	4873	 3732	 0.001719	 0.011531	 0.01975	 520.129904	 520.129904	 520.129904	 0.0	 0.0	 1	 -30.0	 30.0;
	4873	 1420	 9.1e-05	 0.00056	 0.00089	 409.033671	 409.033671	 409.033671	 0.0	 0.0	 1	 -30.0	 30.0;
	3546	 3519	 0.00476	 0.025289	 0.03457	 347.351393	 347.351393	 347.351393	 0.0	 0.0	 1	 -30.0	 30.0;
	113	 1418	 0.000219	 0.00164	 0.0104	 432.49423	 432.49423	 432.49423	 0.0	 0.0	 1	 -30.0	 30.0;
	178	 7251	 0.002159	 0.01163	 0.01394	 250.326236	 250.326236	 250.326236	 0.0	 0.0	 1	 -30.0	 30.0;
	178	 1418	 0.00295	 0.01539	 0.01473	 406.094623	 406.094623	 406.094623	 0.0	 0.0	 1	 -30.0	 30.0;
	2713	 2852	 0.007789	 0.033039	 0.06273	 417.564264	 417.564264	 417.564264	 0.0	 0.0	 1	 -30.0	 30.0;
	6633	 2793	 0.00026	 0.0013	 0.00175	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5884	 8166	 0.00162	 0.013229	 0.01781	 456.8796	 456.8796	 456.8796	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 538	 0.007919	 0.04194	 0.05924	 442.949131	 442.949131	 442.949131	 0.0	 0.0	 1	 -30.0	 30.0;
	618	 7683	 0.001229	 0.00401	 0.00746	 402.473875	 402.473875	 402.473875	 0.0	 0.0	 1	 -30.0	 30.0;
	4678	 4979	 0.008021	 0.042831	 0.05823	 442.663343	 442.663343	 442.663343	 0.0	 0.0	 1	 -30.0	 30.0;
	6020	 704	 0.007711	 0.03006	 0.0513	 450.90929	 450.90929	 450.90929	 0.0	 0.0	 1	 -30.0	 30.0;
	7974	 715	 0.00261	 0.015469	 0.03032	 432.991502	 432.991502	 432.991502	 0.0	 0.0	 1	 -30.0	 30.0;
	5743	 1420	 0.00139	 0.00536	 0.00906	 357.510598	 357.510598	 357.510598	 0.0	 0.0	 1	 -30.0	 30.0;
	5743	 1420	 0.001419	 0.00525	 0.00923	 364.323793	 364.323793	 364.323793	 0.0	 0.0	 1	 -30.0	 30.0;
	1723	 6987	 0.006289	 0.032271	 0.05537	 288.265597	 288.265597	 288.265597	 0.0	 0.0	 1	 -30.0	 30.0;
	1723	 1944	 0.011031	 0.05625	 0.07992	 374.236839	 374.236839	 374.236839	 0.0	 0.0	 1	 -30.0	 30.0;
	151	 2127	 0.001841	 0.01324	 0.02087	 574.699481	 574.699481	 574.699481	 0.0	 0.0	 1	 -30.0	 30.0;
	6012	 7	 0.000599	 0.00186	 0.24881	 566.621577	 566.621577	 566.621577	 0.0	 0.0	 1	 -30.0	 30.0;
	4080	 3860	 0.00036	 0.001591	 0.15318	 551.484319	 551.484319	 551.484319	 0.0	 0.0	 1	 -30.0	 30.0;
	2769	 3857	 0.003849	 0.027651	 0.02708	 566.138023	 566.138023	 566.138023	 0.0	 0.0	 1	 -30.0	 30.0;
	770	 4056	 0.00186	 0.00874	 0.01811	 594.792691	 594.792691	 594.792691	 0.0	 0.0	 1	 -30.0	 30.0;
	3166	 1987	 0.00025	 0.00285	 0.05944	 1581.321199	 1581.321199	 1581.321199	 0.0	 0.0	 1	 -30.0	 30.0;
	1052	 7190	 0.00207	 0.008841	 0.01568	 433.366456	 433.366456	 433.366456	 0.0	 0.0	 1	 -30.0	 30.0;
	1052	 1120	 6e-05	 0.00039	 0.00101	 557.764804	 557.764804	 557.764804	 0.0	 0.0	 1	 -30.0	 30.0;
	8091	 4415	 0.002159	 0.008909	 0.01568	 467.381751	 467.381751	 467.381751	 0.0	 0.0	 1	 -30.0	 30.0;
	3681	 1120	 0.000219	 0.00039	 0.02353	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4471	 2405	 0.00011	 0.000521	 0.09083	 411.803532	 411.803532	 411.803532	 0.0	 0.0	 1	 -30.0	 30.0;
	4471	 2405	 0.00011	 0.00049	 0.0846	 410.585311	 410.585311	 410.585311	 0.0	 0.0	 1	 -30.0	 30.0;
	4471	 501	 0.000771	 0.003789	 0.00705	 453.649048	 453.649048	 453.649048	 0.0	 0.0	 1	 -30.0	 30.0;
	4471	 2745	 0.000229	 0.002849	 0.00637	 274.540515	 274.540515	 274.540515	 0.0	 0.0	 1	 -30.0	 30.0;
	7251	 4778	 0.00445	 0.027599	 0.04879	 377.153024	 377.153024	 377.153024	 0.0	 0.0	 1	 -30.0	 30.0;
	1559	 3038	 0.00218	 0.02	 0.5337	 1513.3734	 1513.3734	 1513.3734	 0.0	 0.0	 1	 -30.0	 30.0;
	1559	 7675	 0.00074	 0.00865	 0.18397	 1227.31551	 1227.31551	 1227.31551	 0.0	 0.0	 1	 -30.0	 30.0;
	6987	 1121	 0.002531	 0.019419	 0.02875	 404.155454	 404.155454	 404.155454	 0.0	 0.0	 1	 -30.0	 30.0;
	6987	 7290	 0.003	 0.01631	 0.02467	 237.990086	 237.990086	 237.990086	 0.0	 0.0	 1	 -30.0	 30.0;
	7871	 3025	 0.008461	 0.025081	 0.04578	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7423	 3313	 0.00382	 0.013669	 0.02555	 505.518115	 505.518115	 505.518115	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 7683	 0.002581	 0.01814	 0.02881	 525.828143	 525.828143	 525.828143	 0.0	 0.0	 1	 -30.0	 30.0;
	6117	 5537	 0.00201	 0.012219	 0.02258	 542.453787	 542.453787	 542.453787	 0.0	 0.0	 1	 -30.0	 30.0;
	7745	 3926	 0.00087	 0.001599	 0.21745	 378.524808	 378.524808	 378.524808	 0.0	 0.0	 1	 -30.0	 30.0;
	698	 4758	 0.00455	 0.02394	 0.08364	 424.425852	 424.425852	 424.425852	 0.0	 0.0	 1	 -30.0	 30.0;
	1795	 5375	 0.005651	 0.041771	 0.0664	 463.267161	 463.267161	 463.267161	 0.0	 0.0	 1	 -30.0	 30.0;
	8186	 3643	 0.00069	 0.001271	 0.16193	 359.753465	 359.753465	 359.753465	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 7618	 0.00068	 0.00269	 0.28754	 404.417236	 404.417236	 404.417236	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 1845	 0.00036	 0.00261	 0.01518	 477.861802	 477.861802	 477.861802	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 7519	 0.001669	 0.012031	 0.01859	 419.733207	 419.733207	 419.733207	 0.0	 0.0	 1	 -30.0	 30.0;
	4309	 3325	 0.009669	 0.03513	 0.05839	 373.363089	 373.363089	 373.363089	 0.0	 0.0	 1	 -30.0	 30.0;
	4309	 7683	 0.001099	 0.00862	 0.01307	 312.429957	 312.429957	 312.429957	 0.0	 0.0	 1	 -30.0	 30.0;
	7254	 1498	 0.0005	 0.00711	 0.19757	 778.447753	 778.447753	 778.447753	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 924	 0.003919	 0.017781	 0.02867	 513.375391	 513.375391	 513.375391	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 8166	 0.00161	 0.019781	 0.08342	 259.388015	 259.388015	 259.388015	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 715	 0.0007	 0.01256	 0.03036	 622.37508	 622.37508	 622.37508	 0.0	 0.0	 1	 -30.0	 30.0;
	4552	 4898	 0.000409	 0.0018	 0.14985	 331.596451	 331.596451	 331.596451	 0.0	 0.0	 1	 -30.0	 30.0;
	1558	 3558	 2e-05	 0.00043	 0.01109	 2049.22021	 2049.22021	 2049.22021	 0.0	 0.0	 1	 -30.0	 30.0;
	8302	 3558	 3e-05	 0.0004	 0.01224	 1834.604393	 1834.604393	 1834.604393	 0.0	 0.0	 1	 -30.0	 30.0;
	255	 8309	 0.00968	 0.056659	 0.07481	 476.271675	 476.271675	 476.271675	 0.0	 0.0	 1	 -30.0	 30.0;
	7297	 3325	 0.003969	 0.02925	 0.04743	 367.464417	 367.464417	 367.464417	 0.0	 0.0	 1	 -30.0	 30.0;
	5184	 8166	 0.00219	 0.01468	 0.02567	 526.450781	 526.450781	 526.450781	 0.0	 0.0	 1	 -30.0	 30.0;
	5184	 7673	 0.000401	 0.003159	 0.00455	 494.560608	 494.560608	 494.560608	 0.0	 0.0	 1	 -30.0	 30.0;
	5184	 6242	 0.000531	 0.003	 0.00426	 493.552727	 493.552727	 493.552727	 0.0	 0.0	 1	 -30.0	 30.0;
	4743	 6587	 0.00136	 0.00576	 0.01065	 482.379164	 482.379164	 482.379164	 0.0	 0.0	 1	 -30.0	 30.0;
	7990	 8166	 0.000849	 0.006289	 0.00929	 466.170771	 466.170771	 466.170771	 0.0	 0.0	 1	 -30.0	 30.0;
	7990	 8166	 0.000841	 0.006409	 0.0091	 470.065876	 470.065876	 470.065876	 0.0	 0.0	 1	 -30.0	 30.0;
	7990	 8166	 0.00045	 0.00506	 0.01742	 246.977559	 246.977559	 246.977559	 0.0	 0.0	 1	 -30.0	 30.0;
	197	 1904	 0.003669	 0.02988	 0.04453	 508.503651	 508.503651	 508.503651	 0.0	 0.0	 1	 -30.0	 30.0;
	471	 5369	 0.002	 0.01568	 0.02366	 522.926057	 522.926057	 522.926057	 0.0	 0.0	 1	 -30.0	 30.0;
	2405	 1940	 0.00031	 0.0008	 0.19236	 419.490858	 419.490858	 419.490858	 0.0	 0.0	 1	 -30.0	 30.0;
	1105	 4758	 0.00043	 0.00038	 0.09851	 288.866134	 288.866134	 288.866134	 0.0	 0.0	 1	 -30.0	 30.0;
	8155	 5440	 0.00043	 0.002229	 0.00348	 376.199253	 376.199253	 376.199253	 0.0	 0.0	 1	 -30.0	 30.0;
	4740	 5440	 0.00049	 0.00218	 0.00395	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3325	 3699	 0.00282	 0.01844	 0.02013	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	798	 3025	 0.00462	 0.014849	 0.02614	 230.435746	 230.435746	 230.435746	 0.0	 0.0	 1	 -30.0	 30.0;
	4676	 3038	 0.00263	 0.04076	 1.13395	 1577.957245	 1577.957245	 1577.957245	 0.0	 0.0	 1	 -30.0	 30.0;
	3179	 2321	 0.01062	 0.056719	 0.07734	 466.875334	 466.875334	 466.875334	 0.0	 0.0	 1	 -30.0	 30.0;
	1734	 7433	 0.0001	 0.00105	 0.02356	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8283	 8045	 0.00239	 0.017341	 0.02802	 481.484456	 481.484456	 481.484456	 0.0	 0.0	 1	 -30.0	 30.0;
	3183	 2273	 0.001341	 0.010581	 0.01547	 539.026232	 539.026232	 539.026232	 0.0	 0.0	 1	 -30.0	 30.0;
	3183	 5575	 0.00101	 0.007599	 0.01116	 577.685017	 577.685017	 577.685017	 0.0	 0.0	 1	 -30.0	 30.0;
	362	 1444	 0.00011	 0.000289	 0.0	 513.765206	 513.765206	 513.765206	 0.0	 0.0	 1	 -30.0	 30.0;
	6644	 6279	 0.00146	 0.01769	 0.54958	 2069.517144	 2069.517144	 2069.517144	 0.0	 0.0	 1	 -30.0	 30.0;
	6644	 6279	 0.0013	 0.02004	 0.48963	 1765.766077	 1765.766077	 1765.766077	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 5061	 0.007909	 0.028349	 0.04925	 425.601014	 425.601014	 425.601014	 0.0	 0.0	 1	 -30.0	 30.0;
	6703	 7765	 0.00012	 0.00049	 0.05628	 255.689532	 255.689532	 255.689532	 0.0	 0.0	 1	 -30.0	 30.0;
	6703	 7765	 0.00012	 0.000479	 0.05739	 274.018474	 274.018474	 274.018474	 0.0	 0.0	 1	 -30.0	 30.0;
	6279	 389	 0.00076	 0.01018	 0.19395	 1643.723179	 1643.723179	 1643.723179	 0.0	 0.0	 1	 -30.0	 30.0;
	6279	 389	 0.0009	 0.00865	 0.22769	 1805.085051	 1805.085051	 1805.085051	 0.0	 0.0	 1	 -30.0	 30.0;
	6279	 389	 0.00096	 0.01294	 0.24709	 1661.782961	 1661.782961	 1661.782961	 0.0	 0.0	 1	 -30.0	 30.0;
	6279	 389	 0.0004	 0.00756	 0.22925	 1723.418821	 1723.418821	 1723.418821	 0.0	 0.0	 1	 -30.0	 30.0;
	6279	 389	 0.00039	 0.00771	 0.22457	 1547.164984	 1547.164984	 1547.164984	 0.0	 0.0	 1	 -30.0	 30.0;
	6279	 7433	 0.00163	 0.02291	 0.74435	 1668.65567	 1668.65567	 1668.65567	 0.0	 0.0	 1	 -30.0	 30.0;
	2679	 2840	 0.00636	 0.03855	 0.08294	 502.920871	 502.920871	 502.920871	 0.0	 0.0	 1	 -30.0	 30.0;
	2679	 2840	 0.00639	 0.03863	 0.09182	 529.349056	 529.349056	 529.349056	 0.0	 0.0	 1	 -30.0	 30.0;
	864	 1580	 0.00113	 0.01362	 0.40548	 812.853419	 812.853419	 812.853419	 0.0	 0.0	 1	 -30.0	 30.0;
	1616	 4899	 0.00861	 0.05318	 0.09851	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	4247	 4449	 0.0012	 0.004669	 0.00851	 446.233411	 446.233411	 446.233411	 0.0	 0.0	 1	 -30.0	 30.0;
	4247	 6419	 0.00018	 0.001091	 0.00206	 522.229496	 522.229496	 522.229496	 0.0	 0.0	 1	 -30.0	 30.0;
	1121	 7290	 0.001401	 0.00612	 0.01045	 460.583798	 460.583798	 460.583798	 0.0	 0.0	 1	 -30.0	 30.0;
	102	 204	 0.00068	 0.00387	 0.00639	 591.707319	 591.707319	 591.707319	 0.0	 0.0	 1	 -30.0	 30.0;
	5193	 7778	 0.0043	 0.033591	 0.04822	 530.276154	 530.276154	 530.276154	 0.0	 0.0	 1	 -30.0	 30.0;
	3256	 4962	 0.003039	 0.01911	 0.03488	 608.944169	 608.944169	 608.944169	 0.0	 0.0	 1	 -30.0	 30.0;
	2952	 110	 6e-05	 0.00111	 0.0041	 955.335694	 955.335694	 955.335694	 0.0	 0.0	 1	 -30.0	 30.0;
	8027	 4349	 5e-05	 0.001091	 0.00348	 956.475418	 956.475418	 956.475418	 0.0	 0.0	 1	 -30.0	 30.0;
	2174	 3002	 3.9e-05	 0.00089	 0.00261	 956.550866	 956.550866	 956.550866	 0.0	 0.0	 1	 -30.0	 30.0;
	1733	 4076	 3.9e-05	 0.000901	 0.00273	 956.641937	 956.641937	 956.641937	 0.0	 0.0	 1	 -30.0	 30.0;
	614	 4056	 0.000169	 0.00111	 0.00178	 610.364728	 610.364728	 610.364728	 0.0	 0.0	 1	 -30.0	 30.0;
	911	 4415	 0.000331	 0.0027	 0.01232	 271.829335	 271.829335	 271.829335	 0.0	 0.0	 1	 -30.0	 30.0;
	5831	 1836	 0.00026	 0.00369	 0.00651	 364.071537	 364.071537	 364.071537	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 6419	 0.000341	 0.00274	 0.00445	 266.040787	 266.040787	 266.040787	 0.0	 0.0	 1	 -30.0	 30.0;
	4853	 6793	 0.00038	 0.00506	 0.00854	 529.962548	 529.962548	 529.962548	 0.0	 0.0	 1	 -30.0	 30.0;
	2321	 5915	 0.00012	 0.000831	 0.0014	 494.08658	 494.08658	 494.08658	 0.0	 0.0	 1	 -30.0	 30.0;
	1014	 538	 0.003031	 0.0123	 0.02196	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 7066	 0.001521	 0.00774	 0.01069	 510.246961	 510.246961	 510.246961	 0.0	 0.0	 1	 -30.0	 30.0;
	3558	 2748	 0.00059	 0.00552	 0.15248	 1743.310316	 1743.310316	 1743.310316	 0.0	 0.0	 1	 -30.0	 30.0;
	3558	 1086	 0.00053	 0.00625	 0.13585	 1664.785575	 1664.785575	 1664.785575	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 7987	 0.00143	 0.01076	 0.01672	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	1646	 7693	 0.00056	 0.00593	 0.13551	 2151.295923	 2151.295923	 2151.295923	 0.0	 0.0	 1	 -30.0	 30.0;
	2237	 6510	 0.00205	 0.01461	 0.02277	 520.681666	 520.681666	 520.681666	 0.0	 0.0	 1	 -30.0	 30.0;
	1944	 2093	 0.01068	 0.054521	 0.07806	 252.776014	 252.776014	 252.776014	 0.0	 0.0	 1	 -30.0	 30.0;
	8166	 7673	 0.00194	 0.011039	 0.02196	 540.488325	 540.488325	 540.488325	 0.0	 0.0	 1	 -30.0	 30.0;
	8166	 6242	 0.00131	 0.010099	 0.01568	 542.276598	 542.276598	 542.276598	 0.0	 0.0	 1	 -30.0	 30.0;
	8166	 2723	 0.001289	 0.014229	 0.02761	 423.655367	 423.655367	 423.655367	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 2929	 0.00455	 0.027031	 0.06482	 501.735039	 501.735039	 501.735039	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 3021	 0.00239	 0.01414	 0.02614	 615.617518	 615.617518	 615.617518	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 7533	 0.004039	 0.029669	 0.0446	 592.903058	 592.903058	 592.903058	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 1904	 0.001099	 0.007771	 0.01233	 640.002126	 640.002126	 640.002126	 0.0	 0.0	 1	 -30.0	 30.0;
	4888	 1845	 0.00082	 0.00762	 0.06097	 516.058372	 516.058372	 516.058372	 0.0	 0.0	 1	 -30.0	 30.0;
	4888	 3744	 0.000719	 0.0033	 0.00474	 286.100464	 286.100464	 286.100464	 0.0	 0.0	 1	 -30.0	 30.0;
	4888	 5010	 0.000599	 0.00361	 0.00705	 401.781124	 401.781124	 401.781124	 0.0	 0.0	 1	 -30.0	 30.0;
	4888	 7519	 0.000521	 0.004039	 0.00624	 490.626635	 490.626635	 490.626635	 0.0	 0.0	 1	 -30.0	 30.0;
	4888	 3121	 0.000901	 0.0088	 0.02818	 552.409511	 552.409511	 552.409511	 0.0	 0.0	 1	 -30.0	 30.0;
	6808	 6338	 0.000781	 0.00306	 0.00513	 261.407967	 261.407967	 261.407967	 0.0	 0.0	 1	 -30.0	 30.0;
	6808	 2184	 0.000419	 0.00399	 0.00888	 275.677571	 275.677571	 275.677571	 0.0	 0.0	 1	 -30.0	 30.0;
	6808	 1844	 0.000841	 0.009841	 0.02547	 384.409763	 384.409763	 384.409763	 0.0	 0.0	 1	 -30.0	 30.0;
	5876	 5575	 0.004021	 0.03064	 0.0474	 515.323705	 515.323705	 515.323705	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 2443	 0.0023	 0.009031	 0.01045	 440.854493	 440.854493	 440.854493	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 2443	 0.002081	 0.009469	 0.02114	 492.750234	 492.750234	 492.750234	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 4993	 0.00164	 0.008831	 0.01157	 374.944451	 374.944451	 374.944451	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 8058	 0.00094	 0.00488	 0.00697	 430.17782	 430.17782	 430.17782	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 8274	 0.000901	 0.00551	 0.01007	 564.77767	 564.77767	 564.77767	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 1049	 0.00051	 0.005961	 0.01547	 227.473073	 227.473073	 227.473073	 0.0	 0.0	 1	 -30.0	 30.0;
	1836	 1599	 0.00113	 0.004349	 0.00851	 542.544477	 542.544477	 542.544477	 0.0	 0.0	 1	 -30.0	 30.0;
	1344	 6001	 0.002081	 0.013031	 0.02315	 510.63449	 510.63449	 510.63449	 0.0	 0.0	 1	 -30.0	 30.0;
	734	 4180	 0.00116	 0.01438	 0.34466	 2143.712381	 2143.712381	 2143.712381	 0.0	 0.0	 1	 -30.0	 30.0;
	7851	 4300	 0.00013	 0.001031	 0.00175	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3732	 557	 0.00036	 0.002659	 0.00372	 519.373898	 519.373898	 519.373898	 0.0	 0.0	 1	 -30.0	 30.0;
	3699	 4898	 0.000771	 0.004539	 0.0213	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	2995	 3715	 0.011902	 0.04088	 0.01812	 130.951615	 130.951615	 130.951615	 0.0	 0.0	 1	 -30.0	 30.0;
	156	 2995	 0.002231	 0.010138	 0.00339	 153.817283	 153.817283	 153.817283	 0.0	 0.0	 1	 -30.0	 30.0;
	1040	 146	 0.00023	 0.0025	 0.05403	 1465.149261	 1465.149261	 1465.149261	 0.0	 0.0	 1	 -30.0	 30.0;
	1040	 146	 0.00023	 0.00254	 0.0529	 1304.930646	 1304.930646	 1304.930646	 0.0	 0.0	 1	 -30.0	 30.0;
	4534	 1040	 0.00179	 0.01478	 0.40555	 1440.152269	 1440.152269	 1440.152269	 0.0	 0.0	 1	 -30.0	 30.0;
	4534	 1040	 0.00183	 0.01446	 0.41306	 1318.221919	 1318.221919	 1318.221919	 0.0	 0.0	 1	 -30.0	 30.0;
	1040	 1397	 0.00031	 0.00312	 0.07001	 1216.893241	 1216.893241	 1216.893241	 0.0	 0.0	 1	 -30.0	 30.0;
	965	 1040	 0.00031	 0.00289	 0.07025	 1423.149523	 1423.149523	 1423.149523	 0.0	 0.0	 1	 -30.0	 30.0;
	826	 1040	 0.00021	 0.00194	 0.0473	 1233.781463	 1233.781463	 1233.781463	 0.0	 0.0	 1	 -30.0	 30.0;
	5965	 6916	 0.001489	 0.006249	 0.00226	 145.836253	 145.836253	 145.836253	 0.0	 0.0	 1	 -30.0	 30.0;
	7022	 6916	 0.010209	 0.042502	 0.01453	 139.322616	 139.322616	 139.322616	 0.0	 0.0	 1	 -30.0	 30.0;
	5965	 2163	 0.001462	 0.006369	 0.00222	 105.302627	 105.302627	 105.302627	 0.0	 0.0	 1	 -30.0	 30.0;
	2163	 8020	 0.0048	 0.01772	 0.00684	 106.55386	 106.55386	 106.55386	 0.0	 0.0	 1	 -30.0	 30.0;
	5965	 5225	 0.00328	 0.01472	 0.005	 228.07212	 228.07212	 228.07212	 0.0	 0.0	 1	 -30.0	 30.0;
	416	 5965	 0.0	 0.000271	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8020	 5965	 0.002031	 0.007591	 0.2538	 145.824562	 145.824562	 145.824562	 0.0	 0.0	 1	 -30.0	 30.0;
	3766	 6264	 0.00372	 0.014431	 0.00567	 224.7232	 224.7232	 224.7232	 0.0	 0.0	 1	 -30.0	 30.0;
	3503	 3766	 0.0	 0.000271	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3766	 4156	 0.00108	 0.003698	 0.00164	 147.684525	 147.684525	 147.684525	 0.0	 0.0	 1	 -30.0	 30.0;
	3766	 8180	 0.000431	 0.001658	 0.02671	 127.290925	 127.290925	 127.290925	 0.0	 0.0	 1	 -30.0	 30.0;
	6264	 2953	 0.000782	 0.002662	 0.08238	 211.722167	 211.722167	 211.722167	 0.0	 0.0	 1	 -30.0	 30.0;
	5225	 568	 0.001729	 0.005498	 0.18189	 171.295062	 171.295062	 171.295062	 0.0	 0.0	 1	 -30.0	 30.0;
	7222	 1765	 0.00221	 0.01891	 0.49862	 1128.918362	 1128.918362	 1128.918362	 0.0	 0.0	 1	 -30.0	 30.0;
	7406	 1765	 0.00335	 0.03107	 0.75602	 1105.40359	 1105.40359	 1105.40359	 0.0	 0.0	 1	 -30.0	 30.0;
	1765	 392	 0.00109	 0.01324	 0.44736	 1807.502543	 1807.502543	 1807.502543	 0.0	 0.0	 1	 -30.0	 30.0;
	3133	 2606	 0.027218	 0.118858	 0.04142	 105.90668	 105.90668	 105.90668	 0.0	 0.0	 1	 -30.0	 30.0;
	5766	 3133	 0.002782	 0.010778	 0.00423	 124.09763	 124.09763	 124.09763	 0.0	 0.0	 1	 -30.0	 30.0;
	3133	 2334	 0.03336	 0.110049	 0.05079	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3133	 2334	 0.02972	 0.124729	 0.04525	 130.277154	 130.277154	 130.277154	 0.0	 0.0	 1	 -30.0	 30.0;
	3133	 3322	 0.00244	 0.009351	 0.00347	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3133	 3322	 0.002151	 0.009649	 0.00328	 138.266498	 138.266498	 138.266498	 0.0	 0.0	 1	 -30.0	 30.0;
	3133	 3322	 0.00244	 0.009458	 0.00372	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 5271	 0.017102	 0.080911	 0.02603	 129.048004	 129.048004	 129.048004	 0.0	 0.0	 1	 -30.0	 30.0;
	2223	 5847	 0.030871	 0.129529	 0.04698	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 1718	 0.008778	 0.041551	 0.01337	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 1718	 0.008591	 0.038471	 0.01308	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 1718	 0.01032	 0.038049	 0.01468	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 631	 0.004151	 0.017409	 0.00632	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 631	 0.004062	 0.017751	 0.00619	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2569	 5552	 0.000338	 0.00156	 0.00047	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7752	 5552	 0.002689	 0.010018	 0.0041	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5552	 3940	 0.020471	 0.070289	 0.03116	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3639	 2672	 4e-05	 0.000271	 7e-05	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7739	 3639	 0.023289	 0.097751	 0.03546	 118.391475	 118.391475	 118.391475	 0.0	 0.0	 1	 -30.0	 30.0;
	4879	 2672	 0.005969	 0.02292	 0.00849	 104.944872	 104.944872	 104.944872	 0.0	 0.0	 1	 -30.0	 30.0;
	138	 2672	 0.00428	 0.019138	 0.0065	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1766	 7752	 0.01588	 0.054529	 0.02417	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5739	 3878	 0.0	 0.000271	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3878	 2819	 0.00368	 0.007311	 0.00262	 130.122828	 130.122828	 130.122828	 0.0	 0.0	 1	 -30.0	 30.0;
	6421	 3878	 0.006369	 0.0324	 0.00907	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	923	 3878	 0.000791	 0.003569	 0.00119	 111.03762	 111.03762	 111.03762	 0.0	 0.0	 1	 -30.0	 30.0;
	3802	 3878	 0.000809	 0.003431	 0.00124	 125.219479	 125.219479	 125.219479	 0.0	 0.0	 1	 -30.0	 30.0;
	2819	 5366	 0.008871	 0.004431	 0.07735	 252.567043	 252.567043	 252.567043	 0.0	 0.0	 1	 -30.0	 30.0;
	8301	 6417	 0.0	 0.000271	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6076	 3144	 0.0	 0.000271	 0.0	 155.063581	 155.063581	 155.063581	 0.0	 0.0	 1	 -30.0	 30.0;
	7051	 3426	 0.0	 0.000271	 0.0	 107.487349	 107.487349	 107.487349	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 138	 0.0	 0.000271	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	567	 4071	 0.0	 0.000271	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	883	 7173	 0.0	 0.000271	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7932	 4072	 0.00096	 0.003391	 0.09439	 129.49877	 129.49877	 129.49877	 0.0	 0.0	 1	 -30.0	 30.0;
	1777	 4072	 0.0	 0.000271	 0.0	 106.472021	 106.472021	 106.472021	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 5808	 0.004471	 0.021831	 0.00635	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 3163	 0.00624	 0.03	 0.00887	 136.333789	 136.333789	 136.333789	 0.0	 0.0	 1	 -30.0	 30.0;
	3015	 2210	 0.0008	 0.0038	 0.00122	 140.23532	 140.23532	 140.23532	 0.0	 0.0	 1	 -30.0	 30.0;
	156	 3015	 0.010058	 0.035969	 0.01532	 142.253766	 142.253766	 142.253766	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 2210	 0.000782	 0.00352	 0.0012	 118.142839	 118.142839	 118.142839	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 8088	 0.008471	 0.040089	 0.01289	 137.884841	 137.884841	 137.884841	 0.0	 0.0	 1	 -30.0	 30.0;
	7038	 5337	 0.00038	 0.00312	 0.08549	 1467.887286	 1467.887286	 1467.887286	 0.0	 0.0	 1	 -30.0	 30.0;
	7038	 5337	 0.00038	 0.00305	 0.08708	 1215.640725	 1215.640725	 1215.640725	 0.0	 0.0	 1	 -30.0	 30.0;
	547	 7038	 0.00255	 0.02375	 0.57789	 1360.475715	 1360.475715	 1360.475715	 0.0	 0.0	 1	 -30.0	 30.0;
	547	 7038	 0.0026	 0.02326	 0.58922	 1528.514815	 1528.514815	 1528.514815	 0.0	 0.0	 1	 -30.0	 30.0;
	7038	 5512	 0.00268	 0.03039	 0.60533	 1353.050794	 1353.050794	 1353.050794	 0.0	 0.0	 1	 -30.0	 30.0;
	7038	 5512	 0.00262	 0.02814	 0.59217	 1216.088945	 1216.088945	 1216.088945	 0.0	 0.0	 1	 -30.0	 30.0;
	2471	 7418	 0.000258	 0.000929	 0.06197	 112.059704	 112.059704	 112.059704	 0.0	 0.0	 1	 -30.0	 30.0;
	2879	 7418	 0.003049	 0.013911	 0.00465	 142.987722	 142.987722	 142.987722	 0.0	 0.0	 1	 -30.0	 30.0;
	2471	 5235	 0.000258	 0.000911	 0.06312	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7139	 5235	 0.000871	 0.003991	 0.00133	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5025	 3003	 0.024218	 0.1016	 0.03686	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 6237	 0.0	 0.000271	 0.0	 139.750519	 139.750519	 139.750519	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 4118	 0.0	 0.000222	 0.0	 136.960186	 136.960186	 136.960186	 0.0	 0.0	 1	 -30.0	 30.0;
	5025	 1937	 0.02372	 0.103591	 0.03611	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 6378	 0.0	 0.000271	 0.0	 135.708432	 135.708432	 135.708432	 0.0	 0.0	 1	 -30.0	 30.0;
	6901	 4118	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	146	 2283	 0.00038	 0.00396	 0.08553	 906.352396	 906.352396	 906.352396	 0.0	 0.0	 1	 -30.0	 30.0;
	146	 2283	 0.00038	 0.00404	 0.08375	 930.120567	 930.120567	 930.120567	 0.0	 0.0	 1	 -30.0	 30.0;
	146	 2283	 0.00042	 0.0036	 0.09515	 1011.249723	 1011.249723	 1011.249723	 0.0	 0.0	 1	 -30.0	 30.0;
	146	 2283	 0.00043	 0.00352	 0.09694	 977.12905	 977.12905	 977.12905	 0.0	 0.0	 1	 -30.0	 30.0;
	4534	 146	 0.00177	 0.01845	 0.39814	 1396.948721	 1396.948721	 1396.948721	 0.0	 0.0	 1	 -30.0	 30.0;
	7173	 8084	 0.007831	 0.035089	 0.01192	 133.396924	 133.396924	 133.396924	 0.0	 0.0	 1	 -30.0	 30.0;
	7173	 6654	 0.002089	 0.007182	 0.00319	 270.014683	 270.014683	 270.014683	 0.0	 0.0	 1	 -30.0	 30.0;
	4672	 8084	 0.008871	 0.034391	 0.01351	 248.201495	 248.201495	 248.201495	 0.0	 0.0	 1	 -30.0	 30.0;
	4672	 4416	 0.002129	 0.007031	 0.00325	 167.103066	 167.103066	 167.103066	 0.0	 0.0	 1	 -30.0	 30.0;
	6802	 4672	 0.007222	 0.032831	 0.01099	 229.769703	 229.769703	 229.769703	 0.0	 0.0	 1	 -30.0	 30.0;
	4672	 6978	 0.006049	 0.021431	 0.0086	 105.780673	 105.780673	 105.780673	 0.0	 0.0	 1	 -30.0	 30.0;
	2568	 7932	 0.0114	 0.005622	 0.41898	 143.162053	 143.162053	 143.162053	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 2295	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2295	 8081	 0.00976	 0.043991	 0.01389	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3327	 1254	 0.017658	 0.0684	 0.02688	 156.751551	 156.751551	 156.751551	 0.0	 0.0	 1	 -30.0	 30.0;
	3327	 1254	 0.018	 0.067	 0.0274	 159.080466	 159.080466	 159.080466	 0.0	 0.0	 1	 -30.0	 30.0;
	1254	 7035	 0.003378	 0.009631	 0.00241	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1254	 4787	 0.016409	 0.07168	 0.02498	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1254	 1247	 0.0182	 0.04612	 0.013	 210.810502	 210.810502	 210.810502	 0.0	 0.0	 1	 -30.0	 30.0;
	1254	 2827	 0.004818	 0.017231	 0.00734	 144.936539	 144.936539	 144.936539	 0.0	 0.0	 1	 -30.0	 30.0;
	6784	 4987	 0.000209	 0.000911	 0.00032	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6784	 2424	 0.000249	 0.000831	 0.00039	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7834	 4529	 0.00136	 0.006458	 0.00208	 115.181552	 115.181552	 115.181552	 0.0	 0.0	 1	 -30.0	 30.0;
	4529	 4347	 0.002782	 0.013129	 0.00422	 112.48293	 112.48293	 112.48293	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 1662	 0.008049	 0.036031	 0.01224	 133.674658	 133.674658	 133.674658	 0.0	 0.0	 1	 -30.0	 30.0;
	1662	 2415	 0.022311	 0.0864	 0.03396	 126.189341	 126.189341	 126.189341	 0.0	 0.0	 1	 -30.0	 30.0;
	607	 1384	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 1384	 0.00912	 0.035311	 0.01387	 173.035513	 173.035513	 173.035513	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 1100	 0.001471	 0.005489	 0.00225	 136.189856	 136.189856	 136.189856	 0.0	 0.0	 1	 -30.0	 30.0;
	6552	 7837	 0.00058	 0.00639	 0.13256	 1083.949577	 1083.949577	 1083.949577	 0.0	 0.0	 1	 -30.0	 30.0;
	6552	 7837	 0.00057	 0.00651	 0.12974	 997.006065	 997.006065	 997.006065	 0.0	 0.0	 1	 -30.0	 30.0;
	4666	 3637	 0.002111	 0.007542	 0.00321	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1095	 3637	 0.014049	 0.037031	 0.01003	 126.033976	 126.033976	 126.033976	 0.0	 0.0	 1	 -30.0	 30.0;
	235	 2471	 0.0	 0.000222	 0.0	 147.589955	 147.589955	 147.589955	 0.0	 0.0	 1	 -30.0	 30.0;
	235	 6150	 0.002071	 0.005609	 0.25839	 164.723748	 164.723748	 164.723748	 0.0	 0.0	 1	 -30.0	 30.0;
	1796	 235	 0.00368	 0.016711	 0.00559	 189.962759	 189.962759	 189.962759	 0.0	 0.0	 1	 -30.0	 30.0;
	1796	 235	 0.0036	 0.017018	 0.00547	 150.870026	 150.870026	 150.870026	 0.0	 0.0	 1	 -30.0	 30.0;
	235	 7353	 0.00012	 0.000431	 0.02737	 258.105362	 258.105362	 258.105362	 0.0	 0.0	 1	 -30.0	 30.0;
	2471	 6696	 0.00012	 0.000431	 0.02789	 124.744811	 124.744811	 124.744811	 0.0	 0.0	 1	 -30.0	 30.0;
	6417	 5366	 0.01328	 0.031071	 0.00949	 249.134984	 249.134984	 249.134984	 0.0	 0.0	 1	 -30.0	 30.0;
	7646	 6417	 0.031911	 0.071711	 0.0228	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5639	 3144	 0.000382	 0.001289	 0.04004	 205.183329	 205.183329	 205.183329	 0.0	 0.0	 1	 -30.0	 30.0;
	1796	 5639	 0.002582	 0.00988	 0.00366	 193.979125	 193.979125	 193.979125	 0.0	 0.0	 1	 -30.0	 30.0;
	2353	 3426	 0.00036	 0.001218	 0.03799	 208.528352	 208.528352	 208.528352	 0.0	 0.0	 1	 -30.0	 30.0;
	4176	 2353	 0.002458	 0.00908	 0.0035	 195.74088	 195.74088	 195.74088	 0.0	 0.0	 1	 -30.0	 30.0;
	6285	 5538	 0.000911	 0.003271	 0.00139	 117.091917	 117.091917	 117.091917	 0.0	 0.0	 1	 -30.0	 30.0;
	156	 6285	 0.01436	 0.05344	 0.02186	 110.327826	 110.327826	 110.327826	 0.0	 0.0	 1	 -30.0	 30.0;
	141	 6017	 0.000462	 0.001631	 0.0007	 127.251694	 127.251694	 127.251694	 0.0	 0.0	 1	 -30.0	 30.0;
	141	 5538	 0.000929	 0.0032	 0.00141	 110.290673	 110.290673	 110.290673	 0.0	 0.0	 1	 -30.0	 30.0;
	8243	 6017	 0.0	 0.000222	 0.0	 148.535135	 148.535135	 148.535135	 0.0	 0.0	 1	 -30.0	 30.0;
	5162	 6017	 0.013391	 0.060849	 0.02037	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	138	 4560	 0.010631	 0.048342	 0.01619	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5271	 3008	 0.005498	 0.021302	 0.00837	 132.775464	 132.775464	 132.775464	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 1356	 0.001449	 0.006329	 0.00221	 117.441359	 117.441359	 117.441359	 0.0	 0.0	 1	 -30.0	 30.0;
	760	 8090	 0.007951	 0.029329	 0.01131	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	760	 1718	 0.02072	 0.086938	 0.03154	 118.26365	 118.26365	 118.26365	 0.0	 0.0	 1	 -30.0	 30.0;
	211	 760	 0.007182	 0.02672	 0.01093	 125.222337	 125.222337	 125.222337	 0.0	 0.0	 1	 -30.0	 30.0;
	6569	 2151	 0.00424	 0.019129	 0.00604	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2606	 6569	 0.010542	 0.047938	 0.01606	 145.965378	 145.965378	 145.965378	 0.0	 0.0	 1	 -30.0	 30.0;
	6569	 3322	 0.016751	 0.06488	 0.0255	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4071	 3258	 0.016671	 0.059071	 0.02372	 148.346774	 148.346774	 148.346774	 0.0	 0.0	 1	 -30.0	 30.0;
	4071	 5647	 0.00536	 0.024151	 0.00762	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5114	 2606	 0.0	 0.000222	 0.0	 124.581132	 124.581132	 124.581132	 0.0	 0.0	 1	 -30.0	 30.0;
	2606	 4818	 0.007089	 0.017938	 0.00506	 270.094704	 270.094704	 270.094704	 0.0	 0.0	 1	 -30.0	 30.0;
	5087	 2606	 0.020849	 0.052831	 0.0149	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5224	 4818	 0.010609	 0.005209	 0.09247	 255.170055	 255.170055	 255.170055	 0.0	 0.0	 1	 -30.0	 30.0;
	2225	 4675	 0.020898	 0.098071	 0.02974	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5906	 4675	 0.002258	 0.008409	 0.00344	 127.162061	 127.162061	 127.162061	 0.0	 0.0	 1	 -30.0	 30.0;
	379	 5732	 0.00056	 0.00236	 0.00085	 111.008522	 111.008522	 111.008522	 0.0	 0.0	 1	 -30.0	 30.0;
	5732	 923	 0.014258	 0.064311	 0.0203	 111.03762	 111.03762	 111.03762	 0.0	 0.0	 1	 -30.0	 30.0;
	7938	 1814	 0.0	 0.000222	 0.0	 122.874456	 122.874456	 122.874456	 0.0	 0.0	 1	 -30.0	 30.0;
	6026	 1814	 0.040249	 0.143902	 0.06127	 133.017865	 133.017865	 133.017865	 0.0	 0.0	 1	 -30.0	 30.0;
	7925	 1814	 0.021778	 0.071862	 0.03316	 164.73362	 164.73362	 164.73362	 0.0	 0.0	 1	 -30.0	 30.0;
	1814	 3486	 0.022742	 0.09932	 0.03462	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4785	 1814	 0.021511	 0.07092	 0.03272	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 3875	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3875	 8044	 0.010818	 0.0454	 0.01646	 118.102569	 118.102569	 118.102569	 0.0	 0.0	 1	 -30.0	 30.0;
	2084	 3875	 0.013671	 0.059698	 0.0208	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5450	 7080	 0.00011	 0.00059	 0.92171	 1006.144885	 1006.144885	 1006.144885	 0.0	 0.0	 1	 -30.0	 30.0;
	1634	 7080	 0.00093	 0.00993	 0.20878	 1444.785193	 1444.785193	 1444.785193	 0.0	 0.0	 1	 -30.0	 30.0;
	1881	 5450	 0.00037	 0.00305	 0.08352	 1491.500785	 1491.500785	 1491.500785	 0.0	 0.0	 1	 -30.0	 30.0;
	2548	 915	 0.0001	 0.00066	 0.82116	 1163.863734	 1163.863734	 1163.863734	 0.0	 0.0	 1	 -30.0	 30.0;
	1634	 2548	 0.00105	 0.00973	 0.23662	 1411.432615	 1411.432615	 1411.432615	 0.0	 0.0	 1	 -30.0	 30.0;
	915	 1504	 0.00037	 0.00298	 0.08506	 1618.608373	 1618.608373	 1618.608373	 0.0	 0.0	 1	 -30.0	 30.0;
	1881	 4534	 0.00105	 0.01196	 0.23808	 1487.032406	 1487.032406	 1487.032406	 0.0	 0.0	 1	 -30.0	 30.0;
	1504	 146	 0.00073	 0.00626	 0.16502	 1543.968207	 1543.968207	 1543.968207	 0.0	 0.0	 1	 -30.0	 30.0;
	3531	 6983	 0.00112	 0.002329	 0.0008	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3531	 8307	 0.0068	 0.032178	 0.01035	 225.030812	 225.030812	 225.030812	 0.0	 0.0	 1	 -30.0	 30.0;
	5048	 3531	 0.013871	 0.06308	 0.02112	 171.328317	 171.328317	 171.328317	 0.0	 0.0	 1	 -30.0	 30.0;
	5927	 3835	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3541	 3835	 0.00636	 0.028689	 0.00906	 130.203369	 130.203369	 130.203369	 0.0	 0.0	 1	 -30.0	 30.0;
	4744	 3835	 0.005231	 0.020942	 0.00745	 109.818863	 109.818863	 109.818863	 0.0	 0.0	 1	 -30.0	 30.0;
	4057	 3835	 0.019129	 0.063111	 0.02912	 210.887665	 210.887665	 210.887665	 0.0	 0.0	 1	 -30.0	 30.0;
	3835	 2820	 0.006649	 0.0298	 0.01013	 182.355332	 182.355332	 182.355332	 0.0	 0.0	 1	 -30.0	 30.0;
	6983	 5176	 0.0006	 0.001609	 0.00042	 268.363866	 268.363866	 268.363866	 0.0	 0.0	 1	 -30.0	 30.0;
	98	 379	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7472	 379	 0.014849	 0.066942	 0.02113	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7800	 5518	 0.00392	 0.009182	 0.0001	 244.150575	 244.150575	 244.150575	 0.0	 0.0	 1	 -30.0	 30.0;
	5518	 3368	 0.0	 0.00028	 0.0	 111.302624	 111.302624	 111.302624	 0.0	 0.0	 1	 -30.0	 30.0;
	5518	 273	 0.0	 0.00028	 0.0	 145.505778	 145.505778	 145.505778	 0.0	 0.0	 1	 -30.0	 30.0;
	5518	 5383	 0.0	 0.00028	 0.0	 136.560601	 136.560601	 136.560601	 0.0	 0.0	 1	 -30.0	 30.0;
	2300	 5586	 0.00384	 0.00936	 0.0001	 256.929213	 256.929213	 256.929213	 0.0	 0.0	 1	 -30.0	 30.0;
	5586	 6423	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5586	 5904	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5586	 1440	 0.0	 0.00028	 0.0	 110.400572	 110.400572	 110.400572	 0.0	 0.0	 1	 -30.0	 30.0;
	2300	 7800	 0.0	 0.000222	 0.0	 145.39484	 145.39484	 145.39484	 0.0	 0.0	 1	 -30.0	 30.0;
	3368	 6698	 0.02008	 0.09128	 0.03056	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3704	 6423	 0.023991	 0.092942	 0.03653	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5210	 273	 0.01384	 0.06552	 0.02108	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	329	 5904	 0.00476	 0.022538	 0.00725	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 2288	 0.00496	 0.016382	 0.00756	 146.44758	 146.44758	 146.44758	 0.0	 0.0	 1	 -30.0	 30.0;
	1440	 7017	 0.00244	 0.008049	 0.00372	 112.170641	 112.170641	 112.170641	 0.0	 0.0	 1	 -30.0	 30.0;
	8133	 508	 0.000671	 0.002502	 0.00103	 111.160509	 111.160509	 111.160509	 0.0	 0.0	 1	 -30.0	 30.0;
	508	 4575	 0.0066	 0.029569	 0.01005	 110.946688	 110.946688	 110.946688	 0.0	 0.0	 1	 -30.0	 30.0;
	8133	 6680	 0.000689	 0.002449	 0.00105	 166.986672	 166.986672	 166.986672	 0.0	 0.0	 1	 -30.0	 30.0;
	84	 6680	 0.007271	 0.024969	 0.01107	 149.701411	 149.701411	 149.701411	 0.0	 0.0	 1	 -30.0	 30.0;
	789	 8133	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3541	 2931	 0.007649	 0.031849	 0.01089	 164.852872	 164.852872	 164.852872	 0.0	 0.0	 1	 -30.0	 30.0;
	6055	 5377	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6055	 6432	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	252	 6055	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 5377	 0.019471	 0.074818	 0.02772	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5611	 6432	 0.009231	 0.041622	 0.01314	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2486	 7723	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2022	 5766	 0.000258	 0.001089	 0.00037	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2022	 3278	 0.019871	 0.042889	 0.01419	 127.848472	 127.848472	 127.848472	 0.0	 0.0	 1	 -30.0	 30.0;
	3278	 7723	 0.00076	 0.001978	 0.0006	 263.609646	 263.609646	 263.609646	 0.0	 0.0	 1	 -30.0	 30.0;
	5496	 7723	 0.000751	 0.001831	 0.00059	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7175	 5496	 0.039151	 0.088	 0.02798	 226.763989	 226.763989	 226.763989	 0.0	 0.0	 1	 -30.0	 30.0;
	357	 5032	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5032	 2590	 0.032351	 0.141289	 0.04924	 123.451488	 123.451488	 123.451488	 0.0	 0.0	 1	 -30.0	 30.0;
	872	 5032	 0.022569	 0.074449	 0.03435	 109.708185	 109.708185	 109.708185	 0.0	 0.0	 1	 -30.0	 30.0;
	5032	 4867	 5.8e-05	 0.000222	 0.00011	 122.217922	 122.217922	 122.217922	 0.0	 0.0	 1	 -30.0	 30.0;
	6063	 8287	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1380	 8287	 0.009542	 0.031471	 0.01452	 125.944602	 125.944602	 125.944602	 0.0	 0.0	 1	 -30.0	 30.0;
	6349	 8287	 0.021671	 0.09856	 0.03299	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2802	 2121	 0.005609	 0.013978	 0.00439	 275.136271	 275.136271	 275.136271	 0.0	 0.0	 1	 -30.0	 30.0;
	7599	 2121	 0.003751	 0.01016	 0.00268	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7327	 3327	 0.000529	 0.00208	 0.00082	 123.286251	 123.286251	 123.286251	 0.0	 0.0	 1	 -30.0	 30.0;
	7327	 3709	 0.008862	 0.029231	 0.01349	 151.204138	 151.204138	 151.204138	 0.0	 0.0	 1	 -30.0	 30.0;
	863	 5556	 0.000538	 0.00204	 0.00083	 108.187271	 108.187271	 108.187271	 0.0	 0.0	 1	 -30.0	 30.0;
	863	 7450	 0.009569	 0.026289	 0.00684	 260.074703	 260.074703	 260.074703	 0.0	 0.0	 1	 -30.0	 30.0;
	3327	 3106	 0.00028	 0.001209	 0.00042	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1095	 3106	 0.005489	 0.014249	 0.0043	 125.633353	 125.633353	 125.633353	 0.0	 0.0	 1	 -30.0	 30.0;
	5556	 2802	 0.000271	 0.001231	 0.00041	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3327	 5236	 0.000338	 0.001311	 0.00052	 131.317424	 131.317424	 131.317424	 0.0	 0.0	 1	 -30.0	 30.0;
	5236	 5228	 0.005791	 0.02716	 0.00824	 146.481875	 146.481875	 146.481875	 0.0	 0.0	 1	 -30.0	 30.0;
	3958	 6552	 0.00288	 0.03132	 0.64931	 1268.180547	 1268.180547	 1268.180547	 0.0	 0.0	 1	 -30.0	 30.0;
	3958	 6552	 0.00282	 0.03191	 0.6355	 1245.530622	 1245.530622	 1245.530622	 0.0	 0.0	 1	 -30.0	 30.0;
	6552	 5337	 0.00111	 0.01111	 0.2496	 1341.82028	 1341.82028	 1341.82028	 0.0	 0.0	 1	 -30.0	 30.0;
	6552	 6114	 0.00108	 0.01133	 0.2445	 1322.548132	 1322.548132	 1322.548132	 0.0	 0.0	 1	 -30.0	 30.0;
	5556	 5771	 0.008751	 0.033911	 0.01332	 114.799115	 114.799115	 114.799115	 0.0	 0.0	 1	 -30.0	 30.0;
	5556	 267	 0.002418	 0.00936	 0.00368	 190.560057	 190.560057	 190.560057	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 4314	 0.0	 0.000222	 0.0	 129.276115	 129.276115	 129.276115	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 247	 0.00944	 0.044271	 0.01342	 140.564497	 140.564497	 140.564497	 0.0	 0.0	 1	 -30.0	 30.0;
	4314	 7278	 0.006542	 0.0272	 0.0093	 133.156862	 133.156862	 133.156862	 0.0	 0.0	 1	 -30.0	 30.0;
	3258	 2207	 0.001591	 0.005658	 0.00228	 136.694662	 136.694662	 136.694662	 0.0	 0.0	 1	 -30.0	 30.0;
	2334	 1011	 0.000711	 0.001822	 0.00055	 299.990767	 299.990767	 299.990767	 0.0	 0.0	 1	 -30.0	 30.0;
	1011	 4175	 0.010369	 0.021511	 0.00741	 302.506484	 302.506484	 302.506484	 0.0	 0.0	 1	 -30.0	 30.0;
	2334	 7175	 0.001978	 0.0068	 0.00301	 119.012415	 119.012415	 119.012415	 0.0	 0.0	 1	 -30.0	 30.0;
	485	 5456	 0.009062	 0.023902	 0.00647	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5456	 606	 0.0092	 0.025249	 0.00657	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7652	 819	 0.0022	 0.005942	 0.00157	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4487	 7652	 0.016169	 0.03352	 0.01155	 116.328343	 116.328343	 116.328343	 0.0	 0.0	 1	 -30.0	 30.0;
	4655	 606	 0.006902	 0.014898	 0.00493	 132.661668	 132.661668	 132.661668	 0.0	 0.0	 1	 -30.0	 30.0;
	4301	 4655	 0.018609	 0.041849	 0.0133	 114.748712	 114.748712	 114.748712	 0.0	 0.0	 1	 -30.0	 30.0;
	3234	 4470	 0.00156	 0.00696	 0.00237	 139.12828	 139.12828	 139.12828	 0.0	 0.0	 1	 -30.0	 30.0;
	4821	 3234	 0.01592	 0.07532	 0.02422	 126.479806	 126.479806	 126.479806	 0.0	 0.0	 1	 -30.0	 30.0;
	2240	 4470	 0.00176	 0.006822	 0.00268	 116.242087	 116.242087	 116.242087	 0.0	 0.0	 1	 -30.0	 30.0;
	2240	 7789	 0.015542	 0.069582	 0.02364	 106.931101	 106.931101	 106.931101	 0.0	 0.0	 1	 -30.0	 30.0;
	6639	 1486	 0.00176	 0.004631	 0.00126	 110.215849	 110.215849	 110.215849	 0.0	 0.0	 1	 -30.0	 30.0;
	1997	 1486	 0.02272	 0.061458	 0.01624	 273.862174	 273.862174	 273.862174	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 2553	 0.00348	 0.015809	 0.00529	 106.588934	 106.588934	 106.588934	 0.0	 0.0	 1	 -30.0	 30.0;
	7940	 2553	 0.013449	 0.056431	 0.02047	 106.530478	 106.530478	 106.530478	 0.0	 0.0	 1	 -30.0	 30.0;
	4448	 1161	 0.002911	 0.01272	 0.00444	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 1161	 0.0034	 0.016102	 0.00518	 114.140503	 114.140503	 114.140503	 0.0	 0.0	 1	 -30.0	 30.0;
	5970	 4448	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4448	 8145	 0.030151	 0.079538	 0.02154	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4821	 4448	 0.017769	 0.063511	 0.02704	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4448	 3726	 0.031249	 0.084538	 0.02233	 106.936297	 106.936297	 106.936297	 0.0	 0.0	 1	 -30.0	 30.0;
	7872	 5682	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 4121	 0.013698	 0.047049	 0.02085	 129.409397	 129.409397	 129.409397	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 4121	 0.01396	 0.046031	 0.02124	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7397	 5682	 0.007938	 0.037569	 0.01209	 144.953167	 144.953167	 144.953167	 0.0	 0.0	 1	 -30.0	 30.0;
	7940	 5682	 0.016751	 0.070271	 0.02549	 116.743515	 116.743515	 116.743515	 0.0	 0.0	 1	 -30.0	 30.0;
	6639	 5594	 0.00172	 0.00472	 0.00123	 121.65284	 121.65284	 121.65284	 0.0	 0.0	 1	 -30.0	 30.0;
	5594	 3094	 0.007271	 0.015689	 0.00519	 117.280278	 117.280278	 117.280278	 0.0	 0.0	 1	 -30.0	 30.0;
	473	 2344	 0.001471	 0.004	 0.18414	 111.603741	 111.603741	 111.603741	 0.0	 0.0	 1	 -30.0	 30.0;
	473	 2675	 0.001991	 0.007729	 0.2484	 113.244686	 113.244686	 113.244686	 0.0	 0.0	 1	 -30.0	 30.0;
	7560	 473	 0.003151	 0.047689	 0.03121	 133.01085	 133.01085	 133.01085	 0.0	 0.0	 1	 -30.0	 30.0;
	473	 322	 0.000809	 0.002769	 0.10055	 110.41694	 110.41694	 110.41694	 0.0	 0.0	 1	 -30.0	 30.0;
	7600	 473	 0.002009	 0.020209	 0.01103	 145.093203	 145.093203	 145.093203	 0.0	 0.0	 1	 -30.0	 30.0;
	3828	 5787	 0.0	 0.00028	 0.0	 140.888477	 140.888477	 140.888477	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 7927	 0.001	 0.002831	 0.12539	 191.006146	 191.006146	 191.006146	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 7315	 0.001502	 0.005169	 0.18744	 246.562629	 246.562629	 246.562629	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 5787	 0.001969	 0.0206	 0.0108	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	6929	 4744	 0.000151	 0.000649	 0.00022	 107.989038	 107.989038	 107.989038	 0.0	 0.0	 1	 -30.0	 30.0;
	6929	 3263	 0.000142	 0.000662	 0.00022	 132.305732	 132.305732	 132.305732	 0.0	 0.0	 1	 -30.0	 30.0;
	2159	 3263	 0.004409	 0.01628	 0.00627	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6067	 6089	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8293	 6843	 0.0	 0.000222	 0.0	 134.244157	 134.244157	 134.244157	 0.0	 0.0	 1	 -30.0	 30.0;
	6089	 8014	 0.00028	 0.000791	 0.03499	 135.840675	 135.840675	 135.840675	 0.0	 0.0	 1	 -30.0	 30.0;
	5120	 6843	 0.000622	 0.001671	 0.07722	 137.570733	 137.570733	 137.570733	 0.0	 0.0	 1	 -30.0	 30.0;
	3975	 660	 0.000471	 0.0016	 0.00071	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3929	 660	 0.013889	 0.065751	 0.02115	 106.24365	 106.24365	 106.24365	 0.0	 0.0	 1	 -30.0	 30.0;
	3975	 2924	 0.000471	 0.00156	 0.00073	 127.359515	 127.359515	 127.359515	 0.0	 0.0	 1	 -30.0	 30.0;
	4121	 2924	 0.018262	 0.082978	 0.02778	 123.720389	 123.720389	 123.720389	 0.0	 0.0	 1	 -30.0	 30.0;
	1100	 2415	 0.02168	 0.077489	 0.03299	 126.614906	 126.614906	 126.614906	 0.0	 0.0	 1	 -30.0	 30.0;
	7225	 5025	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5025	 7215	 0.000538	 0.001902	 0.00076	 142.405234	 142.405234	 142.405234	 0.0	 0.0	 1	 -30.0	 30.0;
	2879	 5025	 0.004578	 0.017031	 0.00697	 110.573604	 110.573604	 110.573604	 0.0	 0.0	 1	 -30.0	 30.0;
	2879	 5025	 0.004662	 0.016671	 0.0071	 111.756768	 111.756768	 111.756768	 0.0	 0.0	 1	 -30.0	 30.0;
	3983	 4121	 0.0	 0.000222	 0.0	 147.670495	 147.670495	 147.670495	 0.0	 0.0	 1	 -30.0	 30.0;
	4121	 2885	 0.0242	 0.093769	 0.03684	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8044	 1870	 0.002289	 0.008129	 0.00327	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4392	 907	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	907	 3333	 0.00668	 0.02588	 0.01017	 116.10205	 116.10205	 116.10205	 0.0	 0.0	 1	 -30.0	 30.0;
	1061	 3333	 0.00308	 0.013778	 0.00468	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 907	 0.032169	 0.124618	 0.04897	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1214	 7560	 0.006778	 0.02236	 0.01032	 184.731013	 184.731013	 184.731013	 0.0	 0.0	 1	 -30.0	 30.0;
	7370	 1214	 0.00308	 0.011929	 0.00469	 149.979665	 149.979665	 149.979665	 0.0	 0.0	 1	 -30.0	 30.0;
	5314	 6440	 0.016911	 0.070391	 0.02406	 115.438761	 115.438761	 115.438761	 0.0	 0.0	 1	 -30.0	 30.0;
	2334	 5314	 0.03196	 0.149969	 0.04548	 124.072169	 124.072169	 124.072169	 0.0	 0.0	 1	 -30.0	 30.0;
	5264	 7222	 0.00016	 0.00049	 0.69896	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2780	 5264	 7e-05	 0.00049	 0.01418	 1113.950706	 1113.950706	 1113.950706	 0.0	 0.0	 1	 -30.0	 30.0;
	7369	 7794	 0.0022	 0.00852	 0.00335	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5803	 7794	 0.000431	 0.000951	 0.0003	 133.746625	 133.746625	 133.746625	 0.0	 0.0	 1	 -30.0	 30.0;
	7369	 5292	 0.002249	 0.008351	 0.00341	 112.031125	 112.031125	 112.031125	 0.0	 0.0	 1	 -30.0	 30.0;
	7016	 5292	 0.019431	 0.053351	 0.01388	 262.167714	 262.167714	 262.167714	 0.0	 0.0	 1	 -30.0	 30.0;
	4526	 7369	 0.0	 0.000222	 0.0	 118.470976	 118.470976	 118.470976	 0.0	 0.0	 1	 -30.0	 30.0;
	5265	 4788	 0.001929	 0.008111	 0.00294	 131.096847	 131.096847	 131.096847	 0.0	 0.0	 1	 -30.0	 30.0;
	7600	 5265	 0.00652	 0.021511	 0.00992	 110.327566	 110.327566	 110.327566	 0.0	 0.0	 1	 -30.0	 30.0;
	5827	 4788	 0.001889	 0.008271	 0.00288	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5827	 7560	 0.012289	 0.051551	 0.0187	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7583	 4788	 0.001431	 0.005071	 0.00203	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1062	 4788	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7940	 7739	 0.007271	 0.0344	 0.01106	 112.040218	 112.040218	 112.040218	 0.0	 0.0	 1	 -30.0	 30.0;
	6561	 7739	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1813	 8044	 0.003289	 0.011329	 0.00502	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8044	 1247	 0.012129	 0.032831	 0.00867	 258.504686	 258.504686	 258.504686	 0.0	 0.0	 1	 -30.0	 30.0;
	8044	 156	 0.006031	 0.025289	 0.00917	 143.390164	 143.390164	 143.390164	 0.0	 0.0	 1	 -30.0	 30.0;
	8044	 156	 0.005911	 0.025778	 0.00899	 131.942001	 131.942001	 131.942001	 0.0	 0.0	 1	 -30.0	 30.0;
	421	 8044	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1988	 7472	 0.000529	 0.001969	 0.0008	 139.865874	 139.865874	 139.865874	 0.0	 0.0	 1	 -30.0	 30.0;
	7645	 7472	 0.000538	 0.001929	 0.00082	 114.608936	 114.608936	 114.608936	 0.0	 0.0	 1	 -30.0	 30.0;
	1568	 6519	 0.001151	 0.004222	 0.00163	 117.57412	 117.57412	 117.57412	 0.0	 0.0	 1	 -30.0	 30.0;
	4386	 1568	 0.003818	 0.017222	 0.00543	 110.335101	 110.335101	 110.335101	 0.0	 0.0	 1	 -30.0	 30.0;
	2288	 7090	 0.00416	 0.019502	 0.00591	 110.222864	 110.222864	 110.222864	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 2412	 0.001991	 0.00372	 0.00156	 203.674366	 203.674366	 203.674366	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 2894	 0.009889	 0.026751	 0.00707	 205.001203	 205.001203	 205.001203	 0.0	 0.0	 1	 -30.0	 30.0;
	3484	 2412	 0.002018	 0.00364	 0.00158	 265.037289	 265.037289	 265.037289	 0.0	 0.0	 1	 -30.0	 30.0;
	6553	 3484	 0.01644	 0.036942	 0.01174	 112.097376	 112.097376	 112.097376	 0.0	 0.0	 1	 -30.0	 30.0;
	8308	 2412	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2334	 5315	 0.019071	 0.07388	 0.02903	 108.361082	 108.361082	 108.361082	 0.0	 0.0	 1	 -30.0	 30.0;
	468	 5315	 0.02804	 0.1256	 0.04268	 131.083077	 131.083077	 131.083077	 0.0	 0.0	 1	 -30.0	 30.0;
	1433	 5315	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5315	 5224	 0.001911	 0.000751	 0.01661	 265.201747	 265.201747	 265.201747	 0.0	 0.0	 1	 -30.0	 30.0;
	6361	 3871	 0.008098	 0.028689	 0.01152	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6765	 6361	 0.017609	 0.068191	 0.0268	 149.645033	 149.645033	 149.645033	 0.0	 0.0	 1	 -30.0	 30.0;
	6361	 4176	 0.015018	 0.058191	 0.02287	 122.216623	 122.216623	 122.216623	 0.0	 0.0	 1	 -30.0	 30.0;
	6075	 6359	 0.007031	 0.014578	 0.00502	 239.644211	 239.644211	 239.644211	 0.0	 0.0	 1	 -30.0	 30.0;
	6075	 3750	 0.003791	 0.012529	 0.00577	 129.266502	 129.266502	 129.266502	 0.0	 0.0	 1	 -30.0	 30.0;
	6075	 4190	 0.010249	 0.035209	 0.01561	 165.006678	 165.006678	 165.006678	 0.0	 0.0	 1	 -30.0	 30.0;
	7022	 848	 0.002489	 0.005818	 0.00177	 225.690464	 225.690464	 225.690464	 0.0	 0.0	 1	 -30.0	 30.0;
	3085	 7022	 0.002071	 0.009751	 0.00296	 118.116339	 118.116339	 118.116339	 0.0	 0.0	 1	 -30.0	 30.0;
	3085	 2963	 0.001871	 0.006902	 0.00266	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3085	 4905	 0.003658	 0.014062	 0.00522	 110.433308	 110.433308	 110.433308	 0.0	 0.0	 1	 -30.0	 30.0;
	7017	 7256	 0.002289	 0.008178	 0.00348	 110.391219	 110.391219	 110.391219	 0.0	 0.0	 1	 -30.0	 30.0;
	1104	 7256	 0.002329	 0.008	 0.00354	 110.128294	 110.128294	 110.128294	 0.0	 0.0	 1	 -30.0	 30.0;
	1104	 2288	 0.002071	 0.009249	 0.00314	 109.94461	 109.94461	 109.94461	 0.0	 0.0	 1	 -30.0	 30.0;
	1380	 6501	 0.005951	 0.021249	 0.00905	 110.089063	 110.089063	 110.089063	 0.0	 0.0	 1	 -30.0	 30.0;
	329	 6501	 0.006058	 0.0208	 0.00922	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 993	 0.000942	 0.003129	 0.00144	 137.685828	 137.685828	 137.685828	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 3750	 0.030849	 0.10176	 0.04696	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2044	 993	 0.00084	 0.003551	 0.00128	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2288	 2044	 0.002378	 0.007831	 0.00361	 107.677269	 107.677269	 107.677269	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 1249	 0.007231	 0.01624	 0.00517	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1383	 3492	 0.001311	 0.005111	 0.00201	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 5316	 0.001338	 0.005009	 0.00205	 127.529948	 127.529948	 127.529948	 0.0	 0.0	 1	 -30.0	 30.0;
	3298	 3492	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1249	 515	 0.000338	 0.00116	 0.00052	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	515	 1173	 0.025778	 0.069751	 0.01842	 109.629203	 109.629203	 109.629203	 0.0	 0.0	 1	 -30.0	 30.0;
	2016	 515	 0.004009	 0.01376	 0.0061	 105.236116	 105.236116	 105.236116	 0.0	 0.0	 1	 -30.0	 30.0;
	4472	 515	 0.00408	 0.013462	 0.00621	 133.57853	 133.57853	 133.57853	 0.0	 0.0	 1	 -30.0	 30.0;
	3399	 515	 0.000329	 0.001262	 0.0005	 141.095543	 141.095543	 141.095543	 0.0	 0.0	 1	 -30.0	 30.0;
	4356	 515	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7845	 1333	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2437	 1183	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8229	 1333	 0.000711	 0.002018	 0.0621	 114.217666	 114.217666	 114.217666	 0.0	 0.0	 1	 -30.0	 30.0;
	1183	 4609	 0.00068	 0.001502	 0.05898	 137.620876	 137.620876	 137.620876	 0.0	 0.0	 1	 -30.0	 30.0;
	3427	 847	 0.00012	 0.00056	 0.00018	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2654	 847	 0.02516	 0.086418	 0.03831	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3427	 5637	 0.00012	 0.00052	 0.00018	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5637	 6349	 0.032591	 0.116511	 0.04961	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7412	 3427	 0.0	 0.00028	 0.0	 122.668428	 122.668428	 122.668428	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 1988	 0.01752	 0.062098	 0.02494	 123.540862	 123.540862	 123.540862	 0.0	 0.0	 1	 -30.0	 30.0;
	7645	 2445	 0.00076	 0.003551	 0.00114	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8386	 2207	 4e-05	 0.00028	 0.00918	 111.127774	 111.127774	 111.127774	 0.0	 0.0	 1	 -30.0	 30.0;
	8386	 5116	 0.000858	 0.004458	 0.0641	 111.164666	 111.164666	 111.164666	 0.0	 0.0	 1	 -30.0	 30.0;
	5116	 5796	 8e-05	 0.000338	 0.01726	 116.14336	 116.14336	 116.14336	 0.0	 0.0	 1	 -30.0	 30.0;
	5201	 6158	 4e-05	 0.00028	 0.00918	 146.396658	 146.396658	 146.396658	 0.0	 0.0	 1	 -30.0	 30.0;
	6158	 2521	 0.000982	 0.004369	 0.07264	 121.920702	 121.920702	 121.920702	 0.0	 0.0	 1	 -30.0	 30.0;
	2517	 5201	 0.01704	 0.083271	 0.02426	 121.527613	 121.527613	 121.527613	 0.0	 0.0	 1	 -30.0	 30.0;
	2521	 2765	 7.1e-05	 0.000351	 0.01689	 130.006694	 130.006694	 130.006694	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 5501	 0.000271	 0.00068	 0.0002	 247.729944	 247.729944	 247.729944	 0.0	 0.0	 1	 -30.0	 30.0;
	8252	 4444	 0.012809	 0.05376	 0.0195	 129.826128	 129.826128	 129.826128	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 6689	 0.00364	 0.015262	 0.00554	 140.746622	 140.746622	 140.746622	 0.0	 0.0	 1	 -30.0	 30.0;
	1059	 4515	 0.00012	 0.000431	 0.00018	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7606	 4515	 0.003982	 0.015271	 0.00566	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1059	 3753	 0.00012	 0.000418	 0.00018	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7933	 3753	 0.000431	 0.00172	 0.00061	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	572	 2996	 0.00024	 0.00032	 0.01062	 133.493832	 133.493832	 133.493832	 0.0	 0.0	 1	 -30.0	 30.0;
	3146	 572	 0.002418	 0.011462	 0.00369	 111.88901	 111.88901	 111.88901	 0.0	 0.0	 1	 -30.0	 30.0;
	6271	 4057	 0.00028	 0.000311	 0.01204	 172.86352	 172.86352	 172.86352	 0.0	 0.0	 1	 -30.0	 30.0;
	6271	 7606	 0.003658	 0.01664	 0.00557	 209.212165	 209.212165	 209.212165	 0.0	 0.0	 1	 -30.0	 30.0;
	7606	 2996	 0.003582	 0.016951	 0.00546	 111.739621	 111.739621	 111.739621	 0.0	 0.0	 1	 -30.0	 30.0;
	1716	 4569	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4569	 2132	 0.006231	 0.029249	 0.00887	 132.292742	 132.292742	 132.292742	 0.0	 0.0	 1	 -30.0	 30.0;
	4569	 7933	 0.00144	 0.005529	 0.00205	 130.333013	 130.333013	 130.333013	 0.0	 0.0	 1	 -30.0	 30.0;
	4569	 5397	 0.011111	 0.023978	 0.00794	 125.851851	 125.851851	 125.851851	 0.0	 0.0	 1	 -30.0	 30.0;
	7924	 1059	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2180	 5075	 0.001182	 0.002409	 0.00093	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5715	 2773	 0.006098	 0.029822	 0.00869	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2773	 7482	 0.00096	 0.003378	 0.00135	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3821	 6026	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6026	 1456	 0.01044	 0.03444	 0.0159	 111.602702	 111.602702	 111.602702	 0.0	 0.0	 1	 -30.0	 30.0;
	6026	 1456	 0.009298	 0.03904	 0.01416	 140.562678	 140.562678	 140.562678	 0.0	 0.0	 1	 -30.0	 30.0;
	6026	 4785	 0.017311	 0.078738	 0.02636	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	814	 8145	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8145	 485	 0.012449	 0.029129	 0.00889	 105.96072	 105.96072	 105.96072	 0.0	 0.0	 1	 -30.0	 30.0;
	657	 1094	 0.00015	 0.00045	 0.68377	 811.107927	 811.107927	 811.107927	 0.0	 0.0	 1	 -30.0	 30.0;
	6911	 1094	 0.00107	 0.01215	 0.24188	 1342.212555	 1342.212555	 1342.212555	 0.0	 0.0	 1	 -30.0	 30.0;
	2780	 657	 6e-05	 0.00056	 0.01263	 1315.86103	 1315.86103	 1315.86103	 0.0	 0.0	 1	 -30.0	 30.0;
	3791	 7406	 0.00035	 0.00284	 0.07794	 1368.208005	 1368.208005	 1368.208005	 0.0	 0.0	 1	 -30.0	 30.0;
	6847	 7406	 0.00163	 0.01512	 0.36808	 1466.307656	 1466.307656	 1466.307656	 0.0	 0.0	 1	 -30.0	 30.0;
	4534	 7406	 0.00115	 0.00913	 0.26067	 1422.461067	 1422.461067	 1422.461067	 0.0	 0.0	 1	 -30.0	 30.0;
	2600	 7406	 0.00133	 0.01513	 0.30125	 898.140951	 898.140951	 898.140951	 0.0	 0.0	 1	 -30.0	 30.0;
	2600	 7406	 0.00131	 0.01401	 0.29471	 1005.472225	 1005.472225	 1005.472225	 0.0	 0.0	 1	 -30.0	 30.0;
	6911	 7406	 0.00013	 0.00129	 0.03155	 1272.173721	 1272.173721	 1272.173721	 0.0	 0.0	 1	 -30.0	 30.0;
	6461	 7406	 0.00077	 0.00664	 0.17486	 1389.89962	 1389.89962	 1389.89962	 0.0	 0.0	 1	 -30.0	 30.0;
	2288	 3750	 0.028391	 0.12908	 0.04321	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7812	 2288	 0.01216	 0.05532	 0.01852	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 5577	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2179	 5577	 0.023609	 0.053071	 0.01687	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4517	 1610	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1610	 6216	 0.020471	 0.051871	 0.01462	 262.889199	 262.889199	 262.889199	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 1610	 0.01744	 0.049862	 0.01247	 122.545539	 122.545539	 122.545539	 0.0	 0.0	 1	 -30.0	 30.0;
	7789	 2415	 0.009111	 0.039809	 0.01387	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4821	 6405	 0.033022	 0.13856	 0.05026	 120.26157	 120.26157	 120.26157	 0.0	 0.0	 1	 -30.0	 30.0;
	6405	 2415	 0.009529	 0.045089	 0.0145	 139.845869	 139.845869	 139.845869	 0.0	 0.0	 1	 -30.0	 30.0;
	5352	 8229	 0.0	 0.000222	 0.0	 149.728951	 149.728951	 149.728951	 0.0	 0.0	 1	 -30.0	 30.0;
	8229	 781	 0.001889	 0.003462	 0.07129	 266.308787	 266.308787	 266.308787	 0.0	 0.0	 1	 -30.0	 30.0;
	8229	 777	 0.006569	 0.0142	 0.0047	 287.803971	 287.803971	 287.803971	 0.0	 0.0	 1	 -30.0	 30.0;
	6390	 8229	 0.003982	 0.018102	 0.00605	 127.529689	 127.529689	 127.529689	 0.0	 0.0	 1	 -30.0	 30.0;
	8229	 573	 0.00232	 0.007969	 0.00353	 118.205972	 118.205972	 118.205972	 0.0	 0.0	 1	 -30.0	 30.0;
	1303	 2060	 0.002502	 0.011698	 0.00355	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 2060	 0.009351	 0.039209	 0.01422	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2060	 7902	 0.008622	 0.0296	 0.01312	 108.407068	 108.407068	 108.407068	 0.0	 0.0	 1	 -30.0	 30.0;
	1868	 2339	 0.008951	 0.037289	 0.01275	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2339	 4119	 0.005369	 0.02144	 0.00763	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6103	 7448	 0.0	 0.000222	 0.0	 135.014486	 135.014486	 135.014486	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 7448	 0.00608	 0.025551	 0.00927	 117.945905	 117.945905	 117.945905	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 7448	 0.00596	 0.026049	 0.00908	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7448	 1868	 0.001369	 0.004898	 0.00209	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7448	 2180	 0.00144	 0.006031	 0.00219	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4385	 2989	 0.0012	 0.00328	 0.00086	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7606	 4385	 0.00132	 0.006271	 0.00201	 118.643748	 118.643748	 118.643748	 0.0	 0.0	 1	 -30.0	 30.0;
	4385	 4531	 0.009089	 0.040711	 0.01383	 115.774953	 115.774953	 115.774953	 0.0	 0.0	 1	 -30.0	 30.0;
	5741	 6590	 5.8e-05	 0.00028	 4e-05	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2879	 6590	 0.000302	 0.00132	 0.00045	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4059	 2796	 0.00368	 0.016502	 0.00561	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1796	 4059	 0.000329	 0.00124	 0.00051	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4601	 1769	 0.0012	 0.002689	 0.00085	 204.078627	 204.078627	 204.078627	 0.0	 0.0	 1	 -30.0	 30.0;
	2879	 1769	 0.000338	 0.001289	 0.00051	 115.504493	 115.504493	 115.504493	 0.0	 0.0	 1	 -30.0	 30.0;
	372	 5741	 0.000942	 0.002151	 0.00073	 253.519757	 253.519757	 253.519757	 0.0	 0.0	 1	 -30.0	 30.0;
	4812	 7296	 0.00316	 0.010862	 0.00481	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4812	 6275	 0.003222	 0.010618	 0.0049	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3304	 7296	 0.010169	 0.037858	 0.01549	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1668	 6275	 0.00552	 0.024129	 0.00841	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1957	 3858	 0.000449	 0.001889	 0.00069	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4166	 5469	 0.00044	 0.001929	 0.00067	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3480	 4514	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4514	 6739	 0.000418	 0.00192	 0.00061	 132.163617	 132.163617	 132.163617	 0.0	 0.0	 1	 -30.0	 30.0;
	4514	 6519	 0.000409	 0.00196	 0.0006	 110.746896	 110.746896	 110.746896	 0.0	 0.0	 1	 -30.0	 30.0;
	7606	 6739	 0.00608	 0.022431	 0.00865	 132.581648	 132.581648	 132.581648	 0.0	 0.0	 1	 -30.0	 30.0;
	2857	 3629	 0.0	 0.000222	 0.0	 151.721415	 151.721415	 151.721415	 0.0	 0.0	 1	 -30.0	 30.0;
	3915	 3629	 0.00016	 0.000751	 0.00024	 120.49176	 120.49176	 120.49176	 0.0	 0.0	 1	 -30.0	 30.0;
	3915	 7790	 0.046622	 0.173511	 0.07097	 121.3564	 121.3564	 121.3564	 0.0	 0.0	 1	 -30.0	 30.0;
	1376	 3629	 0.000151	 0.000698	 0.00024	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2654	 1376	 0.01464	 0.052329	 0.02228	 128.098667	 128.098667	 128.098667	 0.0	 0.0	 1	 -30.0	 30.0;
	5484	 5822	 0.006129	 0.023751	 0.00933	 159.316372	 159.316372	 159.316372	 0.0	 0.0	 1	 -30.0	 30.0;
	4494	 5822	 0.001049	 0.003311	 0.10976	 132.378998	 132.378998	 132.378998	 0.0	 0.0	 1	 -30.0	 30.0;
	7743	 4871	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4871	 2796	 0.003271	 0.012089	 0.00467	 134.771047	 134.771047	 134.771047	 0.0	 0.0	 1	 -30.0	 30.0;
	4871	 1720	 0.002951	 0.013311	 0.0042	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4871	 4682	 0.017489	 0.082769	 0.02662	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4871	 2177	 0.006231	 0.029498	 0.00949	 135.662446	 135.662446	 135.662446	 0.0	 0.0	 1	 -30.0	 30.0;
	2527	 4772	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5782	 7854	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6802	 4772	 0.00124	 0.004458	 0.15552	 188.595391	 188.595391	 188.595391	 0.0	 0.0	 1	 -30.0	 30.0;
	5324	 7854	 0.001169	 0.001969	 0.05146	 220.838037	 220.838037	 220.838037	 0.0	 0.0	 1	 -30.0	 30.0;
	4201	 8014	 0.000791	 0.002929	 0.09963	 132.433817	 132.433817	 132.433817	 0.0	 0.0	 1	 -30.0	 30.0;
	977	 8014	 0.000911	 0.003138	 0.11378	 253.769952	 253.769952	 253.769952	 0.0	 0.0	 1	 -30.0	 30.0;
	1796	 1720	 0.004671	 0.01672	 0.00711	 130.881467	 130.881467	 130.881467	 0.0	 0.0	 1	 -30.0	 30.0;
	1334	 2344	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2344	 7583	 0.00064	 0.00188	 0.08014	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	547	 6947	 0.00014	 0.00061	 0.28157	 888.824423	 888.824423	 888.824423	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 5354	 0.000698	 0.0024	 0.00106	 139.812613	 139.812613	 139.812613	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 2239	 0.000711	 0.002351	 0.00108	 145.096841	 145.096841	 145.096841	 0.0	 0.0	 1	 -30.0	 30.0;
	7606	 5354	 0.001858	 0.006391	 0.00283	 176.264142	 176.264142	 176.264142	 0.0	 0.0	 1	 -30.0	 30.0;
	4468	 2239	 0.014129	 0.06328	 0.0215	 178.335848	 178.335848	 178.335848	 0.0	 0.0	 1	 -30.0	 30.0;
	4176	 4468	 0.0002	 0.00092	 0.00031	 173.062273	 173.062273	 173.062273	 0.0	 0.0	 1	 -30.0	 30.0;
	8266	 638	 4e-05	 0.0004	 0.00835	 1385.125846	 1385.125846	 1385.125846	 0.0	 0.0	 1	 -30.0	 30.0;
	8266	 3791	 4e-05	 0.00039	 0.00947	 1251.206102	 1251.206102	 1251.206102	 0.0	 0.0	 1	 -30.0	 30.0;
	4534	 638	 0.00066	 0.00705	 0.14833	 1448.784948	 1448.784948	 1448.784948	 0.0	 0.0	 1	 -30.0	 30.0;
	4233	 262	 0.003622	 0.016209	 0.00551	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8207	 4233	 5.8e-05	 0.00028	 4e-05	 256.658233	 256.658233	 256.658233	 0.0	 0.0	 1	 -30.0	 30.0;
	2343	 4233	 3.1e-05	 0.00028	 5e-05	 105.671554	 105.671554	 105.671554	 0.0	 0.0	 1	 -30.0	 30.0;
	7260	 298	 0.00084	 0.002031	 0.00066	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6479	 7485	 0.004511	 0.01972	 0.00687	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6479	 7788	 0.00064	 0.0028	 0.00097	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7707	 7260	 0.004422	 0.020102	 0.00673	 147.378991	 147.378991	 147.378991	 0.0	 0.0	 1	 -30.0	 30.0;
	7260	 4344	 0.0	 0.00028	 0.0	 143.168029	 143.168029	 143.168029	 0.0	 0.0	 1	 -30.0	 30.0;
	6234	 670	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	670	 2931	 0.000822	 0.003622	 0.00126	 175.409635	 175.409635	 175.409635	 0.0	 0.0	 1	 -30.0	 30.0;
	670	 2132	 0.000809	 0.003689	 0.00123	 166.348584	 166.348584	 166.348584	 0.0	 0.0	 1	 -30.0	 30.0;
	3207	 6081	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2373	 6081	 0.001471	 0.00528	 0.00225	 167.814419	 167.814419	 167.814419	 0.0	 0.0	 1	 -30.0	 30.0;
	2373	 6081	 0.001502	 0.005169	 0.00229	 139.314822	 139.314822	 139.314822	 0.0	 0.0	 1	 -30.0	 30.0;
	1972	 6081	 0.000769	 0.002858	 0.0972	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6081	 2084	 0.003698	 0.013209	 0.00563	 138.244934	 138.244934	 138.244934	 0.0	 0.0	 1	 -30.0	 30.0;
	6081	 1957	 0.00116	 0.005271	 0.00177	 128.14855	 128.14855	 128.14855	 0.0	 0.0	 1	 -30.0	 30.0;
	6081	 4597	 0.003378	 0.006178	 0.12747	 263.431937	 263.431937	 263.431937	 0.0	 0.0	 1	 -30.0	 30.0;
	6081	 691	 0.000849	 0.004009	 0.00129	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6081	 149	 0.000431	 0.00112	 0.03729	 150.942772	 150.942772	 150.942772	 0.0	 0.0	 1	 -30.0	 30.0;
	2461	 8307	 0.006778	 0.002631	 0.24938	 216.664747	 216.664747	 216.664747	 0.0	 0.0	 1	 -30.0	 30.0;
	1394	 2820	 0.003569	 0.00468	 0.16087	 278.14952	 278.14952	 278.14952	 0.0	 0.0	 1	 -30.0	 30.0;
	1394	 2820	 0.003178	 0.005298	 0.14333	 267.960644	 267.960644	 267.960644	 0.0	 0.0	 1	 -30.0	 30.0;
	5293	 3880	 0.00388	 0.0174	 0.00591	 129.41901	 129.41901	 129.41901	 0.0	 0.0	 1	 -30.0	 30.0;
	674	 3880	 0.003138	 0.011689	 0.00478	 114.714678	 114.714678	 114.714678	 0.0	 0.0	 1	 -30.0	 30.0;
	5293	 3068	 0.0044	 0.017049	 0.0067	 143.613079	 143.613079	 143.613079	 0.0	 0.0	 1	 -30.0	 30.0;
	3068	 6969	 0.000791	 0.002631	 0.00121	 123.275079	 123.275079	 123.275079	 0.0	 0.0	 1	 -30.0	 30.0;
	4886	 2675	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	417	 6216	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 6216	 0.017698	 0.0584	 0.02695	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 6216	 0.015769	 0.066191	 0.02401	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3958	 7564	 0.00225	 0.02425	 0.51035	 832.427671	 832.427671	 832.427671	 0.0	 0.0	 1	 -30.0	 30.0;
	3958	 7564	 0.00161	 0.02118	 0.66012	 1156.950877	 1156.950877	 1156.950877	 0.0	 0.0	 1	 -30.0	 30.0;
	1031	 7564	 0.00312	 0.03268	 0.70522	 1258.807415	 1258.807415	 1258.807415	 0.0	 0.0	 1	 -30.0	 30.0;
	1031	 7564	 0.00305	 0.0333	 0.69052	 1387.723021	 1387.723021	 1387.723021	 0.0	 0.0	 1	 -30.0	 30.0;
	5653	 5041	 0.000182	 0.000831	 0.00027	 105.853159	 105.853159	 105.853159	 0.0	 0.0	 1	 -30.0	 30.0;
	8008	 5653	 0.013649	 0.054609	 0.01944	 105.853159	 105.853159	 105.853159	 0.0	 0.0	 1	 -30.0	 30.0;
	8154	 7097	 0.007209	 0.03252	 0.01026	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8005	 8154	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7097	 5041	 0.000169	 0.000769	 0.00026	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2484	 5041	 0.011649	 0.026778	 0.00911	 118.998386	 118.998386	 118.998386	 0.0	 0.0	 1	 -30.0	 30.0;
	7485	 2484	 0.004049	 0.01112	 0.0029	 221.09005	 221.09005	 221.09005	 0.0	 0.0	 1	 -30.0	 30.0;
	7485	 5041	 0.007898	 0.037338	 0.01202	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7485	 5041	 0.00772	 0.034578	 0.01175	 107.643494	 107.643494	 107.643494	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 4271	 0.042582	 0.193609	 0.06482	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 7594	 0.027591	 0.130569	 0.042	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 5036	 0.018431	 0.065898	 0.02806	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 26	 0.02836	 0.1134	 0.04036	 134.235843	 134.235843	 134.235843	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 872	 0.046142	 0.15844	 0.07022	 132.421087	 132.421087	 132.421087	 0.0	 0.0	 1	 -30.0	 30.0;
	6835	 5041	 0.011409	 0.027311	 0.00893	 281.707325	 281.707325	 281.707325	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 7902	 0.019271	 0.063569	 0.02934	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 7902	 0.02212	 0.082329	 0.03368	 111.511769	 111.511769	 111.511769	 0.0	 0.0	 1	 -30.0	 30.0;
	2693	 4358	 0.018249	 0.04624	 0.01303	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	605	 4358	 0.008929	 0.01872	 0.29574	 251.062497	 251.062497	 251.062497	 0.0	 0.0	 1	 -30.0	 30.0;
	605	 4358	 0.008742	 0.017329	 0.28931	 253.469614	 253.469614	 253.469614	 0.0	 0.0	 1	 -30.0	 30.0;
	1437	 5394	 0.001569	 0.00412	 0.00111	 150.196085	 150.196085	 150.196085	 0.0	 0.0	 1	 -30.0	 30.0;
	5394	 7098	 0.037409	 0.106911	 0.02673	 167.568121	 167.568121	 167.568121	 0.0	 0.0	 1	 -30.0	 30.0;
	1437	 7599	 0.01836	 0.049671	 0.01312	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3704	 3275	 0.007791	 0.037502	 0.01109	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3704	 1356	 0.014911	 0.051218	 0.0227	 122.244162	 122.244162	 122.244162	 0.0	 0.0	 1	 -30.0	 30.0;
	2223	 4454	 0.007071	 0.0294	 0.01006	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2223	 6698	 0.010169	 0.039378	 0.01547	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7485	 7707	 0.0	 0.00028	 0.0	 112.528916	 112.528916	 112.528916	 0.0	 0.0	 1	 -30.0	 30.0;
	7485	 5890	 0.004449	 0.00924	 0.00319	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3360	 4843	 0.002191	 0.011142	 0.00312	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4843	 7325	 0.00244	 0.011951	 0.00348	 132.609187	 132.609187	 132.609187	 0.0	 0.0	 1	 -30.0	 30.0;
	5611	 6515	 0.004662	 0.020871	 0.00709	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3360	 6515	 0.00528	 0.020449	 0.00804	 119.839643	 119.839643	 119.839643	 0.0	 0.0	 1	 -30.0	 30.0;
	5477	 6515	 0.0036	 0.0144	 0.00513	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2582	 3517	 0.00212	 0.008871	 0.00321	 112.204157	 112.204157	 112.204157	 0.0	 0.0	 1	 -30.0	 30.0;
	5576	 2582	 0.001991	 0.008271	 0.00283	 111.964094	 111.964094	 111.964094	 0.0	 0.0	 1	 -30.0	 30.0;
	345	 3517	 0.002071	 0.009049	 0.00315	 125.994225	 125.994225	 125.994225	 0.0	 0.0	 1	 -30.0	 30.0;
	345	 3584	 0.002031	 0.008098	 0.00288	 125.79859	 125.79859	 125.79859	 0.0	 0.0	 1	 -30.0	 30.0;
	2036	 2444	 0.002631	 0.00868	 0.004	 132.477205	 132.477205	 132.477205	 0.0	 0.0	 1	 -30.0	 30.0;
	2658	 2444	 0.00048	 0.001769	 0.00073	 153.111906	 153.111906	 153.111906	 0.0	 0.0	 1	 -30.0	 30.0;
	2036	 5330	 0.002338	 0.009831	 0.00357	 250.554573	 250.554573	 250.554573	 0.0	 0.0	 1	 -30.0	 30.0;
	5262	 5330	 0.006911	 0.025742	 0.01052	 198.936774	 198.936774	 198.936774	 0.0	 0.0	 1	 -30.0	 30.0;
	7524	 2036	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2179	 3105	 0.005649	 0.020209	 0.00861	 129.266502	 129.266502	 129.266502	 0.0	 0.0	 1	 -30.0	 30.0;
	4175	 3105	 0.037822	 0.075338	 0.02702	 171.309611	 171.309611	 171.309611	 0.0	 0.0	 1	 -30.0	 30.0;
	8323	 2179	 0.0	 0.000222	 0.0	 127.575415	 127.575415	 127.575415	 0.0	 0.0	 1	 -30.0	 30.0;
	2179	 6440	 0.005609	 0.020871	 0.00854	 117.689215	 117.689215	 117.689215	 0.0	 0.0	 1	 -30.0	 30.0;
	2179	 6906	 0.042569	 0.11516	 0.03041	 250.494817	 250.494817	 250.494817	 0.0	 0.0	 1	 -30.0	 30.0;
	1401	 6440	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7669	 5210	 0.00396	 0.010458	 0.00283	 120.780406	 120.780406	 120.780406	 0.0	 0.0	 1	 -30.0	 30.0;
	6349	 5210	 0.019671	 0.088151	 0.02995	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 7786	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1647	 4948	 0.00912	 0.03364	 0.01297	 104.09686	 104.09686	 104.09686	 0.0	 0.0	 1	 -30.0	 30.0;
	4948	 6636	 0.010942	 0.051369	 0.01558	 104.519307	 104.519307	 104.519307	 0.0	 0.0	 1	 -30.0	 30.0;
	2699	 7786	 0.000182	 0.000822	 0.00028	 132.319762	 132.319762	 132.319762	 0.0	 0.0	 1	 -30.0	 30.0;
	2699	 7790	 0.023209	 0.118049	 0.03304	 132.742209	 132.742209	 132.742209	 0.0	 0.0	 1	 -30.0	 30.0;
	1647	 7786	 0.0002	 0.000809	 0.00032	 106.582959	 106.582959	 106.582959	 0.0	 0.0	 1	 -30.0	 30.0;
	1943	 5658	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1397	 6847	 0.00076	 0.00811	 0.17059	 1473.545654	 1473.545654	 1473.545654	 0.0	 0.0	 1	 -30.0	 30.0;
	7387	 2568	 5.8e-05	 0.000231	 0.0064	 116.140242	 116.140242	 116.140242	 0.0	 0.0	 1	 -30.0	 30.0;
	6906	 7387	 0.013471	 0.053849	 0.01917	 116.406285	 116.406285	 116.406285	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 6906	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1492	 1705	 0.007489	 0.03376	 0.01065	 126.377442	 126.377442	 126.377442	 0.0	 0.0	 1	 -30.0	 30.0;
	9	 1492	 0.004271	 0.016431	 0.00608	 134.938363	 134.938363	 134.938363	 0.0	 0.0	 1	 -30.0	 30.0;
	3647	 4650	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7925	 4650	 0.013289	 0.04384	 0.02023	 161.569163	 161.569163	 161.569163	 0.0	 0.0	 1	 -30.0	 30.0;
	7925	 4650	 0.01184	 0.049689	 0.01802	 130.067749	 130.067749	 130.067749	 0.0	 0.0	 1	 -30.0	 30.0;
	7925	 4650	 0.011338	 0.0508	 0.01726	 163.775969	 163.775969	 163.775969	 0.0	 0.0	 1	 -30.0	 30.0;
	3486	 4650	 0.008502	 0.035671	 0.01294	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4650	 3265	 0.02216	 0.088622	 0.03154	 156.819361	 156.819361	 156.819361	 0.0	 0.0	 1	 -30.0	 30.0;
	4650	 4900	 0.019911	 0.101262	 0.02834	 153.32287	 153.32287	 153.32287	 0.0	 0.0	 1	 -30.0	 30.0;
	4650	 399	 0.014551	 0.068258	 0.0207	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4650	 4027	 0.014129	 0.050529	 0.02151	 125.373285	 125.373285	 125.373285	 0.0	 0.0	 1	 -30.0	 30.0;
	4650	 6694	 0.018022	 0.08072	 0.02742	 128.178948	 128.178948	 128.178948	 0.0	 0.0	 1	 -30.0	 30.0;
	468	 6906	 0.005382	 0.02004	 0.0082	 162.311434	 162.311434	 162.311434	 0.0	 0.0	 1	 -30.0	 30.0;
	8245	 584	 0.007769	 0.034791	 0.01183	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	584	 6349	 0.068351	 0.30616	 0.10403	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1632	 4905	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1270	 8252	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	218	 2083	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 392	 0.00163	 0.01819	 0.66584	 1597.08591	 1597.08591	 1597.08591	 0.0	 0.0	 1	 -30.0	 30.0;
	5337	 11	 0.00241	 0.02622	 0.54384	 1269.187561	 1269.187561	 1269.187561	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 11	 0.00236	 0.02672	 0.53228	 1354.906859	 1354.906859	 1354.906859	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 2600	 0.00188	 0.02029	 0.42683	 1028.658566	 1028.658566	 1028.658566	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 2600	 0.00213	 0.01988	 0.48375	 1044.987995	 1044.987995	 1044.987995	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 2654	 0.0	 0.000222	 0.0	 123.994746	 123.994746	 123.994746	 0.0	 0.0	 1	 -30.0	 30.0;
	916	 2654	 0.009822	 0.046449	 0.01494	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6707	 2654	 0.00344	 0.01628	 0.00523	 147.719599	 147.719599	 147.719599	 0.0	 0.0	 1	 -30.0	 30.0;
	2654	 1579	 0.00648	 0.025102	 0.00986	 123.977079	 123.977079	 123.977079	 0.0	 0.0	 1	 -30.0	 30.0;
	3521	 5758	 0.0	 0.00028	 0.0	 124.506567	 124.506567	 124.506567	 0.0	 0.0	 1	 -30.0	 30.0;
	5758	 163	 0.02368	 0.099338	 0.03603	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 5758	 0.017169	 0.061382	 0.02614	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1397	 8026	 0.00209	 0.01796	 0.47366	 1236.43261	 1236.43261	 1236.43261	 0.0	 0.0	 1	 -30.0	 30.0;
	1397	 8026	 0.00213	 0.01758	 0.4826	 1219.593092	 1219.593092	 1219.593092	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 8026	 0.0013	 0.01389	 0.29229	 1185.752803	 1185.752803	 1185.752803	 0.0	 0.0	 1	 -30.0	 30.0;
	4058	 8026	 0.00147	 0.01361	 0.33127	 1295.406792	 1295.406792	 1295.406792	 0.0	 0.0	 1	 -30.0	 30.0;
	547	 3958	 0.00052	 0.00446	 0.11749	 1260.082308	 1260.082308	 1260.082308	 0.0	 0.0	 1	 -30.0	 30.0;
	547	 3958	 0.00053	 0.00436	 0.11971	 1192.674875	 1192.674875	 1192.674875	 0.0	 0.0	 1	 -30.0	 30.0;
	2590	 7016	 0.014889	 0.05544	 0.02267	 155.852357	 155.852357	 155.852357	 0.0	 0.0	 1	 -30.0	 30.0;
	2590	 7016	 0.015178	 0.054289	 0.02311	 123.481886	 123.481886	 123.481886	 0.0	 0.0	 1	 -30.0	 30.0;
	2019	 2590	 0.003111	 0.013569	 0.00473	 126.767933	 126.767933	 126.767933	 0.0	 0.0	 1	 -30.0	 30.0;
	5736	 2590	 0.000791	 0.00376	 0.00121	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2590	 6781	 0.002751	 0.009809	 0.00418	 244.691754	 244.691754	 244.691754	 0.0	 0.0	 1	 -30.0	 30.0;
	2590	 8240	 0.007129	 0.024471	 0.01084	 142.147245	 142.147245	 142.147245	 0.0	 0.0	 1	 -30.0	 30.0;
	2590	 7996	 0.017951	 0.0668	 0.02732	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2590	 4698	 0.006178	 0.02812	 0.00942	 149.714142	 149.714142	 149.714142	 0.0	 0.0	 1	 -30.0	 30.0;
	2590	 1539	 0.006049	 0.028649	 0.00922	 161.800132	 161.800132	 161.800132	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 4534	 0.00396	 0.03136	 0.89602	 1264.767229	 1264.767229	 1264.767229	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 4534	 0.00353	 0.03554	 0.79827	 1130.741518	 1130.741518	 1130.741518	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 4534	 0.00387	 0.0331	 0.87257	 1310.756191	 1310.756191	 1310.756191	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 4534	 0.00394	 0.03239	 0.88903	 1270.723752	 1270.723752	 1270.723752	 0.0	 0.0	 1	 -30.0	 30.0;
	1802	 1144	 0.00225	 0.01786	 0.51036	 1104.145809	 1104.145809	 1104.145809	 0.0	 0.0	 1	 -30.0	 30.0;
	1144	 2780	 0.00124	 0.01101	 0.27878	 1182.129526	 1182.129526	 1182.129526	 0.0	 0.0	 1	 -30.0	 30.0;
	1802	 4058	 0.00201	 0.02024	 0.45468	 1203.784941	 1203.784941	 1203.784941	 0.0	 0.0	 1	 -30.0	 30.0;
	1802	 5679	 0.00197	 0.02063	 0.4454	 1108.354866	 1108.354866	 1108.354866	 0.0	 0.0	 1	 -30.0	 30.0;
	5679	 2780	 0.00126	 0.01078	 0.28414	 1188.165688	 1188.165688	 1188.165688	 0.0	 0.0	 1	 -30.0	 30.0;
	1802	 4909	 0.00193	 0.02103	 0.43612	 1260.831317	 1260.831317	 1260.831317	 0.0	 0.0	 1	 -30.0	 30.0;
	4475	 2373	 0.001209	 0.004551	 0.15228	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2373	 1201	 0.000449	 0.002018	 0.00068	 142.419783	 142.419783	 142.419783	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 2373	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5262	 3441	 0.007049	 0.0252	 0.01073	 120.043332	 120.043332	 120.043332	 0.0	 0.0	 1	 -30.0	 30.0;
	6942	 5262	 0.001191	 0.003222	 0.1485	 136.473306	 136.473306	 136.473306	 0.0	 0.0	 1	 -30.0	 30.0;
	5262	 777	 0.000511	 0.001978	 0.00078	 154.819361	 154.819361	 154.819361	 0.0	 0.0	 1	 -30.0	 30.0;
	5262	 6390	 0.001009	 0.004782	 0.00154	 168.520576	 168.520576	 168.520576	 0.0	 0.0	 1	 -30.0	 30.0;
	5262	 7756	 0.000991	 0.004422	 0.0015	 118.231693	 118.231693	 118.231693	 0.0	 0.0	 1	 -30.0	 30.0;
	3076	 2338	 0.000929	 0.003098	 0.00143	 135.597754	 135.597754	 135.597754	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 3076	 0.005858	 0.0246	 0.00893	 152.936795	 152.936795	 152.936795	 0.0	 0.0	 1	 -30.0	 30.0;
	1394	 8084	 0.0	 0.00028	 0.0	 195.222824	 195.222824	 195.222824	 0.0	 0.0	 1	 -30.0	 30.0;
	2461	 8084	 0.0	 0.00028	 0.0	 209.206969	 209.206969	 209.206969	 0.0	 0.0	 1	 -30.0	 30.0;
	4688	 5170	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5170	 1785	 0.002031	 0.009222	 0.00308	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5414	 5170	 0.01036	 0.045231	 0.01576	 120.196618	 120.196618	 120.196618	 0.0	 0.0	 1	 -30.0	 30.0;
	5170	 2285	 0.026858	 0.062822	 0.01919	 257.680057	 257.680057	 257.680057	 0.0	 0.0	 1	 -30.0	 30.0;
	735	 1785	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1785	 2415	 0.021569	 0.098089	 0.03284	 114.176356	 114.176356	 114.176356	 0.0	 0.0	 1	 -30.0	 30.0;
	7665	 8084	 0.0	 0.000222	 0.0	 136.33301	 136.33301	 136.33301	 0.0	 0.0	 1	 -30.0	 30.0;
	3795	 4800	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4800	 8073	 0.000418	 0.001769	 0.00065	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4800	 6636	 0.000409	 0.001809	 0.00063	 104.519307	 104.519307	 104.519307	 0.0	 0.0	 1	 -30.0	 30.0;
	2736	 4201	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5243	 6150	 0.0	 0.00028	 0.0	 142.675174	 142.675174	 142.675174	 0.0	 0.0	 1	 -30.0	 30.0;
	7572	 4190	 0.000569	 0.00168	 0.07155	 132.951874	 132.951874	 132.951874	 0.0	 0.0	 1	 -30.0	 30.0;
	7572	 7919	 0.000582	 0.001649	 0.0729	 147.44706	 147.44706	 147.44706	 0.0	 0.0	 1	 -30.0	 30.0;
	7919	 4176	 0.001858	 0.006911	 0.00283	 149.08177	 149.08177	 149.08177	 0.0	 0.0	 1	 -30.0	 30.0;
	8372	 7572	 0.0	 0.000222	 0.0	 111.872122	 111.872122	 111.872122	 0.0	 0.0	 1	 -30.0	 30.0;
	4584	 247	 0.0154	 0.006022	 0.37744	 297.277336	 297.277336	 297.277336	 0.0	 0.0	 1	 -30.0	 30.0;
	3155	 5373	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5373	 8257	 8e-05	 0.0004	 0.00013	 121.836264	 121.836264	 121.836264	 0.0	 0.0	 1	 -30.0	 30.0;
	5373	 921	 9.8e-05	 0.000329	 0.00014	 145.496165	 145.496165	 145.496165	 0.0	 0.0	 1	 -30.0	 30.0;
	2334	 8257	 0.023129	 0.076289	 0.0352	 194.581359	 194.581359	 194.581359	 0.0	 0.0	 1	 -30.0	 30.0;
	468	 921	 0.011258	 0.047249	 0.01714	 152.993693	 152.993693	 152.993693	 0.0	 0.0	 1	 -30.0	 30.0;
	2334	 5715	 0.018822	 0.072271	 0.02678	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2334	 7042	 0.002009	 0.006649	 0.00307	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2334	 4062	 0.000942	 0.00424	 0.00134	 132.586324	 132.586324	 132.586324	 0.0	 0.0	 1	 -30.0	 30.0;
	2334	 7482	 0.017711	 0.060809	 0.02696	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2334	 7482	 0.01804	 0.059489	 0.02746	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5337	 5512	 0.0028	 0.03055	 0.63332	 1255.500722	 1255.500722	 1255.500722	 0.0	 0.0	 1	 -30.0	 30.0;
	5337	 5512	 0.00274	 0.03113	 0.61985	 1405.456347	 1405.456347	 1405.456347	 0.0	 0.0	 1	 -30.0	 30.0;
	1286	 4717	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7790	 262	 0.0002	 0.000942	 0.0003	 142.401077	 142.401077	 142.401077	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 5771	 0.004351	 0.014929	 0.00662	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 7790	 0.004831	 0.017289	 0.00736	 135.264421	 135.264421	 135.264421	 0.0	 0.0	 1	 -30.0	 30.0;
	4362	 3845	 0.014289	 0.067609	 0.02174	 136.21168	 136.21168	 136.21168	 0.0	 0.0	 1	 -30.0	 30.0;
	4362	 3845	 0.013978	 0.0626	 0.02127	 171.034734	 171.034734	 171.034734	 0.0	 0.0	 1	 -30.0	 30.0;
	3304	 3709	 0.004431	 0.014609	 0.00674	 145.779615	 145.779615	 145.779615	 0.0	 0.0	 1	 -30.0	 30.0;
	3304	 3715	 0.00664	 0.025711	 0.0101	 131.61906	 131.61906	 131.61906	 0.0	 0.0	 1	 -30.0	 30.0;
	3304	 6446	 0.001289	 0.004422	 0.00197	 172.150608	 172.150608	 172.150608	 0.0	 0.0	 1	 -30.0	 30.0;
	3304	 1668	 0.01448	 0.065822	 0.02204	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3304	 2997	 0.004631	 0.017938	 0.00705	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3304	 2997	 0.00492	 0.01692	 0.0075	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6349	 4717	 0.027511	 0.120182	 0.04188	 147.797021	 147.797021	 147.797021	 0.0	 0.0	 1	 -30.0	 30.0;
	5794	 4717	 0.004	 0.014898	 0.00609	 115.942269	 115.942269	 115.942269	 0.0	 0.0	 1	 -30.0	 30.0;
	6969	 796	 0.000351	 0.001591	 0.0005	 123.096071	 123.096071	 123.096071	 0.0	 0.0	 1	 -30.0	 30.0;
	6349	 796	 0.018929	 0.084791	 0.02881	 123.096071	 123.096071	 123.096071	 0.0	 0.0	 1	 -30.0	 30.0;
	1718	 674	 0.013502	 0.063889	 0.02055	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1705	 4877	 0.01632	 0.057871	 0.02323	 147.719339	 147.719339	 147.719339	 0.0	 0.0	 1	 -30.0	 30.0;
	7094	 1967	 0.0	 0.000222	 0.0	 140.931605	 140.931605	 140.931605	 0.0	 0.0	 1	 -30.0	 30.0;
	2388	 1967	 0.01176	 0.04704	 0.01674	 126.372246	 126.372246	 126.372246	 0.0	 0.0	 1	 -30.0	 30.0;
	2836	 7098	 0.0	 0.000222	 0.0	 145.186474	 145.186474	 145.186474	 0.0	 0.0	 1	 -30.0	 30.0;
	8207	 7098	 0.02892	 0.057622	 0.02067	 259.813597	 259.813597	 259.813597	 0.0	 0.0	 1	 -30.0	 30.0;
	2495	 4246	 0.001711	 0.0078	 0.00261	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2517	 4246	 0.01224	 0.042022	 0.01862	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5877	 1997	 0.007769	 0.061249	 0.45691	 260.958049	 260.958049	 260.958049	 0.0	 0.0	 1	 -30.0	 30.0;
	8134	 5162	 0.001391	 0.0048	 0.00213	 110.657002	 110.657002	 110.657002	 0.0	 0.0	 1	 -30.0	 30.0;
	4141	 8134	 0.004071	 0.01988	 0.00579	 110.657002	 110.657002	 110.657002	 0.0	 0.0	 1	 -30.0	 30.0;
	7109	 5162	 0.001418	 0.004702	 0.00217	 136.648157	 136.648157	 136.648157	 0.0	 0.0	 1	 -30.0	 30.0;
	7109	 2807	 0.012711	 0.048809	 0.01808	 104.032168	 104.032168	 104.032168	 0.0	 0.0	 1	 -30.0	 30.0;
	4865	 1855	 0.0	 0.000222	 0.0	 106.583219	 106.583219	 106.583219	 0.0	 0.0	 1	 -30.0	 30.0;
	7382	 5162	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1855	 5162	 0.00448	 0.016698	 0.00683	 112.794699	 112.794699	 112.794699	 0.0	 0.0	 1	 -30.0	 30.0;
	6297	 4141	 0.014689	 0.052049	 0.0209	 110.503716	 110.503716	 110.503716	 0.0	 0.0	 1	 -30.0	 30.0;
	1855	 156	 0.025631	 0.084538	 0.03902	 111.34809	 111.34809	 111.34809	 0.0	 0.0	 1	 -30.0	 30.0;
	8005	 2381	 0.005431	 0.026551	 0.00774	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2381	 4027	 0.013151	 0.058898	 0.02002	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4606	 7485	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3300	 163	 0.00036	 0.001329	 0.00052	 121.803529	 121.803529	 121.803529	 0.0	 0.0	 1	 -30.0	 30.0;
	5384	 7621	 0.0	 0.00028	 0.0	 234.814128	 234.814128	 234.814128	 0.0	 0.0	 1	 -30.0	 30.0;
	7695	 5384	 0.0	 0.00028	 0.0	 234.814128	 234.814128	 234.814128	 0.0	 0.0	 1	 -30.0	 30.0;
	7621	 5248	 0.00612	 0.014671	 0.38151	 234.814128	 234.814128	 234.814128	 0.0	 0.0	 1	 -30.0	 30.0;
	6557	 7695	 0.006942	 0.014378	 0.43238	 288.451411	 288.451411	 288.451411	 0.0	 0.0	 1	 -30.0	 30.0;
	5625	 2974	 4.9e-05	 0.00028	 7e-05	 108.246507	 108.246507	 108.246507	 0.0	 0.0	 1	 -30.0	 30.0;
	3739	 5625	 0.002071	 0.008289	 0.00295	 108.246507	 108.246507	 108.246507	 0.0	 0.0	 1	 -30.0	 30.0;
	4767	 2974	 4.9e-05	 0.00028	 7e-05	 153.907437	 153.907437	 153.907437	 0.0	 0.0	 1	 -30.0	 30.0;
	4767	 6290	 0.000729	 0.003049	 0.00104	 134.178945	 134.178945	 134.178945	 0.0	 0.0	 1	 -30.0	 30.0;
	2246	 2974	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3094	 8336	 0.000409	 0.00184	 0.00062	 112.219225	 112.219225	 112.219225	 0.0	 0.0	 1	 -30.0	 30.0;
	2693	 8336	 0.0004	 0.00188	 0.00061	 120.980198	 120.980198	 120.980198	 0.0	 0.0	 1	 -30.0	 30.0;
	404	 6247	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6247	 6186	 0.003982	 0.020249	 0.00567	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6247	 7788	 0.006498	 0.031791	 0.00926	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8019	 5808	 0.000129	 0.000609	 0.00019	 123.799371	 123.799371	 123.799371	 0.0	 0.0	 1	 -30.0	 30.0;
	8019	 556	 0.00036	 0.000729	 0.00025	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8019	 7875	 0.000129	 0.000569	 0.00019	 126.333015	 126.333015	 126.333015	 0.0	 0.0	 1	 -30.0	 30.0;
	982	 8019	 0.0	 0.00028	 0.0	 152.298448	 152.298448	 152.298448	 0.0	 0.0	 1	 -30.0	 30.0;
	7875	 486	 0.006862	 0.030942	 0.00977	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3232	 4012	 0.0016	 0.00716	 0.00243	 138.212718	 138.212718	 138.212718	 0.0	 0.0	 1	 -30.0	 30.0;
	3232	 7338	 0.001849	 0.006542	 0.00263	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	697	 4012	 0.001809	 0.007018	 0.00275	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	697	 2689	 0.004302	 0.01588	 0.00612	 133.261304	 133.261304	 133.261304	 0.0	 0.0	 1	 -30.0	 30.0;
	2958	 4012	 0.0	 0.000222	 0.0	 121.347306	 121.347306	 121.347306	 0.0	 0.0	 1	 -30.0	 30.0;
	7016	 6218	 0.008831	 0.036751	 0.01257	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7016	 56	 0.011031	 0.045942	 0.01571	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5950	 7016	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 7016	 0.043418	 0.124111	 0.03102	 221.186699	 221.186699	 221.186699	 0.0	 0.0	 1	 -30.0	 30.0;
	8236	 8073	 0.011698	 0.048702	 0.01666	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7925	 3486	 0.005058	 0.02572	 0.00719	 245.897261	 245.897261	 245.897261	 0.0	 0.0	 1	 -30.0	 30.0;
	7329	 3486	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1245	 5462	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7940	 7397	 0.008969	 0.032062	 0.01364	 135.57723	 135.57723	 135.57723	 0.0	 0.0	 1	 -30.0	 30.0;
	2138	 6370	 0.000489	 0.002369	 0.03105	 110.000988	 110.000988	 110.000988	 0.0	 0.0	 1	 -30.0	 30.0;
	2879	 6370	 0.0028	 0.0096	 0.00426	 108.656484	 108.656484	 108.656484	 0.0	 0.0	 1	 -30.0	 30.0;
	2138	 4279	 0.00048	 0.002191	 0.03038	 120.645046	 120.645046	 120.645046	 0.0	 0.0	 1	 -30.0	 30.0;
	2879	 4279	 0.002849	 0.0094	 0.00433	 130.559565	 130.559565	 130.559565	 0.0	 0.0	 1	 -30.0	 30.0;
	4295	 2138	 0.0	 0.000222	 0.0	 124.719349	 124.719349	 124.719349	 0.0	 0.0	 1	 -30.0	 30.0;
	3789	 7940	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7404	 7940	 0.005138	 0.023391	 0.00783	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3032	 7940	 0.005031	 0.023831	 0.00766	 119.060999	 119.060999	 119.060999	 0.0	 0.0	 1	 -30.0	 30.0;
	5467	 7940	 0.00492	 0.022062	 0.0075	 110.549182	 110.549182	 110.549182	 0.0	 0.0	 1	 -30.0	 30.0;
	7940	 4487	 0.012449	 0.03368	 0.00889	 141.554624	 141.554624	 141.554624	 0.0	 0.0	 1	 -30.0	 30.0;
	3906	 4821	 0.0	 0.000222	 0.0	 112.797557	 112.797557	 112.797557	 0.0	 0.0	 1	 -30.0	 30.0;
	1250	 4821	 0.005582	 0.021622	 0.0085	 128.576453	 128.576453	 128.576453	 0.0	 0.0	 1	 -30.0	 30.0;
	4821	 1766	 0.011769	 0.052729	 0.01792	 108.126216	 108.126216	 108.126216	 0.0	 0.0	 1	 -30.0	 30.0;
	1639	 6908	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7812	 6908	 0.005489	 0.019618	 0.00835	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6765	 6908	 0.005591	 0.0192	 0.00851	 112.016056	 112.016056	 112.016056	 0.0	 0.0	 1	 -30.0	 30.0;
	6378	 1386	 0.0	 0.00028	 0.0	 118.716235	 118.716235	 118.716235	 0.0	 0.0	 1	 -30.0	 30.0;
	6618	 7404	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3032	 7129	 0.0	 0.000222	 0.0	 118.724548	 118.724548	 118.724548	 0.0	 0.0	 1	 -30.0	 30.0;
	1386	 7129	 0.0	 0.00028	 0.0	 118.855232	 118.855232	 118.855232	 0.0	 0.0	 1	 -30.0	 30.0;
	3250	 967	 0.0	 0.000222	 0.0	 110.57932	 110.57932	 110.57932	 0.0	 0.0	 1	 -30.0	 30.0;
	8299	 3250	 0.0	 0.00028	 0.0	 110.580359	 110.580359	 110.580359	 0.0	 0.0	 1	 -30.0	 30.0;
	967	 6505	 0.0	 0.000222	 0.0	 110.372513	 110.372513	 110.372513	 0.0	 0.0	 1	 -30.0	 30.0;
	6505	 5467	 0.0	 0.000222	 0.0	 147.997333	 147.997333	 147.997333	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 6237	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4682	 447	 0.0	 0.000222	 0.0	 123.009815	 123.009815	 123.009815	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 8299	 0.0	 0.00028	 0.0	 110.580359	 110.580359	 110.580359	 0.0	 0.0	 1	 -30.0	 30.0;
	3642	 1118	 0.0	 0.000222	 0.0	 128.62218	 128.62218	 128.62218	 0.0	 0.0	 1	 -30.0	 30.0;
	289	 3642	 0.012969	 0.046369	 0.01975	 134.301055	 134.301055	 134.301055	 0.0	 0.0	 1	 -30.0	 30.0;
	1118	 3353	 0.0	 0.000222	 0.0	 139.793388	 139.793388	 139.793388	 0.0	 0.0	 1	 -30.0	 30.0;
	3353	 1250	 0.0	 0.000222	 0.0	 128.420309	 128.420309	 128.420309	 0.0	 0.0	 1	 -30.0	 30.0;
	447	 6618	 0.0	 0.000222	 0.0	 134.316123	 134.316123	 134.316123	 0.0	 0.0	 1	 -30.0	 30.0;
	7278	 6773	 0.003151	 0.00128	 0.07715	 162.096053	 162.096053	 162.096053	 0.0	 0.0	 1	 -30.0	 30.0;
	1397	 282	 0.00154	 0.01649	 0.3469	 1421.641634	 1421.641634	 1421.641634	 0.0	 0.0	 1	 -30.0	 30.0;
	2879	 5313	 0.001298	 0.00568	 0.00198	 153.207255	 153.207255	 153.207255	 0.0	 0.0	 1	 -30.0	 30.0;
	2879	 1674	 0.0002	 0.000871	 0.0003	 148.804036	 148.804036	 148.804036	 0.0	 0.0	 1	 -30.0	 30.0;
	7956	 7188	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8245	 7188	 4e-05	 0.00028	 7e-05	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2730	 7188	 4e-05	 0.00028	 7e-05	 126.070349	 126.070349	 126.070349	 0.0	 0.0	 1	 -30.0	 30.0;
	2730	 7790	 0.010071	 0.039	 0.01533	 126.185444	 126.185444	 126.185444	 0.0	 0.0	 1	 -30.0	 30.0;
	3940	 4987	 0.000218	 0.000849	 0.00034	 131.164397	 131.164397	 131.164397	 0.0	 0.0	 1	 -30.0	 30.0;
	1683	 4987	 0.000231	 0.00084	 0.00034	 134.623736	 134.623736	 134.623736	 0.0	 0.0	 1	 -30.0	 30.0;
	7813	 4987	 0.000231	 0.000822	 0.00035	 128.246498	 128.246498	 128.246498	 0.0	 0.0	 1	 -30.0	 30.0;
	90	 4987	 0.00024	 0.0008	 0.00036	 110.255599	 110.255599	 110.255599	 0.0	 0.0	 1	 -30.0	 30.0;
	6401	 4987	 0.00024	 0.000782	 0.00036	 118.197918	 118.197918	 118.197918	 0.0	 0.0	 1	 -30.0	 30.0;
	4987	 3469	 0.000209	 0.000889	 0.00032	 140.242075	 140.242075	 140.242075	 0.0	 0.0	 1	 -30.0	 30.0;
	8	 4987	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2912	 4987	 0.000209	 0.000911	 0.00032	 146.39432	 146.39432	 146.39432	 0.0	 0.0	 1	 -30.0	 30.0;
	4347	 1683	 0.00784	 0.025862	 0.01193	 133.505783	 133.505783	 133.505783	 0.0	 0.0	 1	 -30.0	 30.0;
	7813	 5321	 0.001991	 0.009391	 0.00302	 107.006445	 107.006445	 107.006445	 0.0	 0.0	 1	 -30.0	 30.0;
	90	 4560	 0.003591	 0.01184	 0.00547	 110.185451	 110.185451	 110.185451	 0.0	 0.0	 1	 -30.0	 30.0;
	6997	 485	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1397	 1826	 0.00013	 0.00077	 1.1635	 954.363286	 954.363286	 954.363286	 0.0	 0.0	 1	 -30.0	 30.0;
	965	 1826	 0.00013	 0.00076	 1.18504	 1007.752817	 1007.752817	 1007.752817	 0.0	 0.0	 1	 -30.0	 30.0;
	826	 1826	 0.0002	 0.00127	 1.74286	 991.816321	 991.816321	 991.816321	 0.0	 0.0	 1	 -30.0	 30.0;
	3718	 4416	 0.002449	 0.006871	 0.25648	 160.788961	 160.788961	 160.788961	 0.0	 0.0	 1	 -30.0	 30.0;
	2301	 6654	 0.00132	 0.004929	 0.16497	 263.264362	 263.264362	 263.264362	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 2172	 0.0	 0.00028	 0.0	 129.114255	 129.114255	 129.114255	 0.0	 0.0	 1	 -30.0	 30.0;
	2172	 2285	 0.036111	 0.084471	 0.0258	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2172	 2499	 0.043129	 0.093129	 0.03081	 211.828428	 211.828428	 211.828428	 0.0	 0.0	 1	 -30.0	 30.0;
	5462	 7660	 0.001071	 0.004129	 0.00153	 165.402105	 165.402105	 165.402105	 0.0	 0.0	 1	 -30.0	 30.0;
	1061	 7660	 0.01016	 0.036298	 0.01545	 145.94797	 145.94797	 145.94797	 0.0	 0.0	 1	 -30.0	 30.0;
	4386	 5462	 0.010951	 0.055689	 0.01558	 133.312487	 133.312487	 133.312487	 0.0	 0.0	 1	 -30.0	 30.0;
	3553	 6429	 0.005831	 0.022591	 0.00887	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	84	 6429	 0.016542	 0.075222	 0.02518	 144.923289	 144.923289	 144.923289	 0.0	 0.0	 1	 -30.0	 30.0;
	6429	 4832	 0.015938	 0.00716	 0.57456	 127.225194	 127.225194	 127.225194	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 2368	 0.0	 0.000222	 0.0	 190.753354	 190.753354	 190.753354	 0.0	 0.0	 1	 -30.0	 30.0;
	2368	 492	 0.009591	 0.02332	 0.5977	 191.380009	 191.380009	 191.380009	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 5248	 0.0	 0.000222	 0.0	 190.753354	 190.753354	 190.753354	 0.0	 0.0	 1	 -30.0	 30.0;
	2415	 3345	 0.03828	 0.10096	 0.02735	 126.142576	 126.142576	 126.142576	 0.0	 0.0	 1	 -30.0	 30.0;
	84	 3345	 0.03036	 0.086778	 0.02169	 271.433752	 271.433752	 271.433752	 0.0	 0.0	 1	 -30.0	 30.0;
	3013	 1173	 0.0	 0.00028	 0.0	 151.013959	 151.013959	 151.013959	 0.0	 0.0	 1	 -30.0	 30.0;
	7134	 2019	 0.002182	 0.010329	 0.00332	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7134	 4271	 0.002129	 0.009569	 0.00325	 124.765855	 124.765855	 124.765855	 0.0	 0.0	 1	 -30.0	 30.0;
	5136	 2783	 0.0018	 0.00668	 0.00274	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2350	 2783	 0.004569	 0.01636	 0.00696	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5136	 2885	 0.001831	 0.006542	 0.00279	 132.532024	 132.532024	 132.532024	 0.0	 0.0	 1	 -30.0	 30.0;
	2350	 3929	 0.006338	 0.026609	 0.00965	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6306	 6349	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6349	 5517	 0.016231	 0.070902	 0.02471	 121.61205	 121.61205	 121.61205	 0.0	 0.0	 1	 -30.0	 30.0;
	6349	 7528	 0.010138	 0.046102	 0.01543	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 2031	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 8260	 0.006431	 0.028991	 0.00915	 135.175307	 135.175307	 135.175307	 0.0	 0.0	 1	 -30.0	 30.0;
	2495	 5647	 0.01184	 0.053022	 0.01802	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2495	 2517	 0.012529	 0.044422	 0.01783	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6883	 5112	 0.00436	 0.010689	 0.00341	 242.084844	 242.084844	 242.084844	 0.0	 0.0	 1	 -30.0	 30.0;
	4575	 6883	 0.019529	 0.055831	 0.01396	 242.767099	 242.767099	 242.767099	 0.0	 0.0	 1	 -30.0	 30.0;
	2894	 5112	 0.004942	 0.01048	 0.00387	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7306	 5112	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1157	 2198	 0.006431	 0.01764	 0.00459	 230.379472	 230.379472	 230.379472	 0.0	 0.0	 1	 -30.0	 30.0;
	4203	 1157	 4e-05	 0.00028	 7e-05	 118.215585	 118.215585	 118.215585	 0.0	 0.0	 1	 -30.0	 30.0;
	8081	 2198	 0.003431	 0.013218	 0.0049	 127.741692	 127.741692	 127.741692	 0.0	 0.0	 1	 -30.0	 30.0;
	4999	 2198	 0.0	 0.00028	 0.0	 122.946422	 122.946422	 122.946422	 0.0	 0.0	 1	 -30.0	 30.0;
	2198	 5398	 0.00708	 0.014702	 0.00507	 265.50806	 265.50806	 265.50806	 0.0	 0.0	 1	 -30.0	 30.0;
	3299	 2198	 0.065422	 0.130311	 0.04674	 131.82249	 131.82249	 131.82249	 0.0	 0.0	 1	 -30.0	 30.0;
	8081	 3240	 0.003049	 0.013831	 0.00463	 131.231168	 131.231168	 131.231168	 0.0	 0.0	 1	 -30.0	 30.0;
	8252	 8081	 0.011209	 0.051009	 0.01708	 125.614906	 125.614906	 125.614906	 0.0	 0.0	 1	 -30.0	 30.0;
	737	 8081	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7258	 8081	 0.00504	 0.024622	 0.00717	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 3240	 0.009049	 0.033671	 0.01377	 144.230642	 144.230642	 144.230642	 0.0	 0.0	 1	 -30.0	 30.0;
	5138	 3240	 0.0	 0.00028	 0.0	 145.528121	 145.528121	 145.528121	 0.0	 0.0	 1	 -30.0	 30.0;
	4203	 6025	 4e-05	 0.00028	 7e-05	 144.768184	 144.768184	 144.768184	 0.0	 0.0	 1	 -30.0	 30.0;
	4364	 4203	 0.0	 0.00028	 0.0	 127.31197	 127.31197	 127.31197	 0.0	 0.0	 1	 -30.0	 30.0;
	8252	 5398	 0.007631	 0.015569	 0.00598	 253.829188	 253.829188	 253.829188	 0.0	 0.0	 1	 -30.0	 30.0;
	8252	 2225	 0.000822	 0.00316	 0.00124	 134.696742	 134.696742	 134.696742	 0.0	 0.0	 1	 -30.0	 30.0;
	8252	 6756	 0.017751	 0.060929	 0.02701	 128.441353	 128.441353	 128.441353	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 6025	 0.007418	 0.016022	 0.0053	 265.277091	 265.277091	 265.277091	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 8210	 0.007542	 0.035689	 0.01148	 131.800406	 131.800406	 131.800406	 0.0	 0.0	 1	 -30.0	 30.0;
	8109	 423	 0.0	 0.000222	 0.0	 108.830814	 108.830814	 108.830814	 0.0	 0.0	 1	 -30.0	 30.0;
	423	 1179	 0.000338	 0.001218	 0.00052	 126.692069	 126.692069	 126.692069	 0.0	 0.0	 1	 -30.0	 30.0;
	7761	 158	 0.0	 0.000222	 0.0	 117.221821	 117.221821	 117.221821	 0.0	 0.0	 1	 -30.0	 30.0;
	158	 7075	 0.000351	 0.001191	 0.00053	 183.81623	 183.81623	 183.81623	 0.0	 0.0	 1	 -30.0	 30.0;
	6298	 1061	 0.004662	 0.016009	 0.0071	 145.763507	 145.763507	 145.763507	 0.0	 0.0	 1	 -30.0	 30.0;
	6298	 7606	 0.017489	 0.084191	 0.02489	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1061	 25	 0.003809	 0.013111	 0.00581	 138.165433	 138.165433	 138.165433	 0.0	 0.0	 1	 -30.0	 30.0;
	1061	 5530	 0.003489	 0.013502	 0.0053	 134.966162	 134.966162	 134.966162	 0.0	 0.0	 1	 -30.0	 30.0;
	3300	 1061	 0.004738	 0.015658	 0.00723	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2898	 1061	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1061	 2329	 0.010351	 0.035529	 0.01575	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1061	 5775	 0.00388	 0.012822	 0.00592	 126.834963	 126.834963	 126.834963	 0.0	 0.0	 1	 -30.0	 30.0;
	1179	 25	 0.003729	 0.013218	 0.00531	 150.547345	 150.547345	 150.547345	 0.0	 0.0	 1	 -30.0	 30.0;
	5530	 6435	 0.002418	 0.008298	 0.00368	 131.386792	 131.386792	 131.386792	 0.0	 0.0	 1	 -30.0	 30.0;
	7075	 6435	 0.001538	 0.007822	 0.00219	 127.458761	 127.458761	 127.458761	 0.0	 0.0	 1	 -30.0	 30.0;
	1173	 5724	 0.005369	 0.010702	 0.00384	 266.310346	 266.310346	 266.310346	 0.0	 0.0	 1	 -30.0	 30.0;
	2283	 6733	 0.00088	 0.0075	 0.19784	 1492.804639	 1492.804639	 1492.804639	 0.0	 0.0	 1	 -30.0	 30.0;
	2283	 6733	 0.0009	 0.00734	 0.20157	 1436.032724	 1436.032724	 1436.032724	 0.0	 0.0	 1	 -30.0	 30.0;
	1910	 6557	 0.0	 0.00028	 0.0	 288.451411	 288.451411	 288.451411	 0.0	 0.0	 1	 -30.0	 30.0;
	1430	 7560	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1910	 7560	 0.0	 0.00028	 0.0	 288.451411	 288.451411	 288.451411	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 7560	 0.018831	 0.072951	 0.02866	 118.742215	 118.742215	 118.742215	 0.0	 0.0	 1	 -30.0	 30.0;
	5663	 7560	 0.012351	 0.042409	 0.01879	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4575	 3553	 0.001938	 0.008698	 0.00295	 112.425253	 112.425253	 112.425253	 0.0	 0.0	 1	 -30.0	 30.0;
	1874	 4575	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5839	 7850	 0.017871	 0.047151	 0.01277	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7850	 605	 0.00076	 0.002098	 0.00055	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4877	 4584	 0.0	 0.000222	 0.0	 180.462893	 180.462893	 180.462893	 0.0	 0.0	 1	 -30.0	 30.0;
	7325	 2329	 0.005249	 0.024631	 0.00747	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7340	 7325	 0.0	 0.00028	 0.0	 116.163365	 116.163365	 116.163365	 0.0	 0.0	 1	 -30.0	 30.0;
	1577	 3636	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7711	 3636	 0.00016	 0.000502	 0.00023	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3455	 7711	 0.008658	 0.037809	 0.01318	 121.681159	 121.681159	 121.681159	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 3636	 0.000142	 0.00056	 0.00021	 121.076327	 121.076327	 121.076327	 0.0	 0.0	 1	 -30.0	 30.0;
	6136	 5839	 4e-05	 0.00028	 7e-05	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6136	 5087	 4e-05	 0.00028	 7e-05	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6781	 2870	 0.0002	 0.00092	 0.00031	 127.253513	 127.253513	 127.253513	 0.0	 0.0	 1	 -30.0	 30.0;
	2870	 1193	 0.002542	 0.010649	 0.00386	 178.481081	 178.481081	 178.481081	 0.0	 0.0	 1	 -30.0	 30.0;
	5736	 26	 0.054	 0.121351	 0.03857	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5978	 6781	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3143	 3904	 0.001969	 0.004271	 0.00141	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3143	 3299	 0.009111	 0.025009	 0.0065	 288.424911	 288.424911	 288.424911	 0.0	 0.0	 1	 -30.0	 30.0;
	1585	 3143	 0.027502	 0.074369	 0.01964	 129.670503	 129.670503	 129.670503	 0.0	 0.0	 1	 -30.0	 30.0;
	7142	 6145	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6145	 3265	 0.0002	 0.000942	 0.0003	 166.139699	 166.139699	 166.139699	 0.0	 0.0	 1	 -30.0	 30.0;
	6145	 6186	 0.0002	 0.000871	 0.0003	 108.33718	 108.33718	 108.33718	 0.0	 0.0	 1	 -30.0	 30.0;
	1813	 8330	 0.00052	 0.00136	 0.00036	 133.171671	 133.171671	 133.171671	 0.0	 0.0	 1	 -30.0	 30.0;
	2888	 1813	 0.020471	 0.07928	 0.03116	 134.318202	 134.318202	 134.318202	 0.0	 0.0	 1	 -30.0	 30.0;
	4404	 765	 3.1e-05	 0.00028	 5e-05	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5650	 765	 0.015609	 0.076289	 0.02222	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4404	 7258	 3.1e-05	 0.00028	 5e-05	 132.20077	 132.20077	 132.20077	 0.0	 0.0	 1	 -30.0	 30.0;
	2156	 4404	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7646	 6608	 0.008809	 0.041342	 0.01254	 132.074763	 132.074763	 132.074763	 0.0	 0.0	 1	 -30.0	 30.0;
	7885	 6608	 0.011698	 0.017782	 0.41382	 110.235075	 110.235075	 110.235075	 0.0	 0.0	 1	 -30.0	 30.0;
	5397	 7646	 0.029769	 0.069649	 0.02127	 268.430376	 268.430376	 268.430376	 0.0	 0.0	 1	 -30.0	 30.0;
	5287	 5180	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 5180	 0.006738	 0.024089	 0.01025	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5287	 7370	 0.0	 0.00028	 0.0	 154.442121	 154.442121	 154.442121	 0.0	 0.0	 1	 -30.0	 30.0;
	1252	 5287	 0.0	 0.000222	 0.0	 127.1366	 127.1366	 127.1366	 0.0	 0.0	 1	 -30.0	 30.0;
	7803	 3369	 0.0	 0.000222	 0.0	 114.651025	 114.651025	 114.651025	 0.0	 0.0	 1	 -30.0	 30.0;
	5591	 2301	 0.0	 0.000222	 0.0	 109.248325	 109.248325	 109.248325	 0.0	 0.0	 1	 -30.0	 30.0;
	3369	 2301	 0.0	 0.000222	 0.0	 178.57643	 178.57643	 178.57643	 0.0	 0.0	 1	 -30.0	 30.0;
	800	 3369	 0.001062	 0.003649	 0.1323	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2415	 1628	 0.00204	 0.009129	 0.0031	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2415	 1628	 0.00232	 0.008951	 0.00352	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2415	 5427	 0.00152	 0.006911	 0.00231	 108.027489	 108.027489	 108.027489	 0.0	 0.0	 1	 -30.0	 30.0;
	2415	 5427	 0.001489	 0.00704	 0.00226	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2415	 5427	 0.001462	 0.00652	 0.00221	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2415	 7935	 0.001391	 0.003609	 0.00109	 269.768645	 269.768645	 269.768645	 0.0	 0.0	 1	 -30.0	 30.0;
	2415	 5415	 0.001658	 0.003311	 0.00119	 129.171673	 129.171673	 129.171673	 0.0	 0.0	 1	 -30.0	 30.0;
	2415	 7389	 0.000991	 0.004329	 0.00151	 113.547622	 113.547622	 113.547622	 0.0	 0.0	 1	 -30.0	 30.0;
	2415	 2439	 0.010369	 0.038569	 0.01578	 120.722729	 120.722729	 120.722729	 0.0	 0.0	 1	 -30.0	 30.0;
	1213	 1628	 0.0	 0.000222	 0.0	 161.471476	 161.471476	 161.471476	 0.0	 0.0	 1	 -30.0	 30.0;
	1213	 5474	 0.026809	 0.126889	 0.04081	 142.14023	 142.14023	 142.14023	 0.0	 0.0	 1	 -30.0	 30.0;
	7829	 1628	 0.0	 0.000222	 0.0	 168.693608	 168.693608	 168.693608	 0.0	 0.0	 1	 -30.0	 30.0;
	7829	 7668	 0.026218	 0.117489	 0.03992	 163.148534	 163.148534	 163.148534	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 1628	 0.00064	 0.002662	 0.00097	 130.938105	 130.938105	 130.938105	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 1628	 0.000622	 0.002711	 0.00095	 132.30781	 132.30781	 132.30781	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 75	 0.000609	 0.002271	 0.00093	 138.773903	 138.773903	 138.773903	 0.0	 0.0	 1	 -30.0	 30.0;
	4217	 7935	 0.002098	 0.005702	 0.0015	 269.768645	 269.768645	 269.768645	 0.0	 0.0	 1	 -30.0	 30.0;
	1985	 5415	 0.002582	 0.006031	 0.00184	 133.471489	 133.471489	 133.471489	 0.0	 0.0	 1	 -30.0	 30.0;
	3726	 1985	 0.019458	 0.055618	 0.0139	 129.126986	 129.126986	 129.126986	 0.0	 0.0	 1	 -30.0	 30.0;
	1322	 7389	 0.00092	 0.003289	 0.0014	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1322	 75	 0.000942	 0.003222	 0.00143	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7467	 1322	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4217	 5558	 0.03868	 0.1062	 0.02764	 264.496369	 264.496369	 264.496369	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 8321	 0.0	 0.000222	 0.0	 127.13634	 127.13634	 127.13634	 0.0	 0.0	 1	 -30.0	 30.0;
	2177	 8321	 0.000689	 0.00312	 0.00106	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	289	 8321	 0.0008	 0.002991	 0.00123	 127.690509	 127.690509	 127.690509	 0.0	 0.0	 1	 -30.0	 30.0;
	906	 7612	 0.000511	 0.001191	 0.00037	 113.412782	 113.412782	 113.412782	 0.0	 0.0	 1	 -30.0	 30.0;
	8023	 606	 0.0	 0.00028	 0.0	 149.142565	 149.142565	 149.142565	 0.0	 0.0	 1	 -30.0	 30.0;
	2285	 2519	 0.01216	 0.048609	 0.0173	 108.02619	 108.02619	 108.02619	 0.0	 0.0	 1	 -30.0	 30.0;
	3512	 2439	 0.000769	 0.00348	 0.00118	 143.345477	 143.345477	 143.345477	 0.0	 0.0	 1	 -30.0	 30.0;
	3512	 5414	 0.000871	 0.003409	 0.00134	 120.196618	 120.196618	 120.196618	 0.0	 0.0	 1	 -30.0	 30.0;
	5715	 7482	 0.007071	 0.03316	 0.01005	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	486	 5113	 0.009609	 0.038418	 0.01368	 121.668169	 121.668169	 121.668169	 0.0	 0.0	 1	 -30.0	 30.0;
	687	 486	 0.0	 0.00028	 0.0	 144.419003	 144.419003	 144.419003	 0.0	 0.0	 1	 -30.0	 30.0;
	7867	 5113	 0.00724	 0.014951	 0.25617	 121.668169	 121.668169	 121.668169	 0.0	 0.0	 1	 -30.0	 30.0;
	2950	 3929	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7247	 3929	 0.016071	 0.067418	 0.02446	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7247	 3929	 0.015738	 0.068751	 0.02396	 112.292751	 112.292751	 112.292751	 0.0	 0.0	 1	 -30.0	 30.0;
	3929	 3855	 0.017431	 0.037622	 0.01244	 223.982229	 223.982229	 223.982229	 0.0	 0.0	 1	 -30.0	 30.0;
	6138	 5815	 0.001031	 0.003378	 0.1074	 154.905358	 154.905358	 154.905358	 0.0	 0.0	 1	 -30.0	 30.0;
	5815	 7266	 0.000169	 0.00068	 0.00028	 180.218674	 180.218674	 180.218674	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 6138	 0.006249	 0.023262	 0.00952	 154.432768	 154.432768	 154.432768	 0.0	 0.0	 1	 -30.0	 30.0;
	8240	 5484	 8.9e-05	 0.000471	 0.00013	 134.187519	 134.187519	 134.187519	 0.0	 0.0	 1	 -30.0	 30.0;
	2719	 2388	 0.0	 0.000222	 0.0	 117.47981	 117.47981	 117.47981	 0.0	 0.0	 1	 -30.0	 30.0;
	3868	 2388	 0.01564	 0.065089	 0.02226	 114.830552	 114.830552	 114.830552	 0.0	 0.0	 1	 -30.0	 30.0;
	2388	 1551	 0.018938	 0.085391	 0.02696	 135.731036	 135.731036	 135.731036	 0.0	 0.0	 1	 -30.0	 30.0;
	2388	 1342	 0.016511	 0.044662	 0.0118	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7804	 468	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	468	 7867	 0.002689	 0.012938	 0.00382	 152.506034	 152.506034	 152.506034	 0.0	 0.0	 1	 -30.0	 30.0;
	4615	 2604	 0.0	 0.000222	 0.0	 121.16726	 121.16726	 121.16726	 0.0	 0.0	 1	 -30.0	 30.0;
	744	 4615	 0.007649	 0.019631	 0.45863	 128.375103	 128.375103	 128.375103	 0.0	 0.0	 1	 -30.0	 30.0;
	5677	 327	 0.008849	 0.02096	 0.53038	 108.171423	 108.171423	 108.171423	 0.0	 0.0	 1	 -30.0	 30.0;
	2604	 5677	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	327	 4398	 0.0	 0.00028	 0.0	 141.008508	 141.008508	 141.008508	 0.0	 0.0	 1	 -30.0	 30.0;
	9	 2159	 0.00232	 0.00928	 0.00331	 106.685843	 106.685843	 106.685843	 0.0	 0.0	 1	 -30.0	 30.0;
	2445	 1383	 0.0	 0.000222	 0.0	 130.409656	 130.409656	 130.409656	 0.0	 0.0	 1	 -30.0	 30.0;
	6756	 5316	 0.0	 0.000222	 0.0	 127.529948	 127.529948	 127.529948	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 2016	 0.0	 0.000222	 0.0	 108.992934	 108.992934	 108.992934	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 3082	 0.0088	 0.034102	 0.0134	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6689	 4472	 0.0	 0.000222	 0.0	 112.208573	 112.208573	 112.208573	 0.0	 0.0	 1	 -30.0	 30.0;
	6366	 2953	 0.0	 0.00028	 0.0	 134.717786	 134.717786	 134.717786	 0.0	 0.0	 1	 -30.0	 30.0;
	7395	 3718	 0.0	 0.00028	 0.0	 137.527605	 137.527605	 137.527605	 0.0	 0.0	 1	 -30.0	 30.0;
	4916	 1466	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7118	 6978	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6989	 4787	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 8020	 0.0	 0.00028	 0.0	 129.923556	 129.923556	 129.923556	 0.0	 0.0	 1	 -30.0	 30.0;
	8020	 5695	 0.002542	 0.00392	 0.11078	 284.003505	 284.003505	 284.003505	 0.0	 0.0	 1	 -30.0	 30.0;
	6802	 4156	 0.00296	 0.013462	 0.00451	 128.044627	 128.044627	 128.044627	 0.0	 0.0	 1	 -30.0	 30.0;
	7204	 6802	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6802	 92	 0.002489	 0.003991	 0.10852	 268.990262	 268.990262	 268.990262	 0.0	 0.0	 1	 -30.0	 30.0;
	696	 4609	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7237	 4609	 0.000289	 0.000742	 0.03021	 127.090873	 127.090873	 127.090873	 0.0	 0.0	 1	 -30.0	 30.0;
	6846	 3578	 0.0	 0.00028	 0.0	 120.61361	 120.61361	 120.61361	 0.0	 0.0	 1	 -30.0	 30.0;
	2338	 3578	 0.000302	 0.000729	 0.03077	 136.212459	 136.212459	 136.212459	 0.0	 0.0	 1	 -30.0	 30.0;
	3578	 6326	 0.000662	 0.002111	 0.08262	 129.438755	 129.438755	 129.438755	 0.0	 0.0	 1	 -30.0	 30.0;
	4011	 1097	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5924	 1466	 0.000822	 0.002871	 0.07999	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1466	 7877	 0.006391	 0.028809	 0.00909	 106.503198	 106.503198	 106.503198	 0.0	 0.0	 1	 -30.0	 30.0;
	2558	 6978	 0.000831	 0.002809	 0.08156	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6181	 5924	 0.014791	 0.005969	 0.54372	 114.125954	 114.125954	 114.125954	 0.0	 0.0	 1	 -30.0	 30.0;
	3933	 2558	 0.01508	 0.005849	 0.55418	 106.359265	 106.359265	 106.359265	 0.0	 0.0	 1	 -30.0	 30.0;
	3884	 4787	 0.011302	 0.050578	 0.01719	 123.883289	 123.883289	 123.883289	 0.0	 0.0	 1	 -30.0	 30.0;
	906	 4787	 0.01704	 0.033938	 0.01218	 259.046645	 259.046645	 259.046645	 0.0	 0.0	 1	 -30.0	 30.0;
	7653	 4900	 0.001262	 0.00532	 0.00193	 146.333525	 146.333525	 146.333525	 0.0	 0.0	 1	 -30.0	 30.0;
	7653	 2689	 0.00124	 0.005431	 0.00189	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5723	 322	 0.0	 0.00028	 0.0	 107.024112	 107.024112	 107.024112	 0.0	 0.0	 1	 -30.0	 30.0;
	322	 2404	 0.001538	 0.004609	 0.18216	 136.534361	 136.534361	 136.534361	 0.0	 0.0	 1	 -30.0	 30.0;
	1181	 7927	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 5457	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7522	 5457	 0.00244	 0.004071	 0.10626	 299.492196	 299.492196	 299.492196	 0.0	 0.0	 1	 -30.0	 30.0;
	2013	 4668	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5056	 4668	 0.002649	 0.003631	 0.11572	 274.251106	 274.251106	 274.251106	 0.0	 0.0	 1	 -30.0	 30.0;
	4524	 1356	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2289	 1247	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7507	 5313	 0.000849	 0.001769	 0.00062	 107.980984	 107.980984	 107.980984	 0.0	 0.0	 1	 -30.0	 30.0;
	5313	 7139	 0.000951	 0.003991	 0.00144	 149.026691	 149.026691	 149.026691	 0.0	 0.0	 1	 -30.0	 30.0;
	4263	 4398	 0.0	 0.000222	 0.0	 116.552817	 116.552817	 116.552817	 0.0	 0.0	 1	 -30.0	 30.0;
	4263	 7178	 0.0034	 0.00872	 0.20383	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6221	 7247	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1097	 4301	 0.001978	 0.007671	 0.00302	 126.877571	 126.877571	 126.877571	 0.0	 0.0	 1	 -30.0	 30.0;
	1097	 819	 0.002018	 0.00752	 0.00308	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6332	 3868	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3868	 872	 0.018351	 0.070502	 0.02612	 123.216103	 123.216103	 123.216103	 0.0	 0.0	 1	 -30.0	 30.0;
	7606	 4905	 0.0028	 0.014209	 0.00397	 160.337675	 160.337675	 160.337675	 0.0	 0.0	 1	 -30.0	 30.0;
	842	 8180	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6690	 1456	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6290	 1456	 0.02624	 0.096858	 0.03736	 126.419011	 126.419011	 126.419011	 0.0	 0.0	 1	 -30.0	 30.0;
	406	 5386	 5.8e-05	 0.00024	 0.00011	 118.302621	 118.302621	 118.302621	 0.0	 0.0	 1	 -30.0	 30.0;
	406	 6446	 5.8e-05	 0.000231	 0.00011	 171.76947	 171.76947	 171.76947	 0.0	 0.0	 1	 -30.0	 30.0;
	5920	 3715	 0.0012	 0.005809	 0.00172	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5920	 6842	 8.9e-05	 0.00028	 0.00013	 118.517482	 118.517482	 118.517482	 0.0	 0.0	 1	 -30.0	 30.0;
	5920	 5789	 8e-05	 0.00032	 0.00012	 121.12673	 121.12673	 121.12673	 0.0	 0.0	 1	 -30.0	 30.0;
	6842	 2997	 0.006889	 0.032631	 0.01049	 116.546062	 116.546062	 116.546062	 0.0	 0.0	 1	 -30.0	 30.0;
	5789	 2997	 0.006738	 0.030209	 0.01026	 121.269104	 121.269104	 121.269104	 0.0	 0.0	 1	 -30.0	 30.0;
	4770	 2658	 0.001218	 0.004031	 0.00186	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2658	 906	 0.005751	 0.012929	 0.00411	 291.679261	 291.679261	 291.679261	 0.0	 0.0	 1	 -30.0	 30.0;
	142	 3441	 0.000462	 0.001791	 0.0007	 131.458759	 131.458759	 131.458759	 0.0	 0.0	 1	 -30.0	 30.0;
	142	 5658	 0.00352	 0.007302	 0.00252	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	64	 4475	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 1972	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1204	 5120	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5120	 899	 0.001289	 0.005022	 0.16146	 239.000408	 239.000408	 239.000408	 0.0	 0.0	 1	 -30.0	 30.0;
	3245	 7315	 0.0	 0.00028	 0.0	 149.490967	 149.490967	 149.490967	 0.0	 0.0	 1	 -30.0	 30.0;
	7600	 7877	 0.00036	 0.0016	 0.00054	 117.419535	 117.419535	 117.419535	 0.0	 0.0	 1	 -30.0	 30.0;
	7600	 4621	 0.000409	 0.001569	 0.00061	 139.373798	 139.373798	 139.373798	 0.0	 0.0	 1	 -30.0	 30.0;
	7463	 7600	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1111	 7600	 0.001658	 0.004511	 0.2079	 105.829777	 105.829777	 105.829777	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 2359	 0.00176	 0.007911	 0.0025	 205.481848	 205.481848	 205.481848	 0.0	 0.0	 1	 -30.0	 30.0;
	899	 5400	 0.00172	 0.008058	 0.00245	 186.92275	 186.92275	 186.92275	 0.0	 0.0	 1	 -30.0	 30.0;
	5819	 5400	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1317	 7877	 0.0022	 0.00852	 0.00335	 110.010601	 110.010601	 110.010601	 0.0	 0.0	 1	 -30.0	 30.0;
	6852	 4621	 0.000111	 0.000489	 0.00014	 143.333007	 143.333007	 143.333007	 0.0	 0.0	 1	 -30.0	 30.0;
	6852	 7890	 0.00396	 0.013058	 0.00603	 129.342886	 129.342886	 129.342886	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 7980	 0.001138	 0.002529	 0.0992	 223.367264	 223.367264	 223.367264	 0.0	 0.0	 1	 -30.0	 30.0;
	7834	 1513	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8160	 7834	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7834	 2424	 0.001329	 0.005978	 0.00203	 120.366013	 120.366013	 120.366013	 0.0	 0.0	 1	 -30.0	 30.0;
	4887	 8008	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4975	 5926	 0.0	 0.000222	 0.0	 117.966949	 117.966949	 117.966949	 0.0	 0.0	 1	 -30.0	 30.0;
	5926	 7178	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4975	 2994	 0.010191	 0.028329	 0.61098	 145.970314	 145.970314	 145.970314	 0.0	 0.0	 1	 -30.0	 30.0;
	1675	 6401	 0.002391	 0.00788	 0.00363	 107.798339	 107.798339	 107.798339	 0.0	 0.0	 1	 -30.0	 30.0;
	961	 1675	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 1675	 0.002249	 0.008351	 0.00341	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5548	 2765	 0.000302	 0.000969	 0.00045	 105.92019	 105.92019	 105.92019	 0.0	 0.0	 1	 -30.0	 30.0;
	2219	 5796	 0.000271	 0.001102	 0.0004	 108.412524	 108.412524	 108.412524	 0.0	 0.0	 1	 -30.0	 30.0;
	3469	 5548	 0.000391	 0.001738	 0.00059	 105.92019	 105.92019	 105.92019	 0.0	 0.0	 1	 -30.0	 30.0;
	2219	 2912	 0.002289	 0.008178	 0.00348	 108.381607	 108.381607	 108.381607	 0.0	 0.0	 1	 -30.0	 30.0;
	6369	 5321	 0.0	 0.000222	 0.0	 125.783522	 125.783522	 125.783522	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 4347	 0.00112	 0.00504	 0.00171	 126.686353	 126.686353	 126.686353	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 4347	 0.001271	 0.004942	 0.00194	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 4347	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4347	 6553	 0.000418	 0.00192	 0.00064	 112.184931	 112.184931	 112.184931	 0.0	 0.0	 1	 -30.0	 30.0;
	4347	 4075	 0.000409	 0.001951	 0.00063	 121.388616	 121.388616	 121.388616	 0.0	 0.0	 1	 -30.0	 30.0;
	4347	 84	 0.03228	 0.106458	 0.04913	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4347	 84	 0.02876	 0.120649	 0.04377	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4075	 84	 0.05888	 0.117289	 0.04206	 241.664735	 241.664735	 241.664735	 0.0	 0.0	 1	 -30.0	 30.0;
	6290	 7313	 0.00324	 0.01584	 0.00462	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1166	 7313	 0.0	 0.000222	 0.0	 111.705066	 111.705066	 111.705066	 0.0	 0.0	 1	 -30.0	 30.0;
	3399	 6995	 0.00176	 0.004449	 0.00125	 278.107691	 278.107691	 278.107691	 0.0	 0.0	 1	 -30.0	 30.0;
	7462	 916	 0.009929	 0.046969	 0.01511	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7462	 1966	 0.009711	 0.043489	 0.01478	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5794	 1966	 0.005031	 0.02252	 0.00765	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1575	 2404	 0.0	 0.000222	 0.0	 131.346003	 131.346003	 131.346003	 0.0	 0.0	 1	 -30.0	 30.0;
	7741	 5830	 0.0	 0.000222	 0.0	 123.770012	 123.770012	 123.770012	 0.0	 0.0	 1	 -30.0	 30.0;
	6696	 5830	 0.000462	 0.00108	 0.05406	 172.491216	 172.491216	 172.491216	 0.0	 0.0	 1	 -30.0	 30.0;
	7353	 2404	 0.000471	 0.001049	 0.0551	 282.530136	 282.530136	 282.530136	 0.0	 0.0	 1	 -30.0	 30.0;
	1111	 1317	 0.00104	 0.003729	 0.1296	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7594	 4750	 0.002329	 0.008	 0.00354	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7996	 4750	 0.002378	 0.007831	 0.00361	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1834	 4750	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	542	 5794	 0.006711	 0.026018	 0.01022	 117.438501	 117.438501	 117.438501	 0.0	 0.0	 1	 -30.0	 30.0;
	5794	 1579	 0.009298	 0.04232	 0.01417	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7902	 5036	 0.004751	 0.01632	 0.00724	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2516	 1730	 0.0	 0.000222	 0.0	 142.965379	 142.965379	 142.965379	 0.0	 0.0	 1	 -30.0	 30.0;
	1730	 2807	 0.000338	 0.001151	 0.00051	 150.17504	 150.17504	 150.17504	 0.0	 0.0	 1	 -30.0	 30.0;
	1730	 5650	 0.000338	 0.00112	 0.00052	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7879	 6942	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3845	 424	 0.00484	 0.023329	 0.00689	 240.237612	 240.237612	 240.237612	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 6181	 0.004222	 0.017751	 0.00644	 116.295087	 116.295087	 116.295087	 0.0	 0.0	 1	 -30.0	 30.0;
	1047	 3933	 0.004138	 0.018102	 0.00631	 118.648425	 118.648425	 118.648425	 0.0	 0.0	 1	 -30.0	 30.0;
	4069	 3011	 0.0	 0.000222	 0.0	 118.242086	 118.242086	 118.242086	 0.0	 0.0	 1	 -30.0	 30.0;
	4069	 1114	 0.000622	 0.002418	 0.00095	 118.104647	 118.104647	 118.104647	 0.0	 0.0	 1	 -30.0	 30.0;
	3011	 573	 0.000631	 0.002369	 0.00097	 130.665307	 130.665307	 130.665307	 0.0	 0.0	 1	 -30.0	 30.0;
	7042	 8037	 0.00012	 0.00032	 9e-05	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7301	 4785	 0.0	 0.00028	 0.0	 111.056586	 111.056586	 111.056586	 0.0	 0.0	 1	 -30.0	 30.0;
	1002	 5397	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2053	 92	 0.0	 0.00028	 0.0	 114.719614	 114.719614	 114.719614	 0.0	 0.0	 1	 -30.0	 30.0;
	7547	 5695	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5348	 568	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3096	 6738	 0.0	 0.00028	 0.0	 143.524485	 143.524485	 143.524485	 0.0	 0.0	 1	 -30.0	 30.0;
	2065	 7790	 0.001409	 0.00464	 0.00215	 150.93186	 150.93186	 150.93186	 0.0	 0.0	 1	 -30.0	 30.0;
	1585	 2065	 0.003098	 0.014911	 0.00441	 155.047213	 155.047213	 155.047213	 0.0	 0.0	 1	 -30.0	 30.0;
	7790	 2343	 0.004662	 0.015369	 0.0071	 110.735464	 110.735464	 110.735464	 0.0	 0.0	 1	 -30.0	 30.0;
	106	 7450	 9.8e-05	 0.000369	 0.00014	 107.943312	 107.943312	 107.943312	 0.0	 0.0	 1	 -30.0	 30.0;
	7790	 106	 0.001031	 0.003658	 0.00156	 107.883556	 107.883556	 107.883556	 0.0	 0.0	 1	 -30.0	 30.0;
	2997	 5228	 0.001049	 0.003591	 0.00159	 182.667621	 182.667621	 182.667621	 0.0	 0.0	 1	 -30.0	 30.0;
	5576	 3357	 0.003209	 0.012338	 0.00457	 114.421355	 114.421355	 114.421355	 0.0	 0.0	 1	 -30.0	 30.0;
	5775	 5576	 0.003311	 0.012689	 0.00471	 105.856537	 105.856537	 105.856537	 0.0	 0.0	 1	 -30.0	 30.0;
	7244	 2285	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	84	 335	 0.003871	 0.010458	 0.00276	 238.123817	 238.123817	 238.123817	 0.0	 0.0	 1	 -30.0	 30.0;
	7668	 84	 0.000218	 0.000849	 0.00034	 168.240504	 168.240504	 168.240504	 0.0	 0.0	 1	 -30.0	 30.0;
	5474	 84	 0.000231	 0.00084	 0.00034	 160.35898	 160.35898	 160.35898	 0.0	 0.0	 1	 -30.0	 30.0;
	8314	 84	 0.0	 0.00028	 0.0	 132.607109	 132.607109	 132.607109	 0.0	 0.0	 1	 -30.0	 30.0;
	335	 2574	 0.000231	 0.000822	 0.00035	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2499	 2574	 0.00024	 0.0008	 0.00036	 114.101791	 114.101791	 114.101791	 0.0	 0.0	 1	 -30.0	 30.0;
	2140	 2574	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5128	 4386	 0.0	 0.00028	 0.0	 139.83132	 139.83132	 139.83132	 0.0	 0.0	 1	 -30.0	 30.0;
	2306	 5324	 0.000151	 0.00036	 0.01768	 184.20828	 184.20828	 184.20828	 0.0	 0.0	 1	 -30.0	 30.0;
	2306	 7522	 8e-05	 0.00028	 0.0099	 153.982001	 153.982001	 153.982001	 0.0	 0.0	 1	 -30.0	 30.0;
	977	 5056	 8e-05	 0.00028	 0.0099	 118.055284	 118.055284	 118.055284	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 2306	 0.0	 0.000222	 0.0	 115.943568	 115.943568	 115.943568	 0.0	 0.0	 1	 -30.0	 30.0;
	2306	 977	 0.0	 0.00028	 0.0	 121.036576	 121.036576	 121.036576	 0.0	 0.0	 1	 -30.0	 30.0;
	2029	 977	 0.0	 0.000222	 0.0	 143.86925	 143.86925	 143.86925	 0.0	 0.0	 1	 -30.0	 30.0;
	1741	 7893	 0.001711	 0.003058	 0.06059	 107.020475	 107.020475	 107.020475	 0.0	 0.0	 1	 -30.0	 30.0;
	7139	 1741	 0.003369	 0.008889	 0.00241	 260.303594	 260.303594	 260.303594	 0.0	 0.0	 1	 -30.0	 30.0;
	1598	 7893	 0.002009	 0.005311	 0.00144	 265.58886	 265.58886	 265.58886	 0.0	 0.0	 1	 -30.0	 30.0;
	2682	 1598	 0.0	 0.000222	 0.0	 134.623736	 134.623736	 134.623736	 0.0	 0.0	 1	 -30.0	 30.0;
	7338	 774	 0.002551	 0.011578	 0.00388	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3739	 774	 0.002489	 0.0118	 0.0038	 140.798843	 140.798843	 140.798843	 0.0	 0.0	 1	 -30.0	 30.0;
	6573	 7606	 0.0	 0.00028	 0.0	 130.745327	 130.745327	 130.745327	 0.0	 0.0	 1	 -30.0	 30.0;
	7606	 3584	 0.010009	 0.04892	 0.01425	 130.126726	 130.126726	 130.126726	 0.0	 0.0	 1	 -30.0	 30.0;
	4494	 3348	 0.000182	 0.000671	 0.00028	 171.817275	 171.817275	 171.817275	 0.0	 0.0	 1	 -30.0	 30.0;
	7004	 6715	 0.006169	 0.02036	 0.00939	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6715	 1342	 0.007369	 0.0322	 0.01122	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5939	 7004	 0.005498	 0.023071	 0.00837	 146.804296	 146.804296	 146.804296	 0.0	 0.0	 1	 -30.0	 30.0;
	7266	 5939	 0.004809	 0.021671	 0.00684	 173.493814	 173.493814	 173.493814	 0.0	 0.0	 1	 -30.0	 30.0;
	3851	 7004	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7004	 872	 0.016169	 0.06784	 0.02461	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5532	 3299	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8029	 26	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4997	 26	 0.01124	 0.039822	 0.01599	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6297	 156	 0.001169	 0.00532	 0.00178	 110.697792	 110.697792	 110.697792	 0.0	 0.0	 1	 -30.0	 30.0;
	424	 156	 0.001138	 0.005418	 0.00174	 213.79725	 213.79725	 213.79725	 0.0	 0.0	 1	 -30.0	 30.0;
	7760	 3163	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6024	 4997	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2084	 7330	 0.0	 0.000222	 0.0	 151.847942	 151.847942	 151.847942	 0.0	 0.0	 1	 -30.0	 30.0;
	4366	 5403	 0.00212	 0.008871	 0.00321	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1957	 4366	 0.002289	 0.008902	 0.0035	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5403	 6649	 0.00024	 0.000782	 0.00036	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2888	 6649	 0.000209	 0.000889	 0.00032	 115.066197	 115.066197	 115.066197	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 7330	 0.0	 0.000222	 0.0	 114.410443	 114.410443	 114.410443	 0.0	 0.0	 1	 -30.0	 30.0;
	89	 7330	 0.0	 0.000222	 0.0	 108.664018	 108.664018	 108.664018	 0.0	 0.0	 1	 -30.0	 30.0;
	1887	 6649	 0.0	 0.000222	 0.0	 104.38031	 104.38031	 104.38031	 0.0	 0.0	 1	 -30.0	 30.0;
	1594	 4135	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4135	 4897	 0.001209	 0.005529	 0.00185	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4135	 3855	 0.001191	 0.00564	 0.00181	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2587	 4897	 0.014982	 0.0428	 0.0107	 198.291412	 198.291412	 198.291412	 0.0	 0.0	 1	 -30.0	 30.0;
	5724	 7104	 0.012849	 0.022929	 0.45441	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7104	 1620	 0.000431	 0.000929	 0.00031	 254.876992	 254.876992	 254.876992	 0.0	 0.0	 1	 -30.0	 30.0;
	7885	 1620	 0.000849	 0.003831	 0.00121	 131.990585	 131.990585	 131.990585	 0.0	 0.0	 1	 -30.0	 30.0;
	6865	 1620	 0.0	 0.000222	 0.0	 119.682199	 119.682199	 119.682199	 0.0	 0.0	 1	 -30.0	 30.0;
	3595	 2827	 0.000231	 0.000769	 0.00036	 138.853144	 138.853144	 138.853144	 0.0	 0.0	 1	 -30.0	 30.0;
	3595	 3884	 0.0002	 0.000871	 0.00032	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6709	 3595	 0.0	 0.00028	 0.0	 128.372245	 128.372245	 128.372245	 0.0	 0.0	 1	 -30.0	 30.0;
	3707	 542	 0.004049	 0.01844	 0.00618	 127.430442	 127.430442	 127.430442	 0.0	 0.0	 1	 -30.0	 30.0;
	3707	 3455	 0.003969	 0.018791	 0.00604	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4486	 3707	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5558	 352	 0.002271	 0.004258	 0.00177	 266.373479	 266.373479	 266.373479	 0.0	 0.0	 1	 -30.0	 30.0;
	2587	 3334	 0.012449	 0.0248	 0.00889	 130.02644	 130.02644	 130.02644	 0.0	 0.0	 1	 -30.0	 30.0;
	3334	 352	 0.002311	 0.004169	 0.0018	 248.704223	 248.704223	 248.704223	 0.0	 0.0	 1	 -30.0	 30.0;
	3660	 2587	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6521	 352	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4321	 3268	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7890	 3268	 0.0	 0.000222	 0.0	 135.926671	 135.926671	 135.926671	 0.0	 0.0	 1	 -30.0	 30.0;
	5663	 3268	 0.0	 0.000222	 0.0	 125.616205	 125.616205	 125.616205	 0.0	 0.0	 1	 -30.0	 30.0;
	2125	 7528	 0.002071	 0.009049	 0.00315	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2125	 211	 0.002031	 0.009222	 0.00308	 125.279235	 125.279235	 125.279235	 0.0	 0.0	 1	 -30.0	 30.0;
	8294	 2125	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8219	 872	 0.0	 0.000222	 0.0	 123.298202	 123.298202	 123.298202	 0.0	 0.0	 1	 -30.0	 30.0;
	1342	 872	 0.015511	 0.06772	 0.0236	 110.960457	 110.960457	 110.960457	 0.0	 0.0	 1	 -30.0	 30.0;
	7336	 8210	 4e-05	 0.00028	 7e-05	 132.30833	 132.30833	 132.30833	 0.0	 0.0	 1	 -30.0	 30.0;
	7336	 5333	 4e-05	 0.00028	 7e-05	 108.700651	 108.700651	 108.700651	 0.0	 0.0	 1	 -30.0	 30.0;
	23	 7336	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6773	 1530	 0.0052	 0.013898	 0.31199	 132.331453	 132.331453	 132.331453	 0.0	 0.0	 1	 -30.0	 30.0;
	8260	 3802	 0.009071	 0.032151	 0.01291	 128.613346	 128.613346	 128.613346	 0.0	 0.0	 1	 -30.0	 30.0;
	6003	 8260	 0.0	 0.00028	 0.0	 124.865102	 124.865102	 124.865102	 0.0	 0.0	 1	 -30.0	 30.0;
	492	 7331	 0.0	 0.000222	 0.0	 155.264672	 155.264672	 155.264672	 0.0	 0.0	 1	 -30.0	 30.0;
	1530	 6308	 0.0	 0.000222	 0.0	 125.760399	 125.760399	 125.760399	 0.0	 0.0	 1	 -30.0	 30.0;
	7331	 744	 0.0	 0.000222	 0.0	 137.600611	 137.600611	 137.600611	 0.0	 0.0	 1	 -30.0	 30.0;
	7331	 2994	 0.0	 0.000222	 0.0	 114.38784	 114.38784	 114.38784	 0.0	 0.0	 1	 -30.0	 30.0;
	7331	 6308	 0.0	 0.000222	 0.0	 111.687399	 111.687399	 111.687399	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 6835	 0.042889	 0.088942	 0.03064	 129.301836	 129.301836	 129.301836	 0.0	 0.0	 1	 -30.0	 30.0;
	691	 5469	 0.000609	 0.001618	 0.00044	 245.958316	 245.958316	 245.958316	 0.0	 0.0	 1	 -30.0	 30.0;
	399	 8008	 0.011289	 0.057409	 0.01607	 106.854198	 106.854198	 106.854198	 0.0	 0.0	 1	 -30.0	 30.0;
	3672	 781	 0.0	 0.00028	 0.0	 109.960198	 109.960198	 109.960198	 0.0	 0.0	 1	 -30.0	 30.0;
	4698	 3436	 8.9e-05	 0.000449	 0.00013	 144.024355	 144.024355	 144.024355	 0.0	 0.0	 1	 -30.0	 30.0;
	7460	 4344	 0.000169	 0.000662	 0.00024	 150.079951	 150.079951	 150.079951	 0.0	 0.0	 1	 -30.0	 30.0;
	2102	 4597	 0.0	 0.00028	 0.0	 113.084904	 113.084904	 113.084904	 0.0	 0.0	 1	 -30.0	 30.0;
	1193	 5260	 9.8e-05	 0.000511	 0.00015	 161.273762	 161.273762	 161.273762	 0.0	 0.0	 1	 -30.0	 30.0;
	7828	 5260	 0.006338	 0.022662	 0.00965	 181.344421	 181.344421	 181.344421	 0.0	 0.0	 1	 -30.0	 30.0;
	824	 6390	 0.000809	 0.001729	 0.00057	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7756	 1114	 0.00204	 0.007898	 0.0031	 118.104647	 118.104647	 118.104647	 0.0	 0.0	 1	 -30.0	 30.0;
	4560	 8159	 0.00188	 0.00516	 0.00134	 241.218646	 241.218646	 241.218646	 0.0	 0.0	 1	 -30.0	 30.0;
	7828	 7237	 0.000831	 0.003511	 0.00127	 132.707135	 132.707135	 132.707135	 0.0	 0.0	 1	 -30.0	 30.0;
	1201	 149	 0.00064	 0.002871	 0.0009	 130.098666	 130.098666	 130.098666	 0.0	 0.0	 1	 -30.0	 30.0;
	6326	 3348	 0.000182	 0.00064	 0.00028	 132.378998	 132.378998	 132.378998	 0.0	 0.0	 1	 -30.0	 30.0;
	6326	 1551	 0.000191	 0.000631	 0.00029	 157.491483	 157.491483	 157.491483	 0.0	 0.0	 1	 -30.0	 30.0;
	3211	 6326	 0.0	 0.00028	 0.0	 114.410963	 114.410963	 114.410963	 0.0	 0.0	 1	 -30.0	 30.0;
	1927	 282	 0.00043	 0.00337	 0.09639	 1183.909243	 1183.909243	 1183.909243	 0.0	 0.0	 1	 -30.0	 30.0;
	1927	 6461	 0.00038	 0.00383	 0.08588	 1495.382069	 1495.382069	 1495.382069	 0.0	 0.0	 1	 -30.0	 30.0;
	4531	 4889	 0.000431	 0.00112	 0.00031	 274.544169	 274.544169	 274.544169	 0.0	 0.0	 1	 -30.0	 30.0;
	1674	 4531	 0.006458	 0.021302	 0.00983	 136.612823	 136.612823	 136.612823	 0.0	 0.0	 1	 -30.0	 30.0;
	7179	 2517	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6707	 8236	 0.000249	 0.001138	 0.00039	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7750	 6707	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6707	 1579	 0.002449	 0.011169	 0.00374	 108.108289	 108.108289	 108.108289	 0.0	 0.0	 1	 -30.0	 30.0;
	3882	 1579	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4776	 3726	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7933	 7945	 0.000271	 0.001089	 0.00038	 123.714154	 123.714154	 123.714154	 0.0	 0.0	 1	 -30.0	 30.0;
	6078	 3584	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	280	 1342	 0.0	 0.000222	 0.0	 135.089051	 135.089051	 135.089051	 0.0	 0.0	 1	 -30.0	 30.0;
	1260	 800	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3046	 1111	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6235	 4027	 0.0	 0.000222	 0.0	 142.751557	 142.751557	 142.751557	 0.0	 0.0	 1	 -30.0	 30.0;
	710	 1766	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5397	 3146	 0.006729	 0.031862	 0.01025	 121.473573	 121.473573	 121.473573	 0.0	 0.0	 1	 -30.0	 30.0;
	5397	 5048	 0.006591	 0.029498	 0.01003	 186.958344	 186.958344	 186.958344	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 7980	 0.000258	 0.000711	 0.03267	 191.148781	 191.148781	 191.148781	 0.0	 0.0	 1	 -30.0	 30.0;
	4832	 5877	 0.020311	 0.045649	 0.01451	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7460	 6694	 0.004102	 0.014089	 0.00624	 116.487085	 116.487085	 116.487085	 0.0	 0.0	 1	 -30.0	 30.0;
	6694	 1574	 0.0	 0.000222	 0.0	 125.219219	 125.219219	 125.219219	 0.0	 0.0	 1	 -30.0	 30.0;
	5431	 2704	 0.038777	 0.100653	 0.00807	 79.267981	 79.267981	 79.267981	 0.0	 0.0	 1	 -30.0	 30.0;
	2976	 5431	 0.026711	 0.08357	 0.00954	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7061	 2561	 0.062719	 0.144537	 0.01303	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2673	 7061	 0.045033	 0.112364	 0.0094	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4086	 6946	 0.011659	 0.070599	 0.09889	 392.012877	 392.012877	 392.012877	 0.0	 0.0	 1	 -30.0	 30.0;
	4086	 747	 0.00968	 0.04149	 0.07777	 375.523268	 375.523268	 375.523268	 0.0	 0.0	 1	 -30.0	 30.0;
	4086	 747	 0.00862	 0.047021	 0.06929	 387.835032	 387.835032	 387.835032	 0.0	 0.0	 1	 -30.0	 30.0;
	1220	 2561	 0.077471	 0.185529	 0.01613	 70.283175	 70.283175	 70.283175	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 2561	 0.045157	 0.126248	 0.01486	 60.925701	 60.925701	 60.925701	 0.0	 0.0	 1	 -30.0	 30.0;
	4690	 2561	 0.01119	 0.043099	 0.00368	 65.276353	 65.276353	 65.276353	 0.0	 0.0	 1	 -30.0	 30.0;
	4690	 2561	 0.01095	 0.043909	 0.00361	 64.872058	 64.872058	 64.872058	 0.0	 0.0	 1	 -30.0	 30.0;
	2544	 1220	 0.03681	 0.090496	 0.00765	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2883	 5652	 0.056174	 0.129223	 0.01168	 77.293755	 77.293755	 77.293755	 0.0	 0.0	 1	 -30.0	 30.0;
	3491	 2883	 0.029256	 0.116322	 0.01003	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4998	 7768	 0.061347	 0.097917	 0.16601	 80.330732	 80.330732	 80.330732	 0.0	 0.0	 1	 -30.0	 30.0;
	7768	 8082	 0.088719	 0.24762	 0.05075	 66.947262	 66.947262	 66.947262	 0.0	 0.0	 1	 -30.0	 30.0;
	7332	 244	 0.0	 0.000413	 0.0	 69.441433	 69.441433	 69.441433	 0.0	 0.0	 1	 -30.0	 30.0;
	7332	 5151	 0.004612	 0.01738	 0.0016	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7332	 5220	 0.008364	 0.02695	 0.00296	 78.656965	 78.656965	 78.656965	 0.0	 0.0	 1	 -30.0	 30.0;
	7332	 5220	 0.014992	 0.043636	 0.00494	 61.787067	 61.787067	 61.787067	 0.0	 0.0	 1	 -30.0	 30.0;
	7543	 244	 0.003033	 0.012851	 0.00101	 106.186007	 106.186007	 106.186007	 0.0	 0.0	 1	 -30.0	 30.0;
	7543	 244	 0.002967	 0.011901	 0.00099	 87.367223	 87.367223	 87.367223	 0.0	 0.0	 1	 -30.0	 30.0;
	244	 1392	 0.015256	 0.042686	 0.00503	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1764	 244	 0.004397	 0.025653	 0.00627	 126.258069	 126.258069	 126.258069	 0.0	 0.0	 1	 -30.0	 30.0;
	3063	 3592	 0.0027	 0.012961	 0.02101	 386.54022	 386.54022	 386.54022	 0.0	 0.0	 1	 -30.0	 30.0;
	747	 3592	 0.038169	 0.16812	 0.30228	 363.751073	 363.751073	 363.751073	 0.0	 0.0	 1	 -30.0	 30.0;
	3592	 4992	 0.015479	 0.073409	 0.21497	 517.58753	 517.58753	 517.58753	 0.0	 0.0	 1	 -30.0	 30.0;
	5983	 3148	 0.027868	 0.087843	 0.00957	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4577	 5983	 0.013934	 0.040479	 0.00475	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1629	 3148	 0.019231	 0.076471	 0.00653	 60.653631	 60.653631	 60.653631	 0.0	 0.0	 1	 -30.0	 30.0;
	2087	 5251	 0.013421	 0.037256	 0.00462	 71.546931	 71.546931	 71.546931	 0.0	 0.0	 1	 -30.0	 30.0;
	5033	 2087	 0.022438	 0.046851	 0.00459	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7506	 445	 0.014562	 0.045314	 0.02465	 100.683438	 100.683438	 100.683438	 0.0	 0.0	 1	 -30.0	 30.0;
	445	 2544	 0.000826	 0.002207	 0.02371	 61.45098	 61.45098	 61.45098	 0.0	 0.0	 1	 -30.0	 30.0;
	1740	 5194	 0.040628	 0.113562	 0.01388	 102.55116	 102.55116	 102.55116	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 1740	 0.008058	 0.024438	 0.00276	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1740	 5325	 0.022471	 0.041083	 0.14109	 66.861145	 66.861145	 66.861145	 0.0	 0.0	 1	 -30.0	 30.0;
	3990	 7779	 0.047322	 0.096669	 0.00988	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7779	 2976	 0.01914	 0.07614	 0.00653	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	668	 5499	 0.007802	 0.01924	 0.0017	 63.639929	 63.639929	 63.639929	 0.0	 0.0	 1	 -30.0	 30.0;
	668	 5499	 0.005397	 0.015554	 0.00173	 76.619103	 76.619103	 76.619103	 0.0	 0.0	 1	 -30.0	 30.0;
	5499	 6650	 0.024719	 0.040702	 0.07219	 68.373156	 68.373156	 68.373156	 0.0	 0.0	 1	 -30.0	 30.0;
	5499	 6650	 0.02419	 0.041471	 0.07066	 65.77896	 65.77896	 65.77896	 0.0	 0.0	 1	 -30.0	 30.0;
	3867	 2420	 0.039603	 0.109529	 0.01353	 92.919901	 92.919901	 92.919901	 0.0	 0.0	 1	 -30.0	 30.0;
	3142	 3867	 0.013826	 0.039826	 0.00475	 76.348367	 76.348367	 76.348367	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 3867	 0.015174	 0.04981	 0.00519	 77.193157	 77.193157	 77.193157	 0.0	 0.0	 1	 -30.0	 30.0;
	7307	 4177	 0.003669	 0.009008	 0.00075	 69.015037	 69.015037	 69.015037	 0.0	 0.0	 1	 -30.0	 30.0;
	4177	 1829	 0.03276	 0.106603	 0.00954	 112.964527	 112.964527	 112.964527	 0.0	 0.0	 1	 -30.0	 30.0;
	4177	 1829	 0.03019	 0.107612	 0.01029	 113.711959	 113.711959	 113.711959	 0.0	 0.0	 1	 -30.0	 30.0;
	3344	 4177	 0.019033	 0.051653	 0.00562	 79.409351	 79.409351	 79.409351	 0.0	 0.0	 1	 -30.0	 30.0;
	166	 4177	 0.037603	 0.124017	 0.011	 80.738838	 80.738838	 80.738838	 0.0	 0.0	 1	 -30.0	 30.0;
	4177	 8140	 0.034868	 0.097471	 0.01188	 58.685311	 58.685311	 58.685311	 0.0	 0.0	 1	 -30.0	 30.0;
	4177	 5837	 0.043099	 0.130603	 0.01419	 74.815017	 74.815017	 74.815017	 0.0	 0.0	 1	 -30.0	 30.0;
	3990	 7307	 0.06105	 0.110339	 0.01265	 80.307869	 80.307869	 80.307869	 0.0	 0.0	 1	 -30.0	 30.0;
	2552	 5692	 0.041446	 0.108843	 0.01039	 59.70729	 59.70729	 59.70729	 0.0	 0.0	 1	 -30.0	 30.0;
	5692	 213	 0.063471	 0.123207	 0.01485	 66.430748	 66.430748	 66.430748	 0.0	 0.0	 1	 -30.0	 30.0;
	2812	 4995	 0.02343	 0.073603	 0.00774	 74.149892	 74.149892	 74.149892	 0.0	 0.0	 1	 -30.0	 30.0;
	2812	 1726	 0.022537	 0.091587	 0.00764	 73.190595	 73.190595	 73.190595	 0.0	 0.0	 1	 -30.0	 30.0;
	8378	 4195	 0.036744	 0.106934	 0.01255	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8378	 748	 0.006207	 0.023959	 0.00207	 73.936884	 73.936884	 73.936884	 0.0	 0.0	 1	 -30.0	 30.0;
	3142	 3102	 0.003157	 0.011008	 0.00117	 78.454436	 78.454436	 78.454436	 0.0	 0.0	 1	 -30.0	 30.0;
	3142	 3102	 0.003223	 0.010793	 0.0012	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 3102	 0.005	 0.035653	 0.00715	 87.52898	 87.52898	 87.52898	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 3102	 0.004901	 0.036347	 0.00701	 86.042499	 86.042499	 86.042499	 0.0	 0.0	 1	 -30.0	 30.0;
	7308	 1434	 0.007917	 0.029603	 0.0027	 65.15556	 65.15556	 65.15556	 0.0	 0.0	 1	 -30.0	 30.0;
	656	 1434	 0.004876	 0.01476	 0.0017	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4963	 4195	 0.007182	 0.023579	 0.00245	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4963	 4169	 0.007322	 0.023099	 0.0025	 80.588704	 80.588704	 80.588704	 0.0	 0.0	 1	 -30.0	 30.0;
	5325	 7747	 0.010942	 0.040562	 0.00374	 77.31738	 77.31738	 77.31738	 0.0	 0.0	 1	 -30.0	 30.0;
	7747	 823	 0.030603	 0.103702	 0.13068	 62.797996	 62.797996	 62.797996	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 794	 0.01176	 0.041421	 0.00402	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 1292	 0.011868	 0.03581	 0.00413	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	708	 5251	 0.01757	 0.064579	 0.00605	 57.287806	 57.287806	 57.287806	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 6647	 0.017099	 0.064281	 0.00585	 67.474828	 67.474828	 67.474828	 0.0	 0.0	 1	 -30.0	 30.0;
	721	 3491	 0.015207	 0.057397	 0.00522	 87.073624	 87.073624	 87.073624	 0.0	 0.0	 1	 -30.0	 30.0;
	1292	 721	 0.009198	 0.036512	 0.00313	 79.11918	 79.11918	 79.11918	 0.0	 0.0	 1	 -30.0	 30.0;
	721	 6219	 0.024281	 0.239446	 0.03888	 71.315824	 71.315824	 71.315824	 0.0	 0.0	 1	 -30.0	 30.0;
	8304	 1195	 0.052471	 0.157347	 0.01802	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	370	 1195	 0.009314	 0.035909	 0.00307	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7308	 1195	 0.039314	 0.122777	 0.01352	 65.290071	 65.290071	 65.290071	 0.0	 0.0	 1	 -30.0	 30.0;
	7543	 408	 0.001223	 0.003711	 0.03788	 104.54844	 104.54844	 104.54844	 0.0	 0.0	 1	 -30.0	 30.0;
	747	 6691	 0.00518	 0.023091	 0.04158	 404.578039	 404.578039	 404.578039	 0.0	 0.0	 1	 -30.0	 30.0;
	747	 6691	 0.005281	 0.022591	 0.04235	 383.755498	 383.755498	 383.755498	 0.0	 0.0	 1	 -30.0	 30.0;
	2390	 7299	 0.018198	 0.037149	 0.00374	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7183	 5371	 0.012893	 0.040033	 0.00447	 82.619326	 82.619326	 82.619326	 0.0	 0.0	 1	 -30.0	 30.0;
	3493	 5371	 0.007132	 0.020331	 0.00248	 73.635092	 73.635092	 73.635092	 0.0	 0.0	 1	 -30.0	 30.0;
	2919	 1301	 0.00479	 0.05497	 1.09267	 1213.905765	 1213.905765	 1213.905765	 0.0	 0.0	 1	 -30.0	 30.0;
	3990	 1829	 0.047322	 0.139868	 0.01851	 87.529361	 87.529361	 87.529361	 0.0	 0.0	 1	 -30.0	 30.0;
	3153	 1829	 0.005471	 0.017471	 0.00163	 103.648778	 103.648778	 103.648778	 0.0	 0.0	 1	 -30.0	 30.0;
	3153	 1829	 0.013826	 0.040207	 0.00454	 70.506852	 70.506852	 70.506852	 0.0	 0.0	 1	 -30.0	 30.0;
	2704	 1829	 0.010678	 0.03814	 0.00363	 72.958345	 72.958345	 72.958345	 0.0	 0.0	 1	 -30.0	 30.0;
	2704	 1829	 0.010603	 0.034793	 0.00357	 74.931618	 74.931618	 74.931618	 0.0	 0.0	 1	 -30.0	 30.0;
	4223	 1829	 0.014579	 0.043331	 0.00518	 71.034608	 71.034608	 71.034608	 0.0	 0.0	 1	 -30.0	 30.0;
	1829	 8140	 0.021413	 0.079248	 0.0073	 137.635114	 137.635114	 137.635114	 0.0	 0.0	 1	 -30.0	 30.0;
	1829	 6415	 0.031198	 0.098298	 0.0103	 99.798828	 99.798828	 99.798828	 0.0	 0.0	 1	 -30.0	 30.0;
	4755	 3063	 0.009651	 0.045031	 0.07653	 385.332669	 385.332669	 385.332669	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 5009	 0.050207	 0.124066	 0.01123	 72.625497	 72.625497	 72.625497	 0.0	 0.0	 1	 -30.0	 30.0;
	8351	 4129	 0.034314	 0.070521	 0.0057	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6022	 5033	 0.007463	 0.022612	 0.00255	 64.1553	 64.1553	 64.1553	 0.0	 0.0	 1	 -30.0	 30.0;
	6022	 5033	 0.007603	 0.022132	 0.0026	 73.775128	 73.775128	 73.775128	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 3383	 0.01081	 0.033603	 0.00374	 65.332177	 65.332177	 65.332177	 0.0	 0.0	 1	 -30.0	 30.0;
	8304	 4995	 0.011223	 0.036446	 0.00388	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 7183	 0.014182	 0.045669	 0.0049	 70.206584	 70.206584	 70.206584	 0.0	 0.0	 1	 -30.0	 30.0;
	7183	 4995	 0.014463	 0.044744	 0.00499	 71.359264	 71.359264	 71.359264	 0.0	 0.0	 1	 -30.0	 30.0;
	166	 3344	 0.02124	 0.069099	 0.00621	 71.273336	 71.273336	 71.273336	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 1483	 0.008041	 0.030504	 0.00265	 70.960493	 70.960493	 70.960493	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 2113	 0.009107	 0.029893	 0.003	 73.682533	 73.682533	 73.682533	 0.0	 0.0	 1	 -30.0	 30.0;
	7846	 6954	 0.024802	 0.074537	 0.00859	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 7846	 0.038711	 0.136876	 0.01323	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	656	 1726	 0.069413	 0.194223	 0.02376	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8304	 3383	 0.01276	 0.035281	 0.0044	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3827	 6799	 0.008744	 0.025802	 0.00286	 98.627286	 98.627286	 98.627286	 0.0	 0.0	 1	 -30.0	 30.0;
	6799	 2113	 0.008909	 0.025248	 0.00292	 89.589323	 89.589323	 89.589323	 0.0	 0.0	 1	 -30.0	 30.0;
	4690	 1483	 0.009289	 0.029281	 0.00306	 69.456294	 69.456294	 69.456294	 0.0	 0.0	 1	 -30.0	 30.0;
	1523	 3390	 0.021421	 0.081298	 0.00729	 65.889464	 65.889464	 65.889464	 0.0	 0.0	 1	 -30.0	 30.0;
	1523	 6451	 0.044479	 0.139058	 0.0152	 81.273072	 81.273072	 81.273072	 0.0	 0.0	 1	 -30.0	 30.0;
	8213	 6946	 0.008479	 0.049461	 0.06704	 404.373796	 404.373796	 404.373796	 0.0	 0.0	 1	 -30.0	 30.0;
	747	 6946	 0.00394	 0.02236	 0.0311	 456.983627	 456.983627	 456.983627	 0.0	 0.0	 1	 -30.0	 30.0;
	668	 5131	 0.016174	 0.044463	 0.00539	 87.938419	 87.938419	 87.938419	 0.0	 0.0	 1	 -30.0	 30.0;
	668	 5131	 0.014413	 0.05038	 0.0048	 73.740071	 73.740071	 73.740071	 0.0	 0.0	 1	 -30.0	 30.0;
	700	 668	 0.020198	 0.064678	 0.00663	 61.730481	 61.730481	 61.730481	 0.0	 0.0	 1	 -30.0	 30.0;
	700	 668	 0.020587	 0.063364	 0.00676	 62.254808	 62.254808	 62.254808	 0.0	 0.0	 1	 -30.0	 30.0;
	700	 668	 0.031711	 0.059223	 0.00662	 69.794667	 69.794667	 69.794667	 0.0	 0.0	 1	 -30.0	 30.0;
	8351	 3273	 0.056678	 0.178372	 0.01955	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3273	 2673	 0.019496	 0.078083	 0.00662	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5131	 6509	 0.045198	 0.111479	 0.00984	 65.413722	 65.413722	 65.413722	 0.0	 0.0	 1	 -30.0	 30.0;
	4883	 5033	 0.015041	 0.057983	 0.00517	 66.11276	 66.11276	 66.11276	 0.0	 0.0	 1	 -30.0	 30.0;
	949	 4883	 0.03519	 0.105653	 0.01208	 60.703358	 60.703358	 60.703358	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 5652	 0.044	 0.099339	 0.00902	 81.351378	 81.351378	 81.351378	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 7543	 0.013636	 0.039512	 0.00451	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 7543	 0.012149	 0.044777	 0.00402	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5033	 8345	 0.035281	 0.122702	 0.01225	 69.256623	 69.256623	 69.256623	 0.0	 0.0	 1	 -30.0	 30.0;
	3577	 8345	 0.031967	 0.090248	 0.01123	 59.503618	 59.503618	 59.503618	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 8345	 0.023983	 0.066421	 0.00824	 136.705539	 136.705539	 136.705539	 0.0	 0.0	 1	 -30.0	 30.0;
	8351	 6693	 0.032901	 0.126777	 0.01128	 60.697642	 60.697642	 60.697642	 0.0	 0.0	 1	 -30.0	 30.0;
	6693	 7967	 0.015372	 0.059083	 0.01932	 59.601929	 59.601929	 59.601929	 0.0	 0.0	 1	 -30.0	 30.0;
	3827	 6451	 0.012636	 0.024496	 0.00439	 170.595279	 170.595279	 170.595279	 0.0	 0.0	 1	 -30.0	 30.0;
	3827	 6451	 0.012893	 0.024	 0.00447	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	3827	 6755	 0.001917	 0.006091	 0.05198	 134.486488	 134.486488	 134.486488	 0.0	 0.0	 1	 -30.0	 30.0;
	3827	 2113	 0.018149	 0.049413	 0.00594	 71.710783	 71.710783	 71.710783	 0.0	 0.0	 1	 -30.0	 30.0;
	1984	 778	 0.01276	 0.037083	 0.00418	 113.802649	 113.802649	 113.802649	 0.0	 0.0	 1	 -30.0	 30.0;
	8082	 1984	 0.069636	 0.146636	 0.01749	 74.299645	 74.299645	 74.299645	 0.0	 0.0	 1	 -30.0	 30.0;
	2401	 8149	 0.00219	 0.02213	 0.52937	 1171.583519	 1171.583519	 1171.583519	 0.0	 0.0	 1	 -30.0	 30.0;
	2249	 747	 0.00194	 0.0087	 0.01538	 449.544746	 449.544746	 449.544746	 0.0	 0.0	 1	 -30.0	 30.0;
	2249	 747	 0.001979	 0.00851	 0.01566	 425.789253	 425.789253	 425.789253	 0.0	 0.0	 1	 -30.0	 30.0;
	3491	 2420	 0.028893	 0.108496	 0.0099	 58.1848	 58.1848	 58.1848	 0.0	 0.0	 1	 -30.0	 30.0;
	794	 3491	 0.021008	 0.05814	 0.00715	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5131	 3548	 0.018661	 0.056488	 0.00615	 83.877557	 83.877557	 83.877557	 0.0	 0.0	 1	 -30.0	 30.0;
	7983	 949	 0.01381	 0.03776	 0.00704	 57.649614	 57.649614	 57.649614	 0.0	 0.0	 1	 -30.0	 30.0;
	7983	 3577	 0.012298	 0.042793	 0.00627	 63.483317	 63.483317	 63.483317	 0.0	 0.0	 1	 -30.0	 30.0;
	7658	 5325	 0.009281	 0.03038	 0.00316	 67.378041	 67.378041	 67.378041	 0.0	 0.0	 1	 -30.0	 30.0;
	6954	 2552	 0.011438	 0.035711	 0.00395	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7994	 6954	 0.05095	 0.124661	 0.01034	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5009	 8351	 0.058207	 0.110223	 0.01264	 80.361979	 80.361979	 80.361979	 0.0	 0.0	 1	 -30.0	 30.0;
	370	 656	 0.061876	 0.195174	 0.02038	 61.190341	 61.190341	 61.190341	 0.0	 0.0	 1	 -30.0	 30.0;
	7376	 3007	 0.013438	 0.032033	 0.00278	 74.02586	 74.02586	 74.02586	 0.0	 0.0	 1	 -30.0	 30.0;
	4169	 7376	 0.03619	 0.085066	 0.00739	 149.118472	 149.118472	 149.118472	 0.0	 0.0	 1	 -30.0	 30.0;
	3548	 2423	 0.05324	 0.154826	 0.0175	 60.675351	 60.675351	 60.675351	 0.0	 0.0	 1	 -30.0	 30.0;
	3493	 3007	 0.004579	 0.026017	 0.00226	 78.630482	 78.630482	 78.630482	 0.0	 0.0	 1	 -30.0	 30.0;
	2910	 8238	 0.00795	 0.03657	 0.06296	 378.417733	 378.417733	 378.417733	 0.0	 0.0	 1	 -30.0	 30.0;
	2552	 1151	 0.055967	 0.167983	 0.01919	 60.786236	 60.786236	 60.786236	 0.0	 0.0	 1	 -30.0	 30.0;
	7994	 2552	 0.070942	 0.168066	 0.0144	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2266	 2401	 0.00389	 0.04149	 0.88556	 1263.590404	 1263.590404	 1263.590404	 0.0	 0.0	 1	 -30.0	 30.0;
	6424	 2266	 0.003	 0.02776	 0.67411	 1126.790468	 1126.790468	 1126.790468	 0.0	 0.0	 1	 -30.0	 30.0;
	4693	 4755	 0.002159	 0.01261	 0.01683	 382.678266	 382.678266	 382.678266	 0.0	 0.0	 1	 -30.0	 30.0;
	4693	 4755	 0.002021	 0.016849	 0.02199	 414.680468	 414.680468	 414.680468	 0.0	 0.0	 1	 -30.0	 30.0;
	6356	 4755	 0.007151	 0.046719	 0.8722	 615.561885	 615.561885	 615.561885	 0.0	 0.0	 1	 -30.0	 30.0;
	4755	 6282	 0.000539	 0.00368	 0.01177	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4755	 6282	 0.000539	 0.003591	 0.01134	 310.824208	 310.824208	 310.824208	 0.0	 0.0	 1	 -30.0	 30.0;
	7183	 7658	 0.007446	 0.010579	 0.09655	 83.480883	 83.480883	 83.480883	 0.0	 0.0	 1	 -30.0	 30.0;
	7183	 2302	 0.011992	 0.03276	 0.01903	 85.893508	 85.893508	 85.893508	 0.0	 0.0	 1	 -30.0	 30.0;
	700	 2390	 0.034207	 0.085124	 0.00714	 72.432113	 72.432113	 72.432113	 0.0	 0.0	 1	 -30.0	 30.0;
	161	 700	 0.001248	 0.004471	 0.00048	 109.117625	 109.117625	 109.117625	 0.0	 0.0	 1	 -30.0	 30.0;
	161	 700	 0.001223	 0.004562	 0.00047	 105.978716	 105.978716	 105.978716	 0.0	 0.0	 1	 -30.0	 30.0;
	4992	 2910	 0.006961	 0.04039	 0.05461	 396.711619	 396.711619	 396.711619	 0.0	 0.0	 1	 -30.0	 30.0;
	4992	 2910	 0.004521	 0.02305	 0.03572	 391.740806	 391.740806	 391.740806	 0.0	 0.0	 1	 -30.0	 30.0;
	4992	 4023	 0.00395	 0.022789	 0.0313	 457.657706	 457.657706	 457.657706	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 3982	 0.031934	 0.123661	 0.01141	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 3142	 0.019802	 0.070901	 0.00675	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 3142	 0.022438	 0.069479	 0.00765	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 1243	 0.014727	 0.04305	 0.0053	 61.77354	 61.77354	 61.77354	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 116	 0.01343	 0.06824	 0.01274	 78.81815	 78.81815	 78.81815	 0.0	 0.0	 1	 -30.0	 30.0;
	1764	 116	 0.022	 0.060388	 0.00814	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1764	 116	 0.019603	 0.068438	 0.00725	 66.525248	 66.525248	 66.525248	 0.0	 0.0	 1	 -30.0	 30.0;
	1151	 1107	 0.048769	 0.114711	 0.00998	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3153	 3990	 0.046901	 0.148033	 0.0155	 71.215607	 71.215607	 71.215607	 0.0	 0.0	 1	 -30.0	 30.0;
	6270	 3990	 0.055744	 0.139066	 0.01166	 81.118556	 81.118556	 81.118556	 0.0	 0.0	 1	 -30.0	 30.0;
	708	 5033	 0.010917	 0.032901	 0.00371	 58.046669	 58.046669	 58.046669	 0.0	 0.0	 1	 -30.0	 30.0;
	6650	 4998	 0.026322	 0.044388	 0.04865	 65.811349	 65.811349	 65.811349	 0.0	 0.0	 1	 -30.0	 30.0;
	2673	 7506	 0.047438	 0.143727	 0.01562	 86.180821	 86.180821	 86.180821	 0.0	 0.0	 1	 -30.0	 30.0;
	6899	 7506	 0.026876	 0.09776	 0.02275	 75.169775	 75.169775	 75.169775	 0.0	 0.0	 1	 -30.0	 30.0;
	7967	 6899	 0.01705	 0.060802	 0.00588	 61.15738	 61.15738	 61.15738	 0.0	 0.0	 1	 -30.0	 30.0;
	823	 7967	 0.028727	 0.075289	 0.07038	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2673	 5072	 0.002388	 0.015942	 0.00343	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	2673	 2544	 0.088471	 0.217198	 0.01836	 75.133385	 75.133385	 75.133385	 0.0	 0.0	 1	 -30.0	 30.0;
	2423	 6038	 0.01714	 0.056248	 0.00571	 57.724871	 57.724871	 57.724871	 0.0	 0.0	 1	 -30.0	 30.0;
	5849	 3153	 0.004479	 0.014008	 0.00143	 94.919467	 94.919467	 94.919467	 0.0	 0.0	 1	 -30.0	 30.0;
	2704	 5849	 0.009851	 0.032314	 0.00324	 58.847829	 58.847829	 58.847829	 0.0	 0.0	 1	 -30.0	 30.0;
	4223	 5849	 0.001636	 0.005587	 0.05447	 79.452981	 79.452981	 79.452981	 0.0	 0.0	 1	 -30.0	 30.0;
	4223	 2976	 0.021603	 0.084	 0.00765	 64.073946	 64.073946	 64.073946	 0.0	 0.0	 1	 -30.0	 30.0;
	1629	 4270	 0.021727	 0.065893	 0.00742	 59.575827	 59.575827	 59.575827	 0.0	 0.0	 1	 -30.0	 30.0;
	1629	 4169	 0.025686	 0.080256	 0.00884	 66.926495	 66.926495	 66.926495	 0.0	 0.0	 1	 -30.0	 30.0;
	4169	 1629	 0.026182	 0.078587	 0.00901	 67.81644	 67.81644	 67.81644	 0.0	 0.0	 1	 -30.0	 30.0;
	6356	 4693	 0.00536	 0.040919	 0.05922	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	2302	 3493	 0.007388	 0.026628	 0.01555	 81.145229	 81.145229	 81.145229	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 4015	 0.005826	 0.017488	 0.00201	 60.398517	 60.398517	 60.398517	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 4015	 0.005826	 0.016653	 0.00205	 70.298798	 70.298798	 70.298798	 0.0	 0.0	 1	 -30.0	 30.0;
	3577	 4015	 0.026826	 0.082273	 0.00936	 74.035958	 74.035958	 74.035958	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 1392	 0.003256	 0.010587	 0.00163	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 876	 0.003331	 0.010372	 0.00166	 94.78629	 94.78629	 94.78629	 0.0	 0.0	 1	 -30.0	 30.0;
	7468	 7308	 0.025174	 0.077661	 0.00874	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2447	 4270	 0.030248	 0.085413	 0.01045	 80.740744	 80.740744	 80.740744	 0.0	 0.0	 1	 -30.0	 30.0;
	4577	 4270	 0.029471	 0.109198	 0.01008	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1107	 166	 0.058942	 0.115529	 0.0123	 69.580898	 69.580898	 69.580898	 0.0	 0.0	 1	 -30.0	 30.0;
	1243	 3982	 0.028413	 0.083	 0.01018	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7994	 3982	 0.005826	 0.016	 0.00205	 62.624427	 62.624427	 62.624427	 0.0	 0.0	 1	 -30.0	 30.0;
	7757	 3982	 0.005512	 0.016612	 0.00198	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5174	 1392	 0.014256	 0.033909	 0.00267	 75.107283	 75.107283	 75.107283	 0.0	 0.0	 1	 -30.0	 30.0;
	656	 1392	 0.052826	 0.200702	 0.01809	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1764	 1392	 0.01976	 0.061058	 0.00697	 88.672514	 88.672514	 88.672514	 0.0	 0.0	 1	 -30.0	 30.0;
	1764	 1392	 0.014008	 0.053207	 0.00526	 67.843304	 67.843304	 67.843304	 0.0	 0.0	 1	 -30.0	 30.0;
	1764	 1392	 0.013711	 0.054207	 0.00515	 77.613838	 77.613838	 77.613838	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 3142	 0.009132	 0.024843	 0.0022	 62.934984	 62.934984	 62.934984	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 3142	 0.010711	 0.040256	 0.00369	 87.989861	 87.989861	 87.989861	 0.0	 0.0	 1	 -30.0	 30.0;
	5923	 3142	 0.004562	 0.012421	 0.0011	 74.876175	 74.876175	 74.876175	 0.0	 0.0	 1	 -30.0	 30.0;
	7259	 2447	 0.025273	 0.079777	 0.00863	 72.714663	 72.714663	 72.714663	 0.0	 0.0	 1	 -30.0	 30.0;
	876	 5174	 0.009149	 0.028992	 0.00312	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4690	 2113	 0.027149	 0.096802	 0.00897	 69.235856	 69.235856	 69.235856	 0.0	 0.0	 1	 -30.0	 30.0;
	748	 4169	 0.063033	 0.157099	 0.0136	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	748	 7259	 0.009702	 0.035397	 0.00333	 77.08913	 77.08913	 77.08913	 0.0	 0.0	 1	 -30.0	 30.0;
	748	 7259	 0.009504	 0.036091	 0.00326	 67.9902	 67.9902	 67.9902	 0.0	 0.0	 1	 -30.0	 30.0;
	213	 6270	 0.029893	 0.105364	 0.01029	 64.441279	 64.441279	 64.441279	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 5151	 0.005397	 0.020298	 0.00189	 98.404371	 98.404371	 98.404371	 0.0	 0.0	 1	 -30.0	 30.0;
	6755	 2605	 0.001124	 0.002942	 0.03069	 112.453918	 112.453918	 112.453918	 0.0	 0.0	 1	 -30.0	 30.0;
	161	 2605	 0.001207	 0.003174	 0.03302	 84.791889	 84.791889	 84.791889	 0.0	 0.0	 1	 -30.0	 30.0;
	161	 2605	 0.00124	 0.003099	 0.03366	 80.407705	 80.407705	 80.407705	 0.0	 0.0	 1	 -30.0	 30.0;
	5923	 5220	 0.004066	 0.014083	 0.00098	 61.14652	 61.14652	 61.14652	 0.0	 0.0	 1	 -30.0	 30.0;
	2170	 6356	 0.005099	 0.025479	 0.03978	 393.786289	 393.786289	 393.786289	 0.0	 0.0	 1	 -30.0	 30.0;
	2170	 6356	 0.0052	 0.024961	 0.04056	 379.871443	 379.871443	 379.871443	 0.0	 0.0	 1	 -30.0	 30.0;
	7757	 7994	 0.003868	 0.013901	 0.00135	 58.812201	 58.812201	 58.812201	 0.0	 0.0	 1	 -30.0	 30.0;
	6424	 1301	 0.00126	 0.01433	 0.28656	 1265.177274	 1265.177274	 1265.177274	 0.0	 0.0	 1	 -30.0	 30.0;
	7468	 1764	 0.011752	 0.044314	 0.00414	 68.895577	 68.895577	 68.895577	 0.0	 0.0	 1	 -30.0	 30.0;
	8140	 6415	 0.021719	 0.046248	 0.00449	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8140	 5837	 0.05324	 0.100281	 0.01112	 58.18823	 58.18823	 58.18823	 0.0	 0.0	 1	 -30.0	 30.0;
	7628	 6116	 0.00109	 0.01155	 0.41153	 1111.941285	 1111.941285	 1111.941285	 0.0	 0.0	 1	 -30.0	 30.0;
	7628	 6116	 0.0011	 0.01158	 0.41253	 1045.980529	 1045.980529	 1045.980529	 0.0	 0.0	 1	 -30.0	 30.0;
	7628	 7904	 0.00096	 0.01293	 0.39742	 1237.781877	 1237.781877	 1237.781877	 0.0	 0.0	 1	 -30.0	 30.0;
	7628	 7904	 0.00098	 0.01264	 0.40478	 1208.96942	 1208.96942	 1208.96942	 0.0	 0.0	 1	 -30.0	 30.0;
	7628	 514	 0.00101	 0.01059	 0.20637	 1406.774021	 1406.774021	 1406.774021	 0.0	 0.0	 1	 -30.0	 30.0;
	7305	 5629	 0.00112	 0.010969	 0.02902	 535.344896	 535.344896	 535.344896	 0.0	 0.0	 1	 -30.0	 30.0;
	264	 5629	 0.00126	 0.01075	 0.03289	 552.226607	 552.226607	 552.226607	 0.0	 0.0	 1	 -30.0	 30.0;
	3351	 7780	 0.00197	 0.0207	 0.4876	 986.330397	 986.330397	 986.330397	 0.0	 0.0	 1	 -30.0	 30.0;
	3351	 514	 0.00303	 0.0273	 0.51885	 1325.180191	 1325.180191	 1325.180191	 0.0	 0.0	 1	 -30.0	 30.0;
	306	 7316	 0.00194	 0.02339	 0.48042	 913.854324	 913.854324	 913.854324	 0.0	 0.0	 1	 -30.0	 30.0;
	7904	 306	 0.00057	 0.00492	 0.12431	 999.411052	 999.411052	 999.411052	 0.0	 0.0	 1	 -30.0	 30.0;
	6062	 2589	 0.01105	 0.056599	 0.08685	 351.772729	 351.772729	 351.772729	 0.0	 0.0	 1	 -30.0	 30.0;
	4729	 2589	 0.00482	 0.046521	 0.11561	 388.703447	 388.703447	 388.703447	 0.0	 0.0	 1	 -30.0	 30.0;
	6116	 7729	 0.00194	 0.01645	 0.54766	 985.064718	 985.064718	 985.064718	 0.0	 0.0	 1	 -30.0	 30.0;
	7729	 5306	 0.00134	 0.01459	 0.38171	 1046.112165	 1046.112165	 1046.112165	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 7734	 0.000401	 0.00318	 0.00459	 615.119104	 615.119104	 615.119104	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 6408	 0.000349	 0.00293	 0.00412	 571.646499	 571.646499	 571.646499	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 1276	 0.000401	 0.00324	 0.00449	 628.535915	 628.535915	 628.535915	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 2589	 0.01214	 0.058401	 0.09615	 341.784616	 341.784616	 341.784616	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 2589	 0.012979	 0.053281	 0.12809	 332.620716	 332.620716	 332.620716	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 2951	 0.007919	 0.053729	 0.08698	 549.153429	 549.153429	 549.153429	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 6167	 0.014771	 0.06813	 0.11701	 440.256242	 440.256242	 440.256242	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 6167	 0.013789	 0.067711	 0.10063	 449.015847	 449.015847	 449.015847	 0.0	 0.0	 1	 -30.0	 30.0;
	1502	 5629	 0.005349	 0.044469	 0.06071	 534.264997	 534.264997	 534.264997	 0.0	 0.0	 1	 -30.0	 30.0;
	8176	 5629	 0.005229	 0.04118	 0.05939	 534.356069	 534.356069	 534.356069	 0.0	 0.0	 1	 -30.0	 30.0;
	5629	 4469	 0.0008	 0.00676	 0.00895	 556.213926	 556.213926	 556.213926	 0.0	 0.0	 1	 -30.0	 30.0;
	5629	 1953	 0.000781	 0.00626	 0.00876	 258.673162	 258.673162	 258.673162	 0.0	 0.0	 1	 -30.0	 30.0;
	5629	 7138	 0.00363	 0.017409	 0.05251	 268.298515	 268.298515	 268.298515	 0.0	 0.0	 1	 -30.0	 30.0;
	5629	 7138	 0.0037	 0.01705	 0.05352	 271.007027	 271.007027	 271.007027	 0.0	 0.0	 1	 -30.0	 30.0;
	5629	 4544	 0.00449	 0.046469	 0.09119	 508.857648	 508.857648	 508.857648	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 3279	 0.00052	 0.00727	 0.12854	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 5306	 0.00047	 0.0062	 0.11428	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 5306	 0.00046	 0.00631	 0.11184	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4547	 6167	 0.003531	 0.013669	 0.03479	 497.933292	 497.933292	 497.933292	 0.0	 0.0	 1	 -30.0	 30.0;
	6761	 7316	 0.00032	 0.00322	 0.07795	 1131.804478	 1131.804478	 1131.804478	 0.0	 0.0	 1	 -30.0	 30.0;
	6761	 4382	 0.00156	 0.01603	 0.38661	 1009.23372	 1009.23372	 1009.23372	 0.0	 0.0	 1	 -30.0	 30.0;
	6761	 2152	 0.0022	 0.02389	 0.63855	 1444.981988	 1444.981988	 1444.981988	 0.0	 0.0	 1	 -30.0	 30.0;
	6966	 4544	 0.00337	 0.032669	 0.08214	 405.483798	 405.483798	 405.483798	 0.0	 0.0	 1	 -30.0	 30.0;
	8333	 4382	 0.00199	 0.0195	 0.46272	 1157.960524	 1157.960524	 1157.960524	 0.0	 0.0	 1	 -30.0	 30.0;
	8333	 2152	 0.00144	 0.01354	 0.34334	 1043.653207	 1043.653207	 1043.653207	 0.0	 0.0	 1	 -30.0	 30.0;
	8333	 2152	 0.00147	 0.01325	 0.34982	 1136.278781	 1136.278781	 1136.278781	 0.0	 0.0	 1	 -30.0	 30.0;
	8333	 4605	 0.00211	 0.02433	 0.49124	 1156.423017	 1156.423017	 1156.423017	 0.0	 0.0	 1	 -30.0	 30.0;
	3779	 2589	 0.013901	 0.088849	 0.11777	 326.736905	 326.736905	 326.736905	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 7904	 0.00149	 0.01564	 0.3616	 1073.552977	 1073.552977	 1073.552977	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 7239	 0.00294	 0.02278	 0.414	 1356.004044	 1356.004044	 1356.004044	 0.0	 0.0	 1	 -30.0	 30.0;
	7904	 7239	 0.00133	 0.01873	 0.53568	 1160.594557	 1160.594557	 1160.594557	 0.0	 0.0	 1	 -30.0	 30.0;
	7138	 6167	 0.00581	 0.034229	 0.08461	 585.003105	 585.003105	 585.003105	 0.0	 0.0	 1	 -30.0	 30.0;
	7239	 6159	 0.00145	 0.02024	 0.36059	 1625.623906	 1625.623906	 1625.623906	 0.0	 0.0	 1	 -30.0	 30.0;
	7239	 6159	 0.00142	 0.01874	 0.35276	 1772.133962	 1772.133962	 1772.133962	 0.0	 0.0	 1	 -30.0	 30.0;
	7239	 7780	 0.00245	 0.02367	 0.59282	 1178.741219	 1178.741219	 1178.741219	 0.0	 0.0	 1	 -30.0	 30.0;
	7239	 4605	 0.00178	 0.02175	 0.43656	 1133.701351	 1133.701351	 1133.701351	 0.0	 0.0	 1	 -30.0	 30.0;
	5102	 6487	 0.000701	 0.009299	 0.0019	 83.894791	 83.894791	 83.894791	 0.0	 0.0	 1	 -30.0	 30.0;
	5102	 6487	 0.001042	 0.007833	 0.0024	 69.281963	 69.281963	 69.281963	 0.0	 0.0	 1	 -30.0	 30.0;
	5102	 6487	 0.001403	 0.00534	 0.0027	 74.434468	 74.434468	 74.434468	 0.0	 0.0	 1	 -30.0	 30.0;
	5306	 2849	 0.00022	 0.00258	 0.05115	 830.598591	 830.598591	 830.598591	 0.0	 0.0	 1	 -30.0	 30.0;
	2589	 2951	 0.02024	 0.099349	 0.14928	 362.314891	 362.314891	 362.314891	 0.0	 0.0	 1	 -30.0	 30.0;
	2589	 5539	 0.00044	 0.003081	 0.01938	 559.573654	 559.573654	 559.573654	 0.0	 0.0	 1	 -30.0	 30.0;
	2589	 2100	 0.00043	 0.00314	 0.01899	 559.573654	 559.573654	 559.573654	 0.0	 0.0	 1	 -30.0	 30.0;
	2589	 7915	 0.00461	 0.027531	 0.0363	 354.394361	 354.394361	 354.394361	 0.0	 0.0	 1	 -30.0	 30.0;
	8119	 2951	 0.01212	 0.09901	 0.13301	 398.151992	 398.151992	 398.151992	 0.0	 0.0	 1	 -30.0	 30.0;
	328	 5921	 0.000289	 0.00261	 0.06705	 382.74495	 382.74495	 382.74495	 0.0	 0.0	 1	 -30.0	 30.0;
	4160	 328	 0.00043	 0.002831	 0.04948	 441.38987	 441.38987	 441.38987	 0.0	 0.0	 1	 -30.0	 30.0;
	3187	 328	 0.000289	 0.000599	 0.04587	 425.688275	 425.688275	 425.688275	 0.0	 0.0	 1	 -30.0	 30.0;
	6791	 1038	 0.000289	 0.00224	 0.00387	 533.728096	 533.728096	 533.728096	 0.0	 0.0	 1	 -30.0	 30.0;
	3763	 6791	 0.000219	 0.001591	 0.00286	 417.648476	 417.648476	 417.648476	 0.0	 0.0	 1	 -30.0	 30.0;
	2442	 6101	 0.00045	 0.00786	 0.20766	 1841.012426	 1841.012426	 1841.012426	 0.0	 0.0	 1	 -30.0	 30.0;
	2442	 6101	 0.00044	 0.00728	 0.20315	 1650.451746	 1650.451746	 1650.451746	 0.0	 0.0	 1	 -30.0	 30.0;
	6101	 7481	 0.00049	 0.00466	 0.14017	 1527.503852	 1527.503852	 1527.503852	 0.0	 0.0	 1	 -30.0	 30.0;
	6101	 7358	 0.00125	 0.01973	 0.57488	 2025.042652	 2025.042652	 2025.042652	 0.0	 0.0	 1	 -30.0	 30.0;
	6178	 6177	 0.001461	 0.00714	 0.01432	 422.673017	 422.673017	 422.673017	 0.0	 0.0	 1	 -30.0	 30.0;
	8269	 6178	 0.00037	 0.00094	 0.1353	 427.135888	 427.135888	 427.135888	 0.0	 0.0	 1	 -30.0	 30.0;
	6178	 1650	 0.001039	 0.00737	 0.01181	 339.214426	 339.214426	 339.214426	 0.0	 0.0	 1	 -30.0	 30.0;
	4817	 5738	 8.1e-05	 0.00061	 0.00092	 386.063525	 386.063525	 386.063525	 0.0	 0.0	 1	 -30.0	 30.0;
	6628	 7320	 0.00053	 0.00852	 0.23849	 1629.477546	 1629.477546	 1629.477546	 0.0	 0.0	 1	 -30.0	 30.0;
	4969	 7320	 0.00053	 0.00704	 0.24029	 1750.194871	 1750.194871	 1750.194871	 0.0	 0.0	 1	 -30.0	 30.0;
	4647	 3052	 0.0001	 0.00128	 0.12197	 833.732841	 833.732841	 833.732841	 0.0	 0.0	 1	 -30.0	 30.0;
	3959	 8239	 0.0015	 0.00705	 0.01181	 426.65805	 426.65805	 426.65805	 0.0	 0.0	 1	 -30.0	 30.0;
	8239	 6409	 0.009771	 0.05363	 0.07652	 412.437601	 412.437601	 412.437601	 0.0	 0.0	 1	 -30.0	 30.0;
	3959	 8239	 0.00088	 0.007771	 0.01012	 457.238931	 457.238931	 457.238931	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 7651	 0.00539	 0.032979	 0.04202	 401.522771	 401.522771	 401.522771	 0.0	 0.0	 1	 -30.0	 30.0;
	1337	 3777	 0.00482	 0.03086	 0.05736	 314.252144	 314.252144	 314.252144	 0.0	 0.0	 1	 -30.0	 30.0;
	1949	 3777	 0.010539	 0.065479	 0.14325	 473.383689	 473.383689	 473.383689	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 7163	 0.01074	 0.06405	 0.1459	 481.522942	 481.522942	 481.522942	 0.0	 0.0	 1	 -30.0	 30.0;
	4052	 3777	 0.0063	 0.048909	 0.07462	 535.182187	 535.182187	 535.182187	 0.0	 0.0	 1	 -30.0	 30.0;
	1663	 812	 0.0002	 0.00022	 0.00277	 1426.45819	 1426.45819	 1426.45819	 0.0	 0.0	 1	 -30.0	 30.0;
	4530	 812	 0.0002	 0.00022	 0.00272	 1466.197082	 1466.197082	 1466.197082	 0.0	 0.0	 1	 -30.0	 30.0;
	6188	 812	 0.00019	 0.00023	 0.00266	 1495.411029	 1495.411029	 1495.411029	 0.0	 0.0	 1	 -30.0	 30.0;
	836	 1164	 0.000289	 0.0017	 0.00219	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	812	 1085	 0.00145	 0.01937	 0.68469	 1999.469095	 1999.469095	 1999.469095	 0.0	 0.0	 1	 -30.0	 30.0;
	2842	 812	 0.00048	 0.00814	 0.22346	 1788.079014	 1788.079014	 1788.079014	 0.0	 0.0	 1	 -30.0	 30.0;
	2842	 812	 0.00057	 0.00758	 0.26458	 1636.485181	 1636.485181	 1636.485181	 0.0	 0.0	 1	 -30.0	 30.0;
	7598	 3464	 0.0002	 0.00187	 0.00659	 313.789929	 313.789929	 313.789929	 0.0	 0.0	 1	 -30.0	 30.0;
	7598	 3464	 0.000169	 0.00193	 0.00564	 308.383956	 308.383956	 308.383956	 0.0	 0.0	 1	 -30.0	 30.0;
	1934	 1806	 0.00216	 0.03591	 1.05032	 999.743433	 999.743433	 999.743433	 0.0	 0.0	 1	 -30.0	 30.0;
	1934	 3043	 0.00092	 0.01287	 0.43829	 1816.576862	 1816.576862	 1816.576862	 0.0	 0.0	 1	 -30.0	 30.0;
	1146	 3280	 0.02412	 0.10443	 0.18558	 476.4401	 476.4401	 476.4401	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 7651	 0.00063	 0.00401	 0.01805	 240.712315	 240.712315	 240.712315	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 3248	 0.00038	 0.002409	 0.0109	 276.250672	 276.250672	 276.250672	 0.0	 0.0	 1	 -30.0	 30.0;
	4435	 3727	 0.010091	 0.05524	 0.09845	 517.379476	 517.379476	 517.379476	 0.0	 0.0	 1	 -30.0	 30.0;
	4984	 4435	 0.00668	 0.04457	 0.06427	 450.043923	 450.043923	 450.043923	 0.0	 0.0	 1	 -30.0	 30.0;
	6362	 1722	 0.00057	 0.004961	 0.05619	 425.129654	 425.129654	 425.129654	 0.0	 0.0	 1	 -30.0	 30.0;
	1722	 4974	 0.00025	 0.002159	 0.05179	 361.400749	 361.400749	 361.400749	 0.0	 0.0	 1	 -30.0	 30.0;
	476	 4111	 0.00443	 0.01807	 0.03672	 441.326615	 441.326615	 441.326615	 0.0	 0.0	 1	 -30.0	 30.0;
	476	 5298	 0.00037	 0.001659	 0.00331	 495.916007	 495.916007	 495.916007	 0.0	 0.0	 1	 -30.0	 30.0;
	6362	 755	 0.00037	 0.003599	 0.51014	 494.850969	 494.850969	 494.850969	 0.0	 0.0	 1	 -30.0	 30.0;
	6362	 6796	 0.000659	 0.00836	 0.01984	 443.383148	 443.383148	 443.383148	 0.0	 0.0	 1	 -30.0	 30.0;
	6362	 6796	 0.00151	 0.012289	 0.02276	 383.067319	 383.067319	 383.067319	 0.0	 0.0	 1	 -30.0	 30.0;
	6362	 2169	 0.000539	 0.003711	 0.0065	 393.078296	 393.078296	 393.078296	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 1210	 0.00036	 0.00606	 0.16471	 1099.36282	 1099.36282	 1099.36282	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 1210	 0.00035	 0.00618	 0.1612	 949.731678	 949.731678	 949.731678	 0.0	 0.0	 1	 -30.0	 30.0;
	1210	 597	 0.00101	 0.01675	 0.48261	 2008.222221	 2008.222221	 2008.222221	 0.0	 0.0	 1	 -30.0	 30.0;
	1210	 4864	 4e-05	 0.00071	 0.02437	 1629.892857	 1629.892857	 1629.892857	 0.0	 0.0	 1	 -30.0	 30.0;
	1210	 4864	 4e-05	 0.00081	 0.02107	 1805.655692	 1805.655692	 1805.655692	 0.0	 0.0	 1	 -30.0	 30.0;
	1210	 893	 0.00013	 0.00152	 0.038	 2147.154	 2147.154	 2147.154	 0.0	 0.0	 1	 -30.0	 30.0;
	1210	 893	 0.00014	 0.00149	 0.03875	 989.791762	 989.791762	 989.791762	 0.0	 0.0	 1	 -30.0	 30.0;
	1210	 3806	 0.00013	 0.00164	 0.0366	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1210	 3806	 0.00013	 0.00168	 0.03583	 902.635658	 902.635658	 902.635658	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 4052	 0.000669	 0.00511	 0.00806	 476.804004	 476.804004	 476.804004	 0.0	 0.0	 1	 -30.0	 30.0;
	8137	 3147	 3.9e-05	 0.000341	 0.00051	 298.744504	 298.744504	 298.744504	 0.0	 0.0	 1	 -30.0	 30.0;
	5339	 5153	 0.004219	 0.02145	 0.04075	 325.757603	 325.757603	 325.757603	 0.0	 0.0	 1	 -30.0	 30.0;
	5339	 3677	 0.000229	 0.002849	 0.00675	 633.628664	 633.628664	 633.628664	 0.0	 0.0	 1	 -30.0	 30.0;
	1146	 46	 0.0137	 0.10436	 0.17076	 458.358078	 458.358078	 458.358078	 0.0	 0.0	 1	 -30.0	 30.0;
	2425	 1146	 0.001521	 0.01449	 0.04952	 528.627726	 528.627726	 528.627726	 0.0	 0.0	 1	 -30.0	 30.0;
	694	 393	 8.1e-05	 0.00057	 0.00098	 540.212063	 540.212063	 540.212063	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 393	 0.001461	 0.00813	 0.01346	 488.30832	 488.30832	 488.30832	 0.0	 0.0	 1	 -30.0	 30.0;
	1295	 393	 0.00049	 0.00381	 0.00551	 460.350595	 460.350595	 460.350595	 0.0	 0.0	 1	 -30.0	 30.0;
	6840	 2336	 0.000401	 0.00287	 0.00499	 539.15236	 539.15236	 539.15236	 0.0	 0.0	 1	 -30.0	 30.0;
	5178	 4384	 8.3e-05	 0.000347	 0.00118	 77.349301	 77.349301	 77.349301	 0.0	 0.0	 1	 -30.0	 30.0;
	5948	 6388	 0.00023	 0.00285	 0.1104	 1326.04109	 1326.04109	 1326.04109	 0.0	 0.0	 1	 -30.0	 30.0;
	6388	 2908	 0.00016	 0.00218	 0.07368	 2143.632083	 2143.632083	 2143.632083	 0.0	 0.0	 1	 -30.0	 30.0;
	2714	 6388	 0.00057	 0.00736	 0.27483	 1630.352925	 1630.352925	 1630.352925	 0.0	 0.0	 1	 -30.0	 30.0;
	363	 7126	 0.000591	 0.005789	 0.00881	 510.777384	 510.777384	 510.777384	 0.0	 0.0	 1	 -30.0	 30.0;
	363	 3030	 0.002729	 0.011461	 0.04693	 513.788831	 513.788831	 513.788831	 0.0	 0.0	 1	 -30.0	 30.0;
	363	 5543	 0.00051	 0.00205	 0.27176	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	7499	 6122	 0.00031	 0.00374	 0.1517	 1876.493557	 1876.493557	 1876.493557	 0.0	 0.0	 1	 -30.0	 30.0;
	2458	 7499	 0.00032	 0.00518	 0.15553	 2224.462425	 2224.462425	 2224.462425	 0.0	 0.0	 1	 -30.0	 30.0;
	1817	 6623	 0.00136	 0.01038	 0.0167	 487.959277	 487.959277	 487.959277	 0.0	 0.0	 1	 -30.0	 30.0;
	7735	 3679	 0.00151	 0.02083	 0.71503	 1838.464614	 1838.464614	 1838.464614	 0.0	 0.0	 1	 -30.0	 30.0;
	6953	 3679	 0.00015	 0.00232	 0.07104	 1698.109194	 1698.109194	 1698.109194	 0.0	 0.0	 1	 -30.0	 30.0;
	2007	 7361	 1e-05	 0.00025	 0.00413	 1008.902656	 1008.902656	 1008.902656	 0.0	 0.0	 1	 -30.0	 30.0;
	8178	 7361	 1e-05	 0.00023	 0.00469	 1008.121397	 1008.121397	 1008.121397	 0.0	 0.0	 1	 -30.0	 30.0;
	2199	 7361	 0.00047	 0.00683	 0.20319	 1206.519676	 1206.519676	 1206.519676	 0.0	 0.0	 1	 -30.0	 30.0;
	797	 7361	 0.00067	 0.00858	 0.31718	 1310.094063	 1310.094063	 1310.094063	 0.0	 0.0	 1	 -30.0	 30.0;
	2299	 942	 0.003669	 0.025331	 0.09971	 518.573691	 518.573691	 518.573691	 0.0	 0.0	 1	 -30.0	 30.0;
	331	 2299	 0.00525	 0.02994	 0.14222	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4245	 6226	 0.00595	 0.03625	 0.08592	 506.116747	 506.116747	 506.116747	 0.0	 0.0	 1	 -30.0	 30.0;
	4245	 7113	 0.004969	 0.03411	 0.07996	 484.939447	 484.939447	 484.939447	 0.0	 0.0	 1	 -30.0	 30.0;
	510	 1700	 0.005669	 0.04293	 0.0694	 571.45102	 571.45102	 571.45102	 0.0	 0.0	 1	 -30.0	 30.0;
	510	 1700	 0.00555	 0.043771	 0.06799	 527.170968	 527.170968	 527.170968	 0.0	 0.0	 1	 -30.0	 30.0;
	1700	 3487	 0.002831	 0.022401	 0.03479	 360.361242	 360.361242	 360.361242	 0.0	 0.0	 1	 -30.0	 30.0;
	1700	 3487	 0.00325	 0.01938	 0.03984	 413.949612	 413.949612	 413.949612	 0.0	 0.0	 1	 -30.0	 30.0;
	7302	 143	 0.00068	 0.00082	 1.15469	 1038.607604	 1038.607604	 1038.607604	 0.0	 0.0	 1	 -30.0	 30.0;
	7302	 1862	 0.00054	 0.00868	 0.17111	 1362.948494	 1362.948494	 1362.948494	 0.0	 0.0	 1	 -30.0	 30.0;
	1608	 6162	 0.00061	 0.002909	 0.00474	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1608	 1336	 0.002271	 0.01014	 0.01813	 257.572306	 257.572306	 257.572306	 0.0	 0.0	 1	 -30.0	 30.0;
	3547	 1149	 0.00083	 0.00986	 0.4002	 2082.865678	 2082.865678	 2082.865678	 0.0	 0.0	 1	 -30.0	 30.0;
	1149	 7375	 0.00031	 0.00511	 0.15071	 1640.041982	 1640.041982	 1640.041982	 0.0	 0.0	 1	 -30.0	 30.0;
	1149	 7375	 0.0003	 0.00521	 0.1475	 1656.019943	 1656.019943	 1656.019943	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 1149	 0.00081	 0.01288	 0.38613	 2147.065146	 2147.065146	 2147.065146	 0.0	 0.0	 1	 -30.0	 30.0;
	1149	 8181	 0.00039	 0.00645	 0.18093	 1999.089325	 1999.089325	 1999.089325	 0.0	 0.0	 1	 -30.0	 30.0;
	3431	 2109	 0.00243	 0.012211	 0.01893	 328.037814	 328.037814	 328.037814	 0.0	 0.0	 1	 -30.0	 30.0;
	3242	 4816	 0.00018	 0.00226	 0.08496	 2142.906111	 2142.906111	 2142.906111	 0.0	 0.0	 1	 -30.0	 30.0;
	2105	 4816	 0.0002	 0.00347	 0.097	 1759.770064	 1759.770064	 1759.770064	 0.0	 0.0	 1	 -30.0	 30.0;
	2908	 4816	 0.00018	 0.0029	 0.09086	 1992.645092	 1992.645092	 1992.645092	 0.0	 0.0	 1	 -30.0	 30.0;
	4989	 6122	 0.00045	 0.00494	 0.1307	 1412.301411	 1412.301411	 1412.301411	 0.0	 0.0	 1	 -30.0	 30.0;
	6122	 2433	 0.00042	 0.00497	 0.14413	 1614.239379	 1614.239379	 1614.239379	 0.0	 0.0	 1	 -30.0	 30.0;
	2936	 7735	 0.00019	 0.00234	 0.05305	 1269.088176	 1269.088176	 1269.088176	 0.0	 0.0	 1	 -30.0	 30.0;
	1806	 7735	 8e-05	 0.00105	 0.04323	 1678.427658	 1678.427658	 1678.427658	 0.0	 0.0	 1	 -30.0	 30.0;
	1806	 7735	 8e-05	 0.00107	 0.04235	 1617.638217	 1617.638217	 1617.638217	 0.0	 0.0	 1	 -30.0	 30.0;
	7735	 7189	 8e-05	 0.001	 0.40209	 2100.722741	 2100.722741	 2100.722741	 0.0	 0.0	 1	 -30.0	 30.0;
	7735	 3620	 0.00063	 0.01015	 0.29913	 1867.951705	 1867.951705	 1867.951705	 0.0	 0.0	 1	 -30.0	 30.0;
	795	 6051	 0.00064	 0.005651	 0.02099	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	795	 6051	 0.000581	 0.006531	 0.01907	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4651	 7912	 0.007099	 0.04432	 0.06825	 400.579669	 400.579669	 400.579669	 0.0	 0.0	 1	 -30.0	 30.0;
	5921	 1650	 0.00144	 0.01157	 0.01638	 438.946188	 438.946188	 438.946188	 0.0	 0.0	 1	 -30.0	 30.0;
	5921	 7077	 0.00114	 0.00695	 0.01238	 435.365831	 435.365831	 435.365831	 0.0	 0.0	 1	 -30.0	 30.0;
	3242	 1536	 0.00044	 0.0053	 0.21006	 1642.477904	 1642.477904	 1642.477904	 0.0	 0.0	 1	 -30.0	 30.0;
	6414	 6005	 0.00162	 0.009039	 0.03158	 404.154692	 404.154692	 404.154692	 0.0	 0.0	 1	 -30.0	 30.0;
	6414	 6005	 0.00187	 0.0072	 0.06935	 403.31295	 403.31295	 403.31295	 0.0	 0.0	 1	 -30.0	 30.0;
	1209	 6005	 0.00101	 0.00564	 0.00972	 257.289947	 257.289947	 257.289947	 0.0	 0.0	 1	 -30.0	 30.0;
	3370	 6005	 0.0007	 0.00445	 0.0112	 258.04519	 258.04519	 258.04519	 0.0	 0.0	 1	 -30.0	 30.0;
	2638	 6005	 0.001081	 0.00619	 0.03556	 556.806842	 556.806842	 556.806842	 0.0	 0.0	 1	 -30.0	 30.0;
	1806	 7529	 0.00022	 0.00228	 0.06341	 1450.214514	 1450.214514	 1450.214514	 0.0	 0.0	 1	 -30.0	 30.0;
	1806	 5632	 0.00023	 0.00223	 0.06643	 1438.164567	 1438.164567	 1438.164567	 0.0	 0.0	 1	 -30.0	 30.0;
	1806	 7205	 0.0002	 0.00262	 0.05709	 1450.233601	 1450.233601	 1450.233601	 0.0	 0.0	 1	 -30.0	 30.0;
	1806	 1756	 0.00021	 0.00261	 0.05868	 1308.203114	 1308.203114	 1308.203114	 0.0	 0.0	 1	 -30.0	 30.0;
	42	 6340	 0.00663	 0.04181	 0.08125	 461.79859	 461.79859	 461.79859	 0.0	 0.0	 1	 -30.0	 30.0;
	1806	 2226	 0.00059	 0.00921	 0.27853	 1705.04772	 1705.04772	 1705.04772	 0.0	 0.0	 1	 -30.0	 30.0;
	1806	 3788	 0.0014	 0.02227	 0.67283	 1778.163543	 1778.163543	 1778.163543	 0.0	 0.0	 1	 -30.0	 30.0;
	3524	 2554	 0.000401	 0.002469	 0.00474	 442.871015	 442.871015	 442.871015	 0.0	 0.0	 1	 -30.0	 30.0;
	5123	 2554	 0.00212	 0.01218	 0.01702	 384.804151	 384.804151	 384.804151	 0.0	 0.0	 1	 -30.0	 30.0;
	2554	 1849	 0.004169	 0.02439	 0.01892	 448.956403	 448.956403	 448.956403	 0.0	 0.0	 1	 -30.0	 30.0;
	7651	 8235	 0.02336	 0.122419	 0.22706	 336.17821	 336.17821	 336.17821	 0.0	 0.0	 1	 -30.0	 30.0;
	7651	 620	 0.002729	 0.0137	 0.08253	 353.368572	 353.368572	 353.368572	 0.0	 0.0	 1	 -30.0	 30.0;
	2610	 7651	 0.000919	 0.003831	 0.00829	 376.875238	 376.875238	 376.875238	 0.0	 0.0	 1	 -30.0	 30.0;
	2610	 7651	 0.00082	 0.004349	 0.00739	 359.109108	 359.109108	 359.109108	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 7651	 0.01325	 0.055159	 0.10796	 454.823448	 454.823448	 454.823448	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 7651	 0.0108	 0.06074	 0.08728	 442.82186	 442.82186	 442.82186	 0.0	 0.0	 1	 -30.0	 30.0;
	7651	 4378	 0.001099	 0.00631	 0.00879	 422.346075	 422.346075	 422.346075	 0.0	 0.0	 1	 -30.0	 30.0;
	7064	 5738	 0.00495	 0.029151	 0.03895	 428.408599	 428.408599	 428.408599	 0.0	 0.0	 1	 -30.0	 30.0;
	5738	 8110	 0.003909	 0.0227	 0.03087	 401.96822	 401.96822	 401.96822	 0.0	 0.0	 1	 -30.0	 30.0;
	1949	 3235	 0.00061	 0.00424	 0.00726	 312.454345	 312.454345	 312.454345	 0.0	 0.0	 1	 -30.0	 30.0;
	2602	 1038	 0.00068	 0.003919	 0.00535	 532.10558	 532.10558	 532.10558	 0.0	 0.0	 1	 -30.0	 30.0;
	4161	 1038	 0.00368	 0.019901	 0.02641	 241.022491	 241.022491	 241.022491	 0.0	 0.0	 1	 -30.0	 30.0;
	6726	 2105	 0.00025	 0.00388	 0.12151	 1477.941634	 1477.941634	 1477.941634	 0.0	 0.0	 1	 -30.0	 30.0;
	6726	 337	 0.00038	 0.00623	 0.18345	 1224.216144	 1224.216144	 1224.216144	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 4337	 0.000909	 0.006031	 0.00929	 446.598458	 446.598458	 446.598458	 0.0	 0.0	 1	 -30.0	 30.0;
	4337	 1650	 0.001211	 0.0062	 0.01223	 517.71061	 517.71061	 517.71061	 0.0	 0.0	 1	 -30.0	 30.0;
	2199	 366	 0.00022	 0.00322	 0.10273	 1140.784676	 1140.784676	 1140.784676	 0.0	 0.0	 1	 -30.0	 30.0;
	2199	 4108	 0.00018	 0.00307	 0.08602	 1779.656293	 1779.656293	 1779.656293	 0.0	 0.0	 1	 -30.0	 30.0;
	2199	 4482	 0.00068	 0.00873	 0.32682	 1125.183194	 1125.183194	 1125.183194	 0.0	 0.0	 1	 -30.0	 30.0;
	2199	 7396	 0.00124	 0.02016	 0.59343	 1334.082066	 1334.082066	 1334.082066	 0.0	 0.0	 1	 -30.0	 30.0;
	8291	 6628	 0.00025	 0.00332	 0.13434	 1564.457987	 1564.457987	 1564.457987	 0.0	 0.0	 1	 -30.0	 30.0;
	8291	 6628	 0.00025	 0.00335	 0.1165	 1753.709549	 1753.709549	 1753.709549	 0.0	 0.0	 1	 -30.0	 30.0;
	8291	 6628	 0.00025	 0.00325	 0.13692	 1711.401783	 1711.401783	 1711.401783	 0.0	 0.0	 1	 -30.0	 30.0;
	2790	 8291	 0.00076	 0.01075	 0.36484	 1779.002063	 1779.002063	 1779.002063	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 8291	 3e-05	 0.00044	 0.01014	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3147	 6838	 0.001651	 0.010849	 0.01913	 549.79169	 549.79169	 549.79169	 0.0	 0.0	 1	 -30.0	 30.0;
	7542	 3147	 0.00288	 0.018469	 0.03437	 481.001283	 481.001283	 481.001283	 0.0	 0.0	 1	 -30.0	 30.0;
	6255	 1378	 0.00072	 0.00923	 0.3409	 1381.088574	 1381.088574	 1381.088574	 0.0	 0.0	 1	 -30.0	 30.0;
	6255	 5615	 0.00069	 0.00855	 0.33299	 1769.4453	 1769.4453	 1769.4453	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 4163	 0.00124	 0.01667	 0.58961	 2147.105953	 2147.105953	 2147.105953	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 751	 0.00034	 0.00571	 0.1561	 1829.538387	 1829.538387	 1829.538387	 0.0	 0.0	 1	 -30.0	 30.0;
	6294	 2893	 0.0004	 0.00638	 0.19536	 1930.759124	 1930.759124	 1930.759124	 0.0	 0.0	 1	 -30.0	 30.0;
	6294	 2893	 0.00039	 0.0065	 0.19129	 1897.635592	 1897.635592	 1897.635592	 0.0	 0.0	 1	 -30.0	 30.0;
	7161	 2893	 0.00027	 0.00451	 0.12295	 1684.5869	 1684.5869	 1684.5869	 0.0	 0.0	 1	 -30.0	 30.0;
	7446	 3544	 0.012409	 0.074961	 0.11518	 394.975931	 394.975931	 394.975931	 0.0	 0.0	 1	 -30.0	 30.0;
	7446	 7797	 0.002419	 0.01761	 0.02279	 442.990666	 442.990666	 442.990666	 0.0	 0.0	 1	 -30.0	 30.0;
	7446	 1295	 0.006901	 0.053409	 0.06908	 457.935112	 457.935112	 457.935112	 0.0	 0.0	 1	 -30.0	 30.0;
	2602	 10	 0.000599	 0.00356	 0.0048	 502.624413	 502.624413	 502.624413	 0.0	 0.0	 1	 -30.0	 30.0;
	2602	 4111	 0.011841	 0.049341	 0.08708	 435.254946	 435.254946	 435.254946	 0.0	 0.0	 1	 -30.0	 30.0;
	4160	 817	 0.000521	 0.004831	 0.01	 541.421519	 541.421519	 541.421519	 0.0	 0.0	 1	 -30.0	 30.0;
	77	 817	 0.00055	 0.00143	 0.13971	 395.15693	 395.15693	 395.15693	 0.0	 0.0	 1	 -30.0	 30.0;
	7002	 817	 0.0005	 0.00364	 0.06374	 346.468878	 346.468878	 346.468878	 0.0	 0.0	 1	 -30.0	 30.0;
	7002	 817	 0.00056	 0.003469	 0.07625	 350.424189	 350.424189	 350.424189	 0.0	 0.0	 1	 -30.0	 30.0;
	817	 4712	 0.00082	 0.00257	 0.24	 459.323281	 459.323281	 459.323281	 0.0	 0.0	 1	 -30.0	 30.0;
	4117	 4945	 0.00249	 0.01536	 0.01915	 475.615124	 475.615124	 475.615124	 0.0	 0.0	 1	 -30.0	 30.0;
	4117	 2252	 0.00113	 0.00651	 0.00884	 451.763988	 451.763988	 451.763988	 0.0	 0.0	 1	 -30.0	 30.0;
	5853	 4620	 0.00643	 0.045031	 0.07877	 520.635178	 520.635178	 520.635178	 0.0	 0.0	 1	 -30.0	 30.0;
	7714	 5853	 0.003581	 0.02706	 0.05928	 531.014631	 531.014631	 531.014631	 0.0	 0.0	 1	 -30.0	 30.0;
	1658	 3043	 0.00046	 0.00774	 0.23407	 1823.869488	 1823.869488	 1823.869488	 0.0	 0.0	 1	 -30.0	 30.0;
	1658	 5865	 0.00031	 0.00483	 0.14581	 1107.410378	 1107.410378	 1107.410378	 0.0	 0.0	 1	 -30.0	 30.0;
	5392	 3429	 0.001099	 0.00345	 0.53179	 467.185891	 467.185891	 467.185891	 0.0	 0.0	 1	 -30.0	 30.0;
	1142	 894	 0.00913	 0.053211	 0.07112	 368.983287	 368.983287	 368.983287	 0.0	 0.0	 1	 -30.0	 30.0;
	894	 7727	 0.021151	 0.095401	 0.16513	 369.54991	 369.54991	 369.54991	 0.0	 0.0	 1	 -30.0	 30.0;
	5590	 4163	 0.00034	 0.0055	 0.16133	 1816.261594	 1816.261594	 1816.261594	 0.0	 0.0	 1	 -30.0	 30.0;
	2498	 3225	 0.00064	 0.01945	 0.55897	 1821.055114	 1821.055114	 1821.055114	 0.0	 0.0	 1	 -30.0	 30.0;
	2498	 7857	 0.0004	 0.01026	 0.34782	 1474.755388	 1474.755388	 1474.755388	 0.0	 0.0	 1	 -30.0	 30.0;
	6589	 2498	 0.00071	 0.01087	 0.34033	 1268.706432	 1268.706432	 1268.706432	 0.0	 0.0	 1	 -30.0	 30.0;
	7972	 1335	 0.00968	 0.088169	 0.13353	 535.226008	 535.226008	 535.226008	 0.0	 0.0	 1	 -30.0	 30.0;
	7972	 1335	 0.012349	 0.086409	 0.15134	 475.021828	 475.021828	 475.021828	 0.0	 0.0	 1	 -30.0	 30.0;
	1335	 3723	 0.00288	 0.017211	 0.03535	 548.482779	 548.482779	 548.482779	 0.0	 0.0	 1	 -30.0	 30.0;
	3723	 1335	 0.00257	 0.0195	 0.0315	 501.717511	 501.717511	 501.717511	 0.0	 0.0	 1	 -30.0	 30.0;
	2799	 942	 0.00051	 0.00407	 0.02631	 568.535597	 568.535597	 568.535597	 0.0	 0.0	 1	 -30.0	 30.0;
	525	 5922	 0.00019	 0.00309	 0.09344	 1529.789708	 1529.789708	 1529.789708	 0.0	 0.0	 1	 -30.0	 30.0;
	525	 6448	 0.00023	 0.00357	 0.11217	 1616.919485	 1616.919485	 1616.919485	 0.0	 0.0	 1	 -30.0	 30.0;
	2986	 3536	 0.00088	 0.0092	 0.19005	 1190.049398	 1190.049398	 1190.049398	 0.0	 0.0	 1	 -30.0	 30.0;
	2986	 4253	 0.00023	 0.00179	 0.05039	 1588.668455	 1588.668455	 1588.668455	 0.0	 0.0	 1	 -30.0	 30.0;
	5510	 5192	 0.00145	 0.007919	 0.01161	 497.283218	 497.283218	 497.283218	 0.0	 0.0	 1	 -30.0	 30.0;
	425	 5192	 0.00143	 0.00812	 0.01675	 499.145797	 499.145797	 499.145797	 0.0	 0.0	 1	 -30.0	 30.0;
	5192	 5153	 0.00524	 0.02181	 0.04255	 525.24323	 525.24323	 525.24323	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 3431	 0.00261	 0.01913	 0.14499	 451.716356	 451.716356	 451.716356	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 3431	 0.00164	 0.016591	 0.09122	 572.382309	 572.382309	 572.382309	 0.0	 0.0	 1	 -30.0	 30.0;
	5022	 4775	 0.00087	 0.012719	 0.57325	 443.648741	 443.648741	 443.648741	 0.0	 0.0	 1	 -30.0	 30.0;
	1	 6932	 0.00775	 0.03501	 0.01357	 405.595827	 405.595827	 405.595827	 0.0	 0.0	 1	 -30.0	 30.0;
	1	 7107	 0.01944	 0.093479	 0.15775	 458.426287	 458.426287	 458.426287	 0.0	 0.0	 1	 -30.0	 30.0;
	1	 7107	 0.01981	 0.091539	 0.16078	 479.127654	 479.127654	 479.127654	 0.0	 0.0	 1	 -30.0	 30.0;
	1388	 5111	 0.003771	 0.020599	 0.02939	 428.908157	 428.908157	 428.908157	 0.0	 0.0	 1	 -30.0	 30.0;
	7873	 1388	 0.001271	 0.00811	 0.01217	 508.806206	 508.806206	 508.806206	 0.0	 0.0	 1	 -30.0	 30.0;
	7913	 978	 0.00048	 0.01459	 0.41923	 1160.865069	 1160.865069	 1160.865069	 0.0	 0.0	 1	 -30.0	 30.0;
	3225	 7913	 0.00047	 0.01351	 0.41011	 1740.237276	 1740.237276	 1740.237276	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 1337	 0.021729	 0.088281	 0.08487	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1337	 2610	 0.00038	 0.001771	 0.00301	 504.745725	 504.745725	 504.745725	 0.0	 0.0	 1	 -30.0	 30.0;
	1337	 1142	 0.022901	 0.101401	 0.13759	 487.958515	 487.958515	 487.958515	 0.0	 0.0	 1	 -30.0	 30.0;
	4	 4953	 0.002909	 0.01432	 0.09089	 495.301371	 495.301371	 495.301371	 0.0	 0.0	 1	 -30.0	 30.0;
	4	 2425	 0.015729	 0.08824	 0.17591	 422.498114	 422.498114	 422.498114	 0.0	 0.0	 1	 -30.0	 30.0;
	2634	 6309	 0.00038	 0.002169	 0.00301	 320.026213	 320.026213	 320.026213	 0.0	 0.0	 1	 -30.0	 30.0;
	1650	 2634	 0.000479	 0.00212	 0.00394	 314.030753	 314.030753	 314.030753	 0.0	 0.0	 1	 -30.0	 30.0;
	2634	 360	 0.00019	 0.00086	 0.0016	 263.996829	 263.996829	 263.996829	 0.0	 0.0	 1	 -30.0	 30.0;
	692	 126	 0.00089	 0.004901	 0.0083	 366.341459	 366.341459	 366.341459	 0.0	 0.0	 1	 -30.0	 30.0;
	3526	 978	 0.00109	 0.03151	 0.95693	 1823.396257	 1823.396257	 1823.396257	 0.0	 0.0	 1	 -30.0	 30.0;
	510	 5635	 0.003409	 0.020271	 0.04168	 540.98293	 540.98293	 540.98293	 0.0	 0.0	 1	 -30.0	 30.0;
	510	 5635	 0.002909	 0.02388	 0.03564	 480.818378	 480.818378	 480.818378	 0.0	 0.0	 1	 -30.0	 30.0;
	5635	 3487	 0.00545	 0.042969	 0.06675	 496.063093	 496.063093	 496.063093	 0.0	 0.0	 1	 -30.0	 30.0;
	5635	 3487	 0.005341	 0.0438	 0.06536	 488.474839	 488.474839	 488.474839	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 6796	 0.001521	 0.00863	 0.05172	 339.479256	 339.479256	 339.479256	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 4974	 0.00057	 0.005979	 0.00852	 395.763183	 395.763183	 395.763183	 0.0	 0.0	 1	 -30.0	 30.0;
	8276	 5217	 0.00085	 0.01449	 0.40056	 1752.928948	 1752.928948	 1752.928948	 0.0	 0.0	 1	 -30.0	 30.0;
	797	 5217	 0.0006	 0.00777	 0.28066	 1547.739575	 1547.739575	 1547.739575	 0.0	 0.0	 1	 -30.0	 30.0;
	4482	 5217	 0.0003	 0.00492	 0.14491	 1131.764329	 1131.764329	 1131.764329	 0.0	 0.0	 1	 -30.0	 30.0;
	2434	 2389	 0.003349	 0.02686	 0.04071	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	2026	 2389	 0.00213	 0.016849	 0.02652	 609.034097	 609.034097	 609.034097	 0.0	 0.0	 1	 -30.0	 30.0;
	3468	 8382	 0.00077	 0.0106	 0.20935	 1434.038441	 1434.038441	 1434.038441	 0.0	 0.0	 1	 -30.0	 30.0;
	7466	 8382	 0.00155	 0.0148	 0.41791	 1322.398725	 1322.398725	 1322.398725	 0.0	 0.0	 1	 -30.0	 30.0;
	1470	 510	 0.016651	 0.10632	 0.21934	 508.04639	 508.04639	 508.04639	 0.0	 0.0	 1	 -30.0	 30.0;
	1470	 510	 0.014841	 0.12049	 0.19541	 459.328235	 459.328235	 459.328235	 0.0	 0.0	 1	 -30.0	 30.0;
	4240	 510	 9.9e-05	 0.001229	 0.00352	 541.186792	 541.186792	 541.186792	 0.0	 0.0	 1	 -30.0	 30.0;
	7025	 510	 9.9e-05	 0.00114	 0.00345	 535.104834	 535.104834	 535.104834	 0.0	 0.0	 1	 -30.0	 30.0;
	7492	 2002	 0.00048	 0.00781	 0.22253	 1824.77251	 1824.77251	 1824.77251	 0.0	 0.0	 1	 -30.0	 30.0;
	7492	 3036	 0.00076	 0.01058	 0.35945	 1979.683566	 1979.683566	 1979.683566	 0.0	 0.0	 1	 -30.0	 30.0;
	7787	 7492	 0.00073	 0.01181	 0.34268	 979.775589	 979.775589	 979.775589	 0.0	 0.0	 1	 -30.0	 30.0;
	6558	 751	 0.00059	 0.00929	 0.27667	 1736.951645	 1736.951645	 1736.951645	 0.0	 0.0	 1	 -30.0	 30.0;
	133	 751	 8e-05	 0.00092	 0.02228	 1142.336005	 1142.336005	 1142.336005	 0.0	 0.0	 1	 -30.0	 30.0;
	268	 942	 0.00019	 0.000849	 0.00154	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2165	 3597	 0.003479	 0.01538	 0.02885	 281.334276	 281.334276	 281.334276	 0.0	 0.0	 1	 -30.0	 30.0;
	2165	 3597	 0.003539	 0.01505	 0.02939	 289.180882	 289.180882	 289.180882	 0.0	 0.0	 1	 -30.0	 30.0;
	2165	 1336	 0.01387	 0.084099	 0.10971	 393.940996	 393.940996	 393.940996	 0.0	 0.0	 1	 -30.0	 30.0;
	996	 2165	 0.00375	 0.021341	 0.02891	 394.898577	 394.898577	 394.898577	 0.0	 0.0	 1	 -30.0	 30.0;
	7590	 4881	 0.00023	 0.00345	 0.11002	 1805.248279	 1805.248279	 1805.248279	 0.0	 0.0	 1	 -30.0	 30.0;
	4881	 1536	 0.00054	 0.00662	 0.25038	 1644.855906	 1644.855906	 1644.855906	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 7774	 7e-05	 0.00099	 0.02898	 1231.413992	 1231.413992	 1231.413992	 0.0	 0.0	 1	 -30.0	 30.0;
	5001	 366	 0.00012	 0.002	 0.05674	 1769.708571	 1769.708571	 1769.708571	 0.0	 0.0	 1	 -30.0	 30.0;
	208	 3536	 0.00075	 0.00888	 0.35551	 1201.978239	 1201.978239	 1201.978239	 0.0	 0.0	 1	 -30.0	 30.0;
	2818	 3536	 0.00054	 0.00705	 0.1472	 1381.530212	 1381.530212	 1381.530212	 0.0	 0.0	 1	 -30.0	 30.0;
	6226	 3767	 0.00574	 0.0287	 0.04472	 503.921892	 503.921892	 503.921892	 0.0	 0.0	 1	 -30.0	 30.0;
	6226	 5979	 0.001331	 0.009479	 0.04018	 274.702461	 274.702461	 274.702461	 0.0	 0.0	 1	 -30.0	 30.0;
	5979	 6226	 0.00539	 0.024159	 0.04882	 416.512562	 416.512562	 416.512562	 0.0	 0.0	 1	 -30.0	 30.0;
	940	 6226	 0.000539	 0.0028	 0.00795	 451.052184	 451.052184	 451.052184	 0.0	 0.0	 1	 -30.0	 30.0;
	7002	 7269	 0.000969	 0.00724	 0.09464	 393.675022	 393.675022	 393.675022	 0.0	 0.0	 1	 -30.0	 30.0;
	6029	 7269	 0.000349	 0.00339	 0.00514	 468.072216	 468.072216	 468.072216	 0.0	 0.0	 1	 -30.0	 30.0;
	2433	 7590	 0.00021	 0.00349	 0.10119	 1962.953965	 1962.953965	 1962.953965	 0.0	 0.0	 1	 -30.0	 30.0;
	1209	 42	 0.00318	 0.020669	 0.06141	 403.173866	 403.173866	 403.173866	 0.0	 0.0	 1	 -30.0	 30.0;
	1209	 42	 0.003599	 0.02026	 0.06959	 425.485174	 425.485174	 425.485174	 0.0	 0.0	 1	 -30.0	 30.0;
	42	 1122	 0.0053	 0.035521	 0.10017	 382.366566	 382.366566	 382.366566	 0.0	 0.0	 1	 -30.0	 30.0;
	42	 2539	 0.00486	 0.024331	 0.04752	 426.884013	 426.884013	 426.884013	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 4160	 0.000659	 0.00645	 0.00977	 445.273924	 445.273924	 445.273924	 0.0	 0.0	 1	 -30.0	 30.0;
	4953	 3248	 0.00239	 0.01531	 0.06831	 258.454439	 258.454439	 258.454439	 0.0	 0.0	 1	 -30.0	 30.0;
	5322	 1432	 0.00119	 0.01215	 0.40139	 1708.676262	 1708.676262	 1708.676262	 0.0	 0.0	 1	 -30.0	 30.0;
	1432	 5626	 0.00012	 0.0015	 0.06087	 1926.234141	 1926.234141	 1926.234141	 0.0	 0.0	 1	 -30.0	 30.0;
	1432	 5862	 0.00047	 0.00738	 0.22496	 1434.108208	 1434.108208	 1434.108208	 0.0	 0.0	 1	 -30.0	 30.0;
	7126	 5406	 0.00068	 0.00189	 0.25283	 530.246432	 530.246432	 530.246432	 0.0	 0.0	 1	 -30.0	 30.0;
	2176	 8126	 0.003669	 0.022099	 0.02912	 491.890582	 491.890582	 491.890582	 0.0	 0.0	 1	 -30.0	 30.0;
	7873	 8126	 0.004771	 0.0218	 0.03728	 458.497543	 458.497543	 458.497543	 0.0	 0.0	 1	 -30.0	 30.0;
	2638	 6932	 0.001469	 0.006591	 0.04685	 549.721195	 549.721195	 549.721195	 0.0	 0.0	 1	 -30.0	 30.0;
	3039	 461	 8.1e-05	 0.00045	 0.00069	 269.765943	 269.765943	 269.765943	 0.0	 0.0	 1	 -30.0	 30.0;
	461	 425	 0.001021	 0.00782	 0.01187	 487.827814	 487.827814	 487.827814	 0.0	 0.0	 1	 -30.0	 30.0;
	3677	 461	 0.0015	 0.009591	 0.01754	 528.12893	 528.12893	 528.12893	 0.0	 0.0	 1	 -30.0	 30.0;
	5585	 755	 0.00019	 0.001581	 0.2574	 528.278683	 528.278683	 528.278683	 0.0	 0.0	 1	 -30.0	 30.0;
	5585	 7002	 3.9e-05	 0.000479	 0.06686	 612.120612	 612.120612	 612.120612	 0.0	 0.0	 1	 -30.0	 30.0;
	6628	 4964	 0.00027	 0.00281	 0.07485	 1291.068074	 1291.068074	 1291.068074	 0.0	 0.0	 1	 -30.0	 30.0;
	4969	 6628	 0.00096	 0.01609	 0.43218	 1802.841976	 1802.841976	 1802.841976	 0.0	 0.0	 1	 -30.0	 30.0;
	6628	 7787	 0.00027	 0.00339	 0.12538	 973.727579	 973.727579	 973.727579	 0.0	 0.0	 1	 -30.0	 30.0;
	6628	 7787	 0.00023	 0.00398	 0.10693	 1578.45417	 1578.45417	 1578.45417	 0.0	 0.0	 1	 -30.0	 30.0;
	1202	 6838	 0.000901	 0.00937	 0.02245	 588.378075	 588.378075	 588.378075	 0.0	 0.0	 1	 -30.0	 30.0;
	6840	 6838	 0.001901	 0.01549	 0.02295	 449.769185	 449.769185	 449.769185	 0.0	 0.0	 1	 -30.0	 30.0;
	7542	 6838	 0.003591	 0.02205	 0.03251	 489.677818	 489.677818	 489.677818	 0.0	 0.0	 1	 -30.0	 30.0;
	6838	 5177	 0.0013	 0.009901	 0.01574	 523.09372	 523.09372	 523.09372	 0.0	 0.0	 1	 -30.0	 30.0;
	2419	 2790	 0.00022	 0.00299	 0.1103	 2101.265739	 2101.265739	 2101.265739	 0.0	 0.0	 1	 -30.0	 30.0;
	2790	 7832	 0.00047	 0.00564	 0.22482	 1858.568043	 1858.568043	 1858.568043	 0.0	 0.0	 1	 -30.0	 30.0;
	5	 2790	 0.00046	 0.0075	 0.22009	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	5717	 642	 0.00214	 0.020979	 0.03146	 443.912047	 443.912047	 443.912047	 0.0	 0.0	 1	 -30.0	 30.0;
	2610	 642	 0.004651	 0.03332	 0.06904	 466.599072	 466.599072	 466.599072	 0.0	 0.0	 1	 -30.0	 30.0;
	642	 4052	 0.00468	 0.021281	 0.03738	 500.408219	 500.408219	 500.408219	 0.0	 0.0	 1	 -30.0	 30.0;
	642	 4378	 0.00581	 0.028331	 0.04634	 268.228021	 268.228021	 268.228021	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 6526	 7e-05	 0.00086	 0.08756	 1615.085139	 1615.085139	 1615.085139	 0.0	 0.0	 1	 -30.0	 30.0;
	2387	 4049	 0.0002	 0.00279	 0.09258	 1375.547362	 1375.547362	 1375.547362	 0.0	 0.0	 1	 -30.0	 30.0;
	2387	 4049	 0.00017	 0.00333	 0.07644	 1350.84326	 1350.84326	 1350.84326	 0.0	 0.0	 1	 -30.0	 30.0;
	5166	 5322	 1e-05	 0.00036	 0.17353	 1453.798958	 1453.798958	 1453.798958	 0.0	 0.0	 1	 -30.0	 30.0;
	4712	 6013	 0.000401	 0.004081	 0.00588	 462.014646	 462.014646	 462.014646	 0.0	 0.0	 1	 -30.0	 30.0;
	6013	 6500	 0.001581	 0.015719	 0.0234	 479.019816	 479.019816	 479.019816	 0.0	 0.0	 1	 -30.0	 30.0;
	7011	 7113	 0.00012	 0.000229	 0.02988	 285.161554	 285.161554	 285.161554	 0.0	 0.0	 1	 -30.0	 30.0;
	7011	 7113	 0.00012	 0.00024	 0.02927	 264.761217	 264.761217	 264.761217	 0.0	 0.0	 1	 -30.0	 30.0;
	7113	 7725	 0.00132	 0.005729	 0.01972	 456.818251	 456.818251	 456.818251	 0.0	 0.0	 1	 -30.0	 30.0;
	7960	 7113	 0.00438	 0.024901	 0.06154	 426.128008	 426.128008	 426.128008	 0.0	 0.0	 1	 -30.0	 30.0;
	5111	 93	 0.005521	 0.023711	 0.04303	 436.605391	 436.605391	 436.605391	 0.0	 0.0	 1	 -30.0	 30.0;
	208	 6672	 0.0008	 0.01014	 0.28011	 1310.498185	 1310.498185	 1310.498185	 0.0	 0.0	 1	 -30.0	 30.0;
	208	 6672	 0.00068	 0.01229	 0.2374	 1366.621135	 1366.621135	 1366.621135	 0.0	 0.0	 1	 -30.0	 30.0;
	2434	 1109	 0.001901	 0.01163	 0.02246	 505.100483	 505.100483	 505.100483	 0.0	 0.0	 1	 -30.0	 30.0;
	1650	 493	 0.00101	 0.00824	 0.01219	 226.64924	 226.64924	 226.64924	 0.0	 0.0	 1	 -30.0	 30.0;
	7972	 5232	 0.00787	 0.068219	 0.10596	 470.691943	 470.691943	 470.691943	 0.0	 0.0	 1	 -30.0	 30.0;
	7972	 5232	 0.007711	 0.069539	 0.10375	 487.643005	 487.643005	 487.643005	 0.0	 0.0	 1	 -30.0	 30.0;
	1470	 5444	 0.00032	 0.002091	 0.00392	 290.000523	 290.000523	 290.000523	 0.0	 0.0	 1	 -30.0	 30.0;
	2541	 4194	 0.00012	 0.00182	 0.05714	 1984.892397	 1984.892397	 1984.892397	 0.0	 0.0	 1	 -30.0	 30.0;
	4194	 5	 0.00058	 0.00736	 0.28135	 1415.73974	 1415.73974	 1415.73974	 0.0	 0.0	 1	 -30.0	 30.0;
	2541	 1609	 0.00074	 0.01143	 0.35868	 1484.260155	 1484.260155	 1484.260155	 0.0	 0.0	 1	 -30.0	 30.0;
	6558	 5063	 0.00084	 0.01378	 0.39904	 1852.010603	 1852.010603	 1852.010603	 0.0	 0.0	 1	 -30.0	 30.0;
	6558	 6513	 0.00037	 0.00356	 0.10346	 1602.758757	 1602.758757	 1602.758757	 0.0	 0.0	 1	 -30.0	 30.0;
	6448	 6558	 0.00012	 0.00206	 0.05975	 1487.34899	 1487.34899	 1487.34899	 0.0	 0.0	 1	 -30.0	 30.0;
	6789	 5716	 0.00036	 0.00151	 0.00296	 365.184969	 365.184969	 365.184969	 0.0	 0.0	 1	 -30.0	 30.0;
	8276	 1378	 0.0012	 0.01835	 0.574	 987.093885	 987.093885	 987.093885	 0.0	 0.0	 1	 -30.0	 30.0;
	1378	 5615	 0.00088	 0.01503	 0.42549	 1651.957002	 1651.957002	 1651.957002	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 1378	 0.00057	 0.00939	 0.27394	 1774.028202	 1774.028202	 1774.028202	 0.0	 0.0	 1	 -30.0	 30.0;
	3043	 3361	 0.00157	 0.02006	 0.12828	 1757.734315	 1757.734315	 1757.734315	 0.0	 0.0	 1	 -30.0	 30.0;
	3043	 5065	 0.00027	 0.00349	 0.13073	 1816.62096	 1816.62096	 1816.62096	 0.0	 0.0	 1	 -30.0	 30.0;
	6953	 3043	 0.00136	 0.02325	 0.65809	 2020.262295	 2020.262295	 2020.262295	 0.0	 0.0	 1	 -30.0	 30.0;
	3043	 3547	 0.00038	 0.00478	 0.18647	 1756.202732	 1756.202732	 1756.202732	 0.0	 0.0	 1	 -30.0	 30.0;
	3043	 5846	 0.00077	 0.01171	 0.36606	 1620.715863	 1620.715863	 1620.715863	 0.0	 0.0	 1	 -30.0	 30.0;
	8276	 4969	 0.00129	 0.02076	 0.59396	 1215.665736	 1215.665736	 1215.665736	 0.0	 0.0	 1	 -30.0	 30.0;
	8276	 1609	 0.00037	 0.0046	 0.17928	 1302.493408	 1302.493408	 1302.493408	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 8276	 0.00021	 0.00375	 0.10385	 1499.073797	 1499.073797	 1499.073797	 0.0	 0.0	 1	 -30.0	 30.0;
	8276	 1968	 0.00055	 0.00885	 0.26285	 1385.928166	 1385.928166	 1385.928166	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 1650	 0.001659	 0.01138	 0.01701	 464.918256	 464.918256	 464.918256	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 4461	 0.001169	 0.010021	 0.25763	 467.643534	 467.643534	 467.643534	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 1295	 0.002229	 0.00975	 0.02234	 535.867317	 535.867317	 535.867317	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 6462	 0.00049	 0.004521	 0.00728	 446.617892	 446.617892	 446.617892	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 6029	 0.0002	 0.001969	 0.00303	 596.400345	 596.400345	 596.400345	 0.0	 0.0	 1	 -30.0	 30.0;
	2714	 4399	 0.0001	 0.00158	 0.04849	 1691.698527	 1691.698527	 1691.698527	 0.0	 0.0	 1	 -30.0	 30.0;
	2714	 4399	 0.00011	 0.00151	 0.05064	 1552.152667	 1552.152667	 1552.152667	 0.0	 0.0	 1	 -30.0	 30.0;
	1085	 4497	 3e-05	 0.00043	 0.01664	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1085	 621	 0.00037	 0.00589	 0.1739	 1848.088512	 1848.088512	 1848.088512	 0.0	 0.0	 1	 -30.0	 30.0;
	1862	 1085	 0.00087	 0.01218	 0.41371	 1462.290788	 1462.290788	 1462.290788	 0.0	 0.0	 1	 -30.0	 30.0;
	6147	 5232	 0.00362	 0.024409	 0.04396	 474.807296	 474.807296	 474.807296	 0.0	 0.0	 1	 -30.0	 30.0;
	6147	 3487	 0.00488	 0.03119	 0.06434	 450.004675	 450.004675	 450.004675	 0.0	 0.0	 1	 -30.0	 30.0;
	1209	 2104	 0.00055	 0.00264	 0.29916	 542.107412	 542.107412	 542.107412	 0.0	 0.0	 1	 -30.0	 30.0;
	5543	 2104	 0.00031	 0.001341	 0.17141	 542.903809	 542.903809	 542.903809	 0.0	 0.0	 1	 -30.0	 30.0;
	5406	 2104	 0.00012	 0.000669	 0.06739	 513.999553	 513.999553	 513.999553	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 1540	 3.1e-05	 0.000469	 0.0416	 271.351497	 271.351497	 271.351497	 0.0	 0.0	 1	 -30.0	 30.0;
	1818	 1540	 3.1e-05	 0.000461	 0.04257	 277.353434	 277.353434	 277.353434	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 4098	 0.00607	 0.03457	 0.04895	 388.45805	 388.45805	 388.45805	 0.0	 0.0	 1	 -30.0	 30.0;
	4098	 4111	 0.0087	 0.047719	 0.07619	 462.434945	 462.434945	 462.434945	 0.0	 0.0	 1	 -30.0	 30.0;
	3468	 7466	 0.00129	 0.02159	 0.59185	 1399.395831	 1399.395831	 1399.395831	 0.0	 0.0	 1	 -30.0	 30.0;
	3468	 1112	 0.00091	 0.00903	 0.24255	 1673.123391	 1673.123391	 1673.123391	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 3468	 0.0004	 0.00518	 0.19271	 1758.423429	 1758.423429	 1758.423429	 0.0	 0.0	 1	 -30.0	 30.0;
	3468	 6110	 0.00032	 0.00557	 0.15545	 1985.019426	 1985.019426	 1985.019426	 0.0	 0.0	 1	 -30.0	 30.0;
	6796	 4291	 3.1e-05	 0.0002	 0.0003	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6796	 5617	 3.1e-05	 0.000211	 0.00029	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4945	 2328	 0.00199	 0.011591	 0.01528	 471.913974	 471.913974	 471.913974	 0.0	 0.0	 1	 -30.0	 30.0;
	3364	 4945	 0.000211	 0.000919	 0.00194	 353.292361	 353.292361	 353.292361	 0.0	 0.0	 1	 -30.0	 30.0;
	3620	 2226	 0.00109	 0.01525	 0.5183	 1578.295549	 1578.295549	 1578.295549	 0.0	 0.0	 1	 -30.0	 30.0;
	678	 2328	 0.005789	 0.02826	 0.04643	 449.369462	 449.369462	 449.369462	 0.0	 0.0	 1	 -30.0	 30.0;
	5922	 2613	 0.00041	 0.0064	 0.18864	 1848.050338	 1848.050338	 1848.050338	 0.0	 0.0	 1	 -30.0	 30.0;
	5922	 2433	 0.00051	 0.00603	 0.17487	 1679.291847	 1679.291847	 1679.291847	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 3900	 0.00245	 0.02726	 0.08107	 526.953006	 526.953006	 526.953006	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 6500	 0.000271	 0.00337	 0.07711	 438.970195	 438.970195	 438.970195	 0.0	 0.0	 1	 -30.0	 30.0;
	3306	 6253	 0.000151	 0.00064	 0.00118	 311.236124	 311.236124	 311.236124	 0.0	 0.0	 1	 -30.0	 30.0;
	2351	 3306	 0.003341	 0.022091	 0.0325	 304.802075	 304.802075	 304.802075	 0.0	 0.0	 1	 -30.0	 30.0;
	3306	 1122	 0.022	 0.125771	 0.21415	 461.42897	 461.42897	 461.42897	 0.0	 0.0	 1	 -30.0	 30.0;
	3306	 2106	 0.0153	 0.08863	 0.14731	 471.675055	 471.675055	 471.675055	 0.0	 0.0	 1	 -30.0	 30.0;
	3306	 2106	 0.015599	 0.08682	 0.1502	 492.257534	 492.257534	 492.257534	 0.0	 0.0	 1	 -30.0	 30.0;
	639	 1857	 0.001169	 0.00844	 0.0315	 220.406098	 220.406098	 220.406098	 0.0	 0.0	 1	 -30.0	 30.0;
	5716	 639	 0.00081	 0.004271	 0.00851	 375.271012	 375.271012	 375.271012	 0.0	 0.0	 1	 -30.0	 30.0;
	639	 5364	 0.000349	 0.0015	 0.19046	 353.49127	 353.49127	 353.49127	 0.0	 0.0	 1	 -30.0	 30.0;
	3361	 5846	 0.00058	 0.00717	 0.27971	 1943.820034	 1943.820034	 1943.820034	 0.0	 0.0	 1	 -30.0	 30.0;
	3361	 5101	 0.0007	 0.01203	 0.34039	 1813.844101	 1813.844101	 1813.844101	 0.0	 0.0	 1	 -30.0	 30.0;
	5101	 3361	 0.00061	 0.00957	 0.3038	 1918.847395	 1918.847395	 1918.847395	 0.0	 0.0	 1	 -30.0	 30.0;
	7857	 2346	 2e-05	 0.00075	 0.02192	 1522.90252	 1522.90252	 1522.90252	 0.0	 0.0	 1	 -30.0	 30.0;
	6589	 7857	 0.00041	 0.01221	 0.36552	 1974.999304	 1974.999304	 1974.999304	 0.0	 0.0	 1	 -30.0	 30.0;
	942	 1918	 0.00157	 0.007969	 0.04235	 267.079533	 267.079533	 267.079533	 0.0	 0.0	 1	 -30.0	 30.0;
	3864	 1918	 0.00151	 0.00625	 0.01108	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4037	 4040	 2e-05	 0.00023	 0.22918	 1222.544368	 1222.544368	 1222.544368	 0.0	 0.0	 1	 -30.0	 30.0;
	4037	 4040	 2e-05	 0.00022	 0.23342	 1186.407691	 1186.407691	 1186.407691	 0.0	 0.0	 1	 -30.0	 30.0;
	3526	 4037	 0.00026	 0.00395	 0.11957	 1637.191408	 1637.191408	 1637.191408	 0.0	 0.0	 1	 -30.0	 30.0;
	3526	 4037	 0.00025	 0.00403	 0.11708	 1727.97737	 1727.97737	 1727.97737	 0.0	 0.0	 1	 -30.0	 30.0;
	5392	 216	 0.00111	 0.005099	 0.03261	 459.778637	 459.778637	 459.778637	 0.0	 0.0	 1	 -30.0	 30.0;
	216	 4287	 0.000729	 0.0023	 0.35453	 479.571579	 479.571579	 479.571579	 0.0	 0.0	 1	 -30.0	 30.0;
	4287	 7291	 0.003831	 0.016271	 0.11288	 441.822744	 441.822744	 441.822744	 0.0	 0.0	 1	 -30.0	 30.0;
	6782	 8288	 0.001849	 0.014719	 0.02237	 518.119478	 518.119478	 518.119478	 0.0	 0.0	 1	 -30.0	 30.0;
	6710	 6782	 0.00157	 0.010169	 0.01889	 465.878123	 465.878123	 465.878123	 0.0	 0.0	 1	 -30.0	 30.0;
	478	 5717	 0.00149	 0.01513	 0.02181	 259.533195	 259.533195	 259.533195	 0.0	 0.0	 1	 -30.0	 30.0;
	3781	 478	 0.003229	 0.02918	 0.04742	 281.021814	 281.021814	 281.021814	 0.0	 0.0	 1	 -30.0	 30.0;
	7466	 1915	 1e-05	 0.00021	 0.00579	 1731.058308	 1731.058308	 1731.058308	 0.0	 0.0	 1	 -30.0	 30.0;
	2092	 2002	 0.00054	 0.00765	 0.2522	 1558.704184	 1558.704184	 1558.704184	 0.0	 0.0	 1	 -30.0	 30.0;
	3678	 5065	 1e-05	 0.0002	 0.00591	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5065	 5846	 0.00053	 0.00746	 0.25789	 1657.430421	 1657.430421	 1657.430421	 0.0	 0.0	 1	 -30.0	 30.0;
	2944	 3544	 0.010469	 0.057979	 0.10448	 324.763441	 324.763441	 324.763441	 0.0	 0.0	 1	 -30.0	 30.0;
	2944	 2402	 0.00014	 0.000781	 0.00146	 373.343274	 373.343274	 373.343274	 0.0	 0.0	 1	 -30.0	 30.0;
	2944	 808	 0.00181	 0.013039	 0.01802	 360.199295	 360.199295	 360.199295	 0.0	 0.0	 1	 -30.0	 30.0;
	3767	 7960	 0.01107	 0.04905	 0.08621	 422.292728	 422.292728	 422.292728	 0.0	 0.0	 1	 -30.0	 30.0;
	2371	 1468	 0.00038	 0.00468	 0.18993	 1619.730569	 1619.730569	 1619.730569	 0.0	 0.0	 1	 -30.0	 30.0;
	2371	 1468	 0.00034	 0.0053	 0.16921	 1440.179912	 1440.179912	 1440.179912	 0.0	 0.0	 1	 -30.0	 30.0;
	3036	 2371	 0.00012	 0.00185	 0.0555	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3036	 2371	 0.00013	 0.00181	 0.0629	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4808	 7033	 0.000211	 0.0018	 0.00255	 564.274683	 564.274683	 564.274683	 0.0	 0.0	 1	 -30.0	 30.0;
	1346	 3075	 0.00037	 0.00225	 0.00456	 572.895204	 572.895204	 572.895204	 0.0	 0.0	 1	 -30.0	 30.0;
	2506	 7161	 0.00025	 0.00317	 0.12312	 1920.888409	 1920.888409	 1920.888409	 0.0	 0.0	 1	 -30.0	 30.0;
	1536	 2506	 0.00029	 0.00484	 0.13605	 1887.044829	 1887.044829	 1887.044829	 0.0	 0.0	 1	 -30.0	 30.0;
	88	 6570	 0.00057	 0.00858	 0.26443	 1992.073792	 1992.073792	 1992.073792	 0.0	 0.0	 1	 -30.0	 30.0;
	88	 8181	 0.0005	 0.00665	 0.23101	 1918.801981	 1918.801981	 1918.801981	 0.0	 0.0	 1	 -30.0	 30.0;
	7077	 2750	 0.00239	 0.012289	 0.02363	 465.290924	 465.290924	 465.290924	 0.0	 0.0	 1	 -30.0	 30.0;
	5954	 2750	 0.0008	 0.005211	 0.00788	 389.685035	 389.685035	 389.685035	 0.0	 0.0	 1	 -30.0	 30.0;
	5615	 3661	 0.00067	 0.01081	 0.31881	 1605.321049	 1605.321049	 1605.321049	 0.0	 0.0	 1	 -30.0	 30.0;
	2430	 5615	 0.00105	 0.01455	 0.50319	 1748.111075	 1748.111075	 1748.111075	 0.0	 0.0	 1	 -30.0	 30.0;
	439	 6570	 0.0002	 0.00261	 0.09805	 819.0199	 819.0199	 819.0199	 0.0	 0.0	 1	 -30.0	 30.0;
	5429	 7898	 1e-05	 0.0002	 0.00579	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1112	 7898	 0.00036	 0.00601	 0.1702	 2142.250564	 2142.250564	 2142.250564	 0.0	 0.0	 1	 -30.0	 30.0;
	8181	 7898	 0.0001	 0.00151	 0.04834	 2084.53153	 2084.53153	 2084.53153	 0.0	 0.0	 1	 -30.0	 30.0;
	4083	 727	 2e-05	 0.00021	 0.00486	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7466	 727	 0.00046	 0.00568	 0.12832	 1253.351767	 1253.351767	 1253.351767	 0.0	 0.0	 1	 -30.0	 30.0;
	597	 727	 0.00041	 0.00531	 0.11517	 1289.047463	 1289.047463	 1289.047463	 0.0	 0.0	 1	 -30.0	 30.0;
	2419	 2092	 0.0003	 0.00482	 0.1443	 1880.287302	 1880.287302	 1880.287302	 0.0	 0.0	 1	 -30.0	 30.0;
	1862	 199	 1e-05	 0.0002	 0.00567	 1756.195492	 1756.195492	 1756.195492	 0.0	 0.0	 1	 -30.0	 30.0;
	6953	 1030	 1e-05	 0.00022	 0.00563	 1870.018389	 1870.018389	 1870.018389	 0.0	 0.0	 1	 -30.0	 30.0;
	2457	 7774	 2e-05	 0.00025	 0.20796	 791.282908	 791.282908	 791.282908	 0.0	 0.0	 1	 -30.0	 30.0;
	2457	 7774	 2e-05	 0.00026	 0.20371	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	797	 2887	 0.00032	 0.00528	 0.15421	 1722.220934	 1722.220934	 1722.220934	 0.0	 0.0	 1	 -30.0	 30.0;
	2652	 2887	 0.0006	 0.0084	 0.28595	 1887.963647	 1887.963647	 1887.963647	 0.0	 0.0	 1	 -30.0	 30.0;
	5865	 7375	 0.00105	 0.01735	 0.50942	 1544.950869	 1544.950869	 1544.950869	 0.0	 0.0	 1	 -30.0	 30.0;
	3788	 5865	 0.00135	 0.01758	 0.65653	 1483.587496	 1483.587496	 1483.587496	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 7375	 0.0004	 0.0068	 0.19289	 1823.634518	 1823.634518	 1823.634518	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 7375	 0.00039	 0.0063	 0.18869	 1714.246434	 1714.246434	 1714.246434	 0.0	 0.0	 1	 -30.0	 30.0;
	7375	 8181	 0.00067	 0.00834	 0.32443	 1427.773232	 1427.773232	 1427.773232	 0.0	 0.0	 1	 -30.0	 30.0;
	6960	 621	 0.00084	 0.01114	 0.40082	 1893.691782	 1893.691782	 1893.691782	 0.0	 0.0	 1	 -30.0	 30.0;
	1862	 621	 0.00081	 0.011	 0.38053	 1628.589004	 1628.589004	 1628.589004	 0.0	 0.0	 1	 -30.0	 30.0;
	2842	 2874	 0.00059	 0.00726	 0.27888	 1454.734889	 1454.734889	 1454.734889	 0.0	 0.0	 1	 -30.0	 30.0;
	3788	 2874	 0.001	 0.01178	 0.47118	 1754.484884	 1754.484884	 1754.484884	 0.0	 0.0	 1	 -30.0	 30.0;
	4040	 2130	 0.00031	 0.00197	 3.72164	 1218.738775	 1218.738775	 1218.738775	 0.0	 0.0	 1	 -30.0	 30.0;
	4040	 2130	 0.00035	 0.00193	 4.21786	 1254.247549	 1254.247549	 1254.247549	 0.0	 0.0	 1	 -30.0	 30.0;
	5812	 2130	 2e-05	 0.0004	 0.29919	 965.606963	 965.606963	 965.606963	 0.0	 0.0	 1	 -30.0	 30.0;
	5812	 2130	 2e-05	 0.00041	 0.29283	 1021.07305	 1021.07305	 1021.07305	 0.0	 0.0	 1	 -30.0	 30.0;
	4432	 4153	 3.1e-05	 0.000271	 0.03207	 469.163928	 469.163928	 469.163928	 0.0	 0.0	 1	 -30.0	 30.0;
	4153	 4432	 3.1e-05	 0.000281	 0.03091	 470.743004	 470.743004	 470.743004	 0.0	 0.0	 1	 -30.0	 30.0;
	4153	 2935	 0.000229	 0.000271	 0.02886	 525.800707	 525.800707	 525.800707	 0.0	 0.0	 1	 -30.0	 30.0;
	2034	 5309	 0.000289	 0.001229	 0.00234	 216.486225	 216.486225	 216.486225	 0.0	 0.0	 1	 -30.0	 30.0;
	2034	 7960	 0.002479	 0.01106	 0.01984	 221.937924	 221.937924	 221.937924	 0.0	 0.0	 1	 -30.0	 30.0;
	7727	 678	 0.00738	 0.04069	 0.05763	 436.740283	 436.740283	 436.740283	 0.0	 0.0	 1	 -30.0	 30.0;
	6294	 5948	 0.00058	 0.00872	 0.27698	 1775.292564	 1775.292564	 1775.292564	 0.0	 0.0	 1	 -30.0	 30.0;
	5948	 5322	 0.00116	 0.01483	 0.55559	 1930.270097	 1930.270097	 1930.270097	 0.0	 0.0	 1	 -30.0	 30.0;
	5948	 5322	 0.00118	 0.01452	 0.56607	 1969.15533	 1969.15533	 1969.15533	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 2842	 0.00139	 0.02265	 0.66615	 1965.249036	 1965.249036	 1965.249036	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 2842	 0.00149	 0.02349	 0.71021	 1956.487353	 1956.487353	 1956.487353	 0.0	 0.0	 1	 -30.0	 30.0;
	3682	 2842	 0.00086	 0.01488	 0.41499	 1882.413221	 1882.413221	 1882.413221	 0.0	 0.0	 1	 -30.0	 30.0;
	3682	 2842	 0.00095	 0.01554	 0.4511	 1955.024221	 1955.024221	 1955.024221	 0.0	 0.0	 1	 -30.0	 30.0;
	308	 688	 0.019651	 0.09944	 0.19161	 465.171274	 465.171274	 465.171274	 0.0	 0.0	 1	 -30.0	 30.0;
	6414	 1154	 0.0002	 0.001831	 0.28314	 489.93236	 489.93236	 489.93236	 0.0	 0.0	 1	 -30.0	 30.0;
	8038	 2555	 7e-05	 0.00062	 0.00093	 461.105076	 461.105076	 461.105076	 0.0	 0.0	 1	 -30.0	 30.0;
	2555	 10	 0.004039	 0.023081	 0.03444	 474.606863	 474.606863	 474.606863	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 2555	 0.0132	 0.064331	 0.10877	 331.639128	 331.639128	 331.639128	 0.0	 0.0	 1	 -30.0	 30.0;
	2555	 8185	 0.001401	 0.008729	 0.01075	 315.65708	 315.65708	 315.65708	 0.0	 0.0	 1	 -30.0	 30.0;
	5846	 8285	 0.00021	 0.00247	 0.09805	 1139.828342	 1139.828342	 1139.828342	 0.0	 0.0	 1	 -30.0	 30.0;
	5846	 5101	 0.00138	 0.01791	 0.65297	 1811.363423	 1811.363423	 1811.363423	 0.0	 0.0	 1	 -30.0	 30.0;
	7466	 597	 0.00056	 0.00795	 0.26896	 1760.421661	 1760.421661	 1760.421661	 0.0	 0.0	 1	 -30.0	 30.0;
	7466	 4841	 0.00081	 0.00788	 0.21886	 1163.531353	 1163.531353	 1163.531353	 0.0	 0.0	 1	 -30.0	 30.0;
	6914	 6294	 3e-05	 0.00042	 0.00901	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1597	 6294	 3e-05	 0.00042	 0.00883	 859.617058	 859.617058	 859.617058	 0.0	 0.0	 1	 -30.0	 30.0;
	7770	 6294	 3e-05	 0.00035	 0.00749	 846.033554	 846.033554	 846.033554	 0.0	 0.0	 1	 -30.0	 30.0;
	6149	 6294	 3e-05	 0.00036	 0.00733	 779.859548	 779.859548	 779.859548	 0.0	 0.0	 1	 -30.0	 30.0;
	7161	 6294	 0.00035	 0.00423	 0.16401	 977.892538	 977.892538	 977.892538	 0.0	 0.0	 1	 -30.0	 30.0;
	2818	 4647	 0.00076	 0.00904	 0.35756	 1335.030503	 1335.030503	 1335.030503	 0.0	 0.0	 1	 -30.0	 30.0;
	4647	 4253	 0.00029	 0.00361	 0.1378	 1397.584522	 1397.584522	 1397.584522	 0.0	 0.0	 1	 -30.0	 30.0;
	6443	 5510	 0.010349	 0.056729	 0.08363	 478.505397	 478.505397	 478.505397	 0.0	 0.0	 1	 -30.0	 30.0;
	6443	 1857	 0.001581	 0.012771	 0.04044	 549.094747	 549.094747	 549.094747	 0.0	 0.0	 1	 -30.0	 30.0;
	6443	 942	 0.001081	 0.01136	 0.02755	 325.966419	 325.966419	 325.966419	 0.0	 0.0	 1	 -30.0	 30.0;
	6443	 3864	 0.001669	 0.00914	 0.03423	 456.348796	 456.348796	 456.348796	 0.0	 0.0	 1	 -30.0	 30.0;
	6443	 5153	 0.01757	 0.07575	 0.14199	 524.256688	 524.256688	 524.256688	 0.0	 0.0	 1	 -30.0	 30.0;
	741	 6513	 0.00037	 0.00558	 0.17602	 2297.799396	 2297.799396	 2297.799396	 0.0	 0.0	 1	 -30.0	 30.0;
	741	 7832	 0.00041	 0.0072	 0.20119	 1426.54507	 1426.54507	 1426.54507	 0.0	 0.0	 1	 -30.0	 30.0;
	7064	 4161	 0.002479	 0.017961	 0.02974	 431.212755	 431.212755	 431.212755	 0.0	 0.0	 1	 -30.0	 30.0;
	1099	 7064	 0.00155	 0.0127	 0.01877	 453.350304	 453.350304	 453.350304	 0.0	 0.0	 1	 -30.0	 30.0;
	126	 7107	 0.001961	 0.010419	 0.0157	 472.921092	 472.921092	 472.921092	 0.0	 0.0	 1	 -30.0	 30.0;
	1947	 1857	 0.00138	 0.007521	 0.01219	 307.314726	 307.314726	 307.314726	 0.0	 0.0	 1	 -30.0	 30.0;
	8087	 1947	 0.00281	 0.02543	 0.08305	 327.707442	 327.707442	 327.707442	 0.0	 0.0	 1	 -30.0	 30.0;
	1947	 7831	 0.000211	 0.000901	 0.11428	 500.756881	 500.756881	 500.756881	 0.0	 0.0	 1	 -30.0	 30.0;
	6840	 3473	 0.000789	 0.00519	 0.00984	 336.265852	 336.265852	 336.265852	 0.0	 0.0	 1	 -30.0	 30.0;
	6840	 91	 0.00056	 0.004281	 0.00692	 317.794396	 317.794396	 317.794396	 0.0	 0.0	 1	 -30.0	 30.0;
	6840	 7542	 0.00163	 0.012031	 0.02414	 602.762376	 602.762376	 602.762376	 0.0	 0.0	 1	 -30.0	 30.0;
	3781	 6840	 0.000211	 0.00161	 0.00317	 513.413115	 513.413115	 513.413115	 0.0	 0.0	 1	 -30.0	 30.0;
	6840	 5177	 0.00018	 0.00144	 0.00212	 479.810879	 479.810879	 479.810879	 0.0	 0.0	 1	 -30.0	 30.0;
	6637	 1650	 9.1e-05	 0.00081	 0.003	 268.28213	 268.28213	 268.28213	 0.0	 0.0	 1	 -30.0	 30.0;
	7690	 1650	 9.1e-05	 0.00099	 0.00259	 375.445153	 375.445153	 375.445153	 0.0	 0.0	 1	 -30.0	 30.0;
	3030	 4630	 0.001219	 0.01461	 0.03999	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3030	 2003	 0.00769	 0.035169	 0.23743	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	6913	 7476	 5e-05	 0.000219	 0.02513	 453.579697	 453.579697	 453.579697	 0.0	 0.0	 1	 -30.0	 30.0;
	7476	 5364	 0.000281	 0.00112	 0.15427	 444.791894	 444.791894	 444.791894	 0.0	 0.0	 1	 -30.0	 30.0;
	5216	 3900	 0.003591	 0.01825	 0.03656	 448.06017	 448.06017	 448.06017	 0.0	 0.0	 1	 -30.0	 30.0;
	5216	 3900	 0.00125	 0.01386	 0.0417	 472.581195	 472.581195	 472.581195	 0.0	 0.0	 1	 -30.0	 30.0;
	308	 3900	 0.000961	 0.00513	 0.00989	 530.872499	 530.872499	 530.872499	 0.0	 0.0	 1	 -30.0	 30.0;
	1468	 3989	 0.00022	 0.00295	 0.06316	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5144	 7637	 0.00326	 0.02562	 0.03836	 421.708576	 421.708576	 421.708576	 0.0	 0.0	 1	 -30.0	 30.0;
	5144	 6889	 0.00164	 0.013219	 0.01969	 585.57773	 585.57773	 585.57773	 0.0	 0.0	 1	 -30.0	 30.0;
	3797	 753	 8.1e-05	 0.00019	 0.02282	 346.293976	 346.293976	 346.293976	 0.0	 0.0	 1	 -30.0	 30.0;
	3797	 753	 3.9e-05	 0.00032	 0.02349	 396.518045	 396.518045	 396.518045	 0.0	 0.0	 1	 -30.0	 30.0;
	3797	 753	 0.00011	 0.0002	 0.02538	 327.707823	 327.707823	 327.707823	 0.0	 0.0	 1	 -30.0	 30.0;
	3797	 753	 9.1e-05	 0.000151	 0.02223	 350.43524	 350.43524	 350.43524	 0.0	 0.0	 1	 -30.0	 30.0;
	3797	 753	 0.00011	 0.00019	 0.02586	 341.962567	 341.962567	 341.962567	 0.0	 0.0	 1	 -30.0	 30.0;
	3797	 3473	 8.1e-05	 0.001	 0.0514	 453.897493	 453.897493	 453.897493	 0.0	 0.0	 1	 -30.0	 30.0;
	3797	 91	 0.000281	 0.00213	 0.06809	 428.661617	 428.661617	 428.661617	 0.0	 0.0	 1	 -30.0	 30.0;
	3781	 3797	 0.00025	 0.000831	 0.15806	 462.311103	 462.311103	 462.311103	 0.0	 0.0	 1	 -30.0	 30.0;
	7501	 3797	 0.00013	 0.000469	 0.08448	 432.021726	 432.021726	 432.021726	 0.0	 0.0	 1	 -30.0	 30.0;
	2818	 208	 0.00088	 0.01144	 0.41827	 1285.869774	 1285.869774	 1285.869774	 0.0	 0.0	 1	 -30.0	 30.0;
	3942	 208	 0.00076	 0.01445	 0.32748	 1025.275524	 1025.275524	 1025.275524	 0.0	 0.0	 1	 -30.0	 30.0;
	1990	 6960	 0.00048	 0.0076	 0.23009	 1808.416096	 1808.416096	 1808.416096	 0.0	 0.0	 1	 -30.0	 30.0;
	6960	 2146	 0.00017	 0.00273	 0.07982	 1879.373749	 1879.373749	 1879.373749	 0.0	 0.0	 1	 -30.0	 30.0;
	8110	 6863	 0.00014	 0.000849	 0.00114	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2176	 8110	 0.0022	 0.01289	 0.01745	 422.760659	 422.760659	 422.760659	 0.0	 0.0	 1	 -30.0	 30.0;
	3233	 3464	 0.00582	 0.03749	 0.07206	 487.167072	 487.167072	 487.167072	 0.0	 0.0	 1	 -30.0	 30.0;
	3233	 3464	 0.00593	 0.03669	 0.07342	 490.907089	 490.907089	 490.907089	 0.0	 0.0	 1	 -30.0	 30.0;
	3464	 5272	 0.000281	 0.003419	 0.00945	 645.076966	 645.076966	 645.076966	 0.0	 0.0	 1	 -30.0	 30.0;
	3464	 3723	 0.00645	 0.03995	 0.0789	 481.605249	 481.605249	 481.605249	 0.0	 0.0	 1	 -30.0	 30.0;
	3464	 3723	 0.00657	 0.039081	 0.08037	 459.212395	 459.212395	 459.212395	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 8050	 8e-05	 0.00125	 0.03535	 1749.534717	 1749.534717	 1749.534717	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 7929	 8e-05	 0.00127	 0.03449	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 4192	 7e-05	 0.0013	 0.03387	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 1354	 7e-05	 0.0012	 0.03314	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8057	 5063	 5e-05	 0.0006	 0.62678	 1521.50718	 1521.50718	 1521.50718	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 5	 0.00034	 0.00466	 0.16464	 2128.679565	 2128.679565	 2128.679565	 0.0	 0.0	 1	 -30.0	 30.0;
	5979	 5716	 0.000591	 0.00588	 0.0155	 510.378804	 510.378804	 510.378804	 0.0	 0.0	 1	 -30.0	 30.0;
	5716	 5979	 0.00139	 0.00818	 0.01071	 505.532214	 505.532214	 505.532214	 0.0	 0.0	 1	 -30.0	 30.0;
	3864	 5979	 0.00169	 0.013969	 0.05121	 574.066174	 574.066174	 574.066174	 0.0	 0.0	 1	 -30.0	 30.0;
	3607	 305	 0.000229	 0.00163	 0.00283	 450.055735	 450.055735	 450.055735	 0.0	 0.0	 1	 -30.0	 30.0;
	3963	 7725	 0.00275	 0.02836	 0.08626	 611.099776	 611.099776	 611.099776	 0.0	 0.0	 1	 -30.0	 30.0;
	46	 7725	 0.004909	 0.02468	 0.08814	 440.698262	 440.698262	 440.698262	 0.0	 0.0	 1	 -30.0	 30.0;
	7725	 7960	 0.001419	 0.02212	 0.06483	 420.155793	 420.155793	 420.155793	 0.0	 0.0	 1	 -30.0	 30.0;
	4150	 7611	 0.0016	 0.02118	 0.74277	 1924.34385	 1924.34385	 1924.34385	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 5730	 0.00116	 0.01869	 0.52636	 1576.787002	 1576.787002	 1576.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	7396	 7611	 0.00169	 0.02149	 0.77557	 1422.145799	 1422.145799	 1422.145799	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 4841	 0.00171	 0.02913	 0.79419	 862.275445	 862.275445	 862.275445	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 939	 0.00138	 0.0212	 0.67168	 1657.645646	 1657.645646	 1657.645646	 0.0	 0.0	 1	 -30.0	 30.0;
	2252	 1949	 0.00511	 0.02775	 0.03978	 496.254761	 496.254761	 496.254761	 0.0	 0.0	 1	 -30.0	 30.0;
	3620	 3788	 0.0008	 0.01262	 0.38137	 2014.602611	 2014.602611	 2014.602611	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 337	 0.0005	 0.00851	 0.23944	 1746.697306	 1746.697306	 1746.697306	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 2458	 0.00032	 0.00558	 0.15828	 1847.89764	 1847.89764	 1847.89764	 0.0	 0.0	 1	 -30.0	 30.0;
	2442	 5001	 0.00039	 0.00601	 0.18896	 1901.391822	 1901.391822	 1901.391822	 0.0	 0.0	 1	 -30.0	 30.0;
	2442	 4108	 0.00036	 0.00575	 0.17204	 1528.918279	 1528.918279	 1528.918279	 0.0	 0.0	 1	 -30.0	 30.0;
	2442	 7358	 0.00117	 0.01616	 0.55541	 1816.830919	 1816.830919	 1816.830919	 0.0	 0.0	 1	 -30.0	 30.0;
	797	 5590	 0.0003	 0.00471	 0.1467	 1453.871358	 1453.871358	 1453.871358	 0.0	 0.0	 1	 -30.0	 30.0;
	3233	 675	 0.00011	 0.00081	 0.00141	 481.117122	 481.117122	 481.117122	 0.0	 0.0	 1	 -30.0	 30.0;
	3233	 1470	 0.01087	 0.06457	 0.13248	 467.209897	 467.209897	 467.209897	 0.0	 0.0	 1	 -30.0	 30.0;
	3233	 1470	 0.00968	 0.073169	 0.11803	 465.22081	 465.22081	 465.22081	 0.0	 0.0	 1	 -30.0	 30.0;
	1857	 6913	 0.00105	 0.005781	 0.00853	 324.313419	 324.313419	 324.313419	 0.0	 0.0	 1	 -30.0	 30.0;
	1712	 2610	 0.002961	 0.029021	 0.04381	 448.665661	 448.665661	 448.665661	 0.0	 0.0	 1	 -30.0	 30.0;
	3776	 337	 4e-05	 0.00033	 0.02775	 1354.35728	 1354.35728	 1354.35728	 0.0	 0.0	 1	 -30.0	 30.0;
	2119	 337	 4e-05	 0.00035	 0.02842	 1423.539165	 1423.539165	 1423.539165	 0.0	 0.0	 1	 -30.0	 30.0;
	4659	 337	 4e-05	 0.0003	 0.03169	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3040	 337	 4e-05	 0.00028	 0.03202	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4461	 77	 0.000211	 0.00045	 0.08014	 347.595646	 347.595646	 347.595646	 0.0	 0.0	 1	 -30.0	 30.0;
	8346	 3385	 0.00024	 0.001099	 0.00194	 396.650651	 396.650651	 396.650651	 0.0	 0.0	 1	 -30.0	 30.0;
	3763	 8346	 0.00544	 0.029831	 0.04403	 394.631461	 394.631461	 394.631461	 0.0	 0.0	 1	 -30.0	 30.0;
	2387	 6513	 0.00076	 0.0101	 0.33997	 1945.502999	 1945.502999	 1945.502999	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 5298	 0.01106	 0.06313	 0.09	 395.58104	 395.58104	 395.58104	 0.0	 0.0	 1	 -30.0	 30.0;
	5168	 5216	 0.001909	 0.011401	 0.01939	 478.056519	 478.056519	 478.056519	 0.0	 0.0	 1	 -30.0	 30.0;
	5954	 5168	 0.00113	 0.005479	 0.01098	 419.321672	 419.321672	 419.321672	 0.0	 0.0	 1	 -30.0	 30.0;
	1209	 3370	 0.000151	 0.000961	 0.00189	 497.846412	 497.846412	 497.846412	 0.0	 0.0	 1	 -30.0	 30.0;
	1209	 2106	 0.00156	 0.01125	 0.05791	 404.232045	 404.232045	 404.232045	 0.0	 0.0	 1	 -30.0	 30.0;
	1209	 2106	 0.00344	 0.021599	 0.03313	 372.8742	 372.8742	 372.8742	 0.0	 0.0	 1	 -30.0	 30.0;
	1191	 4630	 0.00106	 0.01276	 0.03487	 294.756423	 294.756423	 294.756423	 0.0	 0.0	 1	 -30.0	 30.0;
	3959	 5320	 0.001349	 0.008831	 0.01483	 316.916073	 316.916073	 316.916073	 0.0	 0.0	 1	 -30.0	 30.0;
	3385	 8038	 0.001901	 0.010031	 0.01539	 396.538241	 396.538241	 396.538241	 0.0	 0.0	 1	 -30.0	 30.0;
	2026	 6710	 0.001719	 0.012159	 0.02086	 491.312527	 491.312527	 491.312527	 0.0	 0.0	 1	 -30.0	 30.0;
	2908	 94	 4e-05	 0.00061	 0.01938	 2019.34611	 2019.34611	 2019.34611	 0.0	 0.0	 1	 -30.0	 30.0;
	5507	 171	 0.00126	 0.00595	 0.20657	 346.438775	 346.438775	 346.438775	 0.0	 0.0	 1	 -30.0	 30.0;
	2652	 5	 0.00018	 0.00224	 0.08234	 1955.226282	 1955.226282	 1955.226282	 0.0	 0.0	 1	 -30.0	 30.0;
	5543	 1122	 0.000521	 0.002039	 0.28085	 539.497592	 539.497592	 539.497592	 0.0	 0.0	 1	 -30.0	 30.0;
	7163	 8038	 0.002169	 0.016479	 0.02942	 437.484857	 437.484857	 437.484857	 0.0	 0.0	 1	 -30.0	 30.0;
	4150	 5001	 0.00073	 0.01168	 0.3472	 1878.019874	 1878.019874	 1878.019874	 0.0	 0.0	 1	 -30.0	 30.0;
	7396	 5001	 0.00131	 0.0162	 0.62165	 1484.817633	 1484.817633	 1484.817633	 0.0	 0.0	 1	 -30.0	 30.0;
	6796	 2169	 0.00112	 0.007591	 0.01356	 441.605926	 441.605926	 441.605926	 0.0	 0.0	 1	 -30.0	 30.0;
	6462	 6796	 0.00162	 0.01332	 0.02451	 467.182081	 467.182081	 467.182081	 0.0	 0.0	 1	 -30.0	 30.0;
	5641	 7396	 0.00027	 0.00344	 0.07754	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7264	 7396	 0.0003	 0.00313	 0.08579	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1666	 1609	 0.00014	 0.00243	 0.06637	 1760.448647	 1760.448647	 1760.448647	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 4396	 0.00019	 0.001781	 0.34769	 427.639257	 427.639257	 427.639257	 0.0	 0.0	 1	 -30.0	 30.0;
	2901	 4396	 0.000151	 0.001969	 0.288	 463.643258	 463.643258	 463.643258	 0.0	 0.0	 1	 -30.0	 30.0;
	2351	 1122	 0.025461	 0.14561	 0.24792	 443.990544	 443.990544	 443.990544	 0.0	 0.0	 1	 -30.0	 30.0;
	6889	 7637	 0.004599	 0.028581	 0.0626	 489.087951	 489.087951	 489.087951	 0.0	 0.0	 1	 -30.0	 30.0;
	3727	 1540	 0.00987	 0.05706	 0.09142	 467.498734	 467.498734	 467.498734	 0.0	 0.0	 1	 -30.0	 30.0;
	94	 2335	 9e-05	 0.00103	 0.80805	 1236.235814	 1236.235814	 1236.235814	 0.0	 0.0	 1	 -30.0	 30.0;
	94	 2335	 0.0001	 0.00101	 0.82359	 1114.313363	 1114.313363	 1114.313363	 0.0	 0.0	 1	 -30.0	 30.0;
	2458	 2335	 0.00023	 0.00381	 0.1096	 2103.410745	 2103.410745	 2103.410745	 0.0	 0.0	 1	 -30.0	 30.0;
	112	 1857	 0.002219	 0.01374	 0.06016	 565.846138	 565.846138	 565.846138	 0.0	 0.0	 1	 -30.0	 30.0;
	7820	 2818	 0.00092	 0.00895	 0.25474	 1983.252215	 1983.252215	 1983.252215	 0.0	 0.0	 1	 -30.0	 30.0;
	112	 5716	 0.001151	 0.009479	 0.02574	 561.421753	 561.421753	 561.421753	 0.0	 0.0	 1	 -30.0	 30.0;
	901	 2003	 0.00188	 0.012151	 0.05653	 616.561001	 616.561001	 616.561001	 0.0	 0.0	 1	 -30.0	 30.0;
	3479	 1468	 0.00036	 0.00471	 0.16969	 1654.036849	 1654.036849	 1654.036849	 0.0	 0.0	 1	 -30.0	 30.0;
	3479	 857	 0.00085	 0.01337	 0.40092	 1992.467383	 1992.467383	 1992.467383	 0.0	 0.0	 1	 -30.0	 30.0;
	2760	 3479	 9e-05	 0.00105	 0.04004	 1493.870231	 1493.870231	 1493.870231	 0.0	 0.0	 1	 -30.0	 30.0;
	3036	 3479	 0.00037	 0.00634	 0.17607	 1542.878262	 1542.878262	 1542.878262	 0.0	 0.0	 1	 -30.0	 30.0;
	3723	 2711	 0.00056	 0.004979	 0.00728	 388.777752	 388.777752	 388.777752	 0.0	 0.0	 1	 -30.0	 30.0;
	3487	 5232	 0.00488	 0.029039	 0.06032	 449.906744	 449.906744	 449.906744	 0.0	 0.0	 1	 -30.0	 30.0;
	3487	 5232	 0.004349	 0.032919	 0.05327	 449.35041	 449.35041	 449.35041	 0.0	 0.0	 1	 -30.0	 30.0;
	2387	 2613	 0.00046	 0.00571	 0.21214	 1948.521409	 1948.521409	 1948.521409	 0.0	 0.0	 1	 -30.0	 30.0;
	8288	 5123	 0.010841	 0.04989	 0.08723	 438.216475	 438.216475	 438.216475	 0.0	 0.0	 1	 -30.0	 30.0;
	2940	 901	 0.00282	 0.01436	 0.02737	 406.612091	 406.612091	 406.612091	 0.0	 0.0	 1	 -30.0	 30.0;
	2940	 901	 0.00282	 0.014789	 0.02703	 479.732001	 479.732001	 479.732001	 0.0	 0.0	 1	 -30.0	 30.0;
	233	 2402	 0.00012	 0.000841	 0.00116	 432.717907	 432.717907	 432.717907	 0.0	 0.0	 1	 -30.0	 30.0;
	233	 808	 0.00175	 0.01189	 0.01617	 386.521167	 386.521167	 386.521167	 0.0	 0.0	 1	 -30.0	 30.0;
	233	 1540	 0.00851	 0.04389	 0.12431	 495.991836	 495.991836	 495.991836	 0.0	 0.0	 1	 -30.0	 30.0;
	6057	 6127	 0.00063	 0.00374	 0.00487	 274.109165	 274.109165	 274.109165	 0.0	 0.0	 1	 -30.0	 30.0;
	3526	 143	 0.00037	 0.00484	 0.17841	 994.112709	 994.112709	 994.112709	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 4841	 0.00161	 0.02178	 0.76796	 1800.488327	 1800.488327	 1800.488327	 0.0	 0.0	 1	 -30.0	 30.0;
	7797	 1295	 0.00745	 0.03588	 0.07352	 431.586185	 431.586185	 431.586185	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 4540	 0.00051	 0.00829	 0.24332	 1692.344201	 1692.344201	 1692.344201	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 7358	 0.00124	 0.01751	 0.53074	 1403.637139	 1403.637139	 1403.637139	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 7161	 0.0008	 0.01242	 0.3789	 1018.225766	 1018.225766	 1018.225766	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 4969	 0.00118	 0.01502	 0.54028	 1855.058631	 1855.058631	 1855.058631	 0.0	 0.0	 1	 -30.0	 30.0;
	3526	 6589	 0.00131	 0.01723	 0.6325	 1173.762092	 1173.762092	 1173.762092	 0.0	 0.0	 1	 -30.0	 30.0;
	1154	 5406	 0.000271	 0.001081	 0.14365	 466.864284	 466.864284	 466.864284	 0.0	 0.0	 1	 -30.0	 30.0;
	5626	 2714	 0.00014	 0.00178	 0.06384	 1219.046145	 1219.046145	 1219.046145	 0.0	 0.0	 1	 -30.0	 30.0;
	1154	 1122	 0.00051	 0.00201	 0.27689	 532.129205	 532.129205	 532.129205	 0.0	 0.0	 1	 -30.0	 30.0;
	7161	 2649	 9e-05	 0.00091	 0.02515	 1755.439244	 1755.439244	 1755.439244	 0.0	 0.0	 1	 -30.0	 30.0;
	1772	 425	 9.1e-05	 0.000591	 0.00085	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2935	 4561	 2.1e-05	 0.00025	 0.029	 425.901663	 425.901663	 425.901663	 0.0	 0.0	 1	 -30.0	 30.0;
	1862	 5812	 0.00035	 0.00556	 0.16404	 1739.344785	 1739.344785	 1739.344785	 0.0	 0.0	 1	 -30.0	 30.0;
	1862	 5812	 0.0004	 0.00545	 0.18038	 1787.770986	 1787.770986	 1787.770986	 0.0	 0.0	 1	 -30.0	 30.0;
	5730	 4114	 0.0004	 0.00517	 0.10593	 1027.236899	 1027.236899	 1027.236899	 0.0	 0.0	 1	 -30.0	 30.0;
	4114	 4841	 0.00037	 0.00456	 0.09974	 1241.482819	 1241.482819	 1241.482819	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 5730	 0.00133	 0.01413	 0.37462	 1418.105236	 1418.105236	 1418.105236	 0.0	 0.0	 1	 -30.0	 30.0;
	6409	 3959	 0.01187	 0.05524	 0.09269	 368.591185	 368.591185	 368.591185	 0.0	 0.0	 1	 -30.0	 30.0;
	3959	 2901	 0.00063	 0.0065	 0.40514	 450.05726	 450.05726	 450.05726	 0.0	 0.0	 1	 -30.0	 30.0;
	1540	 3959	 0.011841	 0.052289	 0.09246	 402.781383	 402.781383	 402.781383	 0.0	 0.0	 1	 -30.0	 30.0;
	597	 1234	 0.00055	 0.00517	 0.15398	 928.207898	 928.207898	 928.207898	 0.0	 0.0	 1	 -30.0	 30.0;
	1234	 4864	 0.00097	 0.01163	 0.27287	 1389.334903	 1389.334903	 1389.334903	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 5022	 0.000969	 0.01039	 0.49162	 503.399471	 503.399471	 503.399471	 0.0	 0.0	 1	 -30.0	 30.0;
	8087	 6050	 0.00326	 0.015581	 0.02676	 463.025574	 463.025574	 463.025574	 0.0	 0.0	 1	 -30.0	 30.0;
	2458	 4253	 0.00099	 0.01348	 0.47807	 2230.052342	 2230.052342	 2230.052342	 0.0	 0.0	 1	 -30.0	 30.0;
	5322	 4253	 0.00045	 0.00368	 0.14519	 1988.96192	 1988.96192	 1988.96192	 0.0	 0.0	 1	 -30.0	 30.0;
	942	 3864	 0.002021	 0.011331	 0.0661	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8270	 942	 0.00076	 0.0073	 0.02056	 562.52642	 562.52642	 562.52642	 0.0	 0.0	 1	 -30.0	 30.0;
	1990	 3682	 0.00101	 0.01505	 0.4751	 2209.172262	 2209.172262	 2209.172262	 0.0	 0.0	 1	 -30.0	 30.0;
	5773	 627	 0.0	 0.000347	 1e-05	 302.47988	 302.47988	 302.47988	 0.0	 0.0	 1	 -30.0	 30.0;
	2430	 3661	 0.00065	 0.00768	 0.28563	 2132.706306	 2132.706306	 2132.706306	 0.0	 0.0	 1	 -30.0	 30.0;
	4540	 5590	 0.00025	 0.0035	 0.11792	 1423.639208	 1423.639208	 1423.639208	 0.0	 0.0	 1	 -30.0	 30.0;
	3473	 2332	 0.00013	 0.000331	 0.06511	 383.34663	 383.34663	 383.34663	 0.0	 0.0	 1	 -30.0	 30.0;
	91	 2332	 3.9e-05	 0.00036	 0.00049	 513.730911	 513.730911	 513.730911	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 2610	 0.011021	 0.061901	 0.08894	 462.30272	 462.30272	 462.30272	 0.0	 0.0	 1	 -30.0	 30.0;
	2610	 5298	 0.007901	 0.04495	 0.06366	 424.864442	 424.864442	 424.864442	 0.0	 0.0	 1	 -30.0	 30.0;
	940	 5716	 0.00369	 0.02186	 0.03835	 456.006231	 456.006231	 456.006231	 0.0	 0.0	 1	 -30.0	 30.0;
	5716	 5955	 0.000281	 0.001091	 0.15031	 466.111708	 466.111708	 466.111708	 0.0	 0.0	 1	 -30.0	 30.0;
	5716	 5364	 0.000461	 0.001841	 0.2514	 482.154725	 482.154725	 482.154725	 0.0	 0.0	 1	 -30.0	 30.0;
	1142	 3280	 0.006271	 0.02999	 0.04894	 405.312706	 405.312706	 405.312706	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 10	 0.011219	 0.05245	 0.09075	 397.361692	 397.361692	 397.361692	 0.0	 0.0	 1	 -30.0	 30.0;
	7714	 3963	 0.000281	 0.004091	 0.01608	 584.825154	 584.825154	 584.825154	 0.0	 0.0	 1	 -30.0	 30.0;
	2457	 3611	 0.00041	 0.00534	 0.1924	 1704.290155	 1704.290155	 1704.290155	 0.0	 0.0	 1	 -30.0	 30.0;
	3271	 7542	 0.002659	 0.01557	 0.02216	 226.858819	 226.858819	 226.858819	 0.0	 0.0	 1	 -30.0	 30.0;
	7960	 46	 0.00795	 0.0483	 0.0683	 319.866171	 319.866171	 319.866171	 0.0	 0.0	 1	 -30.0	 30.0;
	6029	 2907	 0.00037	 0.00361	 0.00554	 472.816684	 472.816684	 472.816684	 0.0	 0.0	 1	 -30.0	 30.0;
	1849	 4808	 0.001211	 0.0082	 0.0146	 602.763138	 602.763138	 602.763138	 0.0	 0.0	 1	 -30.0	 30.0;
	1470	 3504	 9.9e-05	 0.00101	 0.00339	 402.96505	 402.96505	 402.96505	 0.0	 0.0	 1	 -30.0	 30.0;
	1470	 3161	 9.9e-05	 0.00099	 0.00343	 343.952797	 343.952797	 343.952797	 0.0	 0.0	 1	 -30.0	 30.0;
	1470	 4722	 0.000169	 0.001539	 0.00227	 509.261943	 509.261943	 509.261943	 0.0	 0.0	 1	 -30.0	 30.0;
	1470	 3496	 0.000169	 0.00157	 0.00222	 486.790212	 486.790212	 486.790212	 0.0	 0.0	 1	 -30.0	 30.0;
	808	 1708	 0.00011	 0.000349	 0.00059	 399.803468	 399.803468	 399.803468	 0.0	 0.0	 1	 -30.0	 30.0;
	808	 1708	 0.00012	 0.000341	 0.0006	 416.429874	 416.429874	 416.429874	 0.0	 0.0	 1	 -30.0	 30.0;
	2430	 790	 0.00017	 0.00314	 0.08502	 801.880911	 801.880911	 801.880911	 0.0	 0.0	 1	 -30.0	 30.0;
	360	 3219	 0.00012	 0.00056	 0.001	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1540	 1423	 0.000219	 0.001469	 0.00214	 481.447112	 481.447112	 481.447112	 0.0	 0.0	 1	 -30.0	 30.0;
	1540	 1423	 0.0002	 0.001781	 0.00197	 445.55514	 445.55514	 445.55514	 0.0	 0.0	 1	 -30.0	 30.0;
	7787	 857	 0.00038	 0.00623	 0.17728	 1650.587331	 1650.587331	 1650.587331	 0.0	 0.0	 1	 -30.0	 30.0;
	3271	 6710	 0.003669	 0.01631	 0.03237	 439.333336	 439.333336	 439.333336	 0.0	 0.0	 1	 -30.0	 30.0;
	632	 4864	 0.00013	 0.00117	 0.0362	 1751.684989	 1751.684989	 1751.684989	 0.0	 0.0	 1	 -30.0	 30.0;
	7625	 4864	 0.00012	 0.0013	 0.03461	 1422.62627	 1422.62627	 1422.62627	 0.0	 0.0	 1	 -30.0	 30.0;
	6409	 2746	 0.00082	 0.004969	 0.00645	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6409	 2746	 0.0008	 0.004599	 0.00631	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1540	 6409	 0.00914	 0.060289	 0.14843	 508.320366	 508.320366	 508.320366	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 7291	 0.005219	 0.02681	 0.03834	 295.981502	 295.981502	 295.981502	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 7291	 0.005919	 0.026271	 0.04345	 303.921847	 303.921847	 303.921847	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 5298	 0.00381	 0.02086	 0.03074	 421.830132	 421.830132	 421.830132	 0.0	 0.0	 1	 -30.0	 30.0;
	1122	 6871	 0.004539	 0.01957	 0.03635	 419.817419	 419.817419	 419.817419	 0.0	 0.0	 1	 -30.0	 30.0;
	2539	 1122	 0.00112	 0.00632	 0.01093	 402.106923	 402.106923	 402.106923	 0.0	 0.0	 1	 -30.0	 30.0;
	6110	 4020	 0.00027	 0.00426	 0.12823	 1795.817886	 1795.817886	 1795.817886	 0.0	 0.0	 1	 -30.0	 30.0;
	8181	 4020	 0.0002	 0.00238	 0.0943	 987.831045	 987.831045	 987.831045	 0.0	 0.0	 1	 -30.0	 30.0;
	987	 4020	 8e-05	 0.00077	 0.07688	 1657.214539	 1657.214539	 1657.214539	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 1099	 0.00149	 0.012091	 0.01773	 593.245623	 593.245623	 593.245623	 0.0	 0.0	 1	 -30.0	 30.0;
	8337	 3864	 0.00064	 0.00356	 0.00563	 308.847314	 308.847314	 308.847314	 0.0	 0.0	 1	 -30.0	 30.0;
	2176	 1109	 0.005729	 0.033	 0.04566	 580.775723	 580.775723	 580.775723	 0.0	 0.0	 1	 -30.0	 30.0;
	8185	 6057	 0.0017	 0.007599	 0.01317	 320.741065	 320.741065	 320.741065	 0.0	 0.0	 1	 -30.0	 30.0;
	7358	 5862	 0.00221	 0.02589	 0.56042	 1568.408379	 1568.408379	 1568.408379	 0.0	 0.0	 1	 -30.0	 30.0;
	3370	 171	 0.000331	 0.000831	 0.07725	 377.56113	 377.56113	 377.56113	 0.0	 0.0	 1	 -30.0	 30.0;
	3781	 7501	 9.9e-05	 0.00045	 0.06456	 370.274288	 370.274288	 370.274288	 0.0	 0.0	 1	 -30.0	 30.0;
	7831	 3864	 0.00039	 0.00163	 0.19294	 485.314782	 485.314782	 485.314782	 0.0	 0.0	 1	 -30.0	 30.0;
	7396	 4841	 0.00383	 0.04628	 1.7907	 1461.963673	 1461.963673	 1461.963673	 0.0	 0.0	 1	 -30.0	 30.0;
	5954	 6500	 0.00106	 0.01101	 0.01571	 447.971004	 447.971004	 447.971004	 0.0	 0.0	 1	 -30.0	 30.0;
	8270	 6623	 0.00131	 0.012659	 0.03469	 513.017965	 513.017965	 513.017965	 0.0	 0.0	 1	 -30.0	 30.0;
	2430	 5101	 0.00052	 0.00735	 0.24795	 1439.370352	 1439.370352	 1439.370352	 0.0	 0.0	 1	 -30.0	 30.0;
	5101	 2430	 0.00058	 0.0074	 0.27818	 1104.306405	 1104.306405	 1104.306405	 0.0	 0.0	 1	 -30.0	 30.0;
	939	 2430	 0.0013	 0.01837	 0.61988	 1261.642852	 1261.642852	 1261.642852	 0.0	 0.0	 1	 -30.0	 30.0;
	4240	 7025	 3.9e-05	 0.000599	 0.00178	 246.662429	 246.662429	 246.662429	 0.0	 0.0	 1	 -30.0	 30.0;
	1142	 6871	 0.00031	 0.001461	 0.00251	 507.896637	 507.896637	 507.896637	 0.0	 0.0	 1	 -30.0	 30.0;
	2935	 6314	 0.001151	 0.008771	 0.01387	 489.786418	 489.786418	 489.786418	 0.0	 0.0	 1	 -30.0	 30.0;
	4432	 3756	 0.00095	 0.00457	 0.02953	 587.022295	 587.022295	 587.022295	 0.0	 0.0	 1	 -30.0	 30.0;
	4432	 1186	 0.001419	 0.00982	 0.06946	 450.821267	 450.821267	 450.821267	 0.0	 0.0	 1	 -30.0	 30.0;
	7831	 5955	 0.00037	 0.00144	 0.19778	 486.944157	 486.944157	 486.944157	 0.0	 0.0	 1	 -30.0	 30.0;
	6623	 1191	 0.00143	 0.01225	 0.05644	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	996	 6871	 0.00044	 0.00207	 0.00346	 392.576071	 392.576071	 392.576071	 0.0	 0.0	 1	 -30.0	 30.0;
	3942	 5862	 0.00076	 0.01509	 0.31584	 1640.322367	 1640.322367	 1640.322367	 0.0	 0.0	 1	 -30.0	 30.0;
	2106	 2638	 0.0007	 0.004039	 0.02175	 307.394747	 307.394747	 307.394747	 0.0	 0.0	 1	 -30.0	 30.0;
	4052	 7873	 0.004419	 0.01918	 0.03587	 405.440739	 405.440739	 405.440739	 0.0	 0.0	 1	 -30.0	 30.0;
	6050	 3677	 0.006099	 0.029539	 0.0505	 517.30098	 517.30098	 517.30098	 0.0	 0.0	 1	 -30.0	 30.0;
	6917	 6675	 0.00106	 0.00513	 0.01653	 282.58984	 282.58984	 282.58984	 0.0	 0.0	 1	 -30.0	 30.0;
	7971	 8379	 0.001021	 0.004711	 0.01581	 573.728562	 573.728562	 573.728562	 0.0	 0.0	 1	 -30.0	 30.0;
	1505	 4451	 0.000211	 0.00106	 0.0034	 533.632071	 533.632071	 533.632071	 0.0	 0.0	 1	 -30.0	 30.0;
	7364	 3625	 7e-05	 0.00087	 0.08388	 240.77938	 240.77938	 240.77938	 0.0	 0.0	 1	 -30.0	 30.0;
	7364	 4451	 3.9e-05	 0.000651	 0.06049	 237.717634	 237.717634	 237.717634	 0.0	 0.0	 1	 -30.0	 30.0;
	8379	 7371	 0.002039	 0.008271	 0.15139	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8379	 7371	 0.002	 0.00843	 0.1483	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3702	 6675	 0.001219	 0.00725	 0.01913	 609.403717	 609.403717	 609.403717	 0.0	 0.0	 1	 -30.0	 30.0;
	6675	 8379	 0.001151	 0.006789	 0.01791	 529.526245	 529.526245	 529.526245	 0.0	 0.0	 1	 -30.0	 30.0;
	3702	 6675	 0.0012	 0.006711	 0.01871	 591.093827	 591.093827	 591.093827	 0.0	 0.0	 1	 -30.0	 30.0;
	6675	 8379	 0.00112	 0.006289	 0.01752	 558.939204	 558.939204	 558.939204	 0.0	 0.0	 1	 -30.0	 30.0;
	6956	 6489	 0.002021	 0.01101	 0.00315	 293.388068	 293.388068	 293.388068	 0.0	 0.0	 1	 -30.0	 30.0;
	6489	 3702	 0.0015	 0.008521	 0.02341	 241.831463	 241.831463	 241.831463	 0.0	 0.0	 1	 -30.0	 30.0;
	6489	 3702	 0.001469	 0.00868	 0.02291	 240.468442	 240.468442	 240.468442	 0.0	 0.0	 1	 -30.0	 30.0;
	8379	 3625	 0.000719	 0.00443	 0.09403	 307.362739	 307.362739	 307.362739	 0.0	 0.0	 1	 -30.0	 30.0;
	8379	 4451	 0.0005	 0.00268	 0.00764	 602.736464	 602.736464	 602.736464	 0.0	 0.0	 1	 -30.0	 30.0;
	5638	 1767	 0.029149	 0.051802	 0.00605	 66.399882	 66.399882	 66.399882	 0.0	 0.0	 1	 -30.0	 30.0;
	5172	 1767	 0.035777	 0.063587	 0.00743	 63.377575	 63.377575	 63.377575	 0.0	 0.0	 1	 -30.0	 30.0;
	5638	 2810	 0.025967	 0.058702	 0.00539	 69.41495	 69.41495	 69.41495	 0.0	 0.0	 1	 -30.0	 30.0;
	2810	 72	 0.01943	 0.043942	 0.00403	 59.794741	 59.794741	 59.794741	 0.0	 0.0	 1	 -30.0	 30.0;
	2810	 1715	 0.05776	 0.115802	 0.01198	 85.304975	 85.304975	 85.304975	 0.0	 0.0	 1	 -30.0	 30.0;
	192	 2810	 0.027388	 0.054917	 0.00568	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	72	 1715	 0.028438	 0.104719	 0.00981	 72.038868	 72.038868	 72.038868	 0.0	 0.0	 1	 -30.0	 30.0;
	4730	 4567	 0.008091	 0.03755	 0.06156	 425.193289	 425.193289	 425.193289	 0.0	 0.0	 1	 -30.0	 30.0;
	7701	 4567	 0.00556	 0.02913	 0.04236	 447.559088	 447.559088	 447.559088	 0.0	 0.0	 1	 -30.0	 30.0;
	7005	 192	 0.033512	 0.069909	 0.00695	 60.853873	 60.853873	 60.853873	 0.0	 0.0	 1	 -30.0	 30.0;
	7701	 4376	 0.00587	 0.02949	 0.04463	 411.347414	 411.347414	 411.347414	 0.0	 0.0	 1	 -30.0	 30.0;
	2475	 5221	 0.013314	 0.040719	 0.00459	 75.109379	 75.109379	 75.109379	 0.0	 0.0	 1	 -30.0	 30.0;
	2475	 5221	 0.01357	 0.039876	 0.00467	 75.934545	 75.934545	 75.934545	 0.0	 0.0	 1	 -30.0	 30.0;
	2475	 5221	 0.014579	 0.041157	 0.00503	 59.8197	 59.8197	 59.8197	 0.0	 0.0	 1	 -30.0	 30.0;
	2475	 3888	 0.031298	 0.112364	 0.01079	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2475	 3888	 0.030653	 0.114521	 0.01057	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	224	 3540	 0.00537	 0.04394	 0.05792	 449.747084	 449.747084	 449.747084	 0.0	 0.0	 1	 -30.0	 30.0;
	224	 3540	 0.005461	 0.04726	 0.05897	 439.296374	 439.296374	 439.296374	 0.0	 0.0	 1	 -30.0	 30.0;
	4730	 224	 0.01312	 0.074419	 0.09989	 429.742278	 429.742278	 429.742278	 0.0	 0.0	 1	 -30.0	 30.0;
	5221	 6225	 0.0	 0.000413	 0.0	 63.643358	 63.643358	 63.643358	 0.0	 0.0	 1	 -30.0	 30.0;
	6225	 1823	 0.052702	 0.121281	 0.01394	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8277	 2966	 0.00103	 0.01397	 0.24541	 1165.369648	 1165.369648	 1165.369648	 0.0	 0.0	 1	 -30.0	 30.0;
	3888	 1715	 0.002959	 0.014851	 0.00261	 68.545582	 68.545582	 68.545582	 0.0	 0.0	 1	 -30.0	 30.0;
	3888	 1715	 0.002769	 0.016339	 0.00245	 88.317375	 88.317375	 88.317375	 0.0	 0.0	 1	 -30.0	 30.0;
	8277	 6962	 0.00167	 0.02105	 0.40047	 1229.742875	 1229.742875	 1229.742875	 0.0	 0.0	 1	 -30.0	 30.0;
	5172	 1715	 0.067826	 0.163702	 0.01407	 74.732329	 74.732329	 74.732329	 0.0	 0.0	 1	 -30.0	 30.0;
	3292	 2193	 0.009463	 0.038388	 0.00495	 77.058074	 77.058074	 77.058074	 0.0	 0.0	 1	 -30.0	 30.0;
	4773	 2193	 0.021289	 0.124008	 0.01113	 61.851465	 61.851465	 61.851465	 0.0	 0.0	 1	 -30.0	 30.0;
	5353	 5030	 0.035587	 0.104182	 0.0121	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1076	 5030	 0.040678	 0.119107	 0.01382	 59.339576	 59.339576	 59.339576	 0.0	 0.0	 1	 -30.0	 30.0;
	6646	 7563	 0.00156	 0.01963	 0.35333	 1310.433684	 1310.433684	 1310.433684	 0.0	 0.0	 1	 -30.0	 30.0;
	6646	 2964	 0.00255	 0.02314	 0.6124	 1435.99455	 1435.99455	 1435.99455	 0.0	 0.0	 1	 -30.0	 30.0;
	6377	 7676	 0.01305	 0.035686	 0.00541	 74.648497	 74.648497	 74.648497	 0.0	 0.0	 1	 -30.0	 30.0;
	6377	 7676	 0.013314	 0.034959	 0.00551	 75.451563	 75.451563	 75.451563	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 7676	 0.005612	 0.022636	 0.00193	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	55	 7676	 0.029826	 0.113909	 0.01017	 102.566021	 102.566021	 102.566021	 0.0	 0.0	 1	 -30.0	 30.0;
	6123	 7676	 0.04824	 0.109727	 0.0097	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6377	 6833	 0.010802	 0.04124	 0.00369	 72.659029	 72.659029	 72.659029	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 6377	 0.021851	 0.050934	 0.00913	 70.303561	 70.303561	 70.303561	 0.0	 0.0	 1	 -30.0	 30.0;
	3196	 6377	 0.070223	 0.192198	 0.02927	 59.801219	 59.801219	 59.801219	 0.0	 0.0	 1	 -30.0	 30.0;
	3196	 6377	 0.071603	 0.188281	 0.02985	 60.284202	 60.284202	 60.284202	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 6833	 0.008339	 0.021066	 0.0035	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1970	 1871	 0.024744	 0.092099	 0.00845	 59.618886	 59.618886	 59.618886	 0.0	 0.0	 1	 -30.0	 30.0;
	2680	 3527	 0.029579	 0.114661	 0.01006	 84.473902	 84.473902	 84.473902	 0.0	 0.0	 1	 -30.0	 30.0;
	1076	 3527	 0.009298	 0.035488	 0.00315	 58.160032	 58.160032	 58.160032	 0.0	 0.0	 1	 -30.0	 30.0;
	4285	 3527	 0.020149	 0.078107	 0.00686	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2778	 5353	 0.017826	 0.063777	 0.00608	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2964	 7563	 0.00158	 0.02095	 0.35686	 1324.034959	 1324.034959	 1324.034959	 0.0	 0.0	 1	 -30.0	 30.0;
	2862	 7563	 0.00076	 0.00957	 0.18383	 1272.650242	 1272.650242	 1272.650242	 0.0	 0.0	 1	 -30.0	 30.0;
	4329	 2680	 0.005678	 0.044198	 0.00864	 57.95636	 57.95636	 57.95636	 0.0	 0.0	 1	 -30.0	 30.0;
	4329	 2680	 0.006438	 0.043314	 0.00979	 58.280063	 58.280063	 58.280063	 0.0	 0.0	 1	 -30.0	 30.0;
	5896	 2680	 0.013612	 0.043157	 0.00468	 82.151204	 82.151204	 82.151204	 0.0	 0.0	 1	 -30.0	 30.0;
	822	 2680	 0.056248	 0.147934	 0.0234	 68.778404	 68.778404	 68.778404	 0.0	 0.0	 1	 -30.0	 30.0;
	822	 2680	 0.057339	 0.144851	 0.02385	 64.941409	 64.941409	 64.941409	 0.0	 0.0	 1	 -30.0	 30.0;
	7671	 2680	 0.000463	 0.003603	 0.00086	 242.998241	 242.998241	 242.998241	 0.0	 0.0	 1	 -30.0	 30.0;
	2680	 6857	 0.037107	 0.138157	 0.01267	 77.790264	 77.790264	 77.790264	 0.0	 0.0	 1	 -30.0	 30.0;
	4329	 7360	 0.004058	 0.015107	 0.00134	 67.85969	 67.85969	 67.85969	 0.0	 0.0	 1	 -30.0	 30.0;
	5961	 1168	 0.011793	 0.034521	 0.004	 73.13782	 73.13782	 73.13782	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 1168	 0.019636	 0.073132	 0.00672	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3922	 1586	 0.0	 0.000413	 0.0	 254.536471	 254.536471	 254.536471	 0.0	 0.0	 1	 -30.0	 30.0;
	3292	 829	 0.014339	 0.041983	 0.00486	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4727	 829	 0.029314	 0.118281	 0.01003	 87.839536	 87.839536	 87.839536	 0.0	 0.0	 1	 -30.0	 30.0;
	7700	 2473	 0.016636	 0.064488	 0.00564	 65.526132	 65.526132	 65.526132	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 2473	 0.034273	 0.127612	 0.01171	 85.059959	 85.059959	 85.059959	 0.0	 0.0	 1	 -30.0	 30.0;
	2473	 4773	 0.00886	 0.02495	 0.00297	 74.253919	 74.253919	 74.253919	 0.0	 0.0	 1	 -30.0	 30.0;
	7700	 5881	 0.026587	 0.084364	 0.00905	 74.576098	 74.576098	 74.576098	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 4148	 0.039298	 0.115058	 0.01339	 59.682331	 59.682331	 59.682331	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 5961	 0.036066	 0.134289	 0.01229	 63.693085	 63.693085	 63.693085	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 1546	 0.000529	 0.001554	 0.00022	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	55	 5896	 0.03981	 0.160628	 0.01352	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7360	 5896	 0.008438	 0.025744	 0.00286	 72.604729	 72.604729	 72.604729	 0.0	 0.0	 1	 -30.0	 30.0;
	5896	 3456	 0.024223	 0.093876	 0.00827	 74.669836	 74.669836	 74.669836	 0.0	 0.0	 1	 -30.0	 30.0;
	5881	 4277	 0.019868	 0.054017	 0.0047	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6123	 4277	 0.051248	 0.121347	 0.01037	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5079	 5049	 0.042793	 0.101314	 0.00864	 61.955683	 61.955683	 61.955683	 0.0	 0.0	 1	 -30.0	 30.0;
	5079	 5049	 0.030091	 0.099372	 0.0103	 62.69435	 62.69435	 62.69435	 0.0	 0.0	 1	 -30.0	 30.0;
	2074	 5049	 0.005488	 0.020959	 0.00189	 58.011993	 58.011993	 58.011993	 0.0	 0.0	 1	 -30.0	 30.0;
	1884	 4580	 0.009198	 0.025851	 0.00308	 98.108485	 98.108485	 98.108485	 0.0	 0.0	 1	 -30.0	 30.0;
	4580	 5557	 0.019752	 0.057843	 0.0067	 71.184552	 71.184552	 71.184552	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 4580	 0.032934	 0.096413	 0.01123	 98.492584	 98.492584	 98.492584	 0.0	 0.0	 1	 -30.0	 30.0;
	6097	 7718	 0.05586	 0.112686	 0.01123	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7954	 7718	 0.029744	 0.057636	 0.00604	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3252	 6097	 0.004868	 0.013686	 0.00165	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	376	 6097	 0.005413	 0.015207	 0.00187	 73.747121	 73.747121	 73.747121	 0.0	 0.0	 1	 -30.0	 30.0;
	5961	 6097	 0.043669	 0.084653	 0.0088	 99.710233	 99.710233	 99.710233	 0.0	 0.0	 1	 -30.0	 30.0;
	376	 3252	 0.004818	 0.01724	 0.00167	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	41	 3252	 0.017719	 0.054017	 0.00604	 83.145748	 83.145748	 83.145748	 0.0	 0.0	 1	 -30.0	 30.0;
	5961	 3549	 0.004364	 0.017719	 0.00231	 60.053856	 60.053856	 60.053856	 0.0	 0.0	 1	 -30.0	 30.0;
	3549	 1560	 0.007463	 0.041727	 0.00395	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1884	 4148	 0.016289	 0.065711	 0.00552	 80.806665	 80.806665	 80.806665	 0.0	 0.0	 1	 -30.0	 30.0;
	2074	 2778	 0.02014	 0.072066	 0.00686	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2740	 7661	 0.003091	 0.011826	 0.00108	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3196	 7661	 0.00386	 0.013793	 0.00127	 82.499866	 82.499866	 82.499866	 0.0	 0.0	 1	 -30.0	 30.0;
	1970	 2740	 0.036	 0.114223	 0.01227	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4727	 3196	 0.027942	 0.081793	 0.0095	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5079	 4266	 0.027008	 0.061041	 0.00592	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6593	 4266	 0.025504	 0.072198	 0.00621	 66.954502	 66.954502	 66.954502	 0.0	 0.0	 1	 -30.0	 30.0;
	5557	 5881	 0.01686	 0.060331	 0.00578	 67.165414	 67.165414	 67.165414	 0.0	 0.0	 1	 -30.0	 30.0;
	6939	 1560	 0.010091	 0.038529	 0.00342	 72.913381	 72.913381	 72.913381	 0.0	 0.0	 1	 -30.0	 30.0;
	6593	 6939	 0.027099	 0.082603	 0.00922	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4275	 5014	 0.014463	 0.051719	 0.0049	 90.213295	 90.213295	 90.213295	 0.0	 0.0	 1	 -30.0	 30.0;
	5014	 4773	 0.014612	 0.041066	 0.00495	 111.82023	 111.82023	 111.82023	 0.0	 0.0	 1	 -30.0	 30.0;
	1673	 55	 0.001661	 0.006446	 0.00056	 74.349563	 74.349563	 74.349563	 0.0	 0.0	 1	 -30.0	 30.0;
	6605	 55	 0.005198	 0.019331	 0.00173	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6153	 1673	 0.003512	 0.011587	 0.00122	 61.530048	 61.530048	 61.530048	 0.0	 0.0	 1	 -30.0	 30.0;
	6153	 6605	 0.004339	 0.015512	 0.00147	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5079	 7954	 0.043628	 0.081231	 0.00875	 70.717954	 70.717954	 70.717954	 0.0	 0.0	 1	 -30.0	 30.0;
	2464	 1076	 0.031661	 0.092669	 0.0108	 73.093618	 73.093618	 73.093618	 0.0	 0.0	 1	 -30.0	 30.0;
	1560	 41	 0.017562	 0.070818	 0.00598	 79.825078	 79.825078	 79.825078	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 4148	 0.008843	 0.033802	 0.00306	 64.479003	 64.479003	 64.479003	 0.0	 0.0	 1	 -30.0	 30.0;
	6223	 8040	 0.01164	 0.05205	 0.09202	 411.696457	 411.696457	 411.696457	 0.0	 0.0	 1	 -30.0	 30.0;
	1560	 5961	 0.007934	 0.042653	 0.00413	 70.334807	 70.334807	 70.334807	 0.0	 0.0	 1	 -30.0	 30.0;
	8142	 5961	 0.00343	 0.014488	 0.00184	 91.397983	 91.397983	 91.397983	 0.0	 0.0	 1	 -30.0	 30.0;
	107	 5961	 0.004339	 0.022421	 0.00225	 69.96957	 69.96957	 69.96957	 0.0	 0.0	 1	 -30.0	 30.0;
	5961	 3922	 0.00143	 0.007149	 0.00125	 71.749269	 71.749269	 71.749269	 0.0	 0.0	 1	 -30.0	 30.0;
	5961	 3922	 0.001446	 0.007	 0.00127	 72.782871	 72.782871	 72.782871	 0.0	 0.0	 1	 -30.0	 30.0;
	5961	 3922	 0.001504	 0.007256	 0.00127	 79.007913	 79.007913	 79.007913	 0.0	 0.0	 1	 -30.0	 30.0;
	5961	 3922	 0.001529	 0.007099	 0.0013	 71.867586	 71.867586	 71.867586	 0.0	 0.0	 1	 -30.0	 30.0;
	1560	 1892	 0.015653	 0.051669	 0.0053	 61.804596	 61.804596	 61.804596	 0.0	 0.0	 1	 -30.0	 30.0;
	3833	 2964	 0.00046	 0.00424	 0.10354	 1255.971979	 1255.971979	 1255.971979	 0.0	 0.0	 1	 -30.0	 30.0;
	3292	 4773	 0.049339	 0.138727	 0.01683	 64.906924	 64.906924	 64.906924	 0.0	 0.0	 1	 -30.0	 30.0;
	4285	 5079	 0.005421	 0.017876	 0.00092	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	822	 2464	 0.001678	 0.006421	 0.00054	 77.916964	 77.916964	 77.916964	 0.0	 0.0	 1	 -30.0	 30.0;
	822	 6857	 0.024512	 0.055752	 0.0049	 57.462899	 57.462899	 57.462899	 0.0	 0.0	 1	 -30.0	 30.0;
	3534	 1546	 0.019347	 0.072058	 0.00662	 60.255813	 60.255813	 60.255813	 0.0	 0.0	 1	 -30.0	 30.0;
	4275	 3534	 0.002364	 0.008777	 0.00077	 61.632551	 61.632551	 61.632551	 0.0	 0.0	 1	 -30.0	 30.0;
	3534	 4773	 0.032331	 0.102537	 0.01102	 84.312908	 84.312908	 84.312908	 0.0	 0.0	 1	 -30.0	 30.0;
	107	 8142	 0.00305	 0.017711	 0.00156	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4990	 6593	 0.005289	 0.009463	 0.0011	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4990	 7636	 0.00181	 0.007298	 0.00064	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7636	 6593	 0.000893	 0.00338	 0.00027	 76.177084	 76.177084	 76.177084	 0.0	 0.0	 1	 -30.0	 30.0;
	3456	 7636	 0.012033	 0.046579	 0.00414	 73.603083	 73.603083	 73.603083	 0.0	 0.0	 1	 -30.0	 30.0;
	5446	 1541	 0.00017	 0.01734	 0.0	 1203.266954	 1203.266954	 1203.266954	 0.0	 0.0	 1	 -30.0	 30.0;
	3820	 7459	 0.00017	 0.01767	 0.0	 1089.73958	 1089.73958	 1089.73958	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 1853	 0.0006	 0.040218	 0.0	 648.427861	 648.427861	 648.427861	 0.0	 0.0	 1	 -30.0	 30.0;
	8013	 1986	 0.00076	 0.002409	 0.04476	 104.057109	 104.057109	 104.057109	 0.0	 0.0	 1	 -30.0	 30.0;
	8013	 3433	 0.0	 0.000538	 0.0	 104.057109	 104.057109	 104.057109	 0.0	 0.0	 1	 -30.0	 30.0;
	5802	 1426	 0.00528	 0.027569	 0.04458	 150.278704	 150.278704	 150.278704	 0.0	 0.0	 1	 -30.0	 30.0;
	5802	 1426	 0.005382	 0.026978	 0.04542	 135.677256	 135.677256	 135.677256	 0.0	 0.0	 1	 -30.0	 30.0;
	4777	 5802	 0.00104	 0.009649	 0.00974	 241.083286	 241.083286	 241.083286	 0.0	 0.0	 1	 -30.0	 30.0;
	4777	 5802	 0.001062	 0.009449	 0.00993	 279.017537	 279.017537	 279.017537	 0.0	 0.0	 1	 -30.0	 30.0;
	3087	 4769	 0.000289	 0.000889	 0.00033	 222.321798	 222.321798	 222.321798	 0.0	 0.0	 1	 -30.0	 30.0;
	1098	 4769	 0.003502	 0.01524	 0.00403	 212.739833	 212.739833	 212.739833	 0.0	 0.0	 1	 -30.0	 30.0;
	3087	 7221	 0.000289	 0.00088	 0.00033	 122.53151	 122.53151	 122.53151	 0.0	 0.0	 1	 -30.0	 30.0;
	1098	 7221	 0.003431	 0.014111	 0.00394	 217.001198	 217.001198	 217.001198	 0.0	 0.0	 1	 -30.0	 30.0;
	7603	 5016	 0.001502	 0.1272	 0.0	 227.270614	 227.270614	 227.270614	 0.0	 0.0	 1	 -30.0	 30.0;
	80	 655	 8e-05	 0.000729	 0.00047	 315.658206	 315.658206	 315.658206	 0.0	 0.0	 1	 -30.0	 30.0;
	1098	 655	 0.003818	 0.012911	 0.00432	 182.65489	 182.65489	 182.65489	 0.0	 0.0	 1	 -30.0	 30.0;
	8246	 655	 0.001618	 0.013711	 0.01077	 242.555356	 242.555356	 242.555356	 0.0	 0.0	 1	 -30.0	 30.0;
	3055	 1711	 0.001062	 0.007791	 0.00315	 192.125657	 192.125657	 192.125657	 0.0	 0.0	 1	 -30.0	 30.0;
	5930	 1711	 0.001809	 0.008951	 0.00459	 135.105679	 135.105679	 135.105679	 0.0	 0.0	 1	 -30.0	 30.0;
	5256	 1711	 0.007142	 0.020311	 0.00702	 157.541626	 157.541626	 157.541626	 0.0	 0.0	 1	 -30.0	 30.0;
	3055	 7574	 0.000942	 0.008831	 0.0028	 215.314007	 215.314007	 215.314007	 0.0	 0.0	 1	 -30.0	 30.0;
	5930	 7574	 0.001769	 0.008289	 0.00449	 136.159978	 136.159978	 136.159978	 0.0	 0.0	 1	 -30.0	 30.0;
	5256	 7574	 0.00728	 0.019898	 0.00716	 160.031882	 160.031882	 160.031882	 0.0	 0.0	 1	 -30.0	 30.0;
	8009	 5211	 0.003569	 0.017951	 0.01071	 184.0459	 184.0459	 184.0459	 0.0	 0.0	 1	 -30.0	 30.0;
	3128	 8009	 0.001991	 0.007271	 0.00598	 169.833904	 169.833904	 169.833904	 0.0	 0.0	 1	 -30.0	 30.0;
	6986	 8009	 0.000391	 0.001462	 0.00421	 198.201518	 198.201518	 198.201518	 0.0	 0.0	 1	 -30.0	 30.0;
	2374	 7402	 0.003502	 0.018289	 0.01048	 182.312724	 182.312724	 182.312724	 0.0	 0.0	 1	 -30.0	 30.0;
	222	 2374	 0.001769	 0.00824	 0.00533	 176.097346	 176.097346	 176.097346	 0.0	 0.0	 1	 -30.0	 30.0;
	6986	 2374	 0.0004	 0.001431	 0.0043	 147.723236	 147.723236	 147.723236	 0.0	 0.0	 1	 -30.0	 30.0;
	1655	 4311	 0.0	 0.000413	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4798	 6826	 0.001471	 0.1296	 0.0	 187.74582	 187.74582	 187.74582	 0.0	 0.0	 1	 -30.0	 30.0;
	1986	 6684	 0.00056	 0.015018	 0.0	 105.874204	 105.874204	 105.874204	 0.0	 0.0	 1	 -30.0	 30.0;
	145	 7696	 0.000631	 0.01472	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	145	 1986	 0.0	 0.001169	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	145	 6892	 0.000942	 0.003342	 0.06995	 112.281319	 112.281319	 112.281319	 0.0	 0.0	 1	 -30.0	 30.0;
	145	 2456	 0.001582	 0.002831	 0.03332	 228.462351	 228.462351	 228.462351	 0.0	 0.0	 1	 -30.0	 30.0;
	2838	 6403	 0.0008	 0.003422	 0.0042	 180.916777	 180.916777	 180.916777	 0.0	 0.0	 1	 -30.0	 30.0;
	2838	 6403	 0.000822	 0.003351	 0.00428	 175.967182	 175.967182	 175.967182	 0.0	 0.0	 1	 -30.0	 30.0;
	6892	 2456	 0.002631	 0.004889	 0.05504	 234.79724	 234.79724	 234.79724	 0.0	 0.0	 1	 -30.0	 30.0;
	6892	 2095	 0.005418	 0.022489	 0.15481	 134.606588	 134.606588	 134.606588	 0.0	 0.0	 1	 -30.0	 30.0;
	6892	 2095	 0.00552	 0.022018	 0.15779	 136.088791	 136.088791	 136.088791	 0.0	 0.0	 1	 -30.0	 30.0;
	6701	 6872	 0.004091	 0.020893	 0.00189	 139.485689	 139.485689	 139.485689	 0.0	 0.0	 1	 -30.0	 30.0;
	6701	 6872	 0.004	 0.019339	 0.00185	 131.823321	 131.823321	 131.823321	 0.0	 0.0	 1	 -30.0	 30.0;
	6701	 4021	 0.016479	 0.037058	 0.03335	 103.164843	 103.164843	 103.164843	 0.0	 0.0	 1	 -30.0	 30.0;
	6701	 4259	 0.016347	 0.05124	 0.00521	 69.598617	 69.598617	 69.598617	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 6872	 0.007058	 0.030587	 0.00259	 157.446346	 157.446346	 157.446346	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 6872	 0.007149	 0.029934	 0.00264	 146.6163	 146.6163	 146.6163	 0.0	 0.0	 1	 -30.0	 30.0;
	6189	 5627	 0.002089	 0.003449	 0.05042	 243.249562	 243.249562	 243.249562	 0.0	 0.0	 1	 -30.0	 30.0;
	6189	 5627	 0.002129	 0.003378	 0.05139	 248.50495	 248.50495	 248.50495	 0.0	 0.0	 1	 -30.0	 30.0;
	2117	 646	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	646	 3890	 0.007489	 0.0516	 0.01757	 122.367571	 122.367571	 122.367571	 0.0	 0.0	 1	 -30.0	 30.0;
	646	 3890	 0.008489	 0.050569	 0.01991	 123.296383	 123.296383	 123.296383	 0.0	 0.0	 1	 -30.0	 30.0;
	793	 2917	 0.0	 0.047951	 0.50558	 118.686876	 118.686876	 118.686876	 0.0	 0.0	 1	 -30.0	 30.0;
	6431	 2917	 0.001649	 0.016591	 0.37763	 129.665827	 129.665827	 129.665827	 0.0	 0.0	 1	 -30.0	 30.0;
	7116	 2917	 0.001618	 0.016898	 0.36958	 132.87601	 132.87601	 132.87601	 0.0	 0.0	 1	 -30.0	 30.0;
	3178	 5627	 0.006871	 0.039911	 0.01519	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3178	 5627	 0.007009	 0.039089	 0.01549	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3178	 2895	 0.001658	 0.011871	 0.00368	 110.478514	 110.478514	 110.478514	 0.0	 0.0	 1	 -30.0	 30.0;
	3178	 2895	 0.001631	 0.010991	 0.0036	 112.490984	 112.490984	 112.490984	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 8275	 0.00092	 0.004689	 0.00279	 116.429148	 116.429148	 116.429148	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 8275	 0.002049	 0.0038	 0.06219	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5737	 8275	 0.005649	 0.026	 0.0176	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 2771	 0.000902	 0.004782	 0.00274	 167.836503	 167.836503	 167.836503	 0.0	 0.0	 1	 -30.0	 30.0;
	250	 2771	 0.003471	 0.014471	 0.01055	 143.937059	 143.937059	 143.937059	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 2771	 0.002089	 0.00372	 0.06341	 189.279205	 189.279205	 189.279205	 0.0	 0.0	 1	 -30.0	 30.0;
	3816	 1721	 0.003569	 0.010671	 0.00362	 187.603966	 187.603966	 187.603966	 0.0	 0.0	 1	 -30.0	 30.0;
	3550	 3816	 0.019782	 0.061658	 0.01962	 116.406285	 116.406285	 116.406285	 0.0	 0.0	 1	 -30.0	 30.0;
	440	 5211	 0.000409	 0.0014	 0.00438	 174.887422	 174.887422	 174.887422	 0.0	 0.0	 1	 -30.0	 30.0;
	5211	 487	 0.003302	 0.017311	 0.00992	 200.598763	 200.598763	 200.598763	 0.0	 0.0	 1	 -30.0	 30.0;
	440	 7402	 0.000409	 0.001369	 0.00446	 110.855235	 110.855235	 110.855235	 0.0	 0.0	 1	 -30.0	 30.0;
	7402	 487	 0.003231	 0.016031	 0.0097	 189.504198	 189.504198	 189.504198	 0.0	 0.0	 1	 -30.0	 30.0;
	8254	 7670	 0.000751	 0.005711	 0.12939	 171.908468	 171.908468	 171.908468	 0.0	 0.0	 1	 -30.0	 30.0;
	8254	 8168	 0.0018	 0.00716	 0.08656	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 8254	 0.001978	 0.013462	 0.21156	 146.687903	 146.687903	 146.687903	 0.0	 0.0	 1	 -30.0	 30.0;
	8254	 1770	 0.001502	 0.0056	 0.27143	 142.66634	 142.66634	 142.66634	 0.0	 0.0	 1	 -30.0	 30.0;
	2982	 5825	 0.005991	 0.0284	 0.03521	 164.867421	 164.867421	 164.867421	 0.0	 0.0	 1	 -30.0	 30.0;
	1877	 5825	 0.000302	 0.000858	 0.00034	 119.890305	 119.890305	 119.890305	 0.0	 0.0	 1	 -30.0	 30.0;
	5694	 5825	 0.002622	 0.013231	 0.00952	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6475	 5096	 0.004271	 0.019502	 0.01354	 132.086974	 132.086974	 132.086974	 0.0	 0.0	 1	 -30.0	 30.0;
	1877	 5096	 0.000271	 0.000969	 0.0003	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5694	 5096	 0.00356	 0.014378	 0.02094	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5705	 3141	 0.0022	 0.009569	 0.03479	 141.468367	 141.468367	 141.468367	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 3141	 0.000311	 0.001169	 0.0048	 111.245726	 111.245726	 111.245726	 0.0	 0.0	 1	 -30.0	 30.0;
	3000	 3141	 0.001889	 0.006311	 0.00214	 259.272158	 259.272158	 259.272158	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 2982	 0.000271	 0.00132	 0.00427	 108.100495	 108.100495	 108.100495	 0.0	 0.0	 1	 -30.0	 30.0;
	3000	 2982	 0.001929	 0.006178	 0.00218	 272.441546	 272.441546	 272.441546	 0.0	 0.0	 1	 -30.0	 30.0;
	716	 5985	 0.000339	 0.001149	 0.00841	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	426	 8070	 0.002591	 0.014418	 0.0	 192.853638	 192.853638	 192.853638	 0.0	 0.0	 1	 -30.0	 30.0;
	426	 703	 0.0	 0.00028	 0.0	 247.750989	 247.750989	 247.750989	 0.0	 0.0	 1	 -30.0	 30.0;
	5767	 3128	 0.0014	 0.00652	 0.00421	 237.308541	 237.308541	 237.308541	 0.0	 0.0	 1	 -30.0	 30.0;
	7399	 3128	 0.000418	 0.001338	 0.00454	 108.435907	 108.435907	 108.435907	 0.0	 0.0	 1	 -30.0	 30.0;
	5767	 222	 0.001369	 0.006649	 0.00413	 210.186704	 210.186704	 210.186704	 0.0	 0.0	 1	 -30.0	 30.0;
	7399	 222	 0.000369	 0.00152	 0.00405	 125.21896	 125.21896	 125.21896	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 4834	 0.004689	 0.018151	 0.01534	 148.335083	 148.335083	 148.335083	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 4834	 0.004591	 0.018498	 0.01502	 148.66322	 148.66322	 148.66322	 0.0	 0.0	 1	 -30.0	 30.0;
	1140	 127	 9.8e-05	 0.00028	 0.0	 155.465503	 155.465503	 155.465503	 0.0	 0.0	 1	 -30.0	 30.0;
	1140	 3622	 0.003698	 0.0198	 0.0	 115.771575	 115.771575	 115.771575	 0.0	 0.0	 1	 -30.0	 30.0;
	7271	 1140	 0.005471	 0.0206	 0.03082	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7271	 1140	 0.0062	 0.020191	 0.03493	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1140	 3972	 0.006098	 0.030551	 0.06659	 129.394588	 129.394588	 129.394588	 0.0	 0.0	 1	 -30.0	 30.0;
	861	 5256	 0.004809	 0.019751	 0.00546	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	861	 5256	 0.004711	 0.018289	 0.00534	 270.260201	 270.260201	 270.260201	 0.0	 0.0	 1	 -30.0	 30.0;
	3087	 5486	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5705	 6475	 0.007929	 0.044022	 0.01896	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5497	 1230	 0.009782	 0.033938	 0.01107	 257.757479	 257.757479	 257.757479	 0.0	 0.0	 1	 -30.0	 30.0;
	5497	 5947	 0.003609	 0.016889	 0.00487	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	593	 1266	 0.00044	 0.027591	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6201	 3217	 0.000419	 0.027979	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	316	 3217	 0.000409	 0.02851	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1266	 3217	 0.0	 0.000461	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1266	 2557	 0.000531	 0.005581	 0.02446	 315.63193	 315.63193	 315.63193	 0.0	 0.0	 1	 -30.0	 30.0;
	959	 1266	 0.003841	 0.022461	 0.05954	 481.782819	 481.782819	 481.782819	 0.0	 0.0	 1	 -30.0	 30.0;
	3217	 124	 0.000539	 0.005461	 0.02494	 407.752577	 407.752577	 407.752577	 0.0	 0.0	 1	 -30.0	 30.0;
	3530	 3217	 0.00376	 0.022901	 0.05833	 469.010745	 469.010745	 469.010745	 0.0	 0.0	 1	 -30.0	 30.0;
	4549	 8043	 0.028843	 0.060992	 0.00616	 72.650836	 72.650836	 72.650836	 0.0	 0.0	 1	 -30.0	 30.0;
	4549	 8043	 0.029397	 0.059744	 0.00628	 73.963558	 73.963558	 73.963558	 0.0	 0.0	 1	 -30.0	 30.0;
	1655	 5753	 0.001727	 0.00924	 0.00142	 142.688424	 142.688424	 142.688424	 0.0	 0.0	 1	 -30.0	 30.0;
	1625	 1655	 0.004851	 0.02724	 0.00403	 111.41041	 111.41041	 111.41041	 0.0	 0.0	 1	 -30.0	 30.0;
	1230	 5947	 0.0138	 0.040249	 0.01501	 261.833081	 261.833081	 261.833081	 0.0	 0.0	 1	 -30.0	 30.0;
	1230	 582	 0.007098	 0.022329	 0.00775	 128.886664	 128.886664	 128.886664	 0.0	 0.0	 1	 -30.0	 30.0;
	1230	 1679	 0.001902	 0.008391	 0.00607	 202.887668	 202.887668	 202.887668	 0.0	 0.0	 1	 -30.0	 30.0;
	1230	 1679	 0.001929	 0.008209	 0.00619	 191.922748	 191.922748	 191.922748	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 1230	 0.001649	 0.01228	 0.00982	 130.585546	 130.585546	 130.585546	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 1230	 0.001471	 0.01392	 0.00875	 159.769736	 159.769736	 159.769736	 0.0	 0.0	 1	 -30.0	 30.0;
	1230	 6922	 0.000582	 0.040991	 0.0	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	1230	 283	 0.01116	 0.033671	 0.01217	 290.989992	 290.989992	 290.989992	 0.0	 0.0	 1	 -30.0	 30.0;
	6346	 2251	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4556	 7478	 0.00031	 0.00312	 0.10854	 1277.067284	 1277.067284	 1277.067284	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 7478	 0.00069	 0.00769	 0.24736	 1836.164936	 1836.164936	 1836.164936	 0.0	 0.0	 1	 -30.0	 30.0;
	5570	 4944	 0.010471	 0.029289	 0.01153	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5570	 4944	 0.010671	 0.028671	 0.01175	 127.607891	 127.607891	 127.607891	 0.0	 0.0	 1	 -30.0	 30.0;
	310	 5570	 0.00624	 0.021871	 0.00687	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	310	 5570	 0.007071	 0.021431	 0.00778	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	8062	 7031	 9.8e-05	 0.00028	 0.0	 144.333786	 144.333786	 144.333786	 0.0	 0.0	 1	 -30.0	 30.0;
	8062	 5947	 0.001062	 0.003351	 0.0047	 170.28415	 170.28415	 170.28415	 0.0	 0.0	 1	 -30.0	 30.0;
	8062	 4854	 0.002111	 0.02008	 0.01412	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8062	 5806	 0.001009	 0.010929	 0.00675	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 8062	 0.004711	 0.050609	 0.03014	 133.144391	 133.144391	 133.144391	 0.0	 0.0	 1	 -30.0	 30.0;
	8062	 8246	 0.011462	 0.02396	 0.02125	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4798	 2135	 0.0	 0.0444	 0.1406	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4798	 1024	 0.001698	 0.1128	 0.0	 206.105126	 206.105126	 206.105126	 0.0	 0.0	 1	 -30.0	 30.0;
	4798	 1488	 8.9e-05	 0.000742	 0.0	 132.176088	 132.176088	 132.176088	 0.0	 0.0	 1	 -30.0	 30.0;
	4798	 1488	 8.9e-05	 0.000729	 0.0	 136.136076	 136.136076	 136.136076	 0.0	 0.0	 1	 -30.0	 30.0;
	4798	 2546	 0.000302	 0.000809	 0.02492	 137.198169	 137.198169	 137.198169	 0.0	 0.0	 1	 -30.0	 30.0;
	4798	 8200	 0.001502	 0.002182	 0.06789	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4798	 5578	 0.001311	 0.001871	 0.06139	 113.282878	 113.282878	 113.282878	 0.0	 0.0	 1	 -30.0	 30.0;
	4798	 5578	 0.001369	 0.00204	 0.0638	 200.169042	 200.169042	 200.169042	 0.0	 0.0	 1	 -30.0	 30.0;
	4798	 4198	 0.001049	 0.00308	 0.07664	 274.619254	 274.619254	 274.619254	 0.0	 0.0	 1	 -30.0	 30.0;
	1625	 5346	 0.014967	 0.09105	 0.01258	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4810	 5346	 0.028959	 0.12905	 0.01817	 85.674975	 85.674975	 85.674975	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 5346	 0.006438	 0.041256	 0.00593	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 5346	 0.006554	 0.040364	 0.00604	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2135	 1145	 0.0	 0.012742	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 7670	 0.001018	 0.00868	 0.17458	 168.331956	 168.331956	 168.331956	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 8168	 0.001871	 0.00548	 0.30536	 218.160459	 218.160459	 218.160459	 0.0	 0.0	 1	 -30.0	 30.0;
	8168	 6779	 0.00228	 0.004338	 0.13292	 234.751514	 234.751514	 234.751514	 0.0	 0.0	 1	 -30.0	 30.0;
	8168	 6779	 0.00224	 0.004431	 0.1302	 244.563669	 244.563669	 244.563669	 0.0	 0.0	 1	 -30.0	 30.0;
	2749	 731	 0.00076	 0.00747	 0.27098	 1711.253692	 1711.253692	 1711.253692	 0.0	 0.0	 1	 -30.0	 30.0;
	5150	 731	 0.00103	 0.01061	 0.3694	 1489.864552	 1489.864552	 1489.864552	 0.0	 0.0	 1	 -30.0	 30.0;
	2042	 8165	 0.002689	 0.013818	 0.0	 227.846867	 227.846867	 227.846867	 0.0	 0.0	 1	 -30.0	 30.0;
	487	 2042	 0.002111	 0.003769	 0.12183	 116.955778	 116.955778	 116.955778	 0.0	 0.0	 1	 -30.0	 30.0;
	487	 2042	 0.002151	 0.003689	 0.12422	 277.833853	 277.833853	 277.833853	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 4926	 0.00176	 0.012702	 0.01192	 193.494324	 193.494324	 193.494324	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 4926	 0.001729	 0.012951	 0.01167	 250.289829	 250.289829	 250.289829	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 953	 0.000151	 0.000511	 0.00034	 255.059117	 255.059117	 255.059117	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 953	 0.000151	 0.000502	 0.00034	 263.546513	 263.546513	 263.546513	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 1679	 0.01076	 0.05508	 0.03402	 153.451474	 153.451474	 153.451474	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 1679	 0.010542	 0.05616	 0.03332	 150.815986	 150.815986	 150.815986	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 6190	 0.003089	 0.009	 0.00268	 224.382592	 224.382592	 224.382592	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 6190	 0.003031	 0.009169	 0.00262	 231.574847	 231.574847	 231.574847	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 5694	 0.001849	 0.00872	 0.00591	 137.274033	 137.274033	 137.274033	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 5694	 0.00188	 0.008538	 0.00602	 109.650767	 109.650767	 109.650767	 0.0	 0.0	 1	 -30.0	 30.0;
	2703	 3000	 0.004151	 0.01556	 0.00468	 257.106141	 257.106141	 257.106141	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 2703	 0.006591	 0.026778	 0.00744	 311.269535	 311.269535	 311.269535	 0.0	 0.0	 1	 -30.0	 30.0;
	6346	 8056	 0.00056	 0.038671	 0.0	 506.894542	 506.894542	 506.894542	 0.0	 0.0	 1	 -30.0	 30.0;
	1596	 537	 0.0	 0.00045	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	537	 7459	 0.00162	 0.01968	 0.5839	 1616.229055	 1616.229055	 1616.229055	 0.0	 0.0	 1	 -30.0	 30.0;
	6346	 7958	 9.8e-05	 0.00028	 0.0	 123.145955	 123.145955	 123.145955	 0.0	 0.0	 1	 -30.0	 30.0;
	6346	 5767	 0.002649	 0.015111	 0.01134	 217.975996	 217.975996	 217.975996	 0.0	 0.0	 1	 -30.0	 30.0;
	6346	 5767	 0.002702	 0.014809	 0.01156	 246.781906	 246.781906	 246.781906	 0.0	 0.0	 1	 -30.0	 30.0;
	6346	 4576	 0.0008	 0.005711	 0.02164	 137.188816	 137.188816	 137.188816	 0.0	 0.0	 1	 -30.0	 30.0;
	6346	 4576	 0.000782	 0.005809	 0.02118	 142.379773	 142.379773	 142.379773	 0.0	 0.0	 1	 -30.0	 30.0;
	6346	 2998	 0.001049	 0.007738	 0.0052	 289.566246	 289.566246	 289.566246	 0.0	 0.0	 1	 -30.0	 30.0;
	6346	 2998	 0.001071	 0.007569	 0.0053	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	6346	 2838	 0.005138	 0.025338	 0.16348	 125.818596	 125.818596	 125.818596	 0.0	 0.0	 1	 -30.0	 30.0;
	6346	 2838	 0.005031	 0.025831	 0.16015	 139.961223	 139.961223	 139.961223	 0.0	 0.0	 1	 -30.0	 30.0;
	6346	 1331	 0.003658	 0.029071	 0.01363	 110.210653	 110.210653	 110.210653	 0.0	 0.0	 1	 -30.0	 30.0;
	6346	 1331	 0.004151	 0.028489	 0.01545	 126.925636	 126.925636	 126.925636	 0.0	 0.0	 1	 -30.0	 30.0;
	1110	 1228	 0.001471	 0.011471	 0.00955	 187.307265	 187.307265	 187.307265	 0.0	 0.0	 1	 -30.0	 30.0;
	1110	 1228	 0.001502	 0.011218	 0.00973	 206.377404	 206.377404	 206.377404	 0.0	 0.0	 1	 -30.0	 30.0;
	2095	 1228	 0.001871	 0.014511	 0.01207	 185.364424	 185.364424	 185.364424	 0.0	 0.0	 1	 -30.0	 30.0;
	2095	 1228	 0.001902	 0.0142	 0.0123	 232.805555	 232.805555	 232.805555	 0.0	 0.0	 1	 -30.0	 30.0;
	179	 6524	 0.000351	 0.004662	 0.00321	 169.898596	 169.898596	 169.898596	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 179	 0.00772	 0.033818	 0.02355	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 7643	 0.0	 0.00051	 0.0	 1919.934707	 1919.934707	 1919.934707	 0.0	 0.0	 1	 -30.0	 30.0;
	7643	 2903	 0.00076	 0.0119	 0.47516	 822.094256	 822.094256	 822.094256	 0.0	 0.0	 1	 -30.0	 30.0;
	7643	 3044	 0.00025	 0.00316	 0.10448	 1583.672874	 1583.672874	 1583.672874	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 3165	 0.00077	 0.01164	 0.48396	 841.706683	 841.706683	 841.706683	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 6137	 0.00025	 0.00322	 0.10235	 1499.709598	 1499.709598	 1499.709598	 0.0	 0.0	 1	 -30.0	 30.0;
	758	 5710	 0.001369	 0.021182	 0.93656	 504.076148	 504.076148	 504.076148	 0.0	 0.0	 1	 -30.0	 30.0;
	2903	 3165	 0.0	 0.00052	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2903	 5685	 0.00015	 0.00328	 0.1124	 798.555789	 798.555789	 798.555789	 0.0	 0.0	 1	 -30.0	 30.0;
	356	 2903	 0.00016	 0.00314	 0.11526	 1365.640448	 1365.640448	 1365.640448	 0.0	 0.0	 1	 -30.0	 30.0;
	3165	 5508	 0.00017	 0.00321	 0.12739	 997.878153	 997.878153	 997.878153	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 3165	 0.00018	 0.00308	 0.13063	 979.61236	 979.61236	 979.61236	 0.0	 0.0	 1	 -30.0	 30.0;
	2921	 3663	 0.00024	 0.01948	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 6731	 0.000631	 0.037902	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2162	 5238	 0.00244	 0.01532	 0.0	 235.644213	 235.644213	 235.644213	 0.0	 0.0	 1	 -30.0	 30.0;
	256	 7333	 0.0	 0.00053	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	256	 5508	 0.00013	 0.00282	 0.0914	 988.91046	 988.91046	 988.91046	 0.0	 0.0	 1	 -30.0	 30.0;
	3713	 256	 0.00038	 0.00708	 0.27003	 1248.464786	 1248.464786	 1248.464786	 0.0	 0.0	 1	 -30.0	 30.0;
	7333	 5685	 0.00013	 0.00261	 0.08942	 1093.320734	 1093.320734	 1093.320734	 0.0	 0.0	 1	 -30.0	 30.0;
	5342	 7333	 0.00038	 0.00722	 0.2644	 1474.513836	 1474.513836	 1474.513836	 0.0	 0.0	 1	 -30.0	 30.0;
	1343	 4777	 0.00016	 0.002769	 0.11027	 254.46052	 254.46052	 254.46052	 0.0	 0.0	 1	 -30.0	 30.0;
	3608	 4777	 0.00016	 0.00272	 0.11239	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	7292	 4777	 0.00016	 0.002662	 0.11451	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	1816	 1455	 0.024479	 0.081727	 0.00705	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6281	 1455	 0.024248	 0.064893	 0.00592	 71.417564	 71.417564	 71.417564	 0.0	 0.0	 1	 -30.0	 30.0;
	612	 7896	 0.0084	 0.04056	 0.02022	 118.878874	 118.878874	 118.878874	 0.0	 0.0	 1	 -30.0	 30.0;
	7896	 184	 0.003809	 0.0248	 0.01222	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7896	 3972	 0.002542	 0.014569	 0.04355	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7896	 3972	 0.002591	 0.01428	 0.04441	 105.095041	 105.095041	 105.095041	 0.0	 0.0	 1	 -30.0	 30.0;
	6880	 7018	 9.8e-05	 0.00028	 1.1	 159.733623	 159.733623	 159.733623	 0.0	 0.0	 1	 -30.0	 30.0;
	6880	 5077	 0.003071	 0.01636	 0.00764	 128.917841	 128.917841	 128.917841	 0.0	 0.0	 1	 -30.0	 30.0;
	6880	 4872	 0.003889	 0.027022	 0.00967	 131.59204	 131.59204	 131.59204	 0.0	 0.0	 1	 -30.0	 30.0;
	4341	 6880	 0.00624	 0.036009	 0.01551	 210.170596	 210.170596	 210.170596	 0.0	 0.0	 1	 -30.0	 30.0;
	4341	 6880	 0.00636	 0.035258	 0.0158	 211.111879	 211.111879	 211.111879	 0.0	 0.0	 1	 -30.0	 30.0;
	4777	 2532	 0.000982	 0.001529	 0.06484	 114.269887	 114.269887	 114.269887	 0.0	 0.0	 1	 -30.0	 30.0;
	4777	 2532	 0.000991	 0.001502	 0.06606	 151.118662	 151.118662	 151.118662	 0.0	 0.0	 1	 -30.0	 30.0;
	7839	 4777	 0.00052	 0.004991	 0.09797	 262.289563	 262.289563	 262.289563	 0.0	 0.0	 1	 -30.0	 30.0;
	4777	 2451	 0.0	 0.00028	 0.0	 127.24364	 127.24364	 127.24364	 0.0	 0.0	 1	 -30.0	 30.0;
	588	 3736	 0.012182	 0.034826	 0.01493	 88.865707	 88.865707	 88.865707	 0.0	 0.0	 1	 -30.0	 30.0;
	1816	 588	 0.025744	 0.059	 0.0192	 125.447954	 125.447954	 125.447954	 0.0	 0.0	 1	 -30.0	 30.0;
	3760	 1490	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 3760	 0.0	 0.000222	 0.0	 118.01995	 118.01995	 118.01995	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 5326	 0.003129	 0.015031	 0.04704	 132.608408	 132.608408	 132.608408	 0.0	 0.0	 1	 -30.0	 30.0;
	3760	 449	 0.00228	 0.019871	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3760	 5326	 0.002791	 0.017031	 0.0419	 125.410698	 125.410698	 125.410698	 0.0	 0.0	 1	 -30.0	 30.0;
	5969	 3145	 0.001431	 0.01252	 0.1777	 210.634352	 210.634352	 210.634352	 0.0	 0.0	 1	 -30.0	 30.0;
	5969	 3717	 0.001649	 0.007631	 0.01346	 140.970576	 140.970576	 140.970576	 0.0	 0.0	 1	 -30.0	 30.0;
	5969	 4768	 0.001471	 0.008649	 0.012	 115.539567	 115.539567	 115.539567	 0.0	 0.0	 1	 -30.0	 30.0;
	449	 5326	 0.00656	 0.009071	 0.20079	 266.038587	 266.038587	 266.038587	 0.0	 0.0	 1	 -30.0	 30.0;
	5488	 3331	 0.0	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1895	 8230	 0.0	 0.00028	 0.0	 241.371153	 241.371153	 241.371153	 0.0	 0.0	 1	 -30.0	 30.0;
	2932	 7298	 0.000521	 0.001529	 0.01597	 392.885294	 392.885294	 392.885294	 0.0	 0.0	 1	 -30.0	 30.0;
	66	 5213	 0.000219	 0.00095	 0.0598	 456.346509	 456.346509	 456.346509	 0.0	 0.0	 1	 -30.0	 30.0;
	33	 5213	 0.000219	 0.00088	 0.0585	 540.911292	 540.911292	 540.911292	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 8273	 0.002391	 0.015618	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4556	 831	 0.0	 0.00054	 0.0	 1456.457345	 1456.457345	 1456.457345	 0.0	 0.0	 1	 -30.0	 30.0;
	1636	 4556	 0.00079	 0.01037	 0.28387	 1686.623965	 1686.623965	 1686.623965	 0.0	 0.0	 1	 -30.0	 30.0;
	599	 4556	 0.00022	 0.00296	 0.08288	 1654.489018	 1654.489018	 1654.489018	 0.0	 0.0	 1	 -30.0	 30.0;
	7801	 831	 0.00077	 0.01056	 0.27783	 1820.927427	 1820.927427	 1820.927427	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 3911	 0.000649	 0.03712	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 4732	 0.003302	 0.019138	 0.02159	 163.562667	 163.562667	 163.562667	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 4732	 0.003369	 0.018742	 0.02201	 150.921468	 150.921468	 150.921468	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 426	 0.001769	 0.018222	 0.08625	 230.358427	 230.358427	 230.358427	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 6779	 0.000858	 0.006809	 0.01934	 156.575921	 156.575921	 156.575921	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 6779	 0.000969	 0.006671	 0.02192	 168.948739	 168.948739	 168.948739	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 7977	 0.005551	 0.03908	 0.0267	 225.5881	 225.5881	 225.5881	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 7977	 0.005431	 0.039822	 0.02613	 229.617716	 229.617716	 229.617716	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 7977	 0.005311	 0.036871	 0.02556	 242.058084	 242.058084	 242.058084	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 998	 0.002169	 0.016271	 0.01291	 129.886663	 129.886663	 129.886663	 0.0	 0.0	 1	 -30.0	 30.0;
	2895	 998	 0.007418	 0.07832	 0.05206	 143.978888	 143.978888	 143.978888	 0.0	 0.0	 1	 -30.0	 30.0;
	4389	 2749	 0.0	 0.0005	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4389	 5756	 0.0	 0.00049	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4389	 7356	 0.00079	 0.00848	 0.27731	 1589.512241	 1589.512241	 1589.512241	 0.0	 0.0	 1	 -30.0	 30.0;
	4389	 2921	 0.00183	 0.0174	 0.6567	 1447.835854	 1447.835854	 1447.835854	 0.0	 0.0	 1	 -30.0	 30.0;
	2749	 5756	 0.0	 0.00048	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2749	 7959	 0.0008	 0.0083	 0.28275	 1691.528717	 1691.528717	 1691.528717	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 61	 0.004449	 0.02404	 0.04483	 144.243113	 144.243113	 144.243113	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 61	 0.004529	 0.023551	 0.04571	 129.99916	 129.99916	 129.99916	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 5627	 0.006791	 0.013271	 0.54829	 272.264877	 272.264877	 272.264877	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 1009	 0.00424	 0.030378	 0.00933	 110.414602	 110.414602	 110.414602	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 1009	 0.004151	 0.028129	 0.00913	 112.32107	 112.32107	 112.32107	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 6622	 0.002311	 0.003622	 0.16224	 123.69285	 123.69285	 123.69285	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 6622	 0.002062	 0.004102	 0.14454	 119.60088	 119.60088	 119.60088	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 6335	 0.00452	 0.029609	 0.01032	 129.868217	 129.868217	 129.868217	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 6335	 0.004422	 0.030169	 0.0101	 129.063333	 129.063333	 129.063333	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 4341	 0.00416	 0.023058	 0.01033	 257.29762	 257.29762	 257.29762	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 3294	 0.002831	 0.020742	 0.00702	 283.517405	 283.517405	 283.517405	 0.0	 0.0	 1	 -30.0	 30.0;
	2838	 1572	 0.002338	 0.01592	 0.0	 114.354844	 114.354844	 114.354844	 0.0	 0.0	 1	 -30.0	 30.0;
	529	 2864	 9.8e-05	 0.00028	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1009	 529	 0.004969	 0.03636	 0.01338	 113.77963	 113.77963	 113.77963	 0.0	 0.0	 1	 -30.0	 30.0;
	6335	 529	 0.003431	 0.015698	 0.05911	 136.760653	 136.760653	 136.760653	 0.0	 0.0	 1	 -30.0	 30.0;
	6596	 529	 0.00456	 0.027582	 0.01254	 110.41694	 110.41694	 110.41694	 0.0	 0.0	 1	 -30.0	 30.0;
	7356	 7959	 0.0	 0.00047	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7605	 7356	 0.00093	 0.01185	 0.33039	 1827.663892	 1827.663892	 1827.663892	 0.0	 0.0	 1	 -30.0	 30.0;
	123	 7959	 0.00091	 0.01207	 0.32336	 1817.230434	 1817.230434	 1817.230434	 0.0	 0.0	 1	 -30.0	 30.0;
	612	 5841	 9.8e-05	 0.00028	 0.0	 135.865876	 135.865876	 135.865876	 0.0	 0.0	 1	 -30.0	 30.0;
	7926	 612	 0.000529	 0.003151	 0.00225	 191.700092	 191.700092	 191.700092	 0.0	 0.0	 1	 -30.0	 30.0;
	7926	 612	 0.00052	 0.003209	 0.0022	 215.685792	 215.685792	 215.685792	 0.0	 0.0	 1	 -30.0	 30.0;
	612	 184	 0.00352	 0.020578	 0.01363	 135.665304	 135.665304	 135.665304	 0.0	 0.0	 1	 -30.0	 30.0;
	8043	 6274	 0.039182	 0.089413	 0.01109	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8043	 8354	 0.033686	 0.067124	 0.00704	 60.51912	 60.51912	 60.51912	 0.0	 0.0	 1	 -30.0	 30.0;
	5800	 3696	 0.044992	 0.093174	 0.01229	 70.244498	 70.244498	 70.244498	 0.0	 0.0	 1	 -30.0	 30.0;
	5471	 5800	 0.013678	 0.052479	 0.01461	 71.76756	 71.76756	 71.76756	 0.0	 0.0	 1	 -30.0	 30.0;
	4434	 5800	 0.005686	 0.022893	 0.00602	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5800	 6473	 0.034281	 0.094653	 0.00913	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2508	 5553	 0.0	 0.00045	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	66	 2508	 0.00032	 0.001469	 0.09518	 449.496352	 449.496352	 449.496352	 0.0	 0.0	 1	 -30.0	 30.0;
	33	 5553	 0.000289	 0.001039	 0.0853	 470.258688	 470.258688	 470.258688	 0.0	 0.0	 1	 -30.0	 30.0;
	2932	 6456	 0.00324	 0.017628	 0.00278	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	2932	 7728	 0.002678	 0.019298	 0.00229	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	2932	 4857	 0.000529	 0.001504	 0.01627	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 3029	 0.00042	 0.0261	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6198	 4363	 0.00043	 0.02555	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5886	 4363	 0.00044	 0.02499	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 4363	 0.00039	 0.02833	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	522	 1239	 0.00019	 0.01594	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	243	 963	 0.000419	 0.026099	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2474	 5426	 0.00043	 0.02555	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7856	 7523	 0.00038	 0.02888	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6246	 3698	 0.00038	 0.02944	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3387	 3029	 0.00037	 0.02999	 0.0	 1891.531637	 1891.531637	 1891.531637	 0.0	 0.0	 1	 -30.0	 30.0;
	1729	 3029	 0.00036	 0.02777	 0.0	 2303.627574	 2303.627574	 2303.627574	 0.0	 0.0	 1	 -30.0	 30.0;
	61	 7377	 9.8e-05	 0.00028	 1.0	 154.204916	 154.204916	 154.204916	 0.0	 0.0	 1	 -30.0	 30.0;
	6613	 61	 0.003951	 0.02048	 0.00715	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	61	 6615	 0.003858	 0.020871	 0.007	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4363	 7523	 0.0	 0.00046	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4363	 3698	 0.0	 0.00045	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4363	 6695	 0.0	 0.00051	 0.0	 834.614143	 834.614143	 834.614143	 0.0	 0.0	 1	 -30.0	 30.0;
	4363	 1827	 0.0	 0.00052	 0.0	 841.047187	 841.047187	 841.047187	 0.0	 0.0	 1	 -30.0	 30.0;
	2221	 5426	 0.0	 0.00051	 0.0	 283.117596	 283.117596	 283.117596	 0.0	 0.0	 1	 -30.0	 30.0;
	2221	 963	 0.0	 0.000521	 0.0	 339.615292	 339.615292	 339.615292	 0.0	 0.0	 1	 -30.0	 30.0;
	2221	 5699	 0.0	 0.000531	 0.0	 388.587608	 388.587608	 388.587608	 0.0	 0.0	 1	 -30.0	 30.0;
	2221	 3952	 0.0	 0.000539	 0.0	 231.336551	 231.336551	 231.336551	 0.0	 0.0	 1	 -30.0	 30.0;
	3029	 7523	 0.0	 0.00053	 0.0	 1426.761611	 1426.761611	 1426.761611	 0.0	 0.0	 1	 -30.0	 30.0;
	3029	 3698	 0.0	 0.00054	 0.0	 974.284399	 974.284399	 974.284399	 0.0	 0.0	 1	 -30.0	 30.0;
	3029	 6695	 0.0	 0.0005	 0.0	 1133.873135	 1133.873135	 1133.873135	 0.0	 0.0	 1	 -30.0	 30.0;
	3029	 1827	 0.0	 0.00049	 0.0	 934.651474	 934.651474	 934.651474	 0.0	 0.0	 1	 -30.0	 30.0;
	293	 5426	 0.0	 0.0005	 0.0	 288.149757	 288.149757	 288.149757	 0.0	 0.0	 1	 -30.0	 30.0;
	293	 963	 0.0	 0.00049	 0.0	 379.415325	 379.415325	 379.415325	 0.0	 0.0	 1	 -30.0	 30.0;
	293	 5699	 0.0	 0.000479	 0.0	 374.199496	 374.199496	 374.199496	 0.0	 0.0	 1	 -30.0	 30.0;
	293	 3952	 0.0	 0.000469	 0.0	 253.335017	 253.335017	 253.335017	 0.0	 0.0	 1	 -30.0	 30.0;
	4421	 7523	 0.00043	 0.00544	 0.28708	 1608.432263	 1608.432263	 1608.432263	 0.0	 0.0	 1	 -30.0	 30.0;
	2284	 5426	 0.0	 0.000461	 0.0	 480.50744	 480.50744	 480.50744	 0.0	 0.0	 1	 -30.0	 30.0;
	963	 1239	 0.0	 0.00045	 0.0	 475.544249	 475.544249	 475.544249	 0.0	 0.0	 1	 -30.0	 30.0;
	1787	 6695	 0.00038	 0.00616	 0.25576	 1475.43397	 1475.43397	 1475.43397	 0.0	 0.0	 1	 -30.0	 30.0;
	4813	 1827	 0.00041	 0.02721	 0.0	 1098.280115	 1098.280115	 1098.280115	 0.0	 0.0	 1	 -30.0	 30.0;
	3952	 959	 0.002081	 0.023	 0.08065	 550.63648	 550.63648	 550.63648	 0.0	 0.0	 1	 -30.0	 30.0;
	6042	 758	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4697	 2468	 0.0	 0.00048	 0.0	 1522.112705	 1522.112705	 1522.112705	 0.0	 0.0	 1	 -30.0	 30.0;
	4697	 1541	 0.0011	 0.01189	 0.39796	 1839.297211	 1839.297211	 1839.297211	 0.0	 0.0	 1	 -30.0	 30.0;
	4697	 2921	 0.00084	 0.00906	 0.30326	 1051.505944	 1051.505944	 1051.505944	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 1541	 0.00112	 0.01165	 0.40561	 1881.026437	 1881.026437	 1881.026437	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 7459	 0.00115	 0.0114	 0.41326	 1760.786293	 1760.786293	 1760.786293	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 5150	 0.00086	 0.00887	 0.3091	 1294.593282	 1294.593282	 1294.593282	 0.0	 0.0	 1	 -30.0	 30.0;
	3055	 6524	 0.00116	 0.00912	 0.00927	 261.909725	 261.909725	 261.909725	 0.0	 0.0	 1	 -30.0	 30.0;
	3055	 6524	 0.001129	 0.009298	 0.00908	 155.178416	 155.178416	 155.178416	 0.0	 0.0	 1	 -30.0	 30.0;
	6524	 8152	 0.000609	 0.005058	 0.07718	 152.475377	 152.475377	 152.475377	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 6524	 0.008009	 0.04	 0.02523	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6524	 3522	 0.002289	 0.016218	 0.0	 193.847922	 193.847922	 193.847922	 0.0	 0.0	 1	 -30.0	 30.0;
	3055	 353	 0.003098	 0.032729	 0.00789	 218.544975	 218.544975	 218.544975	 0.0	 0.0	 1	 -30.0	 30.0;
	3055	 3209	 0.002982	 0.013058	 0.01268	 234.702151	 234.702151	 234.702151	 0.0	 0.0	 1	 -30.0	 30.0;
	3055	 3209	 0.00304	 0.0128	 0.01293	 233.04224	 233.04224	 233.04224	 0.0	 0.0	 1	 -30.0	 30.0;
	3055	 5289	 0.008791	 0.059622	 0.01784	 143.966937	 143.966937	 143.966937	 0.0	 0.0	 1	 -30.0	 30.0;
	8152	 5930	 0.000511	 0.004409	 0.06356	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6963	 5930	 0.009391	 0.030809	 0.00759	 247.943506	 247.943506	 247.943506	 0.0	 0.0	 1	 -30.0	 30.0;
	6963	 5930	 0.009191	 0.031391	 0.00742	 266.943757	 266.943757	 266.943757	 0.0	 0.0	 1	 -30.0	 30.0;
	1552	 2629	 9.8e-05	 0.000222	 0.0	 141.630487	 141.630487	 141.630487	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 1552	 0.00276	 0.014782	 0.0063	 106.409927	 106.409927	 106.409927	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 1552	 0.002809	 0.014458	 0.00642	 106.882777	 106.882777	 106.882777	 0.0	 0.0	 1	 -30.0	 30.0;
	1009	 1552	 0.003138	 0.017502	 0.00719	 160.330661	 160.330661	 160.330661	 0.0	 0.0	 1	 -30.0	 30.0;
	1009	 1552	 0.0032	 0.017138	 0.00732	 155.181014	 155.181014	 155.181014	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 5753	 0.002033	 0.005273	 0.04891	 101.825067	 101.825067	 101.825067	 0.0	 0.0	 1	 -30.0	 30.0;
	3918	 5753	 0.036066	 0.160107	 0.01461	 100.061943	 100.061943	 100.061943	 0.0	 0.0	 1	 -30.0	 30.0;
	664	 8095	 0.027686	 0.04614	 0.04049	 69.413235	 69.413235	 69.413235	 0.0	 0.0	 1	 -30.0	 30.0;
	4923	 8095	 0.025107	 0.051372	 0.00485	 75.269039	 75.269039	 75.269039	 0.0	 0.0	 1	 -30.0	 30.0;
	1625	 494	 0.002479	 0.01086	 0.00305	 77.956784	 77.956784	 77.956784	 0.0	 0.0	 1	 -30.0	 30.0;
	494	 6281	 0.013603	 0.051876	 0.0061	 62.286244	 62.286244	 62.286244	 0.0	 0.0	 1	 -30.0	 30.0;
	8200	 7713	 0.00176	 0.108	 0.0	 213.296341	 213.296341	 213.296341	 0.0	 0.0	 1	 -30.0	 30.0;
	1450	 5046	 0.0	 0.00047	 0.0	 1007.22759	 1007.22759	 1007.22759	 0.0	 0.0	 1	 -30.0	 30.0;
	1450	 7801	 0.00038	 0.00366	 0.13832	 1775.522269	 1775.522269	 1775.522269	 0.0	 0.0	 1	 -30.0	 30.0;
	1450	 7490	 0.00052	 0.00633	 0.18396	 1919.024445	 1919.024445	 1919.024445	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 7715	 0.0	 0.00051	 0.0	 254.903042	 254.903042	 254.903042	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 2962	 0.001599	 0.015599	 0.07413	 333.603066	 333.603066	 333.603066	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 1025	 0.00212	 0.022349	 0.09805	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5046	 1636	 0.00034	 0.00415	 0.12323	 1655.514462	 1655.514462	 1655.514462	 0.0	 0.0	 1	 -30.0	 30.0;
	7442	 5046	 0.00051	 0.00646	 0.18012	 1769.36566	 1769.36566	 1769.36566	 0.0	 0.0	 1	 -30.0	 30.0;
	7715	 332	 0.00163	 0.015271	 0.07552	 345.792131	 345.792131	 345.792131	 0.0	 0.0	 1	 -30.0	 30.0;
	3543	 7715	 0.002159	 0.021901	 0.09998	 269.837962	 269.837962	 269.837962	 0.0	 0.0	 1	 -30.0	 30.0;
	5399	 711	 0.00224	 0.015018	 0.0	 240.856474	 240.856474	 240.856474	 0.0	 0.0	 1	 -30.0	 30.0;
	5399	 2895	 0.004111	 0.00652	 0.01292	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5399	 2895	 0.004191	 0.006391	 0.01318	 175.765831	 175.765831	 175.765831	 0.0	 0.0	 1	 -30.0	 30.0;
	6281	 4646	 0.00238	 0.006744	 0.05757	 100.396125	 100.396125	 100.396125	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 353	 0.003329	 0.033129	 0.00729	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1488	 7603	 0.005809	 0.021182	 0.08336	 117.174536	 117.174536	 117.174536	 0.0	 0.0	 1	 -30.0	 30.0;
	1488	 7603	 0.005689	 0.021591	 0.08166	 138.31846	 138.31846	 138.31846	 0.0	 0.0	 1	 -30.0	 30.0;
	7603	 2466	 0.00132	 0.01052	 0.31568	 139.044102	 139.044102	 139.044102	 0.0	 0.0	 1	 -30.0	 30.0;
	7603	 221	 0.001129	 0.012329	 0.26976	 126.158684	 126.158684	 126.158684	 0.0	 0.0	 1	 -30.0	 30.0;
	7603	 4016	 0.001569	 0.1224	 0.0	 212.493795	 212.493795	 212.493795	 0.0	 0.0	 1	 -30.0	 30.0;
	2838	 2330	 0.000662	 0.036351	 0.0	 469.587206	 469.587206	 469.587206	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 6711	 0.001777	 0.009107	 0.00205	 75.198926	 75.198926	 75.198926	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 1218	 0.002967	 0.002901	 0.03715	 72.285027	 72.285027	 72.285027	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 7514	 0.017893	 0.057479	 0.00824	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6711	 8063	 0.000554	 0.001091	 0.00842	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6711	 6864	 0.006339	 0.022603	 0.00218	 143.126252	 143.126252	 143.126252	 0.0	 0.0	 1	 -30.0	 30.0;
	1218	 324	 0.004174	 0.006702	 0.06492	 60.32002	 60.32002	 60.32002	 0.0	 0.0	 1	 -30.0	 30.0;
	324	 6864	 0.009818	 0.040099	 0.00793	 87.207754	 87.207754	 87.207754	 0.0	 0.0	 1	 -30.0	 30.0;
	250	 5737	 0.003729	 0.01876	 0.0117	 110.15973	 110.15973	 110.15973	 0.0	 0.0	 1	 -30.0	 30.0;
	5326	 6554	 0.000782	 0.059938	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7428	 5326	 0.000769	 0.061111	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 5909	 0.000382	 0.019378	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 348	 0.0	 0.000222	 0.0	 118.349126	 118.349126	 118.349126	 0.0	 0.0	 1	 -30.0	 30.0;
	1009	 6204	 1.8e-05	 0.00188	 0.0	 646.323939	 646.323939	 646.323939	 0.0	 0.0	 1	 -30.0	 30.0;
	7686	 5468	 0.000372	 0.001223	 0.00896	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8200	 5295	 0.000809	 0.001751	 0.06632	 167.703481	 167.703481	 167.703481	 0.0	 0.0	 1	 -30.0	 30.0;
	3066	 793	 0.0	 0.043511	 0.0	 144.540073	 144.540073	 144.540073	 0.0	 0.0	 1	 -30.0	 30.0;
	6753	 3066	 0.003529	 0.022178	 0.02205	 132.642962	 132.642962	 132.642962	 0.0	 0.0	 1	 -30.0	 30.0;
	6753	 3066	 0.0036	 0.021711	 0.02246	 173.189319	 173.189319	 173.189319	 0.0	 0.0	 1	 -30.0	 30.0;
	5792	 210	 0.0	 0.000413	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2030	 5792	 0.047479	 0.102603	 0.01748	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2030	 5792	 0.053727	 0.091281	 0.01976	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	919	 5792	 0.021678	 0.045669	 0.00626	 71.558744	 71.558744	 71.558744	 0.0	 0.0	 1	 -30.0	 30.0;
	2030	 8059	 0.004397	 0.030678	 0.00375	 67.918181	 67.918181	 67.918181	 0.0	 0.0	 1	 -30.0	 30.0;
	2030	 8059	 0.004314	 0.031256	 0.00367	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2030	 6456	 0.008347	 0.055512	 0.00715	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	2030	 2446	 0.006223	 0.039744	 0.00533	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	7503	 2030	 0.006124	 0.041686	 0.00522	 70.813408	 70.813408	 70.813408	 0.0	 0.0	 1	 -30.0	 30.0;
	7503	 2030	 0.006942	 0.040851	 0.00592	 74.32689	 74.32689	 74.32689	 0.0	 0.0	 1	 -30.0	 30.0;
	3696	 5249	 0.019248	 0.039041	 0.0181	 194.614268	 194.614268	 194.614268	 0.0	 0.0	 1	 -30.0	 30.0;
	6473	 3696	 0.015719	 0.04943	 0.00449	 72.954153	 72.954153	 72.954153	 0.0	 0.0	 1	 -30.0	 30.0;
	5037	 1098	 0.00296	 0.011871	 0.00357	 126.914724	 126.914724	 126.914724	 0.0	 0.0	 1	 -30.0	 30.0;
	5037	 8246	 0.01328	 0.04144	 0.01504	 135.902769	 135.902769	 135.902769	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 6475	 0.00736	 0.033222	 0.0115	 153.783508	 153.783508	 153.783508	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 6475	 0.007502	 0.032529	 0.01172	 137.150625	 137.150625	 137.150625	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 2489	 0.00192	 0.02576	 0.01769	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 2489	 0.002169	 0.02524	 0.02005	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 7697	 0.00656	 0.017071	 0.55531	 141.600869	 141.600869	 141.600869	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 2491	 0.002662	 0.007471	 0.2318	 170.461339	 170.461339	 170.461339	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 2925	 0.003191	 0.009062	 0.26848	 187.703732	 187.703732	 187.703732	 0.0	 0.0	 1	 -30.0	 30.0;
	6274	 7862	 0.00981	 0.057298	 0.00507	 65.353897	 65.353897	 65.353897	 0.0	 0.0	 1	 -30.0	 30.0;
	2890	 5767	 0.008342	 0.037031	 0.01238	 186.713085	 186.713085	 186.713085	 0.0	 0.0	 1	 -30.0	 30.0;
	1331	 5767	 0.0086	 0.039791	 0.00835	 228.77464	 228.77464	 228.77464	 0.0	 0.0	 1	 -30.0	 30.0;
	1541	 7459	 0.0	 0.00046	 0.0	 1861.130335	 1861.130335	 1861.130335	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 1541	 0.00055	 0.00685	 0.19546	 1649.116959	 1649.116959	 1649.116959	 0.0	 0.0	 1	 -30.0	 30.0;
	5685	 7459	 0.00054	 0.00699	 0.19138	 1670.444601	 1670.444601	 1670.444601	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 60	 0.0056	 0.052889	 0.02198	 242.180973	 242.180973	 242.180973	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 5396	 0.006058	 0.023591	 0.01851	 186.931843	 186.931843	 186.931843	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 5396	 0.0054	 0.026729	 0.01649	 127.299239	 127.299239	 127.299239	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 7810	 0.00168	 0.01188	 0.00681	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 8179	 0.003178	 0.028658	 0.00591	 223.781657	 223.781657	 223.781657	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 4718	 0.003178	 0.028542	 0.0116	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	1895	 5844	 0.00068	 0.004449	 0.08531	 233.413245	 233.413245	 233.413245	 0.0	 0.0	 1	 -30.0	 30.0;
	1895	 3145	 0.00076	 0.004818	 0.04133	 166.055521	 166.055521	 166.055521	 0.0	 0.0	 1	 -30.0	 30.0;
	2546	 1626	 0.0	 0.000222	 0.0	 108.55334	 108.55334	 108.55334	 0.0	 0.0	 1	 -30.0	 30.0;
	2546	 1488	 9e-06	 0.000222	 0.0	 199.629681	 199.629681	 199.629681	 0.0	 0.0	 1	 -30.0	 30.0;
	3628	 1488	 0.0	 0.000222	 0.0	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	6746	 1488	 1.8e-05	 0.004329	 0.73535	 137.76429	 137.76429	 137.76429	 0.0	 0.0	 1	 -30.0	 30.0;
	5488	 4791	 0.001831	 0.001698	 0.059	 198.526278	 198.526278	 198.526278	 0.0	 0.0	 1	 -30.0	 30.0;
	5488	 4791	 0.002209	 0.001471	 0.08081	 196.002766	 196.002766	 196.002766	 0.0	 0.0	 1	 -30.0	 30.0;
	190	 2564	 0.017653	 0.070289	 0.01037	 84.685576	 84.685576	 84.685576	 0.0	 0.0	 1	 -30.0	 30.0;
	3762	 2564	 0.013231	 0.042207	 0.00518	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3762	 2564	 0.013479	 0.041331	 0.00528	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2540	 2564	 0.013934	 0.055702	 0.02244	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3840	 5471	 0.000537	 0.001471	 0.0166	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5471	 4434	 0.009967	 0.048959	 0.00979	 66.715202	 66.715202	 66.715202	 0.0	 0.0	 1	 -30.0	 30.0;
	5471	 8298	 0.030612	 0.055058	 0.00594	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5471	 8298	 0.031207	 0.053934	 0.00605	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5498	 5471	 0.01314	 0.040579	 0.00386	 71.278481	 71.278481	 71.278481	 0.0	 0.0	 1	 -30.0	 30.0;
	5498	 5471	 0.012851	 0.03757	 0.00378	 97.481655	 97.481655	 97.481655	 0.0	 0.0	 1	 -30.0	 30.0;
	5471	 6358	 0.006901	 0.021174	 0.00202	 58.986151	 58.986151	 58.986151	 0.0	 0.0	 1	 -30.0	 30.0;
	5471	 6358	 0.007653	 0.01924	 0.00224	 58.209187	 58.209187	 58.209187	 0.0	 0.0	 1	 -30.0	 30.0;
	6613	 5081	 0.008982	 0.038462	 0.01685	 108.275346	 108.275346	 108.275346	 0.0	 0.0	 1	 -30.0	 30.0;
	5081	 6615	 0.009151	 0.037649	 0.01717	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5081	 929	 0.004258	 0.03952	 0.0266	 251.414016	 251.414016	 251.414016	 0.0	 0.0	 1	 -30.0	 30.0;
	2372	 5081	 0.003489	 0.0264	 0.02172	 179.344941	 179.344941	 179.344941	 0.0	 0.0	 1	 -30.0	 30.0;
	5081	 2095	 0.003849	 0.05232	 0.02447	 180.254008	 180.254008	 180.254008	 0.0	 0.0	 1	 -30.0	 30.0;
	1816	 3736	 0.032669	 0.080273	 0.00701	 132.894075	 132.894075	 132.894075	 0.0	 0.0	 1	 -30.0	 30.0;
	1728	 3736	 0.004901	 0.014967	 0.11843	 140.194063	 140.194063	 140.194063	 0.0	 0.0	 1	 -30.0	 30.0;
	284	 5249	 0.000562	 0.001058	 0.00858	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7605	 123	 0.0	 0.00045	 0.0	 1548.455674	 1548.455674	 1548.455674	 0.0	 0.0	 1	 -30.0	 30.0;
	7605	 7490	 0.001	 0.01169	 0.35326	 1489.064206	 1489.064206	 1489.064206	 0.0	 0.0	 1	 -30.0	 30.0;
	123	 7442	 0.00098	 0.01192	 0.34605	 1462.15257	 1462.15257	 1462.15257	 0.0	 0.0	 1	 -30.0	 30.0;
	5985	 6864	 0.002339	 0.006223	 0.00074	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5985	 6864	 0.002388	 0.006091	 0.00076	 69.458961	 69.458961	 69.458961	 0.0	 0.0	 1	 -30.0	 30.0;
	2313	 5985	 0.000504	 0.001207	 0.00764	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 6864	 0.00105	 0.007959	 0.00218	 247.971531	 247.971531	 247.971531	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 6864	 0.001033	 0.007372	 0.00213	 267.488781	 267.488781	 267.488781	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 2400	 0.018752	 0.042339	 0.01616	 75.353061	 75.353061	 75.353061	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 2400	 0.018339	 0.039231	 0.01581	 81.494082	 81.494082	 81.494082	 0.0	 0.0	 1	 -30.0	 30.0;
	1816	 6281	 0.036793	 0.081719	 0.00902	 59.071316	 59.071316	 59.071316	 0.0	 0.0	 1	 -30.0	 30.0;
	1816	 7686	 0.003702	 0.015132	 0.00313	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 1816	 0.00124	 0.007314	 0.1597	 226.353164	 226.353164	 226.353164	 0.0	 0.0	 1	 -30.0	 30.0;
	474	 5227	 0.002329	 0.00356	 0.13896	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	474	 5227	 0.002378	 0.00348	 0.14154	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	474	 5227	 0.00212	 0.003951	 0.1261	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	474	 6779	 0.001951	 0.003791	 0.11738	 375.690654	 375.690654	 375.690654	 0.0	 0.0	 1	 -30.0	 30.0;
	60	 7123	 0.002542	 0.01472	 0.0	 149.022534	 149.022534	 149.022534	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 4854	 0.003262	 0.024151	 0.02014	 129.335871	 129.335871	 129.335871	 0.0	 0.0	 1	 -30.0	 30.0;
	8355	 4326	 0.0036	 0.01548	 0.00517	 265.621336	 265.621336	 265.621336	 0.0	 0.0	 1	 -30.0	 30.0;
	8355	 4326	 0.00352	 0.014329	 0.00506	 263.178625	 263.178625	 263.178625	 0.0	 0.0	 1	 -30.0	 30.0;
	1721	 3988	 0.002591	 0.014418	 0.0	 169.449648	 169.449648	 169.449648	 0.0	 0.0	 1	 -30.0	 30.0;
	3209	 1721	 0.001071	 0.003058	 0.00107	 163.590727	 163.590727	 163.590727	 0.0	 0.0	 1	 -30.0	 30.0;
	3209	 4260	 9.8e-05	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3209	 1211	 0.017458	 0.052129	 0.01724	 170.560326	 170.560326	 170.560326	 0.0	 0.0	 1	 -30.0	 30.0;
	6613	 7650	 0.00136	 0.00216	 0.02863	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6615	 7650	 0.001391	 0.00212	 0.02919	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5806	 8246	 0.005858	 0.016591	 0.01086	 115.50787	 115.50787	 115.50787	 0.0	 0.0	 1	 -30.0	 30.0;
	811	 7862	 0.004562	 0.011653	 0.0085	 94.437247	 94.437247	 94.437247	 0.0	 0.0	 1	 -30.0	 30.0;
	811	 5919	 0.030868	 0.064174	 0.0067	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2962	 332	 0.0	 0.000521	 0.0	 305.213229	 305.213229	 305.213229	 0.0	 0.0	 1	 -30.0	 30.0;
	2162	 929	 0.005929	 0.053271	 0.04301	 118.389397	 118.389397	 118.389397	 0.0	 0.0	 1	 -30.0	 30.0;
	2162	 270	 0.00664	 0.040849	 0.0142	 122.309374	 122.309374	 122.309374	 0.0	 0.0	 1	 -30.0	 30.0;
	2162	 2895	 0.00968	 0.049382	 0.02356	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 4264	 9.8e-05	 0.000222	 1.0	 161.053185	 161.053185	 161.053185	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 60	 0.00044	 0.004489	 0.00109	 133.1592	 133.1592	 133.1592	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 3550	 0.01064	 0.043751	 0.01106	 110.785087	 110.785087	 110.785087	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 3550	 0.0104	 0.040511	 0.01082	 124.006697	 124.006697	 124.006697	 0.0	 0.0	 1	 -30.0	 30.0;
	4718	 5289	 0.0024	 0.025498	 0.00897	 130.386793	 130.386793	 130.386793	 0.0	 0.0	 1	 -30.0	 30.0;
	3890	 1096	 0.00264	 0.01412	 0.0	 106.924866	 106.924866	 106.924866	 0.0	 0.0	 1	 -30.0	 30.0;
	426	 5563	 0.000609	 0.03944	 0.0	 672.053467	 672.053467	 672.053467	 0.0	 0.0	 1	 -30.0	 30.0;
	7766	 426	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	426	 5227	 0.001182	 0.003018	 0.0975	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	426	 5227	 0.0012	 0.002951	 0.09931	 303.24148	 303.24148	 303.24148	 0.0	 0.0	 1	 -30.0	 30.0;
	426	 5227	 0.001071	 0.003351	 0.08847	 292.202254	 292.202254	 292.202254	 0.0	 0.0	 1	 -30.0	 30.0;
	426	 6416	 0.001031	 0.01544	 0.30937	 172.067989	 172.067989	 172.067989	 0.0	 0.0	 1	 -30.0	 30.0;
	426	 314	 0.001009	 0.015738	 0.30292	 208.748149	 208.748149	 208.748149	 0.0	 0.0	 1	 -30.0	 30.0;
	426	 6491	 0.000991	 0.01604	 0.29648	 239.094718	 239.094718	 239.094718	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 6622	 0.003898	 0.008862	 0.30829	 256.984811	 256.984811	 256.984811	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 6622	 0.003818	 0.009031	 0.30187	 259.416611	 259.416611	 259.416611	 0.0	 0.0	 1	 -30.0	 30.0;
	582	 283	 0.003831	 0.012502	 0.00417	 112.187529	 112.187529	 112.187529	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 5685	 0.0	 0.00051	 0.0	 870.344065	 870.344065	 870.344065	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 5685	 0.00127	 0.0132	 0.46307	 1505.978756	 1505.978756	 1505.978756	 0.0	 0.0	 1	 -30.0	 30.0;
	6753	 2066	 0.0	 0.000222	 0.0	 309.919835	 309.919835	 309.919835	 0.0	 0.0	 1	 -30.0	 30.0;
	6753	 6955	 0.001338	 0.011209	 0.29817	 153.691796	 153.691796	 153.691796	 0.0	 0.0	 1	 -30.0	 30.0;
	6753	 6364	 0.004222	 0.030062	 0.11194	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7970	 6753	 0.001182	 0.0104	 0.16346	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2066	 3500	 9e-06	 0.000222	 0.0	 149.598527	 149.598527	 149.598527	 0.0	 0.0	 1	 -30.0	 30.0;
	2066	 6364	 0.004138	 0.03064	 0.1096	 119.619846	 119.619846	 119.619846	 0.0	 0.0	 1	 -30.0	 30.0;
	3500	 6364	 0.004049	 0.031209	 0.10727	 120.796254	 120.796254	 120.796254	 0.0	 0.0	 1	 -30.0	 30.0;
	664	 4923	 0.022603	 0.051959	 0.03419	 66.547349	 66.547349	 66.547349	 0.0	 0.0	 1	 -30.0	 30.0;
	4196	 664	 0.013636	 0.032041	 0.09351	 141.959283	 141.959283	 141.959283	 0.0	 0.0	 1	 -30.0	 30.0;
	7697	 2926	 0.00228	 0.009222	 0.08473	 136.488635	 136.488635	 136.488635	 0.0	 0.0	 1	 -30.0	 30.0;
	2491	 2926	 0.002471	 0.010302	 0.0312	 278.20304	 278.20304	 278.20304	 0.0	 0.0	 1	 -30.0	 30.0;
	2925	 2926	 0.001831	 0.007378	 0.00439	 273.315279	 273.315279	 273.315279	 0.0	 0.0	 1	 -30.0	 30.0;
	8059	 3918	 0.006843	 0.049248	 0.00586	 70.366244	 70.366244	 70.366244	 0.0	 0.0	 1	 -30.0	 30.0;
	8059	 3918	 0.006686	 0.045603	 0.00573	 63.192384	 63.192384	 63.192384	 0.0	 0.0	 1	 -30.0	 30.0;
	2502	 7271	 0.004102	 0.011529	 0.1196	 131.716488	 131.716488	 131.716488	 0.0	 0.0	 1	 -30.0	 30.0;
	2502	 7271	 0.004182	 0.01128	 0.12181	 110.269109	 110.269109	 110.269109	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 1933	 0.0	 0.000222	 0.0	 130.275335	 130.275335	 130.275335	 0.0	 0.0	 1	 -30.0	 30.0;
	7390	 1750	 0.003649	 0.0122	 0.04313	 130.123868	 130.123868	 130.123868	 0.0	 0.0	 1	 -30.0	 30.0;
	7390	 1750	 0.00372	 0.011938	 0.04395	 151.865609	 151.865609	 151.865609	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 6431	 0.005031	 0.028102	 0.17151	 144.201803	 144.201803	 144.201803	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 6431	 0.005129	 0.02752	 0.17488	 154.865347	 154.865347	 154.865347	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 7116	 0.005218	 0.026951	 0.17824	 134.189077	 134.189077	 134.189077	 0.0	 0.0	 1	 -30.0	 30.0;
	4019	 3145	 0.00288	 0.01992	 0.12609	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4019	 3145	 0.003262	 0.01952	 0.1429	 105.864591	 105.864591	 105.864591	 0.0	 0.0	 1	 -30.0	 30.0;
	7926	 1009	 0.00956	 0.061022	 0.0234	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7926	 2502	 0.005382	 0.033911	 0.01853	 137.307548	 137.307548	 137.307548	 0.0	 0.0	 1	 -30.0	 30.0;
	7926	 2502	 0.005271	 0.034569	 0.01814	 136.442649	 136.442649	 136.442649	 0.0	 0.0	 1	 -30.0	 30.0;
	7926	 5642	 0.004102	 0.023018	 0.01105	 129.118672	 129.118672	 129.118672	 0.0	 0.0	 1	 -30.0	 30.0;
	1636	 7801	 0.0	 0.00052	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 2122	 0.0	 0.000222	 0.0	 489.728792	 489.728792	 489.728792	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 2895	 0.011631	 0.094591	 0.06991	 110.642193	 110.642193	 110.642193	 0.0	 0.0	 1	 -30.0	 30.0;
	2372	 929	 0.0012	 0.008769	 0.0075	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 8237	 0.001218	 0.008582	 0.00763	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	6475	 6882	 0.002689	 0.013818	 0.0	 233.079392	 233.079392	 233.079392	 0.0	 0.0	 1	 -30.0	 30.0;
	2400	 7514	 0.005	 0.008934	 0.16375	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2557	 124	 0.0	 0.000531	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2557	 4825	 0.001281	 0.0158	 0.05906	 251.837104	 251.837104	 251.837104	 0.0	 0.0	 1	 -30.0	 30.0;
	124	 3543	 0.00125	 0.016099	 0.0578	 302.29552	 302.29552	 302.29552	 0.0	 0.0	 1	 -30.0	 30.0;
	190	 5919	 0.010058	 0.048	 0.00633	 75.423174	 75.423174	 75.423174	 0.0	 0.0	 1	 -30.0	 30.0;
	190	 5919	 0.010248	 0.047	 0.00646	 75.252463	 75.252463	 75.252463	 0.0	 0.0	 1	 -30.0	 30.0;
	190	 2540	 0.004314	 0.024537	 0.01472	 77.119995	 77.119995	 77.119995	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 3000	 0.010791	 0.042151	 0.0122	 302.138856	 302.138856	 302.138856	 0.0	 0.0	 1	 -30.0	 30.0;
	310	 920	 0.0006	 0.040218	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	221	 7818	 0.0	 0.000222	 0.0	 253.399986	 253.399986	 253.399986	 0.0	 0.0	 1	 -30.0	 30.0;
	2921	 5150	 0.0	 0.00053	 0.0	 1713.291416	 1713.291416	 1713.291416	 0.0	 0.0	 1	 -30.0	 30.0;
	2921	 3949	 0.0	 0.00054	 0.0	 1280.889331	 1280.889331	 1280.889331	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 7435	 0.00196	 0.010249	 0.00356	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 1381	 0.002182	 0.010498	 0.00348	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 5878	 0.000582	 0.040991	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 5132	 0.000569	 0.04176	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1331	 2890	 0.003818	 0.013209	 0.00468	 258.743449	 258.743449	 258.743449	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 5737	 0.00428	 0.023511	 0.01299	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 5737	 0.004182	 0.021769	 0.01271	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1787	 4421	 0.0	 0.0005	 0.0	 1114.05404	 1114.05404	 1114.05404	 0.0	 0.0	 1	 -30.0	 30.0;
	1787	 7490	 0.00114	 0.01661	 0.77742	 1510.869686	 1510.869686	 1510.869686	 0.0	 0.0	 1	 -30.0	 30.0;
	3932	 3869	 0.0	 0.000539	 0.0	 325.943556	 325.943556	 325.943556	 0.0	 0.0	 1	 -30.0	 30.0;
	3932	 66	 0.00119	 0.014081	 0.07275	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4421	 7442	 0.00117	 0.01626	 0.79237	 1716.579021	 1716.579021	 1716.579021	 0.0	 0.0	 1	 -30.0	 30.0;
	3869	 33	 0.00106	 0.01595	 0.06482	 243.303463	 243.303463	 243.303463	 0.0	 0.0	 1	 -30.0	 30.0;
	3918	 908	 0.018058	 0.065719	 0.00603	 116.884781	 116.884781	 116.884781	 0.0	 0.0	 1	 -30.0	 30.0;
	3918	 919	 0.012826	 0.025058	 0.00285	 78.962949	 78.962949	 78.962949	 0.0	 0.0	 1	 -30.0	 30.0;
	3918	 919	 0.013331	 0.024	 0.00296	 81.512944	 81.512944	 81.512944	 0.0	 0.0	 1	 -30.0	 30.0;
	7435	 1381	 0.001089	 0.003151	 0.00139	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5256	 2204	 9.8e-05	 0.000222	 1.0	 142.701155	 142.701155	 142.701155	 0.0	 0.0	 1	 -30.0	 30.0;
	310	 1162	 0.000631	 0.054471	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	310	 1931	 0.000622	 0.055489	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	310	 8076	 0.0006	 0.051382	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3762	 5919	 0.017702	 0.064331	 0.00483	 78.984669	 78.984669	 78.984669	 0.0	 0.0	 1	 -30.0	 30.0;
	3762	 1635	 0.012314	 0.04924	 0.00533	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2118	 7595	 0.001223	 0.001248	 0.00012	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4810	 7595	 0.001471	 0.00481	 0.00054	 72.03601	 72.03601	 72.03601	 0.0	 0.0	 1	 -30.0	 30.0;
	908	 7595	 0.011521	 0.03138	 0.00354	 107.059186	 107.059186	 107.059186	 0.0	 0.0	 1	 -30.0	 30.0;
	8200	 7182	 0.0	 0.000222	 0.0	 113.042816	 113.042816	 113.042816	 0.0	 0.0	 1	 -30.0	 30.0;
	8200	 5578	 0.000289	 0.00056	 0.02429	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3616	 3062	 0.00034	 0.01805	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6783	 2466	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1959	 6064	 0.00035	 0.01766	 0.0	 1055.264806	 1055.264806	 1055.264806	 0.0	 0.0	 1	 -30.0	 30.0;
	8131	 3834	 0.00035	 0.01728	 0.0	 1079.404191	 1079.404191	 1079.404191	 0.0	 0.0	 1	 -30.0	 30.0;
	4608	 7540	 0.00031	 0.01958	 0.0	 1882.035426	 1882.035426	 1882.035426	 0.0	 0.0	 1	 -30.0	 30.0;
	6591	 3062	 0.00031	 0.01997	 0.0	 870.210454	 870.210454	 870.210454	 0.0	 0.0	 1	 -30.0	 30.0;
	5826	 3062	 0.0003	 0.02035	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5342	 7454	 0.00016	 0.0025	 1.39792	 1037.565048	 1037.565048	 1037.565048	 0.0	 0.0	 1	 -30.0	 30.0;
	4343	 3062	 0.00029	 0.02074	 0.0	 1130.577632	 1130.577632	 1130.577632	 0.0	 0.0	 1	 -30.0	 30.0;
	1212	 7540	 0.00029	 0.0192	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7689	 7540	 0.00033	 0.01882	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6064	 3834	 0.0	 0.00049	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4304	 6064	 0.0	 0.00048	 0.0	 1310.015082	 1310.015082	 1310.015082	 0.0	 0.0	 1	 -30.0	 30.0;
	7127	 3834	 0.0	 0.00047	 0.0	 1392.405967	 1392.405967	 1392.405967	 0.0	 0.0	 1	 -30.0	 30.0;
	3062	 5350	 0.0	 0.00046	 0.0	 1358.295825	 1358.295825	 1358.295825	 0.0	 0.0	 1	 -30.0	 30.0;
	3062	 378	 0.0	 0.00045	 0.0	 1117.242919	 1117.242919	 1117.242919	 0.0	 0.0	 1	 -30.0	 30.0;
	3062	 8078	 0.0	 0.00051	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7540	 7127	 0.0	 0.00052	 0.0	 1005.396535	 1005.396535	 1005.396535	 0.0	 0.0	 1	 -30.0	 30.0;
	7540	 4304	 0.0	 0.00053	 0.0	 936.681957	 936.681957	 936.681957	 0.0	 0.0	 1	 -30.0	 30.0;
	7540	 8078	 0.0	 0.00054	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	5350	 3721	 0.0	 0.0005	 0.0	 1461.331162	 1461.331162	 1461.331162	 0.0	 0.0	 1	 -30.0	 30.0;
	3721	 7127	 0.0	 0.00049	 0.0	 1869.726815	 1869.726815	 1869.726815	 0.0	 0.0	 1	 -30.0	 30.0;
	3721	 3713	 0.00028	 0.00403	 0.19536	 1402.9138	 1402.9138	 1402.9138	 0.0	 0.0	 1	 -30.0	 30.0;
	5700	 3721	 0.00021	 0.00396	 0.33171	 1798.377546	 1798.377546	 1798.377546	 0.0	 0.0	 1	 -30.0	 30.0;
	378	 2656	 0.0	 0.00048	 0.0	 1134.825521	 1134.825521	 1134.825521	 0.0	 0.0	 1	 -30.0	 30.0;
	2656	 4304	 0.0	 0.00047	 0.0	 1258.250595	 1258.250595	 1258.250595	 0.0	 0.0	 1	 -30.0	 30.0;
	2656	 5342	 0.00029	 0.00394	 0.19898	 977.352831	 977.352831	 977.352831	 0.0	 0.0	 1	 -30.0	 30.0;
	4081	 2656	 0.0002	 0.00404	 0.32465	 1771.321111	 1771.321111	 1771.321111	 0.0	 0.0	 1	 -30.0	 30.0;
	2466	 221	 0.0	 0.000222	 0.0	 115.435124	 115.435124	 115.435124	 0.0	 0.0	 1	 -30.0	 30.0;
	221	 503	 0.0	 0.000222	 0.0	 120.065935	 120.065935	 120.065935	 0.0	 0.0	 1	 -30.0	 30.0;
	7697	 2491	 0.004471	 0.020791	 0.10896	 121.848735	 121.848735	 121.848735	 0.0	 0.0	 1	 -30.0	 30.0;
	7697	 2925	 0.002791	 0.01132	 0.09985	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5227	 7604	 0.000822	 0.001649	 0.04877	 221.546532	 221.546532	 221.546532	 0.0	 0.0	 1	 -30.0	 30.0;
	5227	 7604	 0.0008	 0.00168	 0.04773	 216.064591	 216.064591	 216.064591	 0.0	 0.0	 1	 -30.0	 30.0;
	5227	 7604	 0.000782	 0.00156	 0.04669	 227.85648	 227.85648	 227.85648	 0.0	 0.0	 1	 -30.0	 30.0;
	333	 283	 0.00432	 0.012662	 0.00518	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	333	 283	 0.003849	 0.014351	 0.00462	 145.358467	 145.358467	 145.358467	 0.0	 0.0	 1	 -30.0	 30.0;
	1009	 2310	 0.001418	 0.004618	 0.11025	 148.924586	 148.924586	 148.924586	 0.0	 0.0	 1	 -30.0	 30.0;
	1009	 6596	 0.001689	 0.011631	 0.00607	 113.947985	 113.947985	 113.947985	 0.0	 0.0	 1	 -30.0	 30.0;
	1009	 5642	 0.005991	 0.03832	 0.01384	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8355	 1770	 0.001169	 0.007098	 0.1704	 407.092042	 407.092042	 407.092042	 0.0	 0.0	 1	 -30.0	 30.0;
	6779	 1770	 0.0012	 0.00696	 0.17374	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	4021	 8298	 0.030066	 0.046289	 0.00582	 74.512462	 74.512462	 74.512462	 0.0	 0.0	 1	 -30.0	 30.0;
	4021	 8298	 0.026793	 0.052463	 0.00518	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7012	 4021	 0.023413	 0.057397	 0.03766	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5077	 4872	 0.001631	 0.00832	 0.00405	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5488	 4035	 0.012569	 0.04732	 0.01476	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5488	 4035	 0.012311	 0.048231	 0.01445	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7272	 5913	 0.0	 0.000222	 0.0	 113.078669	 113.078669	 113.078669	 0.0	 0.0	 1	 -30.0	 30.0;
	6364	 7272	 0.000982	 0.004751	 0.17983	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2694	 1145	 0.00144	 0.12	 0.0	 104.359265	 104.359265	 104.359265	 0.0	 0.0	 1	 -30.0	 30.0;
	310	 4872	 0.001249	 0.0064	 0.00311	 148.979925	 148.979925	 148.979925	 0.0	 0.0	 1	 -30.0	 30.0;
	310	 4872	 0.00112	 0.007249	 0.00277	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 3543	 0.0	 0.0005	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8354	 7862	 0.022843	 0.098893	 0.01078	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7862	 5919	 0.034909	 0.072893	 0.00815	 58.24653	 58.24653	 58.24653	 0.0	 0.0	 1	 -30.0	 30.0;
	6955	 338	 0.00188	 0.092222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6955	 1115	 0.00184	 0.093991	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6955	 3649	 0.0018	 0.09576	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5326	 6955	 0.00132	 0.01088	 0.29214	 135.075021	 135.075021	 135.075021	 0.0	 0.0	 1	 -30.0	 30.0;
	5498	 1728	 0.01924	 0.056603	 0.00692	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5498	 1728	 0.017124	 0.064149	 0.00616	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3890	 6119	 9.8e-05	 0.000222	 1.5	 247.83023	 247.83023	 247.83023	 0.0	 0.0	 1	 -30.0	 30.0;
	3890	 758	 0.006889	 0.03404	 0.15314	 174.407817	 174.407817	 174.407817	 0.0	 0.0	 1	 -30.0	 30.0;
	3890	 758	 0.007018	 0.033329	 0.15608	 129.478246	 129.478246	 129.478246	 0.0	 0.0	 1	 -30.0	 30.0;
	3890	 7214	 0.006169	 0.035689	 0.01503	 175.265442	 175.265442	 175.265442	 0.0	 0.0	 1	 -30.0	 30.0;
	3890	 7214	 0.00628	 0.034929	 0.01531	 153.896265	 153.896265	 153.896265	 0.0	 0.0	 1	 -30.0	 30.0;
	3890	 7977	 0.004271	 0.026418	 0.01015	 160.753108	 160.753108	 160.753108	 0.0	 0.0	 1	 -30.0	 30.0;
	3890	 7977	 0.00436	 0.02588	 0.01035	 151.461608	 151.461608	 151.461608	 0.0	 0.0	 1	 -30.0	 30.0;
	3890	 7977	 0.00444	 0.025338	 0.01055	 181.126442	 181.126442	 181.126442	 0.0	 0.0	 1	 -30.0	 30.0;
	3550	 1211	 0.00852	 0.02444	 0.00838	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7810	 44	 0.002671	 0.018929	 0.01139	 218.588103	 218.588103	 218.588103	 0.0	 0.0	 1	 -30.0	 30.0;
	599	 3044	 0.0	 0.00046	 0.0	 1615.181234	 1615.181234	 1615.181234	 0.0	 0.0	 1	 -30.0	 30.0;
	599	 6137	 0.0	 0.00045	 0.0	 1513.237815	 1513.237815	 1513.237815	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 3044	 0.0	 0.00051	 0.0	 1195.498464	 1195.498464	 1195.498464	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 6137	 0.0	 0.00052	 0.0	 1394.418021	 1394.418021	 1394.418021	 0.0	 0.0	 1	 -30.0	 30.0;
	2310	 6596	 0.000329	 0.000902	 0.02604	 133.37562	 133.37562	 133.37562	 0.0	 0.0	 1	 -30.0	 30.0;
	7977	 3376	 0.00068	 0.050351	 0.0	 120.947462	 120.947462	 120.947462	 0.0	 0.0	 1	 -30.0	 30.0;
	3078	 758	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 2284	 0.0	 0.00049	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 959	 0.00212	 0.022531	 0.08223	 558.121849	 558.121849	 558.121849	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 66	 0.000919	 0.012789	 0.0563	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2284	 3530	 0.002159	 0.02206	 0.08381	 438.808248	 438.808248	 438.808248	 0.0	 0.0	 1	 -30.0	 30.0;
	2284	 33	 0.00094	 0.012531	 0.05741	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	174	 6364	 0.00032	 0.014102	 0.0	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	4409	 6364	 0.000329	 0.0138	 0.0	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	3358	 6364	 0.000329	 0.013502	 0.0	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	5737	 487	 0.005818	 0.02396	 0.01614	 155.963814	 155.963814	 155.963814	 0.0	 0.0	 1	 -30.0	 30.0;
	5737	 487	 0.005942	 0.023462	 0.01645	 127.728441	 127.728441	 127.728441	 0.0	 0.0	 1	 -30.0	 30.0;
	5326	 6083	 0.000671	 0.001871	 0.07215	 267.429338	 267.429338	 267.429338	 0.0	 0.0	 1	 -30.0	 30.0;
	4426	 6083	 0.0	 0.001791	 0.0	 155.166205	 155.166205	 155.166205	 0.0	 0.0	 1	 -30.0	 30.0;
	5326	 3189	 0.002249	 0.003471	 0.09006	 224.441049	 224.441049	 224.441049	 0.0	 0.0	 1	 -30.0	 30.0;
	5326	 3189	 0.001631	 0.0042	 0.0777	 195.697493	 195.697493	 195.697493	 0.0	 0.0	 1	 -30.0	 30.0;
	5326	 3438	 0.00092	 0.002582	 0.10491	 184.633065	 184.633065	 184.633065	 0.0	 0.0	 1	 -30.0	 30.0;
	6364	 3189	 0.0	 0.000222	 0.0	 587.159508	 587.159508	 587.159508	 0.0	 0.0	 1	 -30.0	 30.0;
	6364	 5421	 9.8e-05	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7970	 6364	 0.000822	 0.00572	 0.10682	 158.482909	 158.482909	 158.482909	 0.0	 0.0	 1	 -30.0	 30.0;
	6364	 4154	 0.001338	 0.013622	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7310	 6364	 0.00136	 0.004649	 0.21168	 251.24696	 251.24696	 251.24696	 0.0	 0.0	 1	 -30.0	 30.0;
	3189	 4426	 0.0	 0.001751	 0.0	 217.825308	 217.825308	 217.825308	 0.0	 0.0	 1	 -30.0	 30.0;
	3438	 3189	 0.0	 0.001711	 0.0	 184.633585	 184.633585	 184.633585	 0.0	 0.0	 1	 -30.0	 30.0;
	3717	 5844	 0.000662	 0.004529	 0.00945	 283.044555	 283.044555	 283.044555	 0.0	 0.0	 1	 -30.0	 30.0;
	4768	 5844	 0.000649	 0.004618	 0.00925	 235.994174	 235.994174	 235.994174	 0.0	 0.0	 1	 -30.0	 30.0;
	5919	 1635	 0.005669	 0.028992	 0.00286	 74.817684	 74.817684	 74.817684	 0.0	 0.0	 1	 -30.0	 30.0;
	4198	 6582	 0.001631	 0.1176	 0.0	 127.505526	 127.505526	 127.505526	 0.0	 0.0	 1	 -30.0	 30.0;
	1110	 7252	 9.8e-05	 0.000222	 1.1	 143.42316	 143.42316	 143.42316	 0.0	 0.0	 1	 -30.0	 30.0;
	310	 1110	 0.006942	 0.04516	 0.01725	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	310	 1110	 0.0068	 0.04604	 0.0169	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7728	 2446	 0.003289	 0.017909	 0.00282	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	2925	 6714	 0.00056	 0.038671	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4259	 7012	 0.02162	 0.062612	 0.00741	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 2259	 9.8e-05	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 8179	 0.000822	 0.00656	 0.00312	 147.473041	 147.473041	 147.473041	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 839	 0.003009	 0.004649	 0.17188	 281.091841	 281.091841	 281.091841	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 839	 0.003071	 0.004551	 0.17506	 286.565468	 286.565468	 286.565468	 0.0	 0.0	 1	 -30.0	 30.0;
	6335	 4105	 0.00464	 0.029431	 0.02262	 108.443701	 108.443701	 108.443701	 0.0	 0.0	 1	 -30.0	 30.0;
	6335	 4105	 0.005249	 0.02884	 0.02563	 147.102815	 147.102815	 147.102815	 0.0	 0.0	 1	 -30.0	 30.0;
	2838	 5488	 0.001902	 0.012702	 0.00812	 129.95837	 129.95837	 129.95837	 0.0	 0.0	 1	 -30.0	 30.0;
	2838	 5488	 0.001858	 0.012938	 0.00795	 129.216879	 129.216879	 129.216879	 0.0	 0.0	 1	 -30.0	 30.0;
	2838	 6951	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 4937	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5694	 3476	 9.8e-05	 0.000222	 0.7	 132.642962	 132.642962	 132.642962	 0.0	 0.0	 1	 -30.0	 30.0;
	310	 5459	 9.8e-05	 0.000222	 0.5	 120.10023	 120.10023	 120.10023	 0.0	 0.0	 1	 -30.0	 30.0;
	8246	 903	 9.8e-05	 0.000222	 0.5	 122.853411	 122.853411	 122.853411	 0.0	 0.0	 1	 -30.0	 30.0;
	8355	 2882	 9.8e-05	 0.000222	 1.5	 264.071844	 264.071844	 264.071844	 0.0	 0.0	 1	 -30.0	 30.0;
	8355	 758	 0.004738	 0.012529	 0.18966	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8355	 758	 0.004831	 0.012262	 0.19323	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	8355	 758	 0.002711	 0.018431	 0.3923	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4923	 8370	 0.01205	 0.03281	 0.04818	 105.364842	 105.364842	 105.364842	 0.0	 0.0	 1	 -30.0	 30.0;
	3010	 758	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	758	 7057	 0.000649	 0.03712	 0.0	 393.895374	 393.895374	 393.895374	 0.0	 0.0	 1	 -30.0	 30.0;
	758	 4073	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5734	 758	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4341	 3294	 0.00076	 0.005329	 0.00191	 225.127461	 225.127461	 225.127461	 0.0	 0.0	 1	 -30.0	 30.0;
	2895	 270	 0.005769	 0.03528	 0.01485	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6779	 1330	 0.002258	 0.004849	 0.13383	 254.168237	 254.168237	 254.168237	 0.0	 0.0	 1	 -30.0	 30.0;
	6779	 1330	 0.002209	 0.004489	 0.13092	 261.243058	 261.243058	 261.243058	 0.0	 0.0	 1	 -30.0	 30.0;
	959	 3530	 0.0	 0.000479	 0.0	 250.392158	 250.392158	 250.392158	 0.0	 0.0	 1	 -30.0	 30.0;
	959	 5875	 0.00256	 0.01561	 0.03976	 548.981194	 548.981194	 548.981194	 0.0	 0.0	 1	 -30.0	 30.0;
	3530	 4809	 0.00269	 0.01451	 0.04169	 599.588601	 599.588601	 599.588601	 0.0	 0.0	 1	 -30.0	 30.0;
	7503	 5341	 0.003372	 0.028231	 0.00994	 74.803395	 74.803395	 74.803395	 0.0	 0.0	 1	 -30.0	 30.0;
	7503	 8281	 0.007033	 0.047083	 0.01412	 58.867453	 58.867453	 58.867453	 0.0	 0.0	 1	 -30.0	 30.0;
	66	 33	 0.0	 0.000469	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2895	 1811	 9.8e-05	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2502	 2895	 0.00392	 0.025191	 0.00916	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2502	 2895	 0.00444	 0.024689	 0.01038	 138.02072	 138.02072	 138.02072	 0.0	 0.0	 1	 -30.0	 30.0;
	8281	 5341	 0.003529	 0.021223	 0.00341	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3717	 4768	 0.0	 0.000222	 0.0	 131.836779	 131.836779	 131.836779	 0.0	 0.0	 1	 -30.0	 30.0;
	4081	 356	 0.00069	 0.00134	 0.04183	 1499.755012	 1499.755012	 1499.755012	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 5700	 0.00067	 0.00136	 0.04097	 1459.887117	 1459.887117	 1459.887117	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 7686	 0.012992	 0.070207	 0.01089	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	356	 5301	 0.0	 0.00053	 0.0	 849.593646	 849.593646	 849.593646	 0.0	 0.0	 1	 -30.0	 30.0;
	5875	 4809	 0.0	 0.000461	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7490	 7442	 0.0	 0.00054	 0.0	 810.24637	 810.24637	 810.24637	 0.0	 0.0	 1	 -30.0	 30.0;
	6358	 4196	 0.002314	 0.005661	 0.09084	 152.355121	 152.355121	 152.355121	 0.0	 0.0	 1	 -30.0	 30.0;
	4196	 6358	 0.002512	 0.005909	 0.04977	 125.833387	 125.833387	 125.833387	 0.0	 0.0	 1	 -30.0	 30.0;
	5498	 6358	 0.006364	 0.018488	 0.00183	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	5498	 6358	 0.005959	 0.017752	 0.00172	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	5498	 8370	 0.018397	 0.04176	 0.00514	 133.952064	 133.952064	 133.952064	 0.0	 0.0	 1	 -30.0	 30.0;
	5498	 8370	 0.018058	 0.042653	 0.00505	 149.306711	 149.306711	 149.306711	 0.0	 0.0	 1	 -30.0	 30.0;
	6431	 7116	 0.0	 0.000222	 0.0	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2372	 504	 0.0	 0.000529	 0.0	 123.323143	 123.323143	 123.323143	 0.0	 0.0	 1	 -30.0	 30.0;
	8237	 504	 0.0	 0.00052	 0.0	 119.572301	 119.572301	 119.572301	 0.0	 0.0	 1	 -30.0	 30.0;
	2095	 8237	 0.003369	 0.031329	 0.02069	 341.876432	 341.876432	 341.876432	 0.0	 0.0	 1	 -30.0	 30.0;
	2272	 5689	 0.07449	 0.527603	 0.0	 318.572502	 318.572502	 318.572502	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 5689	 0.01093	 0.074531	 0.09945	 440.586995	 440.586995	 440.586995	 0.0	 0.0	 1	 -30.0	 30.0;
	4680	 5689	 0.00887	 0.04576	 0.07789	 557.315164	 557.315164	 557.315164	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 5689	 0.01099	 0.06689	 0.09638	 305.6884	 305.6884	 305.6884	 0.0	 0.0	 1	 -30.0	 30.0;
	7807	 957	 0.04732	 0.42186	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7807	 957	 0.004469	 0.03124	 0.05173	 241.251122	 241.251122	 241.251122	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 388	 0.500289	 1.586157	 0.0	 217.044083	 217.044083	 217.044083	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 3602	 0.01089	 0.060719	 0.09686	 473.369971	 473.369971	 473.369971	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 4371	 0.133469	 0.882645	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7807	 957	 0.005531	 0.032521	 0.04721	 495.166098	 495.166098	 495.166098	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 4371	 0.005219	 0.025659	 0.03021	 506.640311	 506.640311	 506.640311	 0.0	 0.0	 1	 -30.0	 30.0;
	7848	 3502	 0.00186	 0.012789	 0.0185	 411.430483	 411.430483	 411.430483	 0.0	 0.0	 1	 -30.0	 30.0;
	3635	 3502	 0.001	 0.234938	 0.0	 242.206798	 242.206798	 242.206798	 0.0	 0.0	 1	 -30.0	 30.0;
	4617	 6077	 0.00081	 0.004781	 0.00738	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2593	 7410	 0.00082	 0.00468	 0.00755	 231.335027	 231.335027	 231.335027	 0.0	 0.0	 1	 -30.0	 30.0;
	4168	 4181	 0.03374	 0.614711	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7740	 4181	 0.04612	 0.366777	 0.0	 356.132336	 356.132336	 356.132336	 0.0	 0.0	 1	 -30.0	 30.0;
	3027	 4181	 0.001461	 0.01239	 0.01711	 233.779851	 233.779851	 233.779851	 0.0	 0.0	 1	 -30.0	 30.0;
	7740	 4168	 0.078599	 0.394649	 0.0	 389.862224	 389.862224	 389.862224	 0.0	 0.0	 1	 -30.0	 30.0;
	7946	 4168	 0.00143	 0.01263	 0.01674	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6611	 887	 0.007841	 0.05613	 0.08965	 553.892181	 553.892181	 553.892181	 0.0	 0.0	 1	 -30.0	 30.0;
	4824	 2224	 0.0	 0.000103	 0.0	 286.564584	 286.564584	 286.564584	 0.0	 0.0	 1	 -30.0	 30.0;
	4824	 2224	 0.001	 0.328946	 0.0	 577.670156	 577.670156	 577.670156	 0.0	 0.0	 1	 -30.0	 30.0;
	3290	 2224	 0.224855	 1.532376	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	665	 2224	 0.136781	 1.457355	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	665	 2224	 0.01055	 0.074979	 0.10877	 359.098819	 359.098819	 359.098819	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 2224	 0.014909	 0.523802	 0.0	 243.655555	 243.655555	 243.655555	 0.0	 0.0	 1	 -30.0	 30.0;
	1680	 2224	 0.001	 0.71781	 0.0	 229.254487	 229.254487	 229.254487	 0.0	 0.0	 1	 -30.0	 30.0;
	6851	 2224	 0.134271	 1.687004	 0.0	 241.277795	 241.277795	 241.277795	 0.0	 0.0	 1	 -30.0	 30.0;
	3792	 4824	 0.002341	 0.01263	 0.02486	 467.609239	 467.609239	 467.609239	 0.0	 0.0	 1	 -30.0	 30.0;
	3290	 4824	 0.235227	 1.541777	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	665	 4824	 0.16344	 1.266136	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 4824	 0.015479	 0.562376	 0.0	 351.239639	 351.239639	 351.239639	 0.0	 0.0	 1	 -30.0	 30.0;
	1680	 4824	 0.001	 0.767789	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6851	 4824	 0.158281	 1.596364	 0.0	 260.768182	 260.768182	 260.768182	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 3124	 0.006169	 0.039289	 0.07504	 561.653432	 561.653432	 561.653432	 0.0	 0.0	 1	 -30.0	 30.0;
	5536	 3124	 0.08256	 0.638182	 0.0	 290.353376	 290.353376	 290.353376	 0.0	 0.0	 1	 -30.0	 30.0;
	2510	 3124	 0.221653	 1.097397	 0.0	 269.75756	 269.75756	 269.75756	 0.0	 0.0	 1	 -30.0	 30.0;
	3124	 6084	 0.0118	 0.05445	 0.09114	 388.974375	 388.974375	 388.974375	 0.0	 0.0	 1	 -30.0	 30.0;
	2729	 3124	 0.08986	 0.756921	 0.0	 262.867774	 262.867774	 262.867774	 0.0	 0.0	 1	 -30.0	 30.0;
	3645	 577	 0.03887	 0.335083	 0.0	 225.618497	 225.618497	 225.618497	 0.0	 0.0	 1	 -30.0	 30.0;
	577	 3645	 0.00455	 0.036539	 0.05724	 465.617866	 465.617866	 465.617866	 0.0	 0.0	 1	 -30.0	 30.0;
	153	 577	 0.002169	 0.01688	 0.02428	 298.062423	 298.062423	 298.062423	 0.0	 0.0	 1	 -30.0	 30.0;
	153	 577	 0.01045	 0.244731	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5986	 577	 0.001	 0.259525	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3282	 577	 0.036651	 0.378657	 0.0	 354.140581	 354.140581	 354.140581	 0.0	 0.0	 1	 -30.0	 30.0;
	5976	 5704	 0.004669	 0.03839	 0.05287	 347.601743	 347.601743	 347.601743	 0.0	 0.0	 1	 -30.0	 30.0;
	531	 5704	 0.000781	 0.00674	 0.00878	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	3290	 5704	 0.001461	 0.01201	 0.0176	 339.173653	 339.173653	 339.173653	 0.0	 0.0	 1	 -30.0	 30.0;
	8380	 5704	 0.00087	 0.00614	 0.00967	 605.821074	 605.821074	 605.821074	 0.0	 0.0	 1	 -30.0	 30.0;
	8146	 3792	 0.00464	 0.02919	 0.05062	 432.876805	 432.876805	 432.876805	 0.0	 0.0	 1	 -30.0	 30.0;
	1680	 3792	 0.004719	 0.02719	 0.04704	 484.823988	 484.823988	 484.823988	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 3792	 0.00169	 0.01361	 0.0206	 492.999441	 492.999441	 492.999441	 0.0	 0.0	 1	 -30.0	 30.0;
	7243	 3792	 0.00751	 0.04581	 0.0563	 564.403097	 564.403097	 564.403097	 0.0	 0.0	 1	 -30.0	 30.0;
	1222	 5976	 0.00368	 0.022469	 0.04317	 321.379325	 321.379325	 321.379325	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 5976	 0.001659	 0.012599	 0.02016	 512.365605	 512.365605	 512.365605	 0.0	 0.0	 1	 -30.0	 30.0;
	6851	 5976	 0.007341	 0.042419	 0.05508	 541.196699	 541.196699	 541.196699	 0.0	 0.0	 1	 -30.0	 30.0;
	5976	 6812	 0.00186	 0.01456	 0.04413	 527.331009	 527.331009	 527.331009	 0.0	 0.0	 1	 -30.0	 30.0;
	5660	 3060	 0.00312	 0.03151	 0.803	 1152.818827	 1152.818827	 1152.818827	 0.0	 0.0	 1	 -30.0	 30.0;
	8004	 5660	 0.00073	 0.00808	 0.18882	 1285.635462	 1285.635462	 1285.635462	 0.0	 0.0	 1	 -30.0	 30.0;
	6506	 2728	 0.013479	 0.27064	 0.0	 271.849531	 271.849531	 271.849531	 0.0	 0.0	 1	 -30.0	 30.0;
	6506	 2728	 0.00187	 0.020289	 0.05356	 219.981988	 219.981988	 219.981988	 0.0	 0.0	 1	 -30.0	 30.0;
	8209	 2728	 0.012169	 0.298636	 0.0	 284.578165	 284.578165	 284.578165	 0.0	 0.0	 1	 -30.0	 30.0;
	6611	 6292	 0.00337	 0.027831	 0.03842	 596.022343	 596.022343	 596.022343	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 6611	 0.00461	 0.03301	 0.05272	 537.723799	 537.723799	 537.723799	 0.0	 0.0	 1	 -30.0	 30.0;
	6292	 6611	 0.005781	 0.039789	 0.06614	 544.080876	 544.080876	 544.080876	 0.0	 0.0	 1	 -30.0	 30.0;
	6292	 6611	 0.035151	 0.987397	 0.0	 281.112504	 281.112504	 281.112504	 0.0	 0.0	 1	 -30.0	 30.0;
	2077	 6611	 0.013099	 0.631736	 0.0	 254.686986	 254.686986	 254.686986	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 2272	 0.118409	 1.072417	 0.0	 230.656756	 230.656756	 230.656756	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 2272	 0.006281	 0.051961	 0.0717	 475.209305	 475.209305	 475.209305	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 2272	 0.284979	 1.491054	 0.0	 228.636041	 228.636041	 228.636041	 0.0	 0.0	 1	 -30.0	 30.0;
	3645	 2957	 0.006409	 0.038081	 0.07773	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	153	 3645	 0.225806	 1.262624	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5986	 3645	 0.282252	 1.121529	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3282	 3645	 0.561921	 1.55469	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4971	 3457	 0.00322	 0.02808	 0.67532	 1553.684908	 1553.684908	 1553.684908	 0.0	 0.0	 1	 -30.0	 30.0;
	193	 3457	 0.00196	 0.01843	 0.4283	 1284.458637	 1284.458637	 1284.458637	 0.0	 0.0	 1	 -30.0	 30.0;
	6371	 7657	 0.552066	 1.574607	 0.0	 252.431925	 252.431925	 252.431925	 0.0	 0.0	 1	 -30.0	 30.0;
	3020	 7657	 0.010151	 0.087021	 0.1142	 527.680814	 527.680814	 527.680814	 0.0	 0.0	 1	 -30.0	 30.0;
	6616	 7657	 0.16999	 0.991054	 0.0	 264.377499	 264.377499	 264.377499	 0.0	 0.0	 1	 -30.0	 30.0;
	238	 7657	 0.003831	 0.02386	 0.04454	 561.837479	 561.837479	 561.837479	 0.0	 0.0	 1	 -30.0	 30.0;
	238	 7657	 0.00863	 0.535785	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5598	 7657	 0.04357	 0.617335	 0.0	 253.67339	 253.67339	 253.67339	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 2559	 0.008081	 0.03963	 0.06647	 441.086934	 441.086934	 441.086934	 0.0	 0.0	 1	 -30.0	 30.0;
	2559	 1680	 0.00213	 0.01488	 0.02523	 439.756303	 439.756303	 439.756303	 0.0	 0.0	 1	 -30.0	 30.0;
	193	 4123	 0.00219	 0.02232	 0.47486	 1249.013707	 1249.013707	 1249.013707	 0.0	 0.0	 1	 -30.0	 30.0;
	4123	 1197	 0.00352	 0.03947	 0.74414	 1011.823656	 1011.823656	 1011.823656	 0.0	 0.0	 1	 -30.0	 30.0;
	4123	 7613	 0.00222	 0.02857	 0.57471	 1489.538095	 1489.538095	 1489.538095	 0.0	 0.0	 1	 -30.0	 30.0;
	325	 5283	 0.00104	 0.00901	 0.22878	 1289.355491	 1289.355491	 1289.355491	 0.0	 0.0	 1	 -30.0	 30.0;
	2500	 325	 0.00106	 0.00881	 0.23301	 1474.341393	 1474.341393	 1474.341393	 0.0	 0.0	 1	 -30.0	 30.0;
	6016	 3690	 0.00301	 0.031271	 0.08362	 371.577102	 371.577102	 371.577102	 0.0	 0.0	 1	 -30.0	 30.0;
	5283	 2863	 0.00133	 0.01852	 0.34169	 1371.464018	 1371.464018	 1371.464018	 0.0	 0.0	 1	 -30.0	 30.0;
	2863	 4660	 0.00253	 0.0287	 0.64674	 965.460189	 965.460189	 965.460189	 0.0	 0.0	 1	 -30.0	 30.0;
	5283	 2863	 0.06395	 0.413802	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1197	 8384	 0.00075	 0.00981	 0.18449	 1922.559526	 1922.559526	 1922.559526	 0.0	 0.0	 1	 -30.0	 30.0;
	7160	 2069	 0.234814	 1.148326	 0.0	 396.020773	 396.020773	 396.020773	 0.0	 0.0	 1	 -30.0	 30.0;
	1373	 2069	 0.222417	 1.185971	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7952	 2069	 0.08124	 0.548574	 0.0	 426.18326	 426.18326	 426.18326	 0.0	 0.0	 1	 -30.0	 30.0;
	7952	 2069	 0.01132	 0.074211	 0.12996	 442.802426	 442.802426	 442.802426	 0.0	 0.0	 1	 -30.0	 30.0;
	693	 2069	 0.115849	 0.953099	 0.0	 357.041143	 357.041143	 357.041143	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 3877	 0.0	 3.5e-05	 0.0	 1283.864301	 1283.864301	 1283.864301	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 3877	 0.001	 0.517348	 0.0	 987.270277	 987.270277	 987.270277	 0.0	 0.0	 1	 -30.0	 30.0;
	3877	 6853	 0.00051	 0.00504	 0.12794	 1403.909625	 1403.909625	 1403.909625	 0.0	 0.0	 1	 -30.0	 30.0;
	3877	 4737	 0.00258	 0.02748	 0.6791	 1490.412157	 1490.412157	 1490.412157	 0.0	 0.0	 1	 -30.0	 30.0;
	902	 4956	 0.00224	 0.02852	 0.57002	 1489.291936	 1489.291936	 1489.291936	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 2500	 0.00144	 0.01774	 0.36988	 1433.991052	 1433.991052	 1433.991052	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 7601	 0.0	 0.000103	 0.0	 277.679233	 277.679233	 277.679233	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 7601	 0.06794	 0.65593	 0.0	 310.86498	 310.86498	 310.86498	 0.0	 0.0	 1	 -30.0	 30.0;
	7601	 6506	 0.028479	 0.136841	 0.20849	 479.877944	 479.877944	 479.877944	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 3690	 0.02019	 0.10464	 0.17792	 442.933508	 442.933508	 442.933508	 0.0	 0.0	 1	 -30.0	 30.0;
	6853	 2500	 0.00128	 0.01333	 0.32562	 1643.512562	 1643.512562	 1643.512562	 0.0	 0.0	 1	 -30.0	 30.0;
	295	 6195	 0.667066	 1.759628	 0.0	 265.442918	 265.442918	 265.442918	 0.0	 0.0	 1	 -30.0	 30.0;
	4407	 6195	 0.0232	 0.385289	 0.0	 307.122296	 307.122296	 307.122296	 0.0	 0.0	 1	 -30.0	 30.0;
	4407	 6195	 0.00686	 0.03882	 0.07336	 561.918643	 561.918643	 561.918643	 0.0	 0.0	 1	 -30.0	 30.0;
	7125	 6195	 0.04143	 0.328037	 0.0	 305.211324	 305.211324	 305.211324	 0.0	 0.0	 1	 -30.0	 30.0;
	8363	 6195	 0.00107	 0.00707	 0.01049	 469.100292	 469.100292	 469.100292	 0.0	 0.0	 1	 -30.0	 30.0;
	4407	 295	 0.173021	 1.092025	 0.0	 379.037703	 379.037703	 379.037703	 0.0	 0.0	 1	 -30.0	 30.0;
	4407	 295	 0.010849	 0.074771	 0.12694	 645.916803	 645.916803	 645.916803	 0.0	 0.0	 1	 -30.0	 30.0;
	523	 295	 0.18632	 0.723574	 0.0	 360.078883	 360.078883	 360.078883	 0.0	 0.0	 1	 -30.0	 30.0;
	6992	 295	 0.077651	 0.853368	 0.0	 321.281776	 321.281776	 321.281776	 0.0	 0.0	 1	 -30.0	 30.0;
	6992	 295	 0.011169	 0.07225	 0.1297	 488.506467	 488.506467	 488.506467	 0.0	 0.0	 1	 -30.0	 30.0;
	7125	 295	 0.14268	 0.506488	 0.0	 224.216229	 224.216229	 224.216229	 0.0	 0.0	 1	 -30.0	 30.0;
	6616	 295	 0.352417	 1.255207	 0.0	 451.830291	 451.830291	 451.830291	 0.0	 0.0	 1	 -30.0	 30.0;
	238	 295	 0.391322	 1.63	 0.0	 372.163921	 372.163921	 372.163921	 0.0	 0.0	 1	 -30.0	 30.0;
	2928	 2510	 0.006271	 0.037341	 0.07279	 559.869731	 559.869731	 559.869731	 0.0	 0.0	 1	 -30.0	 30.0;
	3282	 2928	 0.005961	 0.054719	 0.18443	 575.91351	 575.91351	 575.91351	 0.0	 0.0	 1	 -30.0	 30.0;
	3195	 4267	 0.0	 0.000103	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3195	 4267	 0.001	 0.333822	 0.0	 221.484854	 221.484854	 221.484854	 0.0	 0.0	 1	 -30.0	 30.0;
	4267	 3384	 0.00587	 0.040281	 0.06694	 428.632276	 428.632276	 428.632276	 0.0	 0.0	 1	 -30.0	 30.0;
	3195	 8209	 0.003599	 0.046841	 0.09995	 225.336138	 225.336138	 225.336138	 0.0	 0.0	 1	 -30.0	 30.0;
	2678	 4737	 0.00224	 0.02796	 0.58727	 1416.867859	 1416.867859	 1416.867859	 0.0	 0.0	 1	 -30.0	 30.0;
	2510	 5536	 0.08693	 0.670269	 0.0	 347.173442	 347.173442	 347.173442	 0.0	 0.0	 1	 -30.0	 30.0;
	3290	 5536	 0.301839	 1.820372	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 5536	 0.00136	 0.01051	 0.01654	 503.597236	 503.597236	 503.597236	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 5536	 0.00445	 0.344835	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7550	 5536	 0.197159	 1.014752	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 5536	 0.097341	 0.78186	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2729	 5536	 0.013039	 0.297211	 0.0	 447.344175	 447.344175	 447.344175	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 5536	 0.035521	 0.685351	 0.0	 299.113362	 299.113362	 299.113362	 0.0	 0.0	 1	 -30.0	 30.0;
	3635	 5536	 0.367335	 1.746467	 0.0	 250.782736	 250.782736	 250.782736	 0.0	 0.0	 1	 -30.0	 30.0;
	2805	 5536	 0.04186	 0.505517	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 5536	 0.001021	 0.284401	 0.0	 264.220124	 264.220124	 264.220124	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 5536	 0.02575	 0.548884	 0.0	 234.766393	 234.766393	 234.766393	 0.0	 0.0	 1	 -30.0	 30.0;
	6812	 5536	 0.002211	 0.016599	 0.02619	 495.947634	 495.947634	 495.947634	 0.0	 0.0	 1	 -30.0	 30.0;
	4671	 7848	 0.0015	 0.00876	 0.01786	 303.028282	 303.028282	 303.028282	 0.0	 0.0	 1	 -30.0	 30.0;
	3635	 4671	 0.00062	 0.00386	 0.00743	 531.831223	 531.831223	 531.831223	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 8146	 0.00188	 0.008651	 0.01566	 466.555632	 466.555632	 466.555632	 0.0	 0.0	 1	 -30.0	 30.0;
	2805	 8146	 0.00651	 0.278678	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 8146	 0.080781	 0.659587	 0.0	 259.504616	 259.504616	 259.504616	 0.0	 0.0	 1	 -30.0	 30.0;
	4875	 6224	 0.0	 0.000103	 0.0	 284.639133	 284.639133	 284.639133	 0.0	 0.0	 1	 -30.0	 30.0;
	4875	 6224	 0.001	 0.232851	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 2741	 0.01614	 0.08307	 0.13914	 450.481751	 450.481751	 450.481751	 0.0	 0.0	 1	 -30.0	 30.0;
	388	 6224	 0.190479	 0.901095	 0.0	 238.547945	 238.547945	 238.547945	 0.0	 0.0	 1	 -30.0	 30.0;
	388	 6224	 0.00281	 0.01663	 0.02379	 524.30089	 524.30089	 524.30089	 0.0	 0.0	 1	 -30.0	 30.0;
	3602	 6224	 0.032841	 0.593161	 0.0	 254.642403	 254.642403	 254.642403	 0.0	 0.0	 1	 -30.0	 30.0;
	7740	 6224	 0.004599	 0.03094	 0.05184	 485.52779	 485.52779	 485.52779	 0.0	 0.0	 1	 -30.0	 30.0;
	4371	 6224	 0.100021	 0.542231	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	388	 4875	 0.1945	 0.883884	 0.0	 238.547945	 238.547945	 238.547945	 0.0	 0.0	 1	 -30.0	 30.0;
	3602	 4875	 0.028409	 0.617727	 0.0	 245.08221	 245.08221	 245.08221	 0.0	 0.0	 1	 -30.0	 30.0;
	4875	 3027	 0.003281	 0.04162	 0.09109	 349.383538	 349.383538	 349.383538	 0.0	 0.0	 1	 -30.0	 30.0;
	4371	 4875	 0.09636	 0.566219	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4371	 4875	 0.007521	 0.044719	 0.04764	 262.314869	 262.314869	 262.314869	 0.0	 0.0	 1	 -30.0	 30.0;
	8209	 6506	 0.0	 0.000103	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8209	 6506	 0.001	 0.19056	 0.0	 595.95985	 595.95985	 595.95985	 0.0	 0.0	 1	 -30.0	 30.0;
	6506	 3020	 0.01356	 0.08876	 0.13214	 552.562694	 552.562694	 552.562694	 0.0	 0.0	 1	 -30.0	 30.0;
	8209	 3020	 0.005271	 0.068591	 0.14636	 274.949383	 274.949383	 274.949383	 0.0	 0.0	 1	 -30.0	 30.0;
	3092	 7848	 0.003591	 0.03075	 0.04138	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	3027	 7848	 0.01	 0.056159	 0.12256	 410.839472	 410.839472	 410.839472	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 7848	 0.011831	 0.067969	 0.10989	 604.640196	 604.640196	 604.640196	 0.0	 0.0	 1	 -30.0	 30.0;
	7946	 7848	 0.00937	 0.05893	 0.10475	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	7848	 6795	 0.000909	 0.004719	 0.00955	 500.196736	 500.196736	 500.196736	 0.0	 0.0	 1	 -30.0	 30.0;
	2018	 1197	 0.00176	 0.01759	 0.1874	 1450.101965	 1450.101965	 1450.101965	 0.0	 0.0	 1	 -30.0	 30.0;
	2725	 2018	 0.00137	 0.01801	 0.33452	 1544.305853	 1544.305853	 1544.305853	 0.0	 0.0	 1	 -30.0	 30.0;
	2018	 6919	 0.00184	 0.01756	 0.45307	 1295.296876	 1295.296876	 1295.296876	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 2805	 0.00213	 0.012539	 0.02512	 474.337079	 474.337079	 474.337079	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 2805	 0.07664	 0.597665	 0.0	 277.409068	 277.409068	 277.409068	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 2805	 0.07132	 0.544959	 0.0	 263.442018	 263.442018	 263.442018	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 2805	 0.00405	 0.02507	 0.04892	 508.119933	 508.119933	 508.119933	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 2805	 0.001	 0.348058	 0.0	 223.504044	 223.504044	 223.504044	 0.0	 0.0	 1	 -30.0	 30.0;
	2729	 2510	 0.06064	 0.52688	 0.0	 251.374889	 251.374889	 251.374889	 0.0	 0.0	 1	 -30.0	 30.0;
	2510	 2729	 0.005271	 0.03093	 0.06438	 524.328707	 524.328707	 524.328707	 0.0	 0.0	 1	 -30.0	 30.0;
	3092	 1222	 0.002841	 0.023409	 0.03254	 409.570191	 409.570191	 409.570191	 0.0	 0.0	 1	 -30.0	 30.0;
	6322	 1837	 0.00226	 0.015841	 0.02118	 468.890714	 468.890714	 468.890714	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 1837	 0.01237	 0.060909	 0.09558	 427.853789	 427.853789	 427.853789	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 3092	 0.01637	 0.07345	 0.12628	 495.440455	 495.440455	 495.440455	 0.0	 0.0	 1	 -30.0	 30.0;
	3640	 1837	 0.00243	 0.018341	 0.02704	 568.059664	 568.059664	 568.059664	 0.0	 0.0	 1	 -30.0	 30.0;
	3139	 717	 0.0026	 0.02813	 0.66438	 1194.146564	 1194.146564	 1194.146564	 0.0	 0.0	 1	 -30.0	 30.0;
	4617	 2593	 0.0	 0.000103	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4617	 2593	 0.02631	 0.515517	 0.0	 577.670156	 577.670156	 577.670156	 0.0	 0.0	 1	 -30.0	 30.0;
	2593	 6292	 0.00394	 0.041169	 0.10702	 216.570056	 216.570056	 216.570056	 0.0	 0.0	 1	 -30.0	 30.0;
	2593	 6292	 0.343719	 1.744855	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2593	 7243	 0.017159	 0.080591	 0.12617	 471.929597	 471.929597	 471.929597	 0.0	 0.0	 1	 -30.0	 30.0;
	4617	 5004	 0.005	 0.066591	 0.13873	 439.265128	 439.265128	 439.265128	 0.0	 0.0	 1	 -30.0	 30.0;
	4617	 6292	 0.065229	 1.288988	 0.0	 264.64614	 264.64614	 264.64614	 0.0	 0.0	 1	 -30.0	 30.0;
	665	 3290	 0.0	 0.000103	 0.0	 265.193329	 265.193329	 265.193329	 0.0	 0.0	 1	 -30.0	 30.0;
	665	 3290	 0.001	 0.56	 0.0	 614.249926	 614.249926	 614.249926	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 3290	 0.063599	 0.651508	 0.0	 301.247248	 301.247248	 301.247248	 0.0	 0.0	 1	 -30.0	 30.0;
	7550	 3290	 0.075159	 1.271095	 0.0	 257.548299	 257.548299	 257.548299	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 3290	 0.360475	 1.617479	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1680	 3290	 0.001	 0.740702	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2729	 3290	 0.363884	 2.00314	 0.0	 266.469089	 266.469089	 266.469089	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 3290	 0.3925	 1.858533	 0.0	 263.333799	 263.333799	 263.333799	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 665	 0.04769	 0.602128	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7550	 665	 0.050341	 1.259855	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1680	 665	 0.001	 0.829566	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3020	 7807	 0.00049	 0.00324	 0.00582	 540.646842	 540.646842	 540.646842	 0.0	 0.0	 1	 -30.0	 30.0;
	7807	 3444	 0.018659	 0.111289	 0.21669	 530.368368	 530.368368	 530.368368	 0.0	 0.0	 1	 -30.0	 30.0;
	7807	 4371	 0.509835	 1.831384	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3020	 7807	 0.0005	 0.00318	 0.00594	 587.63312	 587.63312	 587.63312	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 1347	 0.05936	 0.582149	 0.0	 259.236356	 259.236356	 259.236356	 0.0	 0.0	 1	 -30.0	 30.0;
	2729	 1347	 0.003331	 0.0203	 0.04069	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	7550	 1347	 0.12286	 0.888244	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 1347	 0.033599	 0.599959	 0.0	 255.796226	 255.796226	 255.796226	 0.0	 0.0	 1	 -30.0	 30.0;
	1680	 1347	 0.100539	 0.767066	 0.0	 307.166879	 307.166879	 307.166879	 0.0	 0.0	 1	 -30.0	 30.0;
	2729	 1347	 0.0822	 0.730331	 0.0	 270.740672	 270.740672	 270.740672	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 1347	 0.15512	 0.82874	 0.0	 268.337001	 268.337001	 268.337001	 0.0	 0.0	 1	 -30.0	 30.0;
	4819	 1358	 0.0	 0.000103	 0.0	 233.624382	 233.624382	 233.624382	 0.0	 0.0	 1	 -30.0	 30.0;
	4819	 1358	 0.001	 0.194781	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1358	 2298	 0.0132	 0.071979	 0.13541	 486.451458	 486.451458	 486.451458	 0.0	 0.0	 1	 -30.0	 30.0;
	1358	 339	 0.0148	 0.073031	 0.15524	 511.920918	 511.920918	 511.920918	 0.0	 0.0	 1	 -30.0	 30.0;
	4680	 1358	 0.005781	 0.0378	 0.07101	 543.276858	 543.276858	 543.276858	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 1358	 0.153961	 1.590021	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 1358	 0.00631	 0.03855	 0.0723	 510.037382	 510.037382	 510.037382	 0.0	 0.0	 1	 -30.0	 30.0;
	8102	 1358	 0.14124	 1.705702	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4680	 4819	 0.00589	 0.03699	 0.07235	 545.979654	 545.979654	 545.979654	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 4819	 0.18032	 1.449298	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8102	 4819	 0.150651	 1.729298	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8102	 4819	 0.00636	 0.045409	 0.06238	 455.830947	 455.830947	 455.830947	 0.0	 0.0	 1	 -30.0	 30.0;
	2566	 3425	 0.00173	 0.01602	 0.37844	 1318.885364	 1318.885364	 1318.885364	 0.0	 0.0	 1	 -30.0	 30.0;
	4214	 2566	 0.00207	 0.02233	 0.54858	 1230.722904	 1230.722904	 1230.722904	 0.0	 0.0	 1	 -30.0	 30.0;
	1312	 2566	 0.00178	 0.02178	 0.46938	 1307.298117	 1307.298117	 1307.298117	 0.0	 0.0	 1	 -30.0	 30.0;
	3640	 6322	 0.00589	 0.214174	 0.0	 257.809319	 257.809319	 257.809319	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 6322	 0.105789	 1.66719	 0.0	 223.90491	 223.90491	 223.90491	 0.0	 0.0	 1	 -30.0	 30.0;
	8102	 6322	 0.108969	 1.629731	 0.0	 222.696216	 222.696216	 222.696216	 0.0	 0.0	 1	 -30.0	 30.0;
	7125	 4407	 0.024581	 0.231446	 0.0	 216.906143	 216.906143	 216.906143	 0.0	 0.0	 1	 -30.0	 30.0;
	7125	 4407	 0.004599	 0.035341	 0.05274	 582.38414	 582.38414	 582.38414	 0.0	 0.0	 1	 -30.0	 30.0;
	4660	 1006	 0.00106	 0.01023	 0.2705	 771.521074	 771.521074	 771.521074	 0.0	 0.0	 1	 -30.0	 30.0;
	1013	 1006	 0.00403	 0.04889	 1.04974	 1816.480767	 1816.480767	 1816.480767	 0.0	 0.0	 1	 -30.0	 30.0;
	5616	 4996	 0.00123	 0.01589	 0.33156	 1424.65807	 1424.65807	 1424.65807	 0.0	 0.0	 1	 -30.0	 30.0;
	5616	 3060	 0.00158	 0.01592	 0.38988	 1929.013633	 1929.013633	 1929.013633	 0.0	 0.0	 1	 -30.0	 30.0;
	226	 6430	 0.00219	 0.02123	 0.54184	 1610.157351	 1610.157351	 1610.157351	 0.0	 0.0	 1	 -30.0	 30.0;
	226	 3865	 0.00171	 0.01708	 0.42294	 1568.150373	 1568.150373	 1568.150373	 0.0	 0.0	 1	 -30.0	 30.0;
	226	 3865	 0.00174	 0.0167	 0.43077	 1595.619486	 1595.619486	 1595.619486	 0.0	 0.0	 1	 -30.0	 30.0;
	1013	 226	 0.00515	 0.285942	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1013	 226	 0.00058	 0.00775	 0.14508	 1678.436214	 1678.436214	 1678.436214	 0.0	 0.0	 1	 -30.0	 30.0;
	1013	 226	 0.00057	 0.0079	 0.14199	 1441.758884	 1441.758884	 1441.758884	 0.0	 0.0	 1	 -30.0	 30.0;
	3092	 6084	 0.009341	 0.6725	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3635	 6084	 0.171229	 1.013678	 0.0	 265.199045	 265.199045	 265.199045	 0.0	 0.0	 1	 -30.0	 30.0;
	6812	 6084	 0.00251	 0.02049	 0.02983	 413.065192	 413.065192	 413.065192	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 6795	 0.005909	 0.036349	 0.06605	 593.802339	 593.802339	 593.802339	 0.0	 0.0	 1	 -30.0	 30.0;
	8198	 6919	 0.00091	 0.00886	 0.23265	 1282.470278	 1282.470278	 1282.470278	 0.0	 0.0	 1	 -30.0	 30.0;
	8004	 8198	 0.00054	 0.00532	 0.13846	 1577.81442	 1577.81442	 1577.81442	 0.0	 0.0	 1	 -30.0	 30.0;
	238	 6371	 0.009531	 0.051211	 0.08945	 487.799617	 487.799617	 487.799617	 0.0	 0.0	 1	 -30.0	 30.0;
	238	 6371	 0.785124	 1.943678	 0.0	 227.673887	 227.673887	 227.673887	 0.0	 0.0	 1	 -30.0	 30.0;
	6371	 3447	 0.010789	 0.05194	 0.09025	 529.003824	 529.003824	 529.003824	 0.0	 0.0	 1	 -30.0	 30.0;
	5598	 6371	 0.173281	 0.62781	 0.0	 263.204623	 263.204623	 263.204623	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 3092	 0.00613	 0.033659	 0.05444	 402.093205	 402.093205	 402.093205	 0.0	 0.0	 1	 -30.0	 30.0;
	3635	 3092	 0.11576	 0.840434	 0.0	 284.871955	 284.871955	 284.871955	 0.0	 0.0	 1	 -30.0	 30.0;
	6992	 523	 0.0	 0.000103	 0.0	 266.567781	 266.567781	 266.567781	 0.0	 0.0	 1	 -30.0	 30.0;
	6992	 523	 0.05964	 0.314938	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	523	 1152	 0.002169	 0.017341	 0.02439	 454.597484	 454.597484	 454.597484	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 523	 0.454215	 1.265475	 0.0	 272.22258	 272.22258	 272.22258	 0.0	 0.0	 1	 -30.0	 30.0;
	523	 2360	 0.007091	 0.061521	 0.08131	 541.029418	 541.029418	 541.029418	 0.0	 0.0	 1	 -30.0	 30.0;
	6992	 1569	 0.013021	 0.087711	 0.15121	 594.917675	 594.917675	 594.917675	 0.0	 0.0	 1	 -30.0	 30.0;
	877	 6992	 0.35781	 1.954277	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 6992	 0.0485	 0.815537	 0.0	 331.698572	 331.698572	 331.698572	 0.0	 0.0	 1	 -30.0	 30.0;
	1680	 5004	 0.415537	 1.939483	 0.0	 253.033224	 253.033224	 253.033224	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 5004	 0.097031	 0.677913	 0.0	 280.847293	 280.847293	 280.847293	 0.0	 0.0	 1	 -30.0	 30.0;
	5004	 5133	 0.003031	 0.033021	 0.08406	 465.302355	 465.302355	 465.302355	 0.0	 0.0	 1	 -30.0	 30.0;
	5004	 5133	 0.00637	 0.038979	 0.07806	 581.49972	 581.49972	 581.49972	 0.0	 0.0	 1	 -30.0	 30.0;
	6851	 5004	 0.024271	 0.588967	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7243	 5004	 0.00439	 0.372438	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	191	 5004	 0.001	 0.198331	 0.0	 249.564896	 249.564896	 249.564896	 0.0	 0.0	 1	 -30.0	 30.0;
	191	 5004	 0.00232	 0.01226	 0.02388	 389.552048	 389.552048	 389.552048	 0.0	 0.0	 1	 -30.0	 30.0;
	3447	 1569	 0.014211	 0.079219	 0.11648	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	153	 1569	 0.015151	 0.07637	 0.14567	 539.436624	 539.436624	 539.436624	 0.0	 0.0	 1	 -30.0	 30.0;
	2957	 1569	 0.0	 0.000103	 0.0	 276.425956	 276.425956	 276.425956	 0.0	 0.0	 1	 -30.0	 30.0;
	2957	 1569	 0.001	 0.258698	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5986	 1569	 0.01544	 0.074781	 0.14847	 560.79721	 560.79721	 560.79721	 0.0	 0.0	 1	 -30.0	 30.0;
	877	 2957	 0.013909	 0.073349	 0.11395	 644.851003	 644.851003	 644.851003	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 3581	 0.006919	 0.04764	 0.08176	 448.286134	 448.286134	 448.286134	 0.0	 0.0	 1	 -30.0	 30.0;
	2049	 3581	 0.224318	 1.85469	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7952	 3581	 0.015169	 0.1077	 0.17215	 485.935514	 485.935514	 485.935514	 0.0	 0.0	 1	 -30.0	 30.0;
	339	 3581	 0.130771	 1.06564	 0.0	 265.831209	 265.831209	 265.831209	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 3581	 0.249669	 1.169917	 0.0	 226.300579	 226.300579	 226.300579	 0.0	 0.0	 1	 -30.0	 30.0;
	3425	 451	 0.00127	 0.01444	 0.31414	 1404.012959	 1404.012959	 1404.012959	 0.0	 0.0	 1	 -30.0	 30.0;
	3425	 5545	 0.00318	 0.04235	 0.79571	 1287.072267	 1287.072267	 1287.072267	 0.0	 0.0	 1	 -30.0	 30.0;
	3425	 7876	 0.00131	 0.01758	 0.33385	 1314.72962	 1314.72962	 1314.72962	 0.0	 0.0	 1	 -30.0	 30.0;
	2077	 2764	 0.469607	 1.302025	 0.0	 263.049154	 263.049154	 263.049154	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 2764	 0.001	 0.205711	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 2764	 0.002969	 0.02201	 0.02957	 519.457349	 519.457349	 519.457349	 0.0	 0.0	 1	 -30.0	 30.0;
	8363	 7125	 0.00549	 0.044831	 0.06385	 495.576109	 495.576109	 495.576109	 0.0	 0.0	 1	 -30.0	 30.0;
	3099	 2049	 0.0	 0.000103	 0.0	 374.681907	 374.681907	 374.681907	 0.0	 0.0	 1	 -30.0	 30.0;
	3099	 2049	 0.08343	 1.583099	 0.0	 605.110032	 605.110032	 605.110032	 0.0	 0.0	 1	 -30.0	 30.0;
	2298	 2049	 0.094651	 1.363719	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2049	 2741	 0.00112	 0.00895	 0.01192	 560.387961	 560.387961	 560.387961	 0.0	 0.0	 1	 -30.0	 30.0;
	2741	 2049	 0.00151	 0.00944	 0.01193	 561.801661	 561.801661	 561.801661	 0.0	 0.0	 1	 -30.0	 30.0;
	339	 2049	 0.018669	 0.563368	 0.0	 252.92653	 252.92653	 252.92653	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 2049	 0.00538	 0.652851	 0.0	 240.120162	 240.120162	 240.120162	 0.0	 0.0	 1	 -30.0	 30.0;
	2298	 3099	 0.0	 0.000103	 0.0	 252.133943	 252.133943	 252.133943	 0.0	 0.0	 1	 -30.0	 30.0;
	2298	 3099	 0.001	 0.495455	 0.0	 595.95985	 595.95985	 595.95985	 0.0	 0.0	 1	 -30.0	 30.0;
	339	 3099	 0.036849	 0.734215	 0.0	 231.537365	 231.537365	 231.537365	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 3099	 0.001	 0.459566	 0.0	 237.233699	 237.233699	 237.233699	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 3099	 0.00095	 0.00638	 0.01135	 547.459656	 547.459656	 547.459656	 0.0	 0.0	 1	 -30.0	 30.0;
	2741	 2298	 0.00105	 0.00818	 0.01211	 529.820035	 529.820035	 529.820035	 0.0	 0.0	 1	 -30.0	 30.0;
	339	 2298	 0.040151	 0.657893	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	339	 2298	 0.00193	 0.01406	 0.02108	 521.559227	 521.559227	 521.559227	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 2298	 0.001	 0.49438	 0.0	 254.534947	 254.534947	 254.534947	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 7550	 0.0	 0.000103	 0.0	 323.310493	 323.310493	 323.310493	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 7550	 0.08057	 0.906178	 0.0	 577.670156	 577.670156	 577.670156	 0.0	 0.0	 1	 -30.0	 30.0;
	2729	 7550	 0.0347	 0.658202	 0.0	 303.977861	 303.977861	 303.977861	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 7550	 0.032719	 0.534318	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 7550	 0.004281	 0.033461	 0.05199	 567.927058	 567.927058	 567.927058	 0.0	 0.0	 1	 -30.0	 30.0;
	2729	 5204	 0.001	 0.395785	 0.0	 384.309927	 384.309927	 384.309927	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 5204	 0.14007	 0.838595	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7876	 451	 0.04194	 0.384211	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	451	 7876	 0.00034	 0.00341	 0.08387	 1440.455689	 1440.455689	 1440.455689	 0.0	 0.0	 1	 -30.0	 30.0;
	699	 7160	 0.001969	 0.014021	 0.02462	 377.121016	 377.121016	 377.121016	 0.0	 0.0	 1	 -30.0	 30.0;
	1373	 7160	 0.0	 0.000103	 0.0	 273.981513	 273.981513	 273.981513	 0.0	 0.0	 1	 -30.0	 30.0;
	1373	 7160	 0.001	 0.26219	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7160	 3589	 0.03032	 0.14413	 0.26716	 405.113035	 405.113035	 405.113035	 0.0	 0.0	 1	 -30.0	 30.0;
	1373	 693	 0.01325	 0.11038	 0.15014	 477.926962	 477.926962	 477.926962	 0.0	 0.0	 1	 -30.0	 30.0;
	2331	 2741	 0.011901	 0.07319	 0.13775	 491.149057	 491.149057	 491.149057	 0.0	 0.0	 1	 -30.0	 30.0;
	2741	 3444	 0.00401	 0.03175	 0.04227	 498.094476	 498.094476	 498.094476	 0.0	 0.0	 1	 -30.0	 30.0;
	7876	 2725	 0.00368	 0.03712	 0.91191	 1610.87345	 1610.87345	 1610.87345	 0.0	 0.0	 1	 -30.0	 30.0;
	7876	 2678	 0.00169	 0.02158	 0.4329	 1292.820805	 1292.820805	 1292.820805	 0.0	 0.0	 1	 -30.0	 30.0;
	717	 4214	 0.00116	 0.01472	 0.2961	 1286.22914	 1286.22914	 1286.22914	 0.0	 0.0	 1	 -30.0	 30.0;
	193	 6430	 0.05575	 0.602438	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6430	 193	 0.00163	 0.01604	 0.42269	 1413.577621	 1413.577621	 1413.577621	 0.0	 0.0	 1	 -30.0	 30.0;
	6430	 2725	 0.00269	 0.02759	 0.67961	 1251.493069	 1251.493069	 1251.493069	 0.0	 0.0	 1	 -30.0	 30.0;
	6430	 1197	 0.00256	 0.02877	 0.76243	 1336.106626	 1336.106626	 1336.106626	 0.0	 0.0	 1	 -30.0	 30.0;
	693	 7952	 0.0	 0.000103	 0.0	 306.959587	 306.959587	 306.959587	 0.0	 0.0	 1	 -30.0	 30.0;
	693	 7952	 0.09549	 0.768967	 0.0	 614.249926	 614.249926	 614.249926	 0.0	 0.0	 1	 -30.0	 30.0;
	3602	 388	 0.0	 0.000103	 0.0	 267.716269	 267.716269	 267.716269	 0.0	 0.0	 1	 -30.0	 30.0;
	3602	 388	 0.05899	 0.428306	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3027	 388	 0.005591	 0.04031	 0.07402	 612.017728	 612.017728	 612.017728	 0.0	 0.0	 1	 -30.0	 30.0;
	4371	 388	 0.00714	 0.15039	 0.0	 343.067615	 343.067615	 343.067615	 0.0	 0.0	 1	 -30.0	 30.0;
	7946	 3602	 0.005469	 0.041099	 0.07251	 606.732929	 606.732929	 606.732929	 0.0	 0.0	 1	 -30.0	 30.0;
	4371	 3602	 0.036711	 0.380269	 0.0	 281.411629	 281.411629	 281.411629	 0.0	 0.0	 1	 -30.0	 30.0;
	4410	 193	 0.00056	 0.124578	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4410	 193	 0.0007	 0.00889	 0.17364	 1662.16668	 1662.16668	 1662.16668	 0.0	 0.0	 1	 -30.0	 30.0;
	3020	 2331	 0.013479	 0.11436	 0.15718	 542.738051	 542.738051	 542.738051	 0.0	 0.0	 1	 -30.0	 30.0;
	3589	 3020	 0.012	 0.066919	 0.10486	 555.1748	 555.1748	 555.1748	 0.0	 0.0	 1	 -30.0	 30.0;
	3444	 2331	 0.3925	 1.654463	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3640	 6292	 0.301178	 1.948719	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3640	 6292	 0.009169	 0.06301	 0.10469	 525.960368	 525.960368	 525.960368	 0.0	 0.0	 1	 -30.0	 30.0;
	3060	 717	 0.00176	 0.02342	 0.42947	 882.762592	 882.762592	 882.762592	 0.0	 0.0	 1	 -30.0	 30.0;
	3343	 717	 0.00108	 0.01167	 0.27572	 1497.687013	 1497.687013	 1497.687013	 0.0	 0.0	 1	 -30.0	 30.0;
	3444	 339	 0.191961	 1.234649	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 339	 0.03699	 0.374917	 0.0	 249.644917	 249.644917	 249.644917	 0.0	 0.0	 1	 -30.0	 30.0;
	7946	 7740	 0.00361	 0.03024	 0.04313	 625.025291	 625.025291	 625.025291	 0.0	 0.0	 1	 -30.0	 30.0;
	238	 6616	 0.350806	 1.554649	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6616	 238	 0.004831	 0.06375	 0.13403	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6616	 2311	 0.007099	 0.07076	 0.19694	 256.472973	 256.472973	 256.472973	 0.0	 0.0	 1	 -30.0	 30.0;
	5598	 238	 0.0022	 0.01318	 0.01917	 391.693937	 391.693937	 391.693937	 0.0	 0.0	 1	 -30.0	 30.0;
	238	 877	 0.01775	 0.099419	 0.15277	 454.023621	 454.023621	 454.023621	 0.0	 0.0	 1	 -30.0	 30.0;
	5598	 238	 0.186581	 1.067335	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2725	 2678	 0.00373	 0.05005	 0.92844	 1344.763	 1344.763	 1344.763	 0.0	 0.0	 1	 -30.0	 30.0;
	3447	 877	 0.0	 0.000103	 0.0	 235.279669	 235.279669	 235.279669	 0.0	 0.0	 1	 -30.0	 30.0;
	3447	 877	 0.001	 0.16038	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 877	 0.010531	 0.17819	 0.0	 273.79213	 273.79213	 273.79213	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 877	 0.0025	 0.017081	 0.02869	 505.007126	 505.007126	 505.007126	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 3447	 0.0777	 0.498492	 0.0	 236.015097	 236.015097	 236.015097	 0.0	 0.0	 1	 -30.0	 30.0;
	6851	 1680	 0.01907	 1.485992	 0.0	 257.996797	 257.996797	 257.996797	 0.0	 0.0	 1	 -30.0	 30.0;
	7243	 1680	 0.120669	 1.890888	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8102	 4680	 0.010271	 0.06219	 0.09021	 416.671842	 416.671842	 416.671842	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 3640	 0.298079	 1.623781	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8102	 3640	 0.273223	 1.612107	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2725	 8004	 0.00277	 0.02823	 0.68369	 1480.201163	 1480.201163	 1480.201163	 0.0	 0.0	 1	 -30.0	 30.0;
	1197	 2725	 0.00077	 0.00747	 0.38941	 1251.62997	 1251.62997	 1251.62997	 0.0	 0.0	 1	 -30.0	 30.0;
	6919	 7613	 0.00102	 0.01145	 0.25151	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6919	 7613	 0.00112	 0.01049	 0.29081	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	8102	 5595	 0.0	 0.000103	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8102	 5595	 0.001	 0.22343	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	4996	 3343	 0.0	 3.5e-05	 0.0	 1815.10254	 1815.10254	 1815.10254	 0.0	 0.0	 1	 -30.0	 30.0;
	4996	 3343	 0.001	 0.26178	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	3060	 3343	 0.00153	 0.0214	 0.37463	 840.606207	 840.606207	 840.606207	 0.0	 0.0	 1	 -30.0	 30.0;
	8004	 3343	 0.00468	 0.06143	 1.14105	 1011.676882	 1011.676882	 1011.676882	 0.0	 0.0	 1	 -30.0	 30.0;
	191	 5133	 0.271756	 1.50345	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7243	 6851	 0.0	 0.000103	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7243	 6851	 0.015271	 0.796736	 0.0	 577.670156	 577.670156	 577.670156	 0.0	 0.0	 1	 -30.0	 30.0;
	191	 6851	 0.02776	 0.935537	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	191	 6851	 0.004219	 0.026599	 0.03327	 417.085282	 417.085282	 417.085282	 0.0	 0.0	 1	 -30.0	 30.0;
	191	 7243	 0.001	 0.620888	 0.0	 228.285474	 228.285474	 228.285474	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 3444	 0.361364	 1.973368	 0.0	 239.774167	 239.774167	 239.774167	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 2077	 0.001599	 0.00825	 0.01395	 478.218847	 478.218847	 478.218847	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 2077	 0.659194	 1.990062	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	5986	 153	 0.0	 0.000103	 0.0	 262.053849	 262.053849	 262.053849	 0.0	 0.0	 1	 -30.0	 30.0;
	5986	 153	 0.11788	 0.822417	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3282	 153	 0.086341	 0.745145	 0.0	 284.018782	 284.018782	 284.018782	 0.0	 0.0	 1	 -30.0	 30.0;
	3282	 5986	 0.00569	 0.033281	 0.06485	 540.443742	 540.443742	 540.443742	 0.0	 0.0	 1	 -30.0	 30.0;
	3282	 5986	 0.03618	 0.609897	 0.0	 287.947038	 287.947038	 287.947038	 0.0	 0.0	 1	 -30.0	 30.0;
	22	 4410	 0.00087	 0.00898	 0.29637	 1726.946004	 1726.946004	 1726.946004	 0.0	 0.0	 1	 -30.0	 30.0;
	125	 3384	 0.001	 0.211322	 0.0	 641.690183	 641.690183	 641.690183	 0.0	 0.0	 1	 -30.0	 30.0;
	125	 3384	 0.0	 0.000103	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3589	 3384	 0.13407	 1.029876	 0.0	 256.926424	 256.926424	 256.926424	 0.0	 0.0	 1	 -30.0	 30.0;
	1678	 3384	 0.141419	 0.956033	 0.0	 253.307962	 253.307962	 253.307962	 0.0	 0.0	 1	 -30.0	 30.0;
	3589	 125	 0.12913	 1.151054	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1678	 125	 0.14487	 1.008244	 0.0	 258.958189	 258.958189	 258.958189	 0.0	 0.0	 1	 -30.0	 30.0;
	125	 1678	 0.007599	 0.05356	 0.08699	 378.584633	 378.584633	 378.584633	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 2729	 0.0	 0.000103	 0.0	 223.433931	 223.433931	 223.433931	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 2729	 0.024219	 0.488657	 0.0	 586.819957	 586.819957	 586.819957	 0.0	 0.0	 1	 -30.0	 30.0;
	1678	 3589	 0.001	 0.226901	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1678	 3589	 0.0	 0.000103	 0.0	 265.734422	 265.734422	 265.734422	 0.0	 0.0	 1	 -30.0	 30.0;
	6795	 3635	 0.00063	 0.005159	 0.00728	 500.526345	 500.526345	 500.526345	 0.0	 0.0	 1	 -30.0	 30.0;
	3690	 2311	 0.0	 0.000103	 0.0	 249.578233	 249.578233	 249.578233	 0.0	 0.0	 1	 -30.0	 30.0;
	3690	 2311	 0.001	 0.214277	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3034	 3879	 0.019671	 0.07004	 0.02161	 249.039894	 249.039894	 249.039894	 0.0	 0.0	 1	 -30.0	 30.0;
	3034	 3879	 0.01812	 0.06872	 0.02006	 247.96481	 247.96481	 247.96481	 0.0	 0.0	 1	 -30.0	 30.0;
	5268	 4293	 0.001582	 0.00724	 0.00286	 134.460057	 134.460057	 134.460057	 0.0	 0.0	 1	 -30.0	 30.0;
	5268	 4293	 0.001551	 0.007231	 0.00276	 121.158946	 121.158946	 121.158946	 0.0	 0.0	 1	 -30.0	 30.0;
	5268	 4293	 0.001262	 0.00796	 0.0023	 116.027745	 116.027745	 116.027745	 0.0	 0.0	 1	 -30.0	 30.0;
	4946	 2480	 0.0264	 0.075129	 0.02967	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4946	 4794	 0.00824	 0.044751	 0.01738	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7150	 4293	 0.018271	 0.070191	 0.01993	 143.597231	 143.597231	 143.597231	 0.0	 0.0	 1	 -30.0	 30.0;
	7150	 4293	 0.021711	 0.063129	 0.0238	 111.208314	 111.208314	 111.208314	 0.0	 0.0	 1	 -30.0	 30.0;
	7150	 6867	 0.013191	 0.0428	 0.01355	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7344	 2480	 0.027631	 0.102502	 0.04257	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7344	 6671	 0.005369	 0.052622	 0.03551	 115.511508	 115.511508	 115.511508	 0.0	 0.0	 1	 -30.0	 30.0;
	7344	 6671	 0.013938	 0.0534	 0.01605	 113.675187	 113.675187	 113.675187	 0.0	 0.0	 1	 -30.0	 30.0;
	7344	 6671	 0.01364	 0.049449	 0.01571	 117.107246	 117.107246	 117.107246	 0.0	 0.0	 1	 -30.0	 30.0;
	7344	 1280	 0.007991	 0.037738	 0.06092	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 4293	 0.007671	 0.04096	 0.01464	 128.6757	 128.6757	 128.6757	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 4293	 0.007511	 0.041769	 0.01434	 121.205451	 121.205451	 121.205451	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 3115	 0.004089	 0.010978	 0.01881	 143.5315	 143.5315	 143.5315	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 3115	 0.003	 0.014769	 0.02184	 154.995251	 154.995251	 154.995251	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 553	 0.001351	 0.00784	 0.00259	 114.602441	 114.602441	 114.602441	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 859	 0.003671	 0.022089	 0.00706	 112.212211	 112.212211	 112.212211	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 2683	 0.002378	 0.00772	 0.00257	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4293	 553	 0.006911	 0.03268	 0.01324	 145.811831	 145.811831	 145.811831	 0.0	 0.0	 1	 -30.0	 30.0;
	4293	 1950	 0.00944	 0.03284	 0.01053	 156.430428	 156.430428	 156.430428	 0.0	 0.0	 1	 -30.0	 30.0;
	4293	 5907	 0.009831	 0.02848	 0.01072	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	4293	 859	 0.003671	 0.02092	 0.00701	 157.699329	 157.699329	 157.699329	 0.0	 0.0	 1	 -30.0	 30.0;
	7975	 2480	 0.019378	 0.10932	 0.03713	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7975	 2480	 0.021969	 0.107129	 0.04209	 127.20415	 127.20415	 127.20415	 0.0	 0.0	 1	 -30.0	 30.0;
	7975	 4794	 0.009151	 0.063249	 0.01932	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7975	 3746	 0.029169	 0.088102	 0.0328	 153.837029	 153.837029	 153.837029	 0.0	 0.0	 1	 -30.0	 30.0;
	7975	 4431	 0.031351	 0.115698	 0.03597	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7975	 6671	 0.04936	 0.182018	 0.0567	 118.57438	 118.57438	 118.57438	 0.0	 0.0	 1	 -30.0	 30.0;
	7975	 5740	 0.001609	 0.016889	 0.01089	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	7975	 2551	 0.0	 0.000222	 0.0	 135.397183	 135.397183	 135.397183	 0.0	 0.0	 1	 -30.0	 30.0;
	637	 8105	 0.008698	 0.033591	 0.00959	 201.960415	 201.960415	 201.960415	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 1703	 0.01792	 0.070169	 0.01991	 118.27612	 118.27612	 118.27612	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 7826	 0.00308	 0.008422	 0.00345	 311.769145	 311.769145	 311.769145	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 498	 0.002031	 0.012102	 0.01557	 155.210632	 155.210632	 155.210632	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 498	 0.0068	 0.03452	 0.01063	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 3451	 0.01176	 0.055871	 0.02218	 184.905604	 184.905604	 184.905604	 0.0	 0.0	 1	 -30.0	 30.0;
	3956	 5907	 0.04856	 0.135111	 0.05298	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2480	 5614	 0.039289	 0.146129	 0.04205	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2480	 5614	 0.038471	 0.148938	 0.04117	 121.068273	 121.068273	 121.068273	 0.0	 0.0	 1	 -30.0	 30.0;
	2480	 3101	 0.010911	 0.04116	 0.01192	 250.80087	 250.80087	 250.80087	 0.0	 0.0	 1	 -30.0	 30.0;
	5614	 1280	 0.002898	 0.017409	 0.02202	 208.66527	 208.66527	 208.66527	 0.0	 0.0	 1	 -30.0	 30.0;
	4554	 1135	 0.00544	 0.051431	 0.03503	 126.147512	 126.147512	 126.147512	 0.0	 0.0	 1	 -30.0	 30.0;
	4554	 4844	 0.003791	 0.014342	 0.0042	 189.350133	 189.350133	 189.350133	 0.0	 0.0	 1	 -30.0	 30.0;
	4554	 5376	 0.005969	 0.026302	 0.01126	 108.136608	 108.136608	 108.136608	 0.0	 0.0	 1	 -30.0	 30.0;
	4554	 4338	 0.00608	 0.02572	 0.01147	 122.69259	 122.69259	 122.69259	 0.0	 0.0	 1	 -30.0	 30.0;
	4554	 2411	 0.010818	 0.066769	 0.02286	 260.439993	 260.439993	 260.439993	 0.0	 0.0	 1	 -30.0	 30.0;
	1703	 2185	 0.006649	 0.024138	 0.0076	 136.837556	 136.837556	 136.837556	 0.0	 0.0	 1	 -30.0	 30.0;
	1703	 2185	 0.007542	 0.023662	 0.00861	 147.089825	 147.089825	 147.089825	 0.0	 0.0	 1	 -30.0	 30.0;
	1703	 2185	 0.007991	 0.036622	 0.01082	 144.150361	 144.150361	 144.150361	 0.0	 0.0	 1	 -30.0	 30.0;
	1703	 2185	 0.0116	 0.046018	 0.01267	 106.441624	 106.441624	 106.441624	 0.0	 0.0	 1	 -30.0	 30.0;
	3746	 1950	 0.011631	 0.047049	 0.01341	 159.687377	 159.687377	 159.687377	 0.0	 0.0	 1	 -30.0	 30.0;
	4431	 6671	 0.018822	 0.064009	 0.02166	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1135	 5376	 0.008071	 0.049138	 0.01524	 108.365499	 108.365499	 108.365499	 0.0	 0.0	 1	 -30.0	 30.0;
	1135	 4338	 0.007889	 0.045502	 0.01491	 110.382645	 110.382645	 110.382645	 0.0	 0.0	 1	 -30.0	 30.0;
	1135	 7504	 0.009822	 0.057222	 0.01832	 183.818309	 183.818309	 183.818309	 0.0	 0.0	 1	 -30.0	 30.0;
	2185	 3375	 0.00656	 0.023831	 0.00751	 118.238448	 118.238448	 118.238448	 0.0	 0.0	 1	 -30.0	 30.0;
	2185	 3375	 0.007431	 0.023351	 0.00851	 118.866403	 118.866403	 118.866403	 0.0	 0.0	 1	 -30.0	 30.0;
	2185	 6717	 0.007391	 0.026978	 0.00947	 115.758585	 115.758585	 115.758585	 0.0	 0.0	 1	 -30.0	 30.0;
	2185	 3895	 0.001871	 0.012142	 0.01489	 134.153224	 134.153224	 134.153224	 0.0	 0.0	 1	 -30.0	 30.0;
	2185	 896	 0.003969	 0.026169	 0.00779	 119.319768	 119.319768	 119.319768	 0.0	 0.0	 1	 -30.0	 30.0;
	2185	 2009	 0.008151	 0.04664	 0.06245	 299.425166	 299.425166	 299.425166	 0.0	 0.0	 1	 -30.0	 30.0;
	7430	 34	 0.00076	 0.005622	 0.00181	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	7430	 3375	 0.0094	 0.035791	 0.01011	 146.850542	 146.850542	 146.850542	 0.0	 0.0	 1	 -30.0	 30.0;
	7430	 7067	 0.00844	 0.031031	 0.00921	 227.193711	 227.193711	 227.193711	 0.0	 0.0	 1	 -30.0	 30.0;
	7430	 1537	 0.00028	 0.002062	 0.00069	 141.617757	 141.617757	 141.617757	 0.0	 0.0	 1	 -30.0	 30.0;
	7430	 2623	 0.004849	 0.030031	 0.01219	 113.232735	 113.232735	 113.232735	 0.0	 0.0	 1	 -30.0	 30.0;
	7430	 3895	 0.00268	 0.022391	 0.01774	 152.859113	 152.859113	 152.859113	 0.0	 0.0	 1	 -30.0	 30.0;
	7430	 896	 0.002391	 0.025382	 0.01581	 139.891075	 139.891075	 139.891075	 0.0	 0.0	 1	 -30.0	 30.0;
	498	 3375	 0.017551	 0.078191	 0.0223	 163.445754	 163.445754	 163.445754	 0.0	 0.0	 1	 -30.0	 30.0;
	5900	 1407	 0.003849	 0.02475	 0.12668	 602.904127	 602.904127	 602.904127	 0.0	 0.0	 1	 -30.0	 30.0;
	5900	 6385	 0.0042	 0.02005	 0.13817	 327.881964	 327.881964	 327.881964	 0.0	 0.0	 1	 -30.0	 30.0;
	5900	 3262	 0.00011	 0.000581	 0.00098	 302.33172	 302.33172	 302.33172	 0.0	 0.0	 1	 -30.0	 30.0;
	5900	 707	 0.000169	 0.000651	 0.00086	 304.632126	 304.632126	 304.632126	 0.0	 0.0	 1	 -30.0	 30.0;
	5900	 3606	 0.000169	 0.000659	 0.00085	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 5676	 0.00219	 0.01125	 0.01789	 513.709954	 513.709954	 513.709954	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 8132	 0.00018	 0.000599	 0.05223	 500.565593	 500.565593	 500.565593	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 8042	 0.00018	 0.000591	 0.05321	 401.476664	 401.476664	 401.476664	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 1584	 0.00019	 0.000581	 0.0542	 442.430139	 442.430139	 442.430139	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 2970	 0.000169	 0.000651	 0.04828	 501.006469	 501.006469	 501.006469	 0.0	 0.0	 1	 -30.0	 30.0;
	291	 1804	 0.00231	 0.0138	 0.01967	 463.354803	 463.354803	 463.354803	 0.0	 0.0	 1	 -30.0	 30.0;
	291	 1804	 0.00082	 0.003841	 0.02703	 266.607029	 266.607029	 266.607029	 0.0	 0.0	 1	 -30.0	 30.0;
	291	 157	 0.00305	 0.01762	 0.02598	 513.482085	 513.482085	 513.482085	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 4846	 0.01101	 0.055469	 0.09147	 490.293216	 490.293216	 490.293216	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 7170	 0.009169	 0.0462	 0.07603	 547.455465	 547.455465	 547.455465	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 6385	 0.00201	 0.00905	 0.06553	 244.61085	 244.61085	 244.61085	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 1831	 0.005969	 0.038841	 0.04834	 563.18983	 563.18983	 563.18983	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 7040	 0.00474	 0.02687	 0.03965	 438.613531	 438.613531	 438.613531	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 5047	 0.005409	 0.03438	 0.04521	 478.014222	 478.014222	 478.014222	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 2922	 0.005401	 0.03264	 0.04378	 577.213657	 577.213657	 577.213657	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 8138	 0.00311	 0.015919	 0.02508	 619.294281	 619.294281	 619.294281	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 1619	 0.00462	 0.02613	 0.03855	 422.724078	 422.724078	 422.724078	 0.0	 0.0	 1	 -30.0	 30.0;
	2899	 1012	 0.01044	 0.05187	 0.08461	 482.839855	 482.839855	 482.839855	 0.0	 0.0	 1	 -30.0	 30.0;
	2899	 1012	 0.01001	 0.05113	 0.08454	 479.889375	 479.889375	 479.889375	 0.0	 0.0	 1	 -30.0	 30.0;
	2899	 7698	 0.008331	 0.051729	 0.06919	 543.580555	 543.580555	 543.580555	 0.0	 0.0	 1	 -30.0	 30.0;
	2899	 5698	 0.000169	 0.00089	 0.00138	 452.987162	 452.987162	 452.987162	 0.0	 0.0	 1	 -30.0	 30.0;
	2899	 3632	 0.00214	 0.01099	 0.01749	 511.973884	 511.973884	 511.973884	 0.0	 0.0	 1	 -30.0	 30.0;
	1804	 5286	 0.004669	 0.042349	 0.14328	 479.903855	 479.903855	 479.903855	 0.0	 0.0	 1	 -30.0	 30.0;
	1804	 6574	 0.00139	 0.008789	 0.01406	 431.020324	 431.020324	 431.020324	 0.0	 0.0	 1	 -30.0	 30.0;
	1804	 6574	 0.000219	 0.001669	 0.0088	 514.058615	 514.058615	 514.058615	 0.0	 0.0	 1	 -30.0	 30.0;
	1804	 157	 0.00119	 0.01063	 0.03653	 288.121941	 288.121941	 288.121941	 0.0	 0.0	 1	 -30.0	 30.0;
	2187	 1831	 0.004169	 0.02724	 0.03364	 527.666715	 527.666715	 527.666715	 0.0	 0.0	 1	 -30.0	 30.0;
	2187	 1831	 0.004081	 0.025219	 0.0329	 498.422561	 498.422561	 498.422561	 0.0	 0.0	 1	 -30.0	 30.0;
	2187	 286	 0.00168	 0.01039	 0.01372	 547.939019	 547.939019	 547.939019	 0.0	 0.0	 1	 -30.0	 30.0;
	2187	 1355	 0.0017	 0.01055	 0.01372	 497.428399	 497.428399	 497.428399	 0.0	 0.0	 1	 -30.0	 30.0;
	8104	 5261	 0.00139	 0.008771	 0.01153	 499.966581	 499.966581	 499.966581	 0.0	 0.0	 1	 -30.0	 30.0;
	8104	 5790	 0.000651	 0.00261	 0.29733	 493.939113	 493.939113	 493.939113	 0.0	 0.0	 1	 -30.0	 30.0;
	8104	 5790	 0.000729	 0.00256	 0.33698	 493.012016	 493.012016	 493.012016	 0.0	 0.0	 1	 -30.0	 30.0;
	8104	 1125	 0.0	 0.008169	 0.0	 404.240047	 404.240047	 404.240047	 0.0	 0.0	 1	 -30.0	 30.0;
	8104	 5121	 5e-05	 0.00025	 0.00043	 450.019155	 450.019155	 450.019155	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 7170	 0.003719	 0.022669	 0.03112	 519.4181	 519.4181	 519.4181	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 5817	 0.00732	 0.042711	 0.06424	 482.82385	 482.82385	 482.82385	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 5817	 0.003599	 0.025331	 0.1154	 369.041207	 369.041207	 369.041207	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 8170	 0.00494	 0.027401	 0.04149	 535.492744	 535.492744	 535.492744	 0.0	 0.0	 1	 -30.0	 30.0;
	4846	 6164	 0.0062	 0.03519	 0.05126	 539.983432	 539.983432	 539.983432	 0.0	 0.0	 1	 -30.0	 30.0;
	4846	 6164	 0.00739	 0.04574	 0.0607	 455.013592	 455.013592	 455.013592	 0.0	 0.0	 1	 -30.0	 30.0;
	4846	 2922	 0.006781	 0.034289	 0.05587	 584.529077	 584.529077	 584.529077	 0.0	 0.0	 1	 -30.0	 30.0;
	6164	 2779	 0.003669	 0.03205	 0.10948	 258.910557	 258.910557	 258.910557	 0.0	 0.0	 1	 -30.0	 30.0;
	6164	 2779	 0.002789	 0.026289	 0.08549	 283.904466	 283.904466	 283.904466	 0.0	 0.0	 1	 -30.0	 30.0;
	6164	 2320	 0.005979	 0.031979	 0.0487	 535.395576	 535.395576	 535.395576	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 5676	 0.00425	 0.02132	 0.03461	 570.209936	 570.209936	 570.209936	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 1407	 0.002469	 0.015099	 0.08158	 350.8704	 350.8704	 350.8704	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 8132	 0.004341	 0.02662	 0.03566	 516.018743	 516.018743	 516.018743	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 2970	 0.005219	 0.02287	 0.04417	 612.858327	 612.858327	 612.858327	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 6910	 0.0095	 0.04693	 0.07832	 501.863072	 501.863072	 501.863072	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 157	 0.01099	 0.052909	 0.09588	 472.44173	 472.44173	 472.44173	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 5817	 0.004901	 0.02949	 0.04115	 551.501085	 551.501085	 551.501085	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 4315	 0.00832	 0.038531	 0.07258	 476.250718	 476.250718	 476.250718	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 5145	 0.003909	 0.018091	 0.12873	 394.368154	 394.368154	 394.368154	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 3104	 0.000331	 0.00189	 0.00274	 490.106501	 490.106501	 490.106501	 0.0	 0.0	 1	 -30.0	 30.0;
	7170	 5817	 0.01101	 0.05514	 0.09527	 507.503011	 507.503011	 507.503011	 0.0	 0.0	 1	 -30.0	 30.0;
	7170	 6804	 0.00345	 0.01925	 0.02912	 474.958192	 474.958192	 474.958192	 0.0	 0.0	 1	 -30.0	 30.0;
	7667	 157	 0.00162	 0.00889	 0.05738	 309.690962	 309.690962	 309.690962	 0.0	 0.0	 1	 -30.0	 30.0;
	7667	 8170	 0.00039	 0.00464	 0.02069	 309.170827	 309.170827	 309.170827	 0.0	 0.0	 1	 -30.0	 30.0;
	7667	 4869	 0.00064	 0.010099	 0.03398	 218.940575	 218.940575	 218.940575	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 5261	 0.003151	 0.01613	 0.02679	 571.658693	 571.658693	 571.658693	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 5261	 0.002091	 0.012409	 0.01773	 636.331842	 636.331842	 636.331842	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 8289	 0.0	 0.00799	 0.0	 341.562844	 341.562844	 341.562844	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 4225	 0.0	 0.00906	 0.0	 307.358928	 307.358928	 307.358928	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 6381	 0.000909	 0.010401	 0.03008	 267.854972	 267.854972	 267.854972	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 2262	 0.003211	 0.016081	 0.02635	 593.164078	 593.164078	 593.164078	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 8042	 0.00314	 0.017711	 0.02587	 459.552674	 459.552674	 459.552674	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 1584	 0.00214	 0.010591	 0.01886	 492.373374	 492.373374	 492.373374	 0.0	 0.0	 1	 -30.0	 30.0;
	3159	 2922	 0.00056	 0.003169	 0.0046	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	6574	 6560	 0.001719	 0.0108	 0.01668	 522.053831	 522.053831	 522.053831	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 3603	 0.0005	 0.00174	 0.22866	 529.35782	 529.35782	 529.35782	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 5121	 0.00126	 0.00587	 0.01081	 430.454082	 430.454082	 430.454082	 0.0	 0.0	 1	 -30.0	 30.0;
	6311	 2320	 0.007909	 0.03607	 0.06443	 546.744042	 546.744042	 546.744042	 0.0	 0.0	 1	 -30.0	 30.0;
	6311	 6381	 0.00057	 0.00457	 0.02538	 267.860687	 267.860687	 267.860687	 0.0	 0.0	 1	 -30.0	 30.0;
	6311	 5121	 0.00132	 0.008409	 0.01076	 402.230002	 402.230002	 402.230002	 0.0	 0.0	 1	 -30.0	 30.0;
	157	 2230	 0.003581	 0.017289	 0.02899	 620.550226	 620.550226	 620.550226	 0.0	 0.0	 1	 -30.0	 30.0;
	157	 4315	 0.002711	 0.01526	 0.02361	 494.053048	 494.053048	 494.053048	 0.0	 0.0	 1	 -30.0	 30.0;
	157	 5725	 0.00039	 0.006081	 0.0198	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	157	 4869	 0.00037	 0.005409	 0.01987	 261.895712	 261.895712	 261.895712	 0.0	 0.0	 1	 -30.0	 30.0;
	157	 6560	 0.00244	 0.013789	 0.0212	 490.970725	 490.970725	 490.970725	 0.0	 0.0	 1	 -30.0	 30.0;
	3603	 2262	 0.000349	 0.00149	 0.16079	 550.921506	 550.921506	 550.921506	 0.0	 0.0	 1	 -30.0	 30.0;
	2230	 5817	 0.00212	 0.010531	 0.01776	 597.959988	 597.959988	 597.959988	 0.0	 0.0	 1	 -30.0	 30.0;
	341	 4851	 0.003039	 0.031151	 0.09065	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	341	 5145	 0.001831	 0.0187	 0.05439	 279.968208	 279.968208	 279.968208	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 3583	 0.006599	 0.043169	 0.06859	 443.944818	 443.944818	 443.944818	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 4634	 0.006729	 0.046599	 0.07008	 455.289854	 455.289854	 455.289854	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 3297	 0.002159	 0.010789	 0.01893	 486.167193	 486.167193	 486.167193	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 712	 0.0022	 0.01057	 0.0193	 495.111989	 495.111989	 495.111989	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 944	 0.003461	 0.02049	 0.02882	 356.186064	 356.186064	 356.186064	 0.0	 0.0	 1	 -30.0	 30.0;
	7276	 633	 0.00311	 0.019469	 0.0253	 512.820199	 512.820199	 512.820199	 0.0	 0.0	 1	 -30.0	 30.0;
	7276	 569	 0.01064	 0.065969	 0.0863	 497.949677	 497.949677	 497.949677	 0.0	 0.0	 1	 -30.0	 30.0;
	1012	 286	 0.003539	 0.020479	 0.02889	 498.225939	 498.225939	 498.225939	 0.0	 0.0	 1	 -30.0	 30.0;
	1012	 1355	 0.00357	 0.020719	 0.02875	 513.647461	 513.647461	 513.647461	 0.0	 0.0	 1	 -30.0	 30.0;
	1012	 3583	 0.00275	 0.013831	 0.02866	 465.97491	 465.97491	 465.97491	 0.0	 0.0	 1	 -30.0	 30.0;
	1012	 4634	 0.0028	 0.013531	 0.02919	 464.268563	 464.268563	 464.268563	 0.0	 0.0	 1	 -30.0	 30.0;
	5817	 5145	 0.005151	 0.04851	 0.15767	 277.590067	 277.590067	 277.590067	 0.0	 0.0	 1	 -30.0	 30.0;
	5817	 7698	 0.005401	 0.025281	 0.04781	 545.909159	 545.909159	 545.909159	 0.0	 0.0	 1	 -30.0	 30.0;
	5817	 7698	 0.0055	 0.02475	 0.04873	 527.681957	 527.681957	 527.681957	 0.0	 0.0	 1	 -30.0	 30.0;
	6804	 5047	 0.00093	 0.00538	 0.00796	 452.917049	 452.917049	 452.917049	 0.0	 0.0	 1	 -30.0	 30.0;
	6385	 1831	 0.010331	 0.061849	 0.08789	 563.379594	 563.379594	 563.379594	 0.0	 0.0	 1	 -30.0	 30.0;
	4284	 3297	 0.00686	 0.032771	 0.06007	 479.713711	 479.713711	 479.713711	 0.0	 0.0	 1	 -30.0	 30.0;
	4284	 712	 0.007	 0.032081	 0.06123	 479.183669	 479.183669	 479.183669	 0.0	 0.0	 1	 -30.0	 30.0;
	4851	 3799	 0.007729	 0.038099	 0.06307	 376.577256	 376.577256	 376.577256	 0.0	 0.0	 1	 -30.0	 30.0;
	3799	 633	 0.006581	 0.035281	 0.05409	 576.896622	 576.896622	 576.896622	 0.0	 0.0	 1	 -30.0	 30.0;
	3799	 633	 0.003711	 0.02651	 0.06934	 545.241176	 545.241176	 545.241176	 0.0	 0.0	 1	 -30.0	 30.0;
	3799	 3945	 0.00482	 0.021979	 0.03906	 580.827927	 580.827927	 580.827927	 0.0	 0.0	 1	 -30.0	 30.0;
	3799	 3945	 0.003979	 0.026099	 0.03226	 546.596575	 546.596575	 546.596575	 0.0	 0.0	 1	 -30.0	 30.0;
	1831	 8138	 0.0038	 0.017271	 0.0306	 566.906984	 566.906984	 566.906984	 0.0	 0.0	 1	 -30.0	 30.0;
	1831	 6950	 0.00626	 0.03626	 0.05054	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	7698	 569	 0.00538	 0.02588	 0.04673	 576.167671	 576.167671	 576.167671	 0.0	 0.0	 1	 -30.0	 30.0;
	7698	 569	 0.005479	 0.025341	 0.04763	 555.734945	 555.734945	 555.734945	 0.0	 0.0	 1	 -30.0	 30.0;
	115	 2801	 0.00134	 0.01235	 0.32442	 1227.161496	 1227.161496	 1227.161496	 0.0	 0.0	 1	 -30.0	 30.0;
	115	 484	 0.00127	 0.01399	 0.31268	 1359.478573	 1359.478573	 1359.478573	 0.0	 0.0	 1	 -30.0	 30.0;
	115	 4000	 0.00142	 0.01374	 0.33478	 1363.182148	 1363.182148	 1363.182148	 0.0	 0.0	 1	 -30.0	 30.0;
	7099	 7230	 0.00039	 0.00365	 0.10686	 1227.410946	 1227.410946	 1227.410946	 0.0	 0.0	 1	 -30.0	 30.0;
	7099	 6131	 0.00058	 0.00507	 0.1589	 1300.899956	 1300.899956	 1300.899956	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 5713	 0.00129	 0.01577	 0.31825	 1351.465898	 1351.465898	 1351.465898	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 2733	 0.00033	 0.00373	 0.08976	 1342.584426	 1342.584426	 1342.584426	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 2969	 0.00086	 0.00799	 0.22698	 1426.532564	 1426.532564	 1426.532564	 0.0	 0.0	 1	 -30.0	 30.0;
	1219	 2969	 0.00189	 0.02135	 0.4886	 1452.712963	 1452.712963	 1452.712963	 0.0	 0.0	 1	 -30.0	 30.0;
	1219	 1622	 0.00106	 0.01219	 0.27997	 1228.958325	 1228.958325	 1228.958325	 0.0	 0.0	 1	 -30.0	 30.0;
	1219	 2628	 0.00147	 0.01622	 0.30007	 1333.136262	 1333.136262	 1333.136262	 0.0	 0.0	 1	 -30.0	 30.0;
	1219	 1553	 0.00215	 0.02108	 0.53373	 1352.341935	 1352.341935	 1352.341935	 0.0	 0.0	 1	 -30.0	 30.0;
	397	 7335	 0.00063	 0.0052	 0.16628	 1412.027609	 1412.027609	 1412.027609	 0.0	 0.0	 1	 -30.0	 30.0;
	397	 2969	 0.00159	 0.01792	 0.39884	 1122.516252	 1122.516252	 1122.516252	 0.0	 0.0	 1	 -30.0	 30.0;
	5713	 1622	 0.00157	 0.01981	 0.38575	 1271.233182	 1271.233182	 1271.233182	 0.0	 0.0	 1	 -30.0	 30.0;
	5713	 2628	 0.00158	 0.02014	 0.37007	 1485.359314	 1485.359314	 1485.359314	 0.0	 0.0	 1	 -30.0	 30.0;
	7335	 2801	 0.0018	 0.02388	 0.43689	 1321.450947	 1321.450947	 1321.450947	 0.0	 0.0	 1	 -30.0	 30.0;
	7335	 490	 0.00034	 0.00318	 0.0802	 1376.978244	 1376.978244	 1376.978244	 0.0	 0.0	 1	 -30.0	 30.0;
	7335	 6422	 0.00015	 0.00132	 0.04405	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7335	 7798	 0.00014	 0.0015	 0.03925	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7335	 1051	 0.00013	 0.00153	 0.0382	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7335	 2961	 0.00013	 0.00156	 0.0374	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7335	 5277	 0.0004	 0.00449	 0.1079	 1293.301934	 1293.301934	 1293.301934	 0.0	 0.0	 1	 -30.0	 30.0;
	7335	 5277	 0.00045	 0.0044	 0.12229	 1176.523813	 1176.523813	 1176.523813	 0.0	 0.0	 1	 -30.0	 30.0;
	2801	 1737	 0.0023	 0.01984	 0.55722	 1211.833816	 1211.833816	 1211.833816	 0.0	 0.0	 1	 -30.0	 30.0;
	2801	 8202	 0.0002	 0.00235	 0.04846	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2801	 5449	 0.00019	 0.00239	 0.04747	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2801	 7083	 0.00169	 0.01602	 0.43288	 1343.870509	 1343.870509	 1343.870509	 0.0	 0.0	 1	 -30.0	 30.0;
	2801	 7827	 0.00024	 0.00253	 0.06629	 797.871283	 797.871283	 797.871283	 0.0	 0.0	 1	 -30.0	 30.0;
	2801	 7417	 0.00022	 0.00244	 0.05933	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2801	 5797	 0.00025	 0.00239	 0.06724	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7455	 7230	 0.00066	 0.0061	 0.16047	 1340.01292	 1340.01292	 1340.01292	 0.0	 0.0	 1	 -30.0	 30.0;
	7455	 7230	 0.00062	 0.00844	 0.15693	 1344.202231	 1344.202231	 1344.202231	 0.0	 0.0	 1	 -30.0	 30.0;
	7455	 7131	 0.00124	 0.01353	 0.30148	 1608.977894	 1608.977894	 1608.977894	 0.0	 0.0	 1	 -30.0	 30.0;
	7455	 5613	 0.00046	 0.00452	 0.11391	 1298.385053	 1298.385053	 1298.385053	 0.0	 0.0	 1	 -30.0	 30.0;
	2733	 2969	 0.00045	 0.00531	 0.11598	 1378.151778	 1378.151778	 1378.151778	 0.0	 0.0	 1	 -30.0	 30.0;
	2733	 490	 0.00123	 0.01433	 0.2963	 1158.833269	 1158.833269	 1158.833269	 0.0	 0.0	 1	 -30.0	 30.0;
	2733	 7083	 0.00174	 0.01696	 0.42719	 1453.287553	 1453.287553	 1453.287553	 0.0	 0.0	 1	 -30.0	 30.0;
	4373	 5613	 0.00086	 0.00877	 0.22716	 1406.842472	 1406.842472	 1406.842472	 0.0	 0.0	 1	 -30.0	 30.0;
	4373	 6131	 0.00096	 0.00999	 0.25055	 1245.017242	 1245.017242	 1245.017242	 0.0	 0.0	 1	 -30.0	 30.0;
	4373	 4481	 0.00082	 0.00761	 0.21375	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7230	 1553	 0.00185	 0.01803	 0.45656	 1301.671343	 1301.671343	 1301.671343	 0.0	 0.0	 1	 -30.0	 30.0;
	7230	 1854	 0.00138	 0.01246	 0.37547	 1493.903798	 1493.903798	 1493.903798	 0.0	 0.0	 1	 -30.0	 30.0;
	7230	 7240	 0.00062	 0.00605	 0.15171	 1516.857143	 1516.857143	 1516.857143	 0.0	 0.0	 1	 -30.0	 30.0;
	7230	 6131	 0.00073	 0.00817	 0.20141	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	484	 6810	 0.00094	 0.00999	 0.25635	 1341.339809	 1341.339809	 1341.339809	 0.0	 0.0	 1	 -30.0	 30.0;
	484	 3634	 0.00058	 0.00671	 0.1588	 1226.342063	 1226.342063	 1226.342063	 0.0	 0.0	 1	 -30.0	 30.0;
	1622	 1553	 0.00108	 0.01279	 0.28634	 1367.692651	 1367.692651	 1367.692651	 0.0	 0.0	 1	 -30.0	 30.0;
	1622	 7240	 0.00225	 0.02472	 0.55439	 1399.232603	 1399.232603	 1399.232603	 0.0	 0.0	 1	 -30.0	 30.0;
	1622	 4133	 0.00019	 0.00244	 0.04648	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1622	 5751	 0.00018	 0.00248	 0.04549	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1622	 237	 0.0001	 0.0011	 0.02571	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1622	 1880	 0.00011	 0.00108	 0.0262	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	7131	 5613	 0.00089	 0.00815	 0.21353	 1308.459804	 1308.459804	 1308.459804	 0.0	 0.0	 1	 -30.0	 30.0;
	5519	 2628	 0.0009	 0.00859	 0.21851	 1443.279279	 1443.279279	 1443.279279	 0.0	 0.0	 1	 -30.0	 30.0;
	5519	 6810	 0.00167	 0.02239	 0.4094	 1566.239679	 1566.239679	 1566.239679	 0.0	 0.0	 1	 -30.0	 30.0;
	2628	 4784	 2e-05	 0.00024	 0.00465	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	1553	 122	 0.00157	 0.01326	 0.32339	 1364.026592	 1364.026592	 1364.026592	 0.0	 0.0	 1	 -30.0	 30.0;
	1737	 5050	 0.00155	 0.0139	 0.4163	 1375.657937	 1375.657937	 1375.657937	 0.0	 0.0	 1	 -30.0	 30.0;
	122	 1854	 0.00142	 0.01472	 0.27463	 1370.532694	 1370.532694	 1370.532694	 0.0	 0.0	 1	 -30.0	 30.0;
	4276	 1854	 0.00187	 0.02232	 0.46033	 1539.649235	 1539.649235	 1539.649235	 0.0	 0.0	 1	 -30.0	 30.0;
	4276	 1431	 0.00049	 0.00572	 0.13733	 1355.403127	 1355.403127	 1355.403127	 0.0	 0.0	 1	 -30.0	 30.0;
	1854	 1825	 0.0	 0.00021	 0.0	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6810	 3634	 0.00104	 0.00939	 0.28304	 1374.410029	 1374.410029	 1374.410029	 0.0	 0.0	 1	 -30.0	 30.0;
	6810	 7200	 0.00043	 0.0049	 0.11771	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6810	 7200	 0.00049	 0.0048	 0.13341	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	34	 1068	 0.002009	 0.01464	 0.00501	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	1068	 3375	 0.003302	 0.026	 0.00828	 112.938893	 112.938893	 112.938893	 0.0	 0.0	 1	 -30.0	 30.0;
	350	 3879	 0.006222	 0.018089	 0.00683	 253.457923	 253.457923	 253.457923	 0.0	 0.0	 1	 -30.0	 30.0;
	3375	 6717	 0.0	 0.000222	 0.0	 128.072167	 128.072167	 128.072167	 0.0	 0.0	 1	 -30.0	 30.0;
	3375	 2623	 8.9e-05	 0.000911	 0.00057	 113.159469	 113.159469	 113.159469	 0.0	 0.0	 1	 -30.0	 30.0;
	7957	 7067	 1.8e-05	 0.000222	 2e-05	 227.157857	 227.157857	 227.157857	 0.0	 0.0	 1	 -30.0	 30.0;
	5861	 6717	 0.00388	 0.014289	 0.00423	 290.456607	 290.456607	 290.456607	 0.0	 0.0	 1	 -30.0	 30.0;
	3655	 553	 0.001329	 0.007898	 0.0024	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3655	 4164	 0.00048	 0.002951	 0.00086	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	3655	 7263	 8e-05	 0.00032	 0.00013	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	2584	 4844	 0.000302	 0.001102	 0.00033	 222.634087	 222.634087	 222.634087	 0.0	 0.0	 1	 -30.0	 30.0;
	5907	 276	 0.003742	 0.013098	 0.00419	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	6867	 5567	 0.008911	 0.032298	 0.00997	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	5376	 5931	 0.00124	 0.005409	 0.00234	 103.923048	 103.923048	 103.923048	 0.0	 0.0	 1	 -30.0	 30.0;
	633	 6444	 0.0025	 0.0123	 0.02024	 403.312569	 403.312569	 403.312569	 0.0	 0.0	 1	 -30.0	 30.0;
	633	 6444	 0.001781	 0.013729	 0.01974	 401.755593	 401.755593	 401.755593	 0.0	 0.0	 1	 -30.0	 30.0;
	633	 3945	 0.00324	 0.016039	 0.0262	 561.348972	 561.348972	 561.348972	 0.0	 0.0	 1	 -30.0	 30.0;
	8170	 5725	 0.00037	 0.00474	 0.01951	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	7040	 1619	 9.1e-05	 0.000521	 0.00072	 436.347038	 436.347038	 436.347038	 0.0	 0.0	 1	 -30.0	 30.0;
	5725	 4869	 3.1e-05	 0.00043	 0.00154	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1619	 6994	 0.001281	 0.005909	 0.01151	 217.253281	 217.253281	 217.253281	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 5254	 0.000909	 0.00476	 0.00825	 243.140754	 243.140754	 243.140754	 0.0	 0.0	 1	 -30.0	 30.0;
	4634	 4786	 0.00011	 0.000599	 0.00118	 236.54895	 236.54895	 236.54895	 0.0	 0.0	 1	 -30.0	 30.0;
	3297	 7193	 0.000289	 0.001719	 0.0026	 218.698608	 218.698608	 218.698608	 0.0	 0.0	 1	 -30.0	 30.0;
	6560	 3730	 0.00026	 0.001591	 0.0021	 528.884936	 528.884936	 528.884936	 0.0	 0.0	 1	 -30.0	 30.0;
	5277	 3634	 0.00108	 0.01382	 0.26699	 1483.316984	 1483.316984	 1483.316984	 0.0	 0.0	 1	 -30.0	 30.0;
	6645	 6950	 0.0	 0.0002	 0.0	 575.947042	 575.947042	 575.947042	 0.0	 0.0	 1	 -30.0	 30.0;
	2107	 4858	 0.014281	 0.033446	 0.00353	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5772	 4858	 0.038273	 0.11138	 0.00969	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2534	 194	 0.039504	 0.11795	 0.01	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2644	 2534	 0.039893	 0.095083	 0.0101	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4193	 4827	 0.025107	 0.052256	 0.00463	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 4193	 0.010124	 0.017818	 0.00172	 74.058058	 74.058058	 74.058058	 0.0	 0.0	 1	 -30.0	 30.0;
	463	 6200	 0.035198	 0.083893	 0.0089	 68.904722	 68.904722	 68.904722	 0.0	 0.0	 1	 -30.0	 30.0;
	6200	 5912	 0.026149	 0.064851	 0.00661	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6530	 6725	 0.0	 0.000793	 0.0	 65.920711	 65.920711	 65.920711	 0.0	 0.0	 1	 -30.0	 30.0;
	3416	 6530	 0.02086	 0.051744	 0.00528	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	189	 6725	 0.041992	 0.117446	 0.01062	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 4594	 0.014031	 0.079591	 0.1339	 465.081345	 465.081345	 465.081345	 0.0	 0.0	 1	 -30.0	 30.0;
	4594	 3054	 0.0075	 0.054099	 0.07157	 418.588529	 418.588529	 418.588529	 0.0	 0.0	 1	 -30.0	 30.0;
	3126	 4594	 0.013841	 0.0733	 0.1173	 444.287002	 444.287002	 444.287002	 0.0	 0.0	 1	 -30.0	 30.0;
	4594	 1903	 0.006469	 0.041401	 0.06178	 438.215713	 438.215713	 438.215713	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 2349	 0.005628	 0.015826	 0.00148	 60.587328	 60.587328	 60.587328	 0.0	 0.0	 1	 -30.0	 30.0;
	7842	 1822	 0.026364	 0.056017	 0.00691	 73.95346	 73.95346	 73.95346	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 3416	 0.026099	 0.062182	 0.0066	 78.776234	 78.776234	 78.776234	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 3312	 0.04481	 0.131231	 0.01175	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	189	 2349	 0.005512	 0.01614	 0.00145	 60.681257	 60.681257	 60.681257	 0.0	 0.0	 1	 -30.0	 30.0;
	7842	 189	 0.023488	 0.063479	 0.00615	 74.435109	 74.435109	 74.435109	 0.0	 0.0	 1	 -30.0	 30.0;
	189	 5672	 0.044198	 0.129446	 0.01159	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	815	 1296	 0.006612	 0.01657	 0.00134	 57.946834	 57.946834	 57.946834	 0.0	 0.0	 1	 -30.0	 30.0;
	2488	 815	 0.003967	 0.007521	 0.00081	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5273	 5749	 0.027496	 0.067438	 0.00692	 60.886453	 60.886453	 60.886453	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 5273	 0.044587	 0.102702	 0.01169	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5273	 4082	 0.051438	 0.143868	 0.01301	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5273	 8189	 0.029256	 0.072579	 0.0074	 65.149272	 65.149272	 65.149272	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 5273	 0.049149	 0.122653	 0.01289	 60.444815	 60.444815	 60.444815	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 5273	 0.043372	 0.125157	 0.01138	 64.753741	 64.753741	 64.753741	 0.0	 0.0	 1	 -30.0	 30.0;
	6339	 5273	 0.016471	 0.042529	 0.00417	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6788	 53	 0.0	 0.00076	 0.0	 68.203017	 68.203017	 68.203017	 0.0	 0.0	 1	 -30.0	 30.0;
	53	 4054	 0.038017	 0.110653	 0.00962	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4667	 53	 0.025174	 0.07938	 0.00637	 60.621813	 60.621813	 60.621813	 0.0	 0.0	 1	 -30.0	 30.0;
	4967	 53	 0.043017	 0.128446	 0.01089	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	611	 6788	 0.051636	 0.189413	 0.0171	 58.680357	 58.680357	 58.680357	 0.0	 0.0	 1	 -30.0	 30.0;
	6788	 3206	 0.04714	 0.113008	 0.01237	 59.467037	 59.467037	 59.467037	 0.0	 0.0	 1	 -30.0	 30.0;
	2562	 6788	 0.008149	 0.025711	 0.00206	 89.141588	 89.141588	 89.141588	 0.0	 0.0	 1	 -30.0	 30.0;
	4122	 591	 0.039686	 0.102843	 0.00902	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6449	 591	 0.006372	 0.01857	 0.00161	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	591	 4228	 0.045711	 0.108901	 0.01156	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 1339	 0.04119	 0.106331	 0.01042	 62.746364	 62.746364	 62.746364	 0.0	 0.0	 1	 -30.0	 30.0;
	3061	 1084	 0.013752	 0.03024	 0.00348	 60.766231	 60.766231	 60.766231	 0.0	 0.0	 1	 -30.0	 30.0;
	5305	 4268	 0.00595	 0.019008	 0.03594	 64.491388	 64.491388	 64.491388	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 7195	 0.00576	 0.020331	 0.00191	 72.233395	 72.233395	 72.233395	 0.0	 0.0	 1	 -30.0	 30.0;
	2588	 7273	 0.03586	 0.082107	 0.00907	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	385	 2588	 0.022223	 0.055099	 0.00563	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2847	 6023	 0.008802	 0.02862	 0.00292	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6023	 6849	 0.032719	 0.124942	 0.01084	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	689	 7464	 0.019793	 0.055331	 0.00501	 68.189299	 68.189299	 68.189299	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 7470	 0.01395	 0.034612	 0.00354	 60.571324	 60.571324	 60.571324	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 2012	 0.004727	 0.010107	 0.00096	 60.340788	 60.340788	 60.340788	 0.0	 0.0	 1	 -30.0	 30.0;
	7909	 3349	 0.007289	 0.014364	 0.00147	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4748	 3685	 0.004818	 0.009901	 0.00098	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	422	 4748	 0.012223	 0.031554	 0.00309	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1237	 2859	 0.00108	 0.01189	 0.26132	 1356.757001	 1356.757001	 1356.757001	 0.0	 0.0	 1	 -30.0	 30.0;
	881	 1237	 0.0032	 0.03265	 0.68253	 1330.714163	 1330.714163	 1330.714163	 0.0	 0.0	 1	 -30.0	 30.0;
	6086	 1237	 0.0007	 0.00731	 0.17234	 1421.017022	 1421.017022	 1421.017022	 0.0	 0.0	 1	 -30.0	 30.0;
	2296	 5212	 0.0	 0.000744	 0.0	 124.957922	 124.957922	 124.957922	 0.0	 0.0	 1	 -30.0	 30.0;
	2296	 3837	 0.009248	 0.022041	 0.00234	 72.545476	 72.545476	 72.545476	 0.0	 0.0	 1	 -30.0	 30.0;
	5212	 7785	 0.008124	 0.02286	 0.00213	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7682	 6819	 0.007702	 0.019893	 0.00195	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6819	 6625	 0.015579	 0.04914	 0.00394	 68.778213	 68.778213	 68.778213	 0.0	 0.0	 1	 -30.0	 30.0;
	8002	 2839	 0.00981	 0.068021	 0.09367	 391.775101	 391.775101	 391.775101	 0.0	 0.0	 1	 -30.0	 30.0;
	8002	 1545	 0.006341	 0.042211	 0.06052	 402.213617	 402.213617	 402.213617	 0.0	 0.0	 1	 -30.0	 30.0;
	900	 5630	 0.060281	 0.144512	 0.01581	 59.368155	 59.368155	 59.368155	 0.0	 0.0	 1	 -30.0	 30.0;
	900	 5630	 0.061438	 0.141504	 0.01611	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 2488	 0.016579	 0.039917	 0.00336	 65.171945	 65.171945	 65.171945	 0.0	 0.0	 1	 -30.0	 30.0;
	1443	 3397	 0.0	 0.000843	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2041	 1443	 0.010256	 0.022711	 0.00269	 58.03238	 58.03238	 58.03238	 0.0	 0.0	 1	 -30.0	 30.0;
	1443	 4425	 0.024983	 0.073149	 0.00655	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3397	 3883	 0.008388	 0.02557	 0.0022	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2323	 2599	 0.063512	 0.200339	 0.01607	 72.928813	 72.928813	 72.928813	 0.0	 0.0	 1	 -30.0	 30.0;
	4122	 2323	 0.037562	 0.085967	 0.0095	 84.731111	 84.731111	 84.731111	 0.0	 0.0	 1	 -30.0	 30.0;
	2756	 676	 0.002579	 0.007752	 0.00086	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 676	 0.001777	 0.00495	 0.00059	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5999	 6182	 0.030248	 0.084612	 0.00765	 59.990221	 59.990221	 59.990221	 0.0	 0.0	 1	 -30.0	 30.0;
	6182	 7860	 0.013281	 0.037124	 0.00336	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4965	 7536	 0.009488	 0.023521	 0.0024	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	111	 7536	 0.022579	 0.058314	 0.00571	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4149	 4397	 0.02743	 0.062793	 0.00694	 59.955545	 59.955545	 59.955545	 0.0	 0.0	 1	 -30.0	 30.0;
	6547	 4149	 0.001719	 0.003777	 0.00044	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2513	 1815	 0.035992	 0.085876	 0.00756	 64.022314	 64.022314	 64.022314	 0.0	 0.0	 1	 -30.0	 30.0;
	7452	 2513	 0.008777	 0.01962	 0.00184	 62.73417	 62.73417	 62.73417	 0.0	 0.0	 1	 -30.0	 30.0;
	2755	 7314	 0.001793	 0.001521	 0.05227	 64.767269	 64.767269	 64.767269	 0.0	 0.0	 1	 -30.0	 30.0;
	7314	 2070	 0.004917	 0.007702	 0.05306	 62.1866	 62.1866	 62.1866	 0.0	 0.0	 1	 -30.0	 30.0;
	6465	 3849	 0.001521	 0.004554	 0.00039	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	459	 3849	 0.011198	 0.041099	 0.00372	 57.865098	 57.865098	 57.865098	 0.0	 0.0	 1	 -30.0	 30.0;
	1582	 58	 0.00144	 0.01155	 0.30699	 1223.007068	 1223.007068	 1223.007068	 0.0	 0.0	 1	 -30.0	 30.0;
	1582	 5851	 0.00123	 0.01345	 0.26344	 1084.259579	 1084.259579	 1084.259579	 0.0	 0.0	 1	 -30.0	 30.0;
	411	 5669	 0.007669	 0.02419	 0.00194	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	411	 169	 0.003661	 0.008769	 0.00096	 80.225943	 80.225943	 80.225943	 0.0	 0.0	 1	 -30.0	 30.0;
	7840	 411	 0.00943	 0.036008	 0.00395	 71.538929	 71.538929	 71.538929	 0.0	 0.0	 1	 -30.0	 30.0;
	5686	 411	 0.012661	 0.037802	 0.0032	 79.671514	 79.671514	 79.671514	 0.0	 0.0	 1	 -30.0	 30.0;
	1832	 724	 0.006083	 0.024099	 0.00201	 60.668873	 60.668873	 60.668873	 0.0	 0.0	 1	 -30.0	 30.0;
	1832	 1053	 0.002248	 0.004248	 0.00045	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1605	 4317	 0.019651	 0.141771	 0.18755	 384.928373	 384.928373	 384.928373	 0.0	 0.0	 1	 -30.0	 30.0;
	4317	 3310	 0.004841	 0.02718	 0.04644	 410.355537	 410.355537	 410.355537	 0.0	 0.0	 1	 -30.0	 30.0;
	4317	 3310	 0.00493	 0.02661	 0.04733	 420.565423	 420.565423	 420.565423	 0.0	 0.0	 1	 -30.0	 30.0;
	3939	 4317	 0.008729	 0.04569	 0.08329	 403.289705	 403.289705	 403.289705	 0.0	 0.0	 1	 -30.0	 30.0;
	8025	 6410	 0.002529	 0.005793	 0.00064	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6410	 5542	 0.003579	 0.007876	 0.0009	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7439	 769	 0.014182	 0.03119	 0.00359	 59.346435	 59.346435	 59.346435	 0.0	 0.0	 1	 -30.0	 30.0;
	7439	 3462	 0.061124	 0.192777	 0.01547	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4616	 4255	 0.114603	 0.284256	 0.029	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4255	 6909	 0.00786	 0.019488	 0.00199	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8025	 7793	 0.002669	 0.006124	 0.00068	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3302	 4583	 0.00895	 0.022182	 0.00227	 59.347387	 59.347387	 59.347387	 0.0	 0.0	 1	 -30.0	 30.0;
	4583	 212	 0.002281	 0.008033	 0.00067	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3302	 769	 0.005314	 0.013719	 0.00135	 74.904564	 74.904564	 74.904564	 0.0	 0.0	 1	 -30.0	 30.0;
	952	 4942	 0.031521	 0.069298	 0.00798	 62.993475	 62.993475	 62.993475	 0.0	 0.0	 1	 -30.0	 30.0;
	4942	 7793	 0.003719	 0.013223	 0.00109	 65.413341	 65.413341	 65.413341	 0.0	 0.0	 1	 -30.0	 30.0;
	4942	 212	 0.009719	 0.027818	 0.00249	 72.679796	 72.679796	 72.679796	 0.0	 0.0	 1	 -30.0	 30.0;
	4942	 3601	 0.042669	 0.127397	 0.0108	 66.477617	 66.477617	 66.477617	 0.0	 0.0	 1	 -30.0	 30.0;
	4942	 6088	 0.031157	 0.077281	 0.00788	 70.565724	 70.565724	 70.565724	 0.0	 0.0	 1	 -30.0	 30.0;
	5542	 769	 0.00319	 0.008934	 0.0008	 73.116481	 73.116481	 73.116481	 0.0	 0.0	 1	 -30.0	 30.0;
	769	 5977	 0.01462	 0.046124	 0.0037	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7480	 4026	 0.007587	 0.018628	 0.00172	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6704	 7480	 0.024529	 0.052826	 0.00551	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4642	 4614	 0.041223	 0.115314	 0.01044	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4642	 2469	 0.022512	 0.051521	 0.00569	 58.044573	 58.044573	 58.044573	 0.0	 0.0	 1	 -30.0	 30.0;
	6449	 4642	 0.063537	 0.189702	 0.01607	 61.891475	 61.891475	 61.891475	 0.0	 0.0	 1	 -30.0	 30.0;
	1671	 5069	 0.01524	 0.045496	 0.00385	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	433	 5069	 0.035876	 0.092612	 0.00908	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5669	 4820	 0.015471	 0.046198	 0.00392	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7635	 5124	 0.043364	 0.152818	 0.01437	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1159	 5124	 0.03095	 0.100686	 0.01025	 71.008315	 71.008315	 71.008315	 0.0	 0.0	 1	 -30.0	 30.0;
	1928	 5124	 0.035628	 0.107959	 0.00901	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1087	 5999	 0.010901	 0.034397	 0.00276	 72.671794	 72.671794	 72.671794	 0.0	 0.0	 1	 -30.0	 30.0;
	3129	 2529	 0.026099	 0.060099	 0.00685	 64.832809	 64.832809	 64.832809	 0.0	 0.0	 1	 -30.0	 30.0;
	2494	 3129	 0.025942	 0.057008	 0.00657	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8065	 1476	 0.001901	 0.004636	 0.05444	 76.443629	 76.443629	 76.443629	 0.0	 0.0	 1	 -30.0	 30.0;
	1476	 7943	 0.00176	 0.003124	 0.04966	 100.00993	 100.00993	 100.00993	 0.0	 0.0	 1	 -30.0	 30.0;
	3811	 2599	 0.003876	 0.010909	 0.00102	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2599	 647	 0.003802	 0.011124	 0.001	 123.885454	 123.885454	 123.885454	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 2599	 0.013339	 0.029298	 0.00337	 83.537278	 83.537278	 83.537278	 0.0	 0.0	 1	 -30.0	 30.0;
	1690	 2599	 0.031719	 0.11181	 0.01051	 57.739351	 57.739351	 57.739351	 0.0	 0.0	 1	 -30.0	 30.0;
	3065	 3371	 0.021521	 0.05557	 0.00545	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3846	 3065	 0.037008	 0.107752	 0.00937	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5908	 1791	 0.05743	 0.142463	 0.01454	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5908	 1412	 0.036091	 0.074041	 0.00732	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7159	 3815	 0.001211	 0.00545	 0.01025	 530.342456	 530.342456	 530.342456	 0.0	 0.0	 1	 -30.0	 30.0;
	1922	 3815	 0.013711	 0.078669	 0.11622	 256.521366	 256.521366	 256.521366	 0.0	 0.0	 1	 -30.0	 30.0;
	1130	 4136	 0.050521	 0.125331	 0.01278	 65.475262	 65.475262	 65.475262	 0.0	 0.0	 1	 -30.0	 30.0;
	4136	 4756	 0.085818	 0.221579	 0.02172	 58.640537	 58.640537	 58.640537	 0.0	 0.0	 1	 -30.0	 30.0;
	4136	 5093	 0.014909	 0.034132	 0.00377	 57.971602	 57.971602	 57.971602	 0.0	 0.0	 1	 -30.0	 30.0;
	4136	 4333	 0.035826	 0.113033	 0.00907	 58.796578	 58.796578	 58.796578	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 5752	 0.008289	 0.026017	 0.00285	 73.555452	 73.555452	 73.555452	 0.0	 0.0	 1	 -30.0	 30.0;
	3631	 5752	 0.023339	 0.089587	 0.00801	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3395	 2164	 0.00661	 0.039521	 0.05609	 422.507259	 422.507259	 422.507259	 0.0	 0.0	 1	 -30.0	 30.0;
	4707	 3395	 0.00349	 0.01574	 0.02958	 427.573716	 427.573716	 427.573716	 0.0	 0.0	 1	 -30.0	 30.0;
	689	 6168	 0.03714	 0.088496	 0.0094	 66.236411	 66.236411	 66.236411	 0.0	 0.0	 1	 -30.0	 30.0;
	689	 3545	 0.037256	 0.087669	 0.0077	 59.784453	 59.784453	 59.784453	 0.0	 0.0	 1	 -30.0	 30.0;
	689	 4170	 0.03081	 0.07957	 0.0078	 73.890396	 73.890396	 73.890396	 0.0	 0.0	 1	 -30.0	 30.0;
	4574	 4849	 0.033248	 0.096818	 0.00842	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8253	 4849	 0.011479	 0.034298	 0.00291	 62.691683	 62.691683	 62.691683	 0.0	 0.0	 1	 -30.0	 30.0;
	4400	 995	 0.0	 0.000893	 0.0	 73.883347	 73.883347	 73.883347	 0.0	 0.0	 1	 -30.0	 30.0;
	4400	 3083	 0.019273	 0.042628	 0.00505	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4400	 3396	 0.019628	 0.041702	 0.00515	 71.16931	 71.16931	 71.16931	 0.0	 0.0	 1	 -30.0	 30.0;
	5402	 4400	 0.029512	 0.062719	 0.00774	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6171	 995	 0.034901	 0.105744	 0.00883	 82.235607	 82.235607	 82.235607	 0.0	 0.0	 1	 -30.0	 30.0;
	2045	 995	 0.026289	 0.071083	 0.0069	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	505	 995	 0.041893	 0.121942	 0.0106	 79.374866	 79.374866	 79.374866	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 4614	 0.024851	 0.071711	 0.00652	 62.67263	 62.67263	 62.67263	 0.0	 0.0	 1	 -30.0	 30.0;
	6677	 5843	 0.006512	 0.01681	 0.00165	 82.122054	 82.122054	 82.122054	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 6677	 0.00305	 0.009099	 0.00077	 97.44355	 97.44355	 97.44355	 0.0	 0.0	 1	 -30.0	 30.0;
	1314	 6543	 0.014678	 0.04105	 0.00371	 65.903182	 65.903182	 65.903182	 0.0	 0.0	 1	 -30.0	 30.0;
	5719	 1314	 0.054149	 0.119066	 0.01371	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7527	 677	 0.08557	 0.197909	 0.01736	 60.643152	 60.643152	 60.643152	 0.0	 0.0	 1	 -30.0	 30.0;
	8021	 7527	 0.038314	 0.075496	 0.00777	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5910	 7497	 0.036554	 0.115289	 0.00925	 66.079799	 66.079799	 66.079799	 0.0	 0.0	 1	 -30.0	 30.0;
	2234	 5910	 0.047636	 0.11019	 0.00966	 62.689016	 62.689016	 62.689016	 0.0	 0.0	 1	 -30.0	 30.0;
	2040	 2512	 0.0	 0.000826	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4312	 2512	 0.013397	 0.037488	 0.00339	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2040	 837	 0.03095	 0.079917	 0.00783	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5057	 2040	 0.014058	 0.032198	 0.00356	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 8348	 0.03086	 0.093488	 0.00781	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5719	 4325	 0.023669	 0.071066	 0.00784	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5719	 4325	 0.028083	 0.078537	 0.00711	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	714	 2137	 0.016661	 0.052554	 0.00421	 61.464127	 61.464127	 61.464127	 0.0	 0.0	 1	 -30.0	 30.0;
	2137	 7366	 0.022223	 0.050868	 0.00563	 70.244308	 70.244308	 70.244308	 0.0	 0.0	 1	 -30.0	 30.0;
	302	 976	 0.017	 0.043909	 0.0043	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 7384	 0.017727	 0.05595	 0.00449	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	562	 1400	 0.022223	 0.052967	 0.00563	 59.312521	 59.312521	 59.312521	 0.0	 0.0	 1	 -30.0	 30.0;
	4753	 1400	 0.027628	 0.071347	 0.007	 71.483296	 71.483296	 71.483296	 0.0	 0.0	 1	 -30.0	 30.0;
	5503	 4171	 0.0	 0.00081	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5503	 8124	 0.002983	 0.010149	 0.00103	 66.738446	 66.738446	 66.738446	 0.0	 0.0	 1	 -30.0	 30.0;
	2325	 5503	 0.008678	 0.023463	 0.00227	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4171	 194	 0.002917	 0.010347	 0.00101	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2325	 4171	 0.008512	 0.023917	 0.00223	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 3613	 0.003603	 0.011339	 0.00091	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 2107	 0.006347	 0.015132	 0.00161	 61.53081	 61.53081	 61.53081	 0.0	 0.0	 1	 -30.0	 30.0;
	5200	 5197	 0.027777	 0.08295	 0.00703	 72.925384	 72.925384	 72.925384	 0.0	 0.0	 1	 -30.0	 30.0;
	433	 2798	 0.045438	 0.105124	 0.00921	 79.866041	 79.866041	 79.866041	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 7028	 0.07486	 0.187603	 0.01518	 61.222921	 61.222921	 61.222921	 0.0	 0.0	 1	 -30.0	 30.0;
	1631	 4503	 0.01919	 0.053198	 0.00636	 75.148436	 75.148436	 75.148436	 0.0	 0.0	 1	 -30.0	 30.0;
	7515	 4503	 0.008488	 0.032421	 0.00281	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 6724	 0.00365	 0.03434	 0.77731	 1056.42386	 1056.42386	 1056.42386	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 6724	 0.0049	 0.04432	 1.04447	 1149.693791	 1149.693791	 1149.693791	 0.0	 0.0	 1	 -30.0	 30.0;
	2839	 3057	 0.000901	 0.005539	 0.00767	 379.8703	 379.8703	 379.8703	 0.0	 0.0	 1	 -30.0	 30.0;
	1960	 2839	 0.00894	 0.06106	 0.08534	 439.024304	 439.024304	 439.024304	 0.0	 0.0	 1	 -30.0	 30.0;
	2839	 1613	 0.006919	 0.049419	 0.06639	 393.182704	 393.182704	 393.182704	 0.0	 0.0	 1	 -30.0	 30.0;
	2839	 2050	 0.006771	 0.04576	 0.06494	 488.8014	 488.8014	 488.8014	 0.0	 0.0	 1	 -30.0	 30.0;
	104	 3022	 0.0	 0.000793	 0.0	 83.085351	 83.085351	 83.085351	 0.0	 0.0	 1	 -30.0	 30.0;
	104	 7567	 0.019628	 0.061364	 0.0065	 73.65624	 73.65624	 73.65624	 0.0	 0.0	 1	 -30.0	 30.0;
	104	 5764	 0.011727	 0.033826	 0.00389	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3022	 5411	 0.006438	 0.01943	 0.00222	 68.756303	 68.756303	 68.756303	 0.0	 0.0	 1	 -30.0	 30.0;
	3022	 5411	 0.006562	 0.019033	 0.00226	 72.275882	 72.275882	 72.275882	 0.0	 0.0	 1	 -30.0	 30.0;
	4048	 3022	 0.006421	 0.020893	 0.00212	 79.051734	 79.051734	 79.051734	 0.0	 0.0	 1	 -30.0	 30.0;
	5226	 4307	 0.00031	 0.00355	 0.06244	 1279.201101	 1279.201101	 1279.201101	 0.0	 0.0	 1	 -30.0	 30.0;
	3899	 1925	 0.016752	 0.046397	 0.00554	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2956	 3899	 0.009347	 0.035702	 0.00309	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1925	 7569	 0.011298	 0.040033	 0.00388	 71.567889	 71.567889	 71.567889	 0.0	 0.0	 1	 -30.0	 30.0;
	7942	 1180	 0.001298	 0.004322	 0.03231	 80.957371	 80.957371	 80.957371	 0.0	 0.0	 1	 -30.0	 30.0;
	6988	 1180	 0.000347	 0.000876	 0.00862	 71.515113	 71.515113	 71.515113	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 761	 0.00028	 0.00301	 0.05904	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	58	 2203	 0.00297	 0.02796	 0.63316	 1107.326131	 1107.326131	 1107.326131	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 2905	 0.00274	 0.03157	 0.58502	 1041.633255	 1041.633255	 1041.633255	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 752	 0.00286	 0.010554	 0.00099	 87.597378	 87.597378	 87.597378	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 8357	 0.025818	 0.091446	 0.00886	 60.415474	 60.415474	 60.415474	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 5687	 0.027066	 0.065554	 0.00569	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 2576	 0.086198	 0.151504	 0.01811	 60.095962	 60.095962	 60.095962	 0.0	 0.0	 1	 -30.0	 30.0;
	683	 5687	 0.010893	 0.02719	 0.00286	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 5687	 0.03162	 0.072818	 0.00829	 61.947871	 61.947871	 61.947871	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 752	 0.002802	 0.010752	 0.00097	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 7895	 0.054802	 0.152636	 0.01881	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 6325	 0.014223	 0.048397	 0.00488	 58.741897	 58.741897	 58.741897	 0.0	 0.0	 1	 -30.0	 30.0;
	6528	 6141	 0.01814	 0.043521	 0.00476	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 3612	 0.038248	 0.07586	 0.00804	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7474	 6213	 0.017331	 0.061314	 0.00752	 81.248875	 81.248875	 81.248875	 0.0	 0.0	 1	 -30.0	 30.0;
	3031	 6213	 0.009182	 0.032339	 0.00384	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	761	 4003	 0.00281	 0.02539	 0.59834	 1059.348809	 1059.348809	 1059.348809	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 4003	 0.00158	 0.01426	 0.33592	 1083.291398	 1083.291398	 1083.291398	 0.0	 0.0	 1	 -30.0	 30.0;
	5731	 3247	 0.0	 0.000211	 0.0	 481.730234	 481.730234	 481.730234	 0.0	 0.0	 1	 -30.0	 30.0;
	8366	 5731	 0.00888	 0.061021	 0.08533	 430.049024	 430.049024	 430.049024	 0.0	 0.0	 1	 -30.0	 30.0;
	5731	 1613	 0.006961	 0.04406	 0.06676	 260.422568	 260.422568	 260.422568	 0.0	 0.0	 1	 -30.0	 30.0;
	3247	 8177	 0.00869	 0.06218	 0.08352	 372.454282	 372.454282	 372.454282	 0.0	 0.0	 1	 -30.0	 30.0;
	3247	 6592	 0.002401	 0.027581	 0.05743	 453.170067	 453.170067	 453.170067	 0.0	 0.0	 1	 -30.0	 30.0;
	3247	 2050	 0.00682	 0.04493	 0.0654	 446.563782	 446.563782	 446.563782	 0.0	 0.0	 1	 -30.0	 30.0;
	3120	 7280	 0.00238	 0.009446	 0.00082	 65.112882	 65.112882	 65.112882	 0.0	 0.0	 1	 -30.0	 30.0;
	6704	 3120	 0.017653	 0.060008	 0.00766	 101.485932	 101.485932	 101.485932	 0.0	 0.0	 1	 -30.0	 30.0;
	6659	 2757	 0.01838	 0.051397	 0.00465	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2757	 613	 0.02995	 0.071388	 0.00758	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3137	 3551	 0.023223	 0.042223	 0.00471	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3551	 574	 0.018636	 0.052124	 0.00471	 62.921076	 62.921076	 62.921076	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 2455	 0.00096	 0.01102	 0.20429	 1222.833967	 1222.833967	 1222.833967	 0.0	 0.0	 1	 -30.0	 30.0;
	2455	 4557	 0.00364	 0.02923	 0.77721	 1184.800418	 1184.800418	 1184.800418	 0.0	 0.0	 1	 -30.0	 30.0;
	2455	 2028	 0.00248	 0.02649	 0.61253	 1032.098211	 1032.098211	 1032.098211	 0.0	 0.0	 1	 -30.0	 30.0;
	6363	 2455	 0.00384	 0.04229	 0.81596	 1086.800151	 1086.800151	 1086.800151	 0.0	 0.0	 1	 -30.0	 30.0;
	5164	 2293	 0.0	 0.000219	 0.0	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	8366	 2293	 0.00344	 0.02181	 0.03305	 515.431162	 515.431162	 515.431162	 0.0	 0.0	 1	 -30.0	 30.0;
	2293	 8177	 0.00337	 0.02224	 0.03237	 479.544143	 479.544143	 479.544143	 0.0	 0.0	 1	 -30.0	 30.0;
	2293	 183	 0.010521	 0.05913	 0.101	 417.870248	 417.870248	 417.870248	 0.0	 0.0	 1	 -30.0	 30.0;
	2293	 491	 0.00081	 0.005341	 0.00777	 445.911423	 445.911423	 445.911423	 0.0	 0.0	 1	 -30.0	 30.0;
	2755	 2070	 0.002579	 0.00476	 0.08746	 98.981473	 98.981473	 98.981473	 0.0	 0.0	 1	 -30.0	 30.0;
	8096	 2755	 0.004388	 0.01595	 0.00141	 96.767184	 96.767184	 96.767184	 0.0	 0.0	 1	 -30.0	 30.0;
	2755	 6392	 0.004752	 0.017868	 0.00158	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1070	 4242	 0.00338	 0.012959	 0.00123	 70.15438	 70.15438	 70.15438	 0.0	 0.0	 1	 -30.0	 30.0;
	7176	 1070	 0.007008	 0.02338	 0.00385	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 4047	 0.025347	 0.057942	 0.0064	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3501	 5425	 0.06314	 0.162959	 0.01592	 60.459295	 60.459295	 60.459295	 0.0	 0.0	 1	 -30.0	 30.0;
	3488	 2768	 0.007967	 0.023802	 0.00202	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5959	 3488	 0.006636	 0.016463	 0.00168	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4538	 6884	 0.012091	 0.022893	 0.00245	 61.636552	 61.636552	 61.636552	 0.0	 0.0	 1	 -30.0	 30.0;
	4538	 3365	 0.012322	 0.022388	 0.0025	 58.161747	 58.161747	 58.161747	 0.0	 0.0	 1	 -30.0	 30.0;
	5573	 6173	 0.016529	 0.049347	 0.00419	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7592	 7942	 0.00119	 0.007017	 0.00066	 115.882045	 115.882045	 115.882045	 0.0	 0.0	 1	 -30.0	 30.0;
	7592	 4199	 0.002331	 0.009636	 0.0008	 123.945279	 123.945279	 123.945279	 0.0	 0.0	 1	 -30.0	 30.0;
	2758	 1645	 0.008091	 0.02681	 0.07328	 124.341	 124.341	 124.341	 0.0	 0.0	 1	 -30.0	 30.0;
	1285	 1645	 0.001347	 0.006876	 0.00074	 84.456183	 84.456183	 84.456183	 0.0	 0.0	 1	 -30.0	 30.0;
	6988	 1645	 0.002281	 0.009818	 0.00078	 58.258343	 58.258343	 58.258343	 0.0	 0.0	 1	 -30.0	 30.0;
	361	 7279	 0.001149	 0.00243	 0.0003	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3238	 361	 0.002909	 0.006909	 0.00073	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	613	 2010	 0.000413	 0.000959	 0.00011	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	613	 2010	 0.000421	 0.000942	 0.00011	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6543	 6894	 0.024628	 0.073504	 0.00623	 69.471345	 69.471345	 69.471345	 0.0	 0.0	 1	 -30.0	 30.0;
	6894	 5750	 0.041496	 0.094992	 0.0105	 70.87571	 70.87571	 70.87571	 0.0	 0.0	 1	 -30.0	 30.0;
	3006	 403	 0.01	 0.021273	 0.00519	 61.70838	 61.70838	 61.70838	 0.0	 0.0	 1	 -30.0	 30.0;
	403	 1690	 0.030479	 0.08795	 0.00799	 75.318385	 75.318385	 75.318385	 0.0	 0.0	 1	 -30.0	 30.0;
	403	 1690	 0.031157	 0.094992	 0.00817	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7773	 5604	 0.00962	 0.023298	 0.00202	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1719	 7773	 0.018248	 0.040397	 0.00105	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6161	 5099	 0.005868	 0.01781	 0.00149	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6161	 8192	 0.01	 0.02814	 0.00262	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6161	 32	 0.016562	 0.052033	 0.00569	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6161	 32	 0.016893	 0.050967	 0.0058	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5099	 3309	 0.013281	 0.033149	 0.00349	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4618	 1189	 0.005463	 0.020008	 0.0018	 61.681897	 61.681897	 61.681897	 0.0	 0.0	 1	 -30.0	 30.0;
	4618	 4771	 0.02695	 0.066868	 0.00682	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3309	 4618	 0.002752	 0.008397	 0.00073	 66.387689	 66.387689	 66.387689	 0.0	 0.0	 1	 -30.0	 30.0;
	5275	 4618	 0.002686	 0.007777	 0.00071	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4618	 32	 0.019099	 0.057876	 0.00483	 70.213824	 70.213824	 70.213824	 0.0	 0.0	 1	 -30.0	 30.0;
	4618	 3559	 0.017339	 0.043008	 0.00439	 71.455098	 71.455098	 71.455098	 0.0	 0.0	 1	 -30.0	 30.0;
	1189	 32	 0.017843	 0.068107	 0.00591	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	532	 7923	 0.022289	 0.070314	 0.00564	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7923	 2101	 0.035008	 0.101917	 0.00886	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1278	 900	 0.045231	 0.147174	 0.01498	 78.665158	 78.665158	 78.665158	 0.0	 0.0	 1	 -30.0	 30.0;
	4801	 900	 0.011413	 0.03424	 0.00377	 64.061562	 64.061562	 64.061562	 0.0	 0.0	 1	 -30.0	 30.0;
	6478	 2057	 0.001124	 0.002579	 0.00028	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6478	 5541	 0.046909	 0.135298	 0.01554	 60.989337	 60.989337	 60.989337	 0.0	 0.0	 1	 -30.0	 30.0;
	6478	 4533	 0.035446	 0.075124	 0.00838	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7580	 6478	 0.011107	 0.025793	 0.00221	 63.352045	 63.352045	 63.352045	 0.0	 0.0	 1	 -30.0	 30.0;
	6478	 8242	 0.005983	 0.023752	 0.00198	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4910	 3138	 0.016132	 0.04695	 0.00408	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4565	 3138	 0.008008	 0.019083	 0.00202	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3924	 418	 0.034281	 0.088488	 0.00867	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	418	 4588	 0.009149	 0.036372	 0.00303	 62.690159	 62.690159	 62.690159	 0.0	 0.0	 1	 -30.0	 30.0;
	418	 4328	 0.008711	 0.024124	 0.00288	 75.969602	 75.969602	 75.969602	 0.0	 0.0	 1	 -30.0	 30.0;
	418	 1396	 0.03624	 0.109818	 0.00917	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 2057	 0.036777	 0.116041	 0.00931	 60.759372	 60.759372	 60.759372	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 7736	 0.003851	 0.00995	 0.00098	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 7688	 0.025793	 0.056702	 0.00652	 67.765189	 67.765189	 67.765189	 0.0	 0.0	 1	 -30.0	 30.0;
	2759	 7273	 0.027942	 0.061421	 0.00707	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7736	 8100	 0.021488	 0.047248	 0.00543	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6807	 2859	 0.00015	 0.00136	 0.03769	 1250.611766	 1250.611766	 1250.611766	 0.0	 0.0	 1	 -30.0	 30.0;
	1087	 8204	 0.016909	 0.037174	 0.00428	 91.630424	 91.630424	 91.630424	 0.0	 0.0	 1	 -30.0	 30.0;
	3998	 1087	 0.040496	 0.088512	 0.00783	 64.588365	 64.588365	 64.588365	 0.0	 0.0	 1	 -30.0	 30.0;
	4512	 511	 0.035231	 0.111132	 0.00891	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2001	 4512	 0.031017	 0.086752	 0.00785	 71.246472	 71.246472	 71.246472	 0.0	 0.0	 1	 -30.0	 30.0;
	3613	 2107	 0.003983	 0.014017	 0.00131	 58.836779	 58.836779	 58.836779	 0.0	 0.0	 1	 -30.0	 30.0;
	6082	 905	 0.003521	 0.010496	 0.00089	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4312	 905	 0.002686	 0.00805	 0.00068	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6243	 952	 0.05195	 0.145298	 0.01315	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2800	 6772	 0.023207	 0.053132	 0.00588	 58.835445	 58.835445	 58.835445	 0.0	 0.0	 1	 -30.0	 30.0;
	1929	 2800	 0.049587	 0.150256	 0.01255	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2318	 1339	 0.036719	 0.111298	 0.0093	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	459	 2318	 0.008364	 0.023207	 0.00155	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1285	 5479	 0.005256	 0.024653	 0.00228	 86.869952	 86.869952	 86.869952	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 5479	 0.001347	 0.004397	 0.00058	 75.992655	 75.992655	 75.992655	 0.0	 0.0	 1	 -30.0	 30.0;
	7942	 6278	 0.005149	 0.022826	 0.00223	 105.030089	 105.030089	 105.030089	 0.0	 0.0	 1	 -30.0	 30.0;
	5196	 6278	 0.001207	 0.004992	 0.00052	 90.801828	 90.801828	 90.801828	 0.0	 0.0	 1	 -30.0	 30.0;
	3462	 4616	 0.003934	 0.009744	 0.001	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5066	 6543	 0.01438	 0.04186	 0.00364	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1296	 1677	 0.005744	 0.014967	 0.00116	 75.897011	 75.897011	 75.897011	 0.0	 0.0	 1	 -30.0	 30.0;
	5667	 257	 0.00176	 0.01659	 0.37579	 1099.764309	 1099.764309	 1099.764309	 0.0	 0.0	 1	 -30.0	 30.0;
	4557	 257	 0.00151	 0.01378	 0.37391	 1199.453463	 1199.453463	 1199.453463	 0.0	 0.0	 1	 -30.0	 30.0;
	4557	 257	 0.00128	 0.01392	 0.27253	 1157.297079	 1157.297079	 1157.297079	 0.0	 0.0	 1	 -30.0	 30.0;
	257	 3393	 0.00052	 0.00397	 0.12639	 1193.916859	 1193.916859	 1193.916859	 0.0	 0.0	 1	 -30.0	 30.0;
	2028	 257	 0.00221	 0.02248	 0.46986	 1174.877048	 1174.877048	 1174.877048	 0.0	 0.0	 1	 -30.0	 30.0;
	6449	 6169	 0.007182	 0.017107	 0.00181	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6169	 3734	 0.005149	 0.011339	 0.00131	 70.686137	 70.686137	 70.686137	 0.0	 0.0	 1	 -30.0	 30.0;
	7785	 3837	 0.00943	 0.02157	 0.00239	 60.571324	 60.571324	 60.571324	 0.0	 0.0	 1	 -30.0	 30.0;
	6499	 4026	 0.040636	 0.11257	 0.01346	 64.009358	 64.009358	 64.009358	 0.0	 0.0	 1	 -30.0	 30.0;
	6881	 6499	 0.014496	 0.042231	 0.00367	 61.590445	 61.590445	 61.590445	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 752	 0.002744	 0.00995	 0.00095	 65.892894	 65.892894	 65.892894	 0.0	 0.0	 1	 -30.0	 30.0;
	752	 5967	 0.003099	 0.009752	 0.00107	 58.241196	 58.241196	 58.241196	 0.0	 0.0	 1	 -30.0	 30.0;
	540	 7998	 0.007322	 0.016744	 0.00185	 67.776049	 67.776049	 67.776049	 0.0	 0.0	 1	 -30.0	 30.0;
	5357	 7998	 0.03024	 0.069231	 0.00766	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6107	 1238	 0.008438	 0.018669	 0.00221	 75.165012	 75.165012	 75.165012	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 459	 0.006727	 0.027942	 0.00292	 79.609403	 79.609403	 79.609403	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 459	 0.006587	 0.028488	 0.00286	 69.294728	 69.294728	 69.294728	 0.0	 0.0	 1	 -30.0	 30.0;
	611	 2277	 0.014579	 0.040463	 0.00356	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7168	 2277	 0.012826	 0.036992	 0.00424	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2277	 4484	 0.006909	 0.019917	 0.00229	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 7176	 0.003421	 0.011041	 0.00282	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 8096	 0.005364	 0.016289	 0.00213	 107.708116	 107.708116	 107.708116	 0.0	 0.0	 1	 -30.0	 30.0;
	4047	 3807	 0.012463	 0.030909	 0.00315	 62.666915	 62.666915	 62.666915	 0.0	 0.0	 1	 -30.0	 30.0;
	4047	 3807	 0.012702	 0.030273	 0.00321	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6384	 3807	 0.008331	 0.02438	 0.00218	 63.783204	 63.783204	 63.783204	 0.0	 0.0	 1	 -30.0	 30.0;
	6836	 3807	 0.008149	 0.024843	 0.00213	 77.311473	 77.311473	 77.311473	 0.0	 0.0	 1	 -30.0	 30.0;
	1521	 1665	 0.010789	 0.071169	 0.10359	 403.743537	 403.743537	 403.743537	 0.0	 0.0	 1	 -30.0	 30.0;
	3507	 1665	 0.011901	 0.08499	 0.11417	 379.984615	 379.984615	 379.984615	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 3969	 0.035942	 0.113397	 0.0091	 77.378729	 77.378729	 77.378729	 0.0	 0.0	 1	 -30.0	 30.0;
	2469	 1964	 0.035818	 0.078752	 0.00906	 65.780293	 65.780293	 65.780293	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 4045	 0.052587	 0.147083	 0.01331	 67.02614	 67.02614	 67.02614	 0.0	 0.0	 1	 -30.0	 30.0;
	5959	 1512	 0.007273	 0.016661	 0.00186	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2876	 1512	 0.023488	 0.072488	 0.0064	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8100	 2851	 0.004207	 0.011777	 0.00107	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7688	 2851	 0.005339	 0.020388	 0.00177	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7250	 1185	 0.007446	 0.01638	 0.00188	 59.851327	 59.851327	 59.851327	 0.0	 0.0	 1	 -30.0	 30.0;
	2782	 1185	 0.023033	 0.057124	 0.00582	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	169	 2440	 0.030198	 0.095248	 0.00765	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5702	 4661	 0.0	 0.000744	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2758	 5702	 0.003628	 0.012	 0.00897	 65.388954	 65.388954	 65.388954	 0.0	 0.0	 1	 -30.0	 30.0;
	5702	 3554	 0.00681	 0.028273	 0.00295	 59.498665	 59.498665	 59.498665	 0.0	 0.0	 1	 -30.0	 30.0;
	4661	 5196	 0.006669	 0.028826	 0.00289	 60.381179	 60.381179	 60.381179	 0.0	 0.0	 1	 -30.0	 30.0;
	2712	 1399	 0.04543	 0.100521	 0.01191	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2712	 1399	 0.046273	 0.098331	 0.01213	 68.304186	 68.304186	 68.304186	 0.0	 0.0	 1	 -30.0	 30.0;
	2120	 1399	 0.005041	 0.014554	 0.00167	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4401	 4346	 0.007818	 0.021653	 0.00258	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4346	 4848	 0.041992	 0.154033	 0.01391	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3891	 203	 0.003711	 0.009612	 0.00094	 60.694403	 60.694403	 60.694403	 0.0	 0.0	 1	 -30.0	 30.0;
	3998	 3891	 0.009959	 0.025719	 0.00252	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6849	 203	 0.006744	 0.014314	 0.00177	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1033	 6087	 0.023909	 0.052901	 0.00627	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6087	 6052	 0.024347	 0.051752	 0.00639	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3137	 860	 0.04324	 0.088702	 0.00877	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3137	 482	 0.045223	 0.125488	 0.01057	 63.044727	 63.044727	 63.044727	 0.0	 0.0	 1	 -30.0	 30.0;
	4771	 1198	 0.00305	 0.007893	 0.00078	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3974	 7614	 0.01905	 0.060107	 0.00482	 74.541231	 74.541231	 74.541231	 0.0	 0.0	 1	 -30.0	 30.0;
	7614	 7995	 0.023471	 0.055934	 0.00594	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7171	 2056	 0.004893	 0.014339	 0.00129	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4965	 6155	 0.022934	 0.050397	 0.0058	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	51	 6586	 0.037248	 0.081901	 0.00943	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1203	 6586	 0.013347	 0.039083	 0.0035	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4537	 6586	 0.013058	 0.039818	 0.00342	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6539	 7966	 0.04038	 0.11757	 0.01022	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7966	 6849	 0.037397	 0.111653	 0.00946	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	40	 2023	 0.029273	 0.069752	 0.00741	 57.391833	 57.391833	 57.391833	 0.0	 0.0	 1	 -30.0	 30.0;
	40	 2365	 0.023678	 0.070702	 0.00599	 72.881563	 72.881563	 72.881563	 0.0	 0.0	 1	 -30.0	 30.0;
	1170	 6168	 0.001868	 0.005463	 0.00047	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3190	 3947	 0.00048	 0.00423	 0.10377	 1166.341779	 1166.341779	 1166.341779	 0.0	 0.0	 1	 -30.0	 30.0;
	5305	 7963	 0.003992	 0.010289	 0.00101	 63.655742	 63.655742	 63.655742	 0.0	 0.0	 1	 -30.0	 30.0;
	5305	 3042	 0.003777	 0.009413	 0.00096	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5750	 5305	 0.015091	 0.047174	 0.005	 116.445048	 116.445048	 116.445048	 0.0	 0.0	 1	 -30.0	 30.0;
	7195	 3461	 0.013826	 0.039917	 0.00363	 66.956789	 66.956789	 66.956789	 0.0	 0.0	 1	 -30.0	 30.0;
	7195	 559	 0.015678	 0.039124	 0.00411	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7195	 5541	 0.066851	 0.192818	 0.02215	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7195	 8242	 0.039653	 0.128983	 0.01313	 59.370441	 59.370441	 59.370441	 0.0	 0.0	 1	 -30.0	 30.0;
	7963	 4527	 0.005091	 0.009702	 0.00107	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4527	 955	 0.004066	 0.010083	 0.00103	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 3461	 0.007661	 0.024058	 0.00263	 58.90613	 58.90613	 58.90613	 0.0	 0.0	 1	 -30.0	 30.0;
	7110	 3461	 0.045636	 0.13286	 0.01155	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3042	 955	 0.018421	 0.042868	 0.00387	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1706	 5097	 0.00805	 0.04211	 0.07677	 340.24174	 340.24174	 340.24174	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 3984	 0.003211	 0.02194	 0.03065	 399.074517	 399.074517	 399.074517	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 3939	 0.00974	 0.05531	 0.09304	 452.473505	 452.473505	 452.473505	 0.0	 0.0	 1	 -30.0	 30.0;
	8357	 1644	 0.019719	 0.05495	 0.00677	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5066	 2183	 0.03495	 0.086686	 0.00884	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5719	 2183	 0.041149	 0.122851	 0.01041	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3556	 540	 0.01124	 0.027893	 0.00285	 70.457887	 70.457887	 70.457887	 0.0	 0.0	 1	 -30.0	 30.0;
	4297	 1323	 0.02219	 0.057281	 0.00561	 62.827528	 62.827528	 62.827528	 0.0	 0.0	 1	 -30.0	 30.0;
	1323	 775	 0.011843	 0.030529	 0.00299	 64.128627	 64.128627	 64.128627	 0.0	 0.0	 1	 -30.0	 30.0;
	860	 574	 0.014298	 0.039983	 0.00362	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8116	 4047	 0.008083	 0.028636	 0.00277	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6384	 4047	 0.012942	 0.02962	 0.00327	 58.407715	 58.407715	 58.407715	 0.0	 0.0	 1	 -30.0	 30.0;
	2403	 5278	 0.01657	 0.050017	 0.00569	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1644	 2403	 0.006331	 0.019107	 0.00217	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 3631	 0.003983	 0.013537	 0.00136	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1414	 5667	 0.00136	 0.01515	 0.32663	 977.08561	 977.08561	 977.08561	 0.0	 0.0	 1	 -30.0	 30.0;
	5275	 8192	 0.007876	 0.01743	 0.00206	 68.791169	 68.791169	 68.791169	 0.0	 0.0	 1	 -30.0	 30.0;
	6549	 194	 0.018636	 0.055653	 0.00472	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2440	 6549	 0.010554	 0.031504	 0.00267	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5185	 1589	 0.013488	 0.039686	 0.00383	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1589	 4611	 0.021934	 0.048198	 0.00554	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1699	 7322	 0.0	 0.00086	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1699	 7704	 0.026463	 0.075669	 0.0078	 58.151268	 58.151268	 58.151268	 0.0	 0.0	 1	 -30.0	 30.0;
	1699	 878	 0.029446	 0.081364	 0.00876	 70.906575	 70.906575	 70.906575	 0.0	 0.0	 1	 -30.0	 30.0;
	4941	 1699	 0.055851	 0.127826	 0.01413	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2759	 7322	 0.047818	 0.124744	 0.0097	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4443	 3618	 0.02562	 0.063256	 0.00519	 66.478951	 66.478951	 66.478951	 0.0	 0.0	 1	 -30.0	 30.0;
	3618	 2721	 0.006372	 0.012298	 0.00144	 76.822204	 76.822204	 76.822204	 0.0	 0.0	 1	 -30.0	 30.0;
	1604	 2490	 0.009603	 0.021099	 0.00243	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8100	 6324	 0.014917	 0.052579	 0.00494	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	671	 6324	 0.03014	 0.083512	 0.00999	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6612	 5521	 0.03319	 0.092818	 0.0084	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 6157	 0.024248	 0.067826	 0.00613	 61.760013	 61.760013	 61.760013	 0.0	 0.0	 1	 -30.0	 30.0;
	7137	 7537	 0.048529	 0.153091	 0.01228	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3136	 7137	 0.055397	 0.137421	 0.01402	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8373	 6156	 0.0	 0.000219	 0.0	 418.489456	 418.489456	 418.489456	 0.0	 0.0	 1	 -30.0	 30.0;
	8373	 4978	 0.0013	 0.008539	 0.01243	 418.945193	 418.945193	 418.945193	 0.0	 0.0	 1	 -30.0	 30.0;
	4288	 8373	 0.007169	 0.04463	 0.06183	 410.887104	 410.887104	 410.887104	 0.0	 0.0	 1	 -30.0	 30.0;
	8373	 6550	 0.01787	 0.097419	 0.1706	 471.202933	 471.202933	 471.202933	 0.0	 0.0	 1	 -30.0	 30.0;
	6156	 4978	 0.00164	 0.007409	 0.01415	 393.902129	 393.902129	 393.902129	 0.0	 0.0	 1	 -30.0	 30.0;
	6156	 7830	 0.0097	 0.06274	 0.08217	 417.919784	 417.919784	 417.919784	 0.0	 0.0	 1	 -30.0	 30.0;
	4288	 6156	 0.007021	 0.045469	 0.06052	 430.680045	 430.680045	 430.680045	 0.0	 0.0	 1	 -30.0	 30.0;
	2565	 7357	 0.007496	 0.022397	 0.0019	 67.086918	 67.086918	 67.086918	 0.0	 0.0	 1	 -30.0	 30.0;
	3734	 7357	 0.007959	 0.024124	 0.00201	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6940	 2724	 0.00405	 0.011686	 0.00134	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6940	 1633	 0.005471	 0.01581	 0.00181	 71.405942	 71.405942	 71.405942	 0.0	 0.0	 1	 -30.0	 30.0;
	3525	 6449	 0.012727	 0.031579	 0.00322	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4280	 3525	 0.009529	 0.027496	 0.00315	 94.896033	 94.896033	 94.896033	 0.0	 0.0	 1	 -30.0	 30.0;
	834	 1883	 0.0	 0.000876	 0.0	 72.57253	 72.57253	 72.57253	 0.0	 0.0	 1	 -30.0	 30.0;
	7079	 1883	 0.01243	 0.040413	 0.00411	 61.274744	 61.274744	 61.274744	 0.0	 0.0	 1	 -30.0	 30.0;
	4280	 1883	 0.002636	 0.007967	 0.0009	 69.679971	 69.679971	 69.679971	 0.0	 0.0	 1	 -30.0	 30.0;
	4280	 1883	 0.002686	 0.007802	 0.00092	 74.785676	 74.785676	 74.785676	 0.0	 0.0	 1	 -30.0	 30.0;
	834	 4122	 0.049421	 0.127587	 0.01251	 67.451012	 67.451012	 67.451012	 0.0	 0.0	 1	 -30.0	 30.0;
	4980	 834	 0.006587	 0.018248	 0.00218	 64.696393	 64.696393	 64.696393	 0.0	 0.0	 1	 -30.0	 30.0;
	834	 1791	 0.064438	 0.166364	 0.01631	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6682	 1671	 0.085322	 0.155132	 0.0173	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	59	 4443	 0.050488	 0.130339	 0.01277	 70.636981	 70.636981	 70.636981	 0.0	 0.0	 1	 -30.0	 30.0;
	8012	 59	 0.035471	 0.111893	 0.00898	 66.772169	 66.772169	 66.772169	 0.0	 0.0	 1	 -30.0	 30.0;
	6539	 5028	 0.013876	 0.045132	 0.00459	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5028	 3998	 0.042744	 0.16319	 0.01416	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4559	 4234	 0.027512	 0.080083	 0.00696	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3671	 4559	 0.013132	 0.038223	 0.00332	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7860	 6817	 0.017347	 0.051802	 0.00439	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3136	 6817	 0.036446	 0.086851	 0.00922	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3529	 76	 0.0	 0.000893	 0.0	 102.53287	 102.53287	 102.53287	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 76	 0.013223	 0.056876	 0.00553	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	76	 5402	 0.01662	 0.035322	 0.00436	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6171	 3529	 0.023752	 0.069157	 0.00601	 81.376718	 81.376718	 81.376718	 0.0	 0.0	 1	 -30.0	 30.0;
	3529	 4723	 0.029851	 0.100967	 0.0125	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3529	 3778	 0.014322	 0.031504	 0.00363	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3529	 7072	 0.01481	 0.040017	 0.00388	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3969	 4045	 0.038066	 0.094413	 0.00963	 60.291442	 60.291442	 60.291442	 0.0	 0.0	 1	 -30.0	 30.0;
	5117	 5207	 0.018702	 0.058967	 0.00473	 66.096185	 66.096185	 66.096185	 0.0	 0.0	 1	 -30.0	 30.0;
	7072	 5117	 0.008554	 0.023917	 0.00217	 66.219836	 66.219836	 66.219836	 0.0	 0.0	 1	 -30.0	 30.0;
	1605	 1706	 0.009849	 0.05651	 0.08348	 411.435055	 411.435055	 411.435055	 0.0	 0.0	 1	 -30.0	 30.0;
	7682	 671	 0.013554	 0.032066	 0.00359	 73.749979	 73.749979	 73.749979	 0.0	 0.0	 1	 -30.0	 30.0;
	7682	 2270	 0.013719	 0.042876	 0.00454	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6732	 1141	 0.032512	 0.094636	 0.00823	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1141	 3846	 0.040008	 0.116479	 0.01013	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7039	 385	 0.02319	 0.055273	 0.00587	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	878	 7039	 0.013248	 0.046413	 0.00392	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4941	 7039	 0.073289	 0.23843	 0.02428	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5864	 274	 0.008083	 0.029661	 0.00268	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6516	 274	 0.014661	 0.058273	 0.00486	 63.092358	 63.092358	 63.092358	 0.0	 0.0	 1	 -30.0	 30.0;
	4397	 3241	 0.017273	 0.044587	 0.00437	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3241	 1555	 0.016413	 0.049	 0.00415	 75.052602	 75.052602	 75.052602	 0.0	 0.0	 1	 -30.0	 30.0;
	1563	 6981	 0.054587	 0.120008	 0.01382	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5772	 1563	 0.049521	 0.144149	 0.01253	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7842	 2349	 0.02757	 0.063124	 0.00698	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6669	 4297	 0.037686	 0.089818	 0.00954	 72.55062	 72.55062	 72.55062	 0.0	 0.0	 1	 -30.0	 30.0;
	5066	 559	 0.106033	 0.321289	 0.02683	 66.577452	 66.577452	 66.577452	 0.0	 0.0	 1	 -30.0	 30.0;
	8348	 5066	 0.066959	 0.153273	 0.01695	 76.383233	 76.383233	 76.383233	 0.0	 0.0	 1	 -30.0	 30.0;
	5066	 6088	 0.074421	 0.208132	 0.01884	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5066	 8362	 0.054157	 0.123967	 0.01371	 76.995391	 76.995391	 76.995391	 0.0	 0.0	 1	 -30.0	 30.0;
	613	 3843	 0.086802	 0.24276	 0.02196	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3843	 5359	 0.007628	 0.018826	 0.00155	 61.077741	 61.077741	 61.077741	 0.0	 0.0	 1	 -30.0	 30.0;
	2507	 532	 0.021256	 0.050669	 0.00538	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5936	 97	 0.015893	 0.046223	 0.00402	 59.092273	 59.092273	 59.092273	 0.0	 0.0	 1	 -30.0	 30.0;
	97	 3270	 0.01562	 0.034331	 0.00395	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7085	 5455	 0.011174	 0.023008	 0.00227	 74.269732	 74.269732	 74.269732	 0.0	 0.0	 1	 -30.0	 30.0;
	433	 7085	 0.014438	 0.036174	 0.00292	 78.725745	 78.725745	 78.725745	 0.0	 0.0	 1	 -30.0	 30.0;
	5455	 3270	 0.012636	 0.029752	 0.0025	 57.16968	 57.16968	 57.16968	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 7079	 0.0	 0.000826	 0.0	 67.968289	 67.968289	 67.968289	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 2565	 0.00086	 0.003157	 0.00029	 60.699357	 60.699357	 60.699357	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 1633	 0.01005	 0.027843	 0.00333	 89.241233	 89.241233	 89.241233	 0.0	 0.0	 1	 -30.0	 30.0;
	7079	 931	 0.000843	 0.003223	 0.00029	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5604	 1815	 0.022983	 0.064256	 0.00581	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 5502	 0.008603	 0.018273	 0.00226	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 5502	 0.007661	 0.020702	 0.00201	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 5967	 0.002678	 0.007174	 0.00092	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 5967	 0.002388	 0.008132	 0.00082	 63.232013	 63.232013	 63.232013	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 652	 0.00237	 0.011781	 0.0227	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2050	 3215	 0.001901	 0.012831	 0.01822	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 3685	 0.0	 0.00081	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 5106	 0.017273	 0.025289	 0.00279	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3685	 1007	 0.030909	 0.042397	 0.00506	 73.728068	 73.728068	 73.728068	 0.0	 0.0	 1	 -30.0	 30.0;
	3685	 960	 0.020967	 0.066149	 0.00531	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4368	 5182	 0.049719	 0.109298	 0.01258	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5182	 2107	 0.065909	 0.144901	 0.01668	 80.292246	 80.292246	 80.292246	 0.0	 0.0	 1	 -30.0	 30.0;
	1101	 6104	 0.00614	 0.05775	 1.30752	 1180.046388	 1180.046388	 1180.046388	 0.0	 0.0	 1	 -30.0	 30.0;
	5185	 7942	 0.020678	 0.079256	 0.00897	 60.659727	 60.659727	 60.659727	 0.0	 0.0	 1	 -30.0	 30.0;
	2023	 7942	 0.020529	 0.051702	 0.00562	 69.620527	 69.620527	 69.620527	 0.0	 0.0	 1	 -30.0	 30.0;
	1285	 3184	 0.015066	 0.050711	 0.0043	 64.759267	 64.759267	 64.759267	 0.0	 0.0	 1	 -30.0	 30.0;
	225	 5885	 0.032364	 0.074058	 0.00819	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 225	 0.024893	 0.069612	 0.0063	 60.249907	 60.249907	 60.249907	 0.0	 0.0	 1	 -30.0	 30.0;
	3501	 6981	 0.051289	 0.112769	 0.01298	 68.747348	 68.747348	 68.747348	 0.0	 0.0	 1	 -30.0	 30.0;
	7108	 8100	 0.024124	 0.069562	 0.00799	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8100	 1159	 0.026769	 0.10219	 0.01121	 88.596114	 88.596114	 88.596114	 0.0	 0.0	 1	 -30.0	 30.0;
	7198	 8100	 0.025909	 0.077347	 0.00655	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8100	 702	 0.01324	 0.046628	 0.00554	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7635	 7086	 0.01676	 0.03686	 0.00425	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2270	 7635	 0.017612	 0.043678	 0.00445	 77.229547	 77.229547	 77.229547	 0.0	 0.0	 1	 -30.0	 30.0;
	7250	 4152	 0.02043	 0.057124	 0.00516	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 6363	 0.00084	 0.00669	 0.20687	 1011.741383	 1011.741383	 1011.741383	 0.0	 0.0	 1	 -30.0	 30.0;
	1694	 3924	 0.019893	 0.062752	 0.00503	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5810	 68	 0.058719	 0.164223	 0.01486	 77.188584	 77.188584	 77.188584	 0.0	 0.0	 1	 -30.0	 30.0;
	5810	 2291	 0.021661	 0.049587	 0.00549	 67.210569	 67.210569	 67.210569	 0.0	 0.0	 1	 -30.0	 30.0;
	3346	 1842	 0.008	 0.030686	 0.00347	 73.318438	 73.318438	 73.318438	 0.0	 0.0	 1	 -30.0	 30.0;
	3371	 4124	 0.024017	 0.057248	 0.00608	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4242	 650	 0.005636	 0.020727	 0.00187	 83.714467	 83.714467	 83.714467	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 6392	 0.004769	 0.016826	 0.00158	 63.925146	 63.925146	 63.925146	 0.0	 0.0	 1	 -30.0	 30.0;
	7388	 4689	 0.00895	 0.031554	 0.00297	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7211	 3460	 0.010919	 0.07275	 0.10428	 369.323185	 369.323185	 369.323185	 0.0	 0.0	 1	 -30.0	 30.0;
	3460	 7401	 0.004841	 0.02861	 0.04624	 427.869412	 427.869412	 427.869412	 0.0	 0.0	 1	 -30.0	 30.0;
	4827	 2688	 0.044909	 0.092107	 0.00911	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2876	 2768	 0.011901	 0.039537	 0.00337	 62.938223	 62.938223	 62.938223	 0.0	 0.0	 1	 -30.0	 30.0;
	365	 8224	 0.008421	 0.020066	 0.00213	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8224	 1371	 0.07076	 0.184612	 0.01435	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8224	 4536	 0.00624	 0.018917	 0.00158	 61.838509	 61.838509	 61.838509	 0.0	 0.0	 1	 -30.0	 30.0;
	8224	 1835	 0.055157	 0.127587	 0.01119	 59.699669	 59.699669	 59.699669	 0.0	 0.0	 1	 -30.0	 30.0;
	5207	 685	 0.03562	 0.084876	 0.00901	 64.780987	 64.780987	 64.780987	 0.0	 0.0	 1	 -30.0	 30.0;
	931	 7663	 0.024248	 0.073463	 0.00614	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1677	 2041	 0.006372	 0.012686	 0.00126	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6214	 415	 0.003397	 0.009802	 0.00112	 70.815122	 70.815122	 70.815122	 0.0	 0.0	 1	 -30.0	 30.0;
	6214	 4484	 0.002793	 0.008397	 0.00092	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	111	 6745	 0.035636	 0.100248	 0.00935	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2941	 6745	 0.034901	 0.102182	 0.00916	 61.856609	 61.856609	 61.856609	 0.0	 0.0	 1	 -30.0	 30.0;
	1089	 5125	 0.032388	 0.094281	 0.0082	 61.285604	 61.285604	 61.285604	 0.0	 0.0	 1	 -30.0	 30.0;
	4401	 5125	 0.031421	 0.093802	 0.00795	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7211	 4528	 0.02455	 0.175521	 0.23579	 433.269288	 433.269288	 433.269288	 0.0	 0.0	 1	 -30.0	 30.0;
	7100	 4528	 0.011281	 0.058469	 0.10824	 330.686119	 330.686119	 330.686119	 0.0	 0.0	 1	 -30.0	 30.0;
	4528	 364	 0.015979	 0.102281	 0.1526	 336.733783	 336.733783	 336.733783	 0.0	 0.0	 1	 -30.0	 30.0;
	6659	 5866	 0.0	 0.000777	 0.0	 58.182133	 58.182133	 58.182133	 0.0	 0.0	 1	 -30.0	 30.0;
	6659	 7615	 0.010868	 0.037488	 0.0029	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6659	 7135	 0.011967	 0.024562	 0.00243	 61.868231	 61.868231	 61.868231	 0.0	 0.0	 1	 -30.0	 30.0;
	5866	 7615	 0.010636	 0.034711	 0.00284	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5866	 1593	 0.055091	 0.164496	 0.01394	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5866	 6902	 0.073091	 0.221488	 0.0185	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7497	 7509	 0.01938	 0.056421	 0.00491	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2850	 7509	 0.018983	 0.057496	 0.0048	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4368	 6384	 0.031413	 0.07795	 0.00796	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4368	 6621	 0.046231	 0.119372	 0.0117	 73.576791	 73.576791	 73.576791	 0.0	 0.0	 1	 -30.0	 30.0;
	4820	 2644	 0.012066	 0.029901	 0.00305	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	946	 302	 0.022529	 0.071066	 0.0057	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 946	 0.027471	 0.065471	 0.00695	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	650	 3925	 0.0	 0.00076	 0.0	 69.352076	 69.352076	 69.352076	 0.0	 0.0	 1	 -30.0	 30.0;
	7388	 3925	 0.005868	 0.020678	 0.00194	 61.415924	 61.415924	 61.415924	 0.0	 0.0	 1	 -30.0	 30.0;
	1396	 562	 0.022636	 0.049769	 0.00573	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6066	 1007	 0.033909	 0.047901	 0.0051	 67.666306	 67.666306	 67.666306	 0.0	 0.0	 1	 -30.0	 30.0;
	6066	 1007	 0.034537	 0.04686	 0.00519	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1007	 5106	 0.012959	 0.028661	 0.00249	 70.513711	 70.513711	 70.513711	 0.0	 0.0	 1	 -30.0	 30.0;
	2774	 7159	 0.003919	 0.02719	 0.03744	 607.752622	 607.752622	 607.752622	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 2869	 0.0	 0.000744	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3572	 4774	 0.013909	 0.038909	 0.00352	 80.001885	 80.001885	 80.001885	 0.0	 0.0	 1	 -30.0	 30.0;
	1083	 2869	 0.007579	 0.023	 0.00192	 59.437315	 59.437315	 59.437315	 0.0	 0.0	 1	 -30.0	 30.0;
	1489	 4122	 0.032587	 0.077653	 0.00825	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4122	 1412	 0.035744	 0.085851	 0.00694	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1088	 1977	 0.011969	 0.0687	 0.10148	 404.064764	 404.064764	 404.064764	 0.0	 0.0	 1	 -30.0	 30.0;
	1977	 2923	 0.00431	 0.024719	 0.03652	 447.593764	 447.593764	 447.593764	 0.0	 0.0	 1	 -30.0	 30.0;
	301	 4443	 0.107463	 0.250107	 0.02257	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4443	 780	 0.043099	 0.099678	 0.00874	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4443	 1555	 0.033058	 0.075669	 0.00837	 78.863685	 78.863685	 78.863685	 0.0	 0.0	 1	 -30.0	 30.0;
	7706	 4443	 0.045273	 0.099537	 0.01146	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4443	 2236	 0.071182	 0.141157	 0.01496	 69.037519	 69.037519	 69.037519	 0.0	 0.0	 1	 -30.0	 30.0;
	4443	 2236	 0.072554	 0.138223	 0.01524	 76.793434	 76.793434	 76.793434	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 559	 0.00781	 0.02357	 0.00268	 60.600093	 60.600093	 60.600093	 0.0	 0.0	 1	 -30.0	 30.0;
	559	 5912	 0.014298	 0.042702	 0.00362	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8017	 7303	 0.016793	 0.041661	 0.00425	 65.203572	 65.203572	 65.203572	 0.0	 0.0	 1	 -30.0	 30.0;
	7303	 6884	 0.011017	 0.021711	 0.00224	 78.050141	 78.050141	 78.050141	 0.0	 0.0	 1	 -30.0	 30.0;
	1922	 7211	 0.01255	 0.08125	 0.10642	 499.847312	 499.847312	 499.847312	 0.0	 0.0	 1	 -30.0	 30.0;
	8187	 7124	 0.008041	 0.022488	 0.00204	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8187	 7124	 0.009149	 0.017438	 0.00192	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8187	 6027	 0.032876	 0.06481	 0.00667	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7326	 8187	 0.022512	 0.056769	 0.00473	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7124	 1562	 0.01276	 0.035702	 0.00323	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1615	 5520	 0.007793	 0.02457	 0.00197	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3472	 5520	 0.00762	 0.022752	 0.00193	 74.719754	 74.719754	 74.719754	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 5966	 0.010157	 0.025198	 0.00257	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 4591	 0.018289	 0.054603	 0.00463	 75.922351	 75.922351	 75.922351	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 5093	 0.031876	 0.082322	 0.00807	 57.947024	 57.947024	 57.947024	 0.0	 0.0	 1	 -30.0	 30.0;
	8353	 1615	 0.011289	 0.033917	 0.00374	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4941	 7108	 0.055537	 0.203711	 0.01839	 71.64448	 71.64448	 71.64448	 0.0	 0.0	 1	 -30.0	 30.0;
	2848	 7943	 0.001488	 0.003314	 0.04138	 121.457396	 121.457396	 121.457396	 0.0	 0.0	 1	 -30.0	 30.0;
	7293	 2848	 0.009083	 0.012124	 0.0998	 72.79354	 72.79354	 72.79354	 0.0	 0.0	 1	 -30.0	 30.0;
	3352	 2918	 0.0	 0.000876	 0.0	 95.559824	 95.559824	 95.559824	 0.0	 0.0	 1	 -30.0	 30.0;
	5678	 3190	 0.0011	 0.01267	 0.23494	 1079.22714	 1079.22714	 1079.22714	 0.0	 0.0	 1	 -30.0	 30.0;
	3190	 7373	 0.00252	 0.02751	 0.5387	 1151.601195	 1151.601195	 1151.601195	 0.0	 0.0	 1	 -30.0	 30.0;
	4234	 960	 0.04314	 0.128802	 0.01092	 77.189728	 77.189728	 77.189728	 0.0	 0.0	 1	 -30.0	 30.0;
	3572	 1083	 0.011562	 0.029843	 0.00293	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7074	 724	 0.011256	 0.041174	 0.0033	 61.902145	 61.902145	 61.902145	 0.0	 0.0	 1	 -30.0	 30.0;
	7074	 724	 0.011017	 0.04195	 0.00323	 61.61026	 61.61026	 61.61026	 0.0	 0.0	 1	 -30.0	 30.0;
	6772	 359	 0.029496	 0.076149	 0.00747	 60.32726	 60.32726	 60.32726	 0.0	 0.0	 1	 -30.0	 30.0;
	7401	 1088	 0.009401	 0.05757	 0.07966	 384.622008	 384.622008	 384.622008	 0.0	 0.0	 1	 -30.0	 30.0;
	4401	 1089	 0.056934	 0.185223	 0.01886	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4848	 1089	 0.005479	 0.016479	 0.00181	 65.303598	 65.303598	 65.303598	 0.0	 0.0	 1	 -30.0	 30.0;
	7840	 6135	 0.011289	 0.029157	 0.00286	 77.120948	 77.120948	 77.120948	 0.0	 0.0	 1	 -30.0	 30.0;
	7840	 5686	 0.000504	 0.001446	 0.00012	 67.676213	 67.676213	 67.676213	 0.0	 0.0	 1	 -30.0	 30.0;
	4895	 7840	 0.014347	 0.035802	 0.00376	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4895	 7840	 0.014628	 0.035066	 0.00384	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7840	 5573	 0.019537	 0.05462	 0.00494	 64.897969	 64.897969	 64.897969	 0.0	 0.0	 1	 -30.0	 30.0;
	1633	 4980	 0.003281	 0.009488	 0.00109	 83.183091	 83.183091	 83.183091	 0.0	 0.0	 1	 -30.0	 30.0;
	5750	 2124	 0.033339	 0.086091	 0.00844	 74.712704	 74.712704	 74.712704	 0.0	 0.0	 1	 -30.0	 30.0;
	8362	 2124	 0.032628	 0.095	 0.00826	 63.772535	 63.772535	 63.772535	 0.0	 0.0	 1	 -30.0	 30.0;
	5278	 6325	 0.008281	 0.029331	 0.00284	 58.306165	 58.306165	 58.306165	 0.0	 0.0	 1	 -30.0	 30.0;
	183	 491	 0.008711	 0.059841	 0.08369	 404.655393	 404.655393	 404.655393	 0.0	 0.0	 1	 -30.0	 30.0;
	183	 6550	 0.0127	 0.06389	 0.12127	 408.894968	 408.894968	 408.894968	 0.0	 0.0	 1	 -30.0	 30.0;
	611	 2255	 0.0	 0.000826	 0.0	 104.047548	 104.047548	 104.047548	 0.0	 0.0	 1	 -30.0	 30.0;
	611	 7168	 0.016992	 0.051281	 0.00583	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	611	 415	 0.017322	 0.050223	 0.00595	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	611	 3206	 0.016901	 0.06357	 0.0056	 59.447604	 59.447604	 59.447604	 0.0	 0.0	 1	 -30.0	 30.0;
	611	 3058	 0.037231	 0.112777	 0.00942	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4611	 611	 0.039636	 0.115388	 0.01003	 69.514023	 69.514023	 69.514023	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 611	 0.067339	 0.212438	 0.01704	 58.852021	 58.852021	 58.852021	 0.0	 0.0	 1	 -30.0	 30.0;
	775	 6135	 0.061322	 0.134818	 0.01552	 62.96623	 62.96623	 62.96623	 0.0	 0.0	 1	 -30.0	 30.0;
	2157	 415	 0.04114	 0.119752	 0.01041	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1290	 1509	 0.03657	 0.109198	 0.00925	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	837	 1290	 0.042488	 0.097248	 0.01075	 77.806078	 77.806078	 77.806078	 0.0	 0.0	 1	 -30.0	 30.0;
	1290	 4310	 0.039099	 0.089512	 0.00989	 61.646269	 61.646269	 61.646269	 0.0	 0.0	 1	 -30.0	 30.0;
	1745	 1567	 0.013537	 0.032471	 0.00356	 72.734477	 72.734477	 72.734477	 0.0	 0.0	 1	 -30.0	 30.0;
	4557	 4307	 0.00158	 0.01747	 0.33681	 1010.356574	 1010.356574	 1010.356574	 0.0	 0.0	 1	 -30.0	 30.0;
	1851	 4978	 0.00894	 0.04824	 0.08579	 426.965939	 426.965939	 426.965939	 0.0	 0.0	 1	 -30.0	 30.0;
	4288	 1851	 0.003531	 0.018341	 0.03394	 402.593906	 402.593906	 402.593906	 0.0	 0.0	 1	 -30.0	 30.0;
	7569	 6732	 0.029818	 0.068256	 0.00755	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5697	 5208	 0.0	 0.00081	 0.0	 67.934947	 67.934947	 67.934947	 0.0	 0.0	 1	 -30.0	 30.0;
	5697	 6988	 0.003512	 0.004661	 0.0935	 67.689169	 67.689169	 67.689169	 0.0	 0.0	 1	 -30.0	 30.0;
	4045	 3006	 0.010959	 0.027322	 0.00568	 100.320296	 100.320296	 100.320296	 0.0	 0.0	 1	 -30.0	 30.0;
	4199	 5208	 0.003579	 0.004562	 0.09527	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4753	 1694	 0.045843	 0.136851	 0.0116	 93.890058	 93.890058	 93.890058	 0.0	 0.0	 1	 -30.0	 30.0;
	4753	 3415	 0.044678	 0.135421	 0.01131	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4753	 1600	 0.015793	 0.04786	 0.00399	 78.324879	 78.324879	 78.324879	 0.0	 0.0	 1	 -30.0	 30.0;
	6389	 3846	 0.036248	 0.10138	 0.00917	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1404	 58	 0.00336	 0.02922	 0.71685	 1283.410158	 1283.410158	 1283.410158	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 7100	 0.01663	 0.097229	 0.1596	 429.390949	 429.390949	 429.390949	 0.0	 0.0	 1	 -30.0	 30.0;
	8124	 194	 0.0	 0.000777	 0.0	 82.491483	 82.491483	 82.491483	 0.0	 0.0	 1	 -30.0	 30.0;
	194	 6027	 0.09357	 0.184397	 0.01897	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 194	 0.090248	 0.177719	 0.01762	 59.463227	 59.463227	 59.463227	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 194	 0.091983	 0.174017	 0.01796	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	194	 1139	 0.018256	 0.05314	 0.00462	 100.374596	 100.374596	 100.374596	 0.0	 0.0	 1	 -30.0	 30.0;
	194	 7326	 0.112273	 0.205446	 0.02358	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2164	 3126	 0.003401	 0.02362	 0.03252	 438.873789	 438.873789	 438.873789	 0.0	 0.0	 1	 -30.0	 30.0;
	2164	 6816	 0.002719	 0.012781	 0.02344	 405.740246	 405.740246	 405.740246	 0.0	 0.0	 1	 -30.0	 30.0;
	2164	 1989	 0.00205	 0.022719	 0.08382	 451.980044	 451.980044	 451.980044	 0.0	 0.0	 1	 -30.0	 30.0;
	7265	 7027	 0.036579	 0.090719	 0.00926	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7265	 6875	 0.038802	 0.092446	 0.00982	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 4574	 0.029397	 0.067298	 0.00744	 70.830936	 70.830936	 70.830936	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 8253	 0.054289	 0.124289	 0.01374	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4574	 7171	 0.007421	 0.023438	 0.00188	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4574	 4781	 0.006124	 0.018554	 0.00155	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2956	 7569	 0.010446	 0.034017	 0.00347	 72.947294	 72.947294	 72.947294	 0.0	 0.0	 1	 -30.0	 30.0;
	714	 2562	 0.045702	 0.127802	 0.01156	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4723	 6387	 0.057438	 0.171496	 0.01454	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4473	 6387	 0.025182	 0.057636	 0.00637	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4216	 2576	 0.03224	 0.075033	 0.00677	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	301	 780	 0.075653	 0.13295	 0.01588	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	613	 7074	 0.005058	 0.017017	 0.0016	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	613	 7074	 0.005157	 0.016669	 0.00163	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2107	 3705	 0.046777	 0.101124	 0.01084	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5749	 463	 0.045364	 0.135446	 0.01148	 62.218798	 62.218798	 62.218798	 0.0	 0.0	 1	 -30.0	 30.0;
	6384	 5966	 0.037471	 0.113529	 0.00948	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 1955	 0.058372	 0.168446	 0.01531	 61.247499	 61.247499	 61.247499	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 1955	 0.066157	 0.165083	 0.01735	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2850	 1955	 0.046628	 0.120388	 0.0118	 80.106293	 80.106293	 80.106293	 0.0	 0.0	 1	 -30.0	 30.0;
	4876	 4173	 0.029868	 0.087488	 0.00783	 63.772154	 63.772154	 63.772154	 0.0	 0.0	 1	 -30.0	 30.0;
	4333	 2507	 0.015562	 0.047107	 0.00394	 57.545015	 57.545015	 57.545015	 0.0	 0.0	 1	 -30.0	 30.0;
	7086	 1928	 0.045967	 0.109562	 0.01164	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	613	 7279	 0.00705	 0.016876	 0.00185	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	613	 3238	 0.004	 0.009537	 0.00102	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	613	 2395	 0.06243	 0.161207	 0.0158	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1053	 7135	 0.005942	 0.014149	 0.00151	 78.588566	 78.588566	 78.588566	 0.0	 0.0	 1	 -30.0	 30.0;
	7883	 5879	 0.004651	 0.024159	 0.04472	 427.827496	 427.827496	 427.827496	 0.0	 0.0	 1	 -30.0	 30.0;
	7883	 1425	 0.00474	 0.02363	 0.04555	 462.497056	 462.497056	 462.497056	 0.0	 0.0	 1	 -30.0	 30.0;
	6849	 8204	 0.036669	 0.115669	 0.00928	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7928	 5255	 0.043273	 0.095132	 0.01095	 63.186287	 63.186287	 63.186287	 0.0	 0.0	 1	 -30.0	 30.0;
	7928	 5147	 0.004521	 0.011661	 0.00114	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2905	 5678	 0.00207	 0.01871	 0.44089	 1308.456513	 1308.456513	 1308.456513	 0.0	 0.0	 1	 -30.0	 30.0;
	2923	 1605	 0.00419	 0.02712	 0.03551	 387.146853	 387.146853	 387.146853	 0.0	 0.0	 1	 -30.0	 30.0;
	2923	 1605	 0.002349	 0.022039	 0.05608	 429.784575	 429.784575	 429.784575	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 4533	 0.02	 0.04314	 0.0048	 69.215279	 69.215279	 69.215279	 0.0	 0.0	 1	 -30.0	 30.0;
	7213	 3184	 0.00676	 0.016124	 0.00172	 58.179084	 58.179084	 58.179084	 0.0	 0.0	 1	 -30.0	 30.0;
	6721	 6855	 0.007876	 0.022529	 0.00231	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6855	 3472	 0.025793	 0.060298	 0.00604	 64.309055	 64.309055	 64.309055	 0.0	 0.0	 1	 -30.0	 30.0;
	5940	 6389	 0.067587	 0.204793	 0.0171	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5502	 6612	 0.053008	 0.116554	 0.01342	 73.292908	 73.292908	 73.292908	 0.0	 0.0	 1	 -30.0	 30.0;
	6073	 6027	 0.01195	 0.030868	 0.00303	 70.776255	 70.776255	 70.776255	 0.0	 0.0	 1	 -30.0	 30.0;
	5147	 6073	 0.015463	 0.04876	 0.00391	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	459	 2782	 0.018702	 0.071413	 0.00619	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2834	 4307	 0.00142	 0.01555	 0.30433	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	2834	 1404	 0.00123	 0.01312	 0.30344	 1109.646213	 1109.646213	 1109.646213	 0.0	 0.0	 1	 -30.0	 30.0;
	2834	 1404	 0.00121	 0.01337	 0.29699	 1216.920226	 1216.920226	 1216.920226	 0.0	 0.0	 1	 -30.0	 30.0;
	1414	 2834	 0.00079	 0.01226	 0.35947	 1096.494474	 1096.494474	 1096.494474	 0.0	 0.0	 1	 -30.0	 30.0;
	2633	 2834	 0.00062	 0.00673	 0.13171	 778.657713	 778.657713	 778.657713	 0.0	 0.0	 1	 -30.0	 30.0;
	5551	 4978	 0.0	 0.000211	 0.0	 325.825049	 325.825049	 325.825049	 0.0	 0.0	 1	 -30.0	 30.0;
	4288	 4978	 0.00763	 0.05451	 0.07321	 387.590397	 387.590397	 387.590397	 0.0	 0.0	 1	 -30.0	 30.0;
	6449	 7663	 0.0	 0.00076	 0.0	 72.497463	 72.497463	 72.497463	 0.0	 0.0	 1	 -30.0	 30.0;
	8116	 5300	 0.00657	 0.019603	 0.00166	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6082	 5774	 0.011512	 0.028562	 0.00291	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7198	 7704	 0.014612	 0.05362	 0.00484	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8317	 365	 0.00976	 0.02419	 0.00246	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1396	 4238	 0.007876	 0.022934	 0.002	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4238	 3415	 0.01795	 0.042769	 0.00454	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5864	 5340	 0.023488	 0.046364	 0.007	 71.582941	 71.582941	 71.582941	 0.0	 0.0	 1	 -30.0	 30.0;
	5864	 1567	 0.013802	 0.031802	 0.00363	 68.330097	 68.330097	 68.330097	 0.0	 0.0	 1	 -30.0	 30.0;
	2756	 6743	 0.036678	 0.080636	 0.00928	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6743	 3962	 0.005917	 0.017066	 0.00197	 61.493849	 61.493849	 61.493849	 0.0	 0.0	 1	 -30.0	 30.0;
	7213	 1688	 0.003364	 0.012901	 0.00115	 80.471912	 80.471912	 80.471912	 0.0	 0.0	 1	 -30.0	 30.0;
	2157	 7213	 0.038107	 0.120198	 0.00964	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5185	 1688	 0.003289	 0.011942	 0.00113	 63.852174	 63.852174	 63.852174	 0.0	 0.0	 1	 -30.0	 30.0;
	837	 3889	 0.047818	 0.109479	 0.01211	 71.027177	 71.027177	 71.027177	 0.0	 0.0	 1	 -30.0	 30.0;
	3889	 4093	 0.023603	 0.060744	 0.00595	 75.188447	 75.188447	 75.188447	 0.0	 0.0	 1	 -30.0	 30.0;
	3889	 4541	 0.042851	 0.125488	 0.01124	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3889	 4541	 0.04376	 0.123124	 0.01148	 57.641231	 57.641231	 57.641231	 0.0	 0.0	 1	 -30.0	 30.0;
	4307	 1404	 0.00089	 0.0071	 0.18875	 1185.355263	 1185.355263	 1185.355263	 0.0	 0.0	 1	 -30.0	 30.0;
	7569	 5940	 0.0	 0.000744	 0.0	 95.269844	 95.269844	 95.269844	 0.0	 0.0	 1	 -30.0	 30.0;
	7569	 7384	 0.039554	 0.086942	 0.01001	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	459	 3061	 0.046364	 0.078843	 0.00892	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7343	 3338	 0.006248	 0.007702	 0.0675	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8065	 7343	 0.001273	 0.002661	 0.06447	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5885	 3974	 0.027711	 0.061314	 0.00727	 62.407038	 62.407038	 62.407038	 0.0	 0.0	 1	 -30.0	 30.0;
	5885	 3974	 0.028231	 0.059967	 0.0074	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	954	 5255	 0.029702	 0.056231	 0.00603	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2721	 5824	 0.006256	 0.011397	 0.00118	 71.436998	 71.436998	 71.436998	 0.0	 0.0	 1	 -30.0	 30.0;
	4170	 4360	 0.010298	 0.032512	 0.00261	 59.626507	 59.626507	 59.626507	 0.0	 0.0	 1	 -30.0	 30.0;
	4360	 8300	 0.01805	 0.039686	 0.00457	 64.458427	 64.458427	 64.458427	 0.0	 0.0	 1	 -30.0	 30.0;
	3191	 6459	 0.012849	 0.07226	 0.12346	 592.330719	 592.330719	 592.330719	 0.0	 0.0	 1	 -30.0	 30.0;
	3191	 7783	 0.013099	 0.07075	 0.12583	 637.033738	 637.033738	 637.033738	 0.0	 0.0	 1	 -30.0	 30.0;
	1631	 7515	 0.008314	 0.033033	 0.00275	 93.660474	 93.660474	 93.660474	 0.0	 0.0	 1	 -30.0	 30.0;
	6171	 7978	 0.031843	 0.096463	 0.00806	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7984	 3545	 0.002207	 0.005273	 0.00056	 61.27322	 61.27322	 61.27322	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 7984	 0.009124	 0.027669	 0.00212	 86.819081	 86.819081	 86.819081	 0.0	 0.0	 1	 -30.0	 30.0;
	1509	 4876	 0.010777	 0.032653	 0.00273	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1033	 7236	 0.00757	 0.018901	 0.00199	 66.677097	 66.677097	 66.677097	 0.0	 0.0	 1	 -30.0	 30.0;
	2695	 6052	 0.007719	 0.018512	 0.00203	 67.191707	 67.191707	 67.191707	 0.0	 0.0	 1	 -30.0	 30.0;
	3612	 4216	 0.016198	 0.040818	 0.0034	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	667	 2611	 0.054512	 0.162752	 0.0138	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2611	 2494	 0.030802	 0.067719	 0.0078	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4152	 6465	 0.012298	 0.029281	 0.00311	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	253	 7516	 0.074322	 0.221901	 0.01881	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 7516	 0.009669	 0.023033	 0.00245	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4895	 1848	 0.0	 0.000843	 0.0	 62.221275	 62.221275	 62.221275	 0.0	 0.0	 1	 -30.0	 30.0;
	39	 1171	 0.073463	 0.189678	 0.01859	 58.740944	 58.740944	 58.740944	 0.0	 0.0	 1	 -30.0	 30.0;
	1171	 960	 0.058653	 0.145488	 0.01484	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1414	 3393	 0.00102	 0.01773	 0.46086	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	4723	 3873	 0.00838	 0.02438	 0.00212	 60.19313	 60.19313	 60.19313	 0.0	 0.0	 1	 -30.0	 30.0;
	4723	 6542	 0.01219	 0.03024	 0.00309	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4723	 4473	 0.048744	 0.11614	 0.01234	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6542	 3083	 0.012967	 0.030934	 0.00329	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3873	 3396	 0.006983	 0.021149	 0.00177	 63.125319	 63.125319	 63.125319	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 3873	 0.017347	 0.058702	 0.00726	 59.428932	 59.428932	 59.428932	 0.0	 0.0	 1	 -30.0	 30.0;
	2236	 6547	 0.02457	 0.058562	 0.00622	 69.458009	 69.458009	 69.458009	 0.0	 0.0	 1	 -30.0	 30.0;
	5916	 4931	 0.016083	 0.044983	 0.00407	 73.934217	 73.934217	 73.934217	 0.0	 0.0	 1	 -30.0	 30.0;
	4425	 4931	 0.004843	 0.011512	 0.00122	 62.874778	 62.874778	 62.874778	 0.0	 0.0	 1	 -30.0	 30.0;
	7110	 7580	 0.005058	 0.011339	 0.00099	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6351	 2315	 0.023727	 0.074843	 0.00601	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7978	 2315	 0.031157	 0.098281	 0.00788	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	702	 671	 0.014372	 0.048661	 0.00602	 61.736197	 61.736197	 61.736197	 0.0	 0.0	 1	 -30.0	 30.0;
	881	 2905	 0.00331	 0.02754	 0.70311	 1082.055337	 1082.055337	 1082.055337	 0.0	 0.0	 1	 -30.0	 30.0;
	6816	 6598	 0.002669	 0.01732	 0.02305	 458.85154	 458.85154	 458.85154	 0.0	 0.0	 1	 -30.0	 30.0;
	6598	 7030	 0.019719	 0.103289	 0.1883	 442.757462	 442.757462	 442.757462	 0.0	 0.0	 1	 -30.0	 30.0;
	6816	 3126	 0.00261	 0.016039	 0.02254	 401.775789	 401.775789	 401.775789	 0.0	 0.0	 1	 -30.0	 30.0;
	433	 5936	 0.008587	 0.017446	 0.00163	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8017	 1278	 0.0	 0.000876	 0.0	 73.388171	 73.388171	 73.388171	 0.0	 0.0	 1	 -30.0	 30.0;
	7567	 8017	 0.017413	 0.05443	 0.00577	 61.23702	 61.23702	 61.23702	 0.0	 0.0	 1	 -30.0	 30.0;
	8017	 5764	 0.024744	 0.074289	 0.00819	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1278	 4801	 0.036421	 0.11381	 0.01206	 68.668471	 68.668471	 68.668471	 0.0	 0.0	 1	 -30.0	 30.0;
	4588	 4328	 0.004198	 0.012587	 0.00139	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7366	 6486	 0.014686	 0.044521	 0.00372	 57.733254	 57.733254	 57.733254	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 6486	 0.015231	 0.041256	 0.00348	 57.730397	 57.730397	 57.730397	 0.0	 0.0	 1	 -30.0	 30.0;
	51	 6155	 0.01438	 0.045364	 0.00364	 68.173485	 68.173485	 68.173485	 0.0	 0.0	 1	 -30.0	 30.0;
	6660	 917	 0.025562	 0.076298	 0.00646	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 5772	 0.028083	 0.061744	 0.00711	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	32	 4665	 0.05019	 0.152107	 0.0127	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	635	 4665	 0.027909	 0.072033	 0.00706	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1791	 4228	 0.020512	 0.061248	 0.00519	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	775	 5489	 0.025364	 0.053893	 0.00666	 66.328816	 66.328816	 66.328816	 0.0	 0.0	 1	 -30.0	 30.0;
	7537	 6539	 0.054479	 0.165099	 0.01379	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7537	 6539	 0.055636	 0.161983	 0.01408	 59.309092	 59.309092	 59.309092	 0.0	 0.0	 1	 -30.0	 30.0;
	7537	 2847	 0.051579	 0.154	 0.01305	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	960	 482	 0.035752	 0.106752	 0.00904	 59.996698	 59.996698	 59.996698	 0.0	 0.0	 1	 -30.0	 30.0;
	574	 6066	 0.021124	 0.054537	 0.00534	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	574	 6066	 0.021537	 0.05343	 0.00545	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6045	 491	 0.0082	 0.04119	 0.07819	 391.023668	 391.023668	 391.023668	 0.0	 0.0	 1	 -30.0	 30.0;
	3974	 7995	 0.040281	 0.122058	 0.01019	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4876	 4093	 0.031934	 0.10086	 0.0081	 74.894085	 74.894085	 74.894085	 0.0	 0.0	 1	 -30.0	 30.0;
	4876	 1489	 0.048347	 0.145008	 0.01238	 57.944547	 57.944547	 57.944547	 0.0	 0.0	 1	 -30.0	 30.0;
	4876	 4310	 0.056636	 0.164901	 0.01433	 60.731937	 60.731937	 60.731937	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 6556	 0.048091	 0.119281	 0.01217	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 4459	 0.00305	 0.008793	 0.0008	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 4459	 0.003463	 0.00862	 0.00091	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5359	 4127	 0.004223	 0.009339	 0.0011	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5359	 4127	 0.005281	 0.009603	 0.00107	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5749	 4082	 0.028033	 0.066033	 0.00705	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2397	 8353	 0.012983	 0.051587	 0.0043	 75.226171	 75.226171	 75.226171	 0.0	 0.0	 1	 -30.0	 30.0;
	6086	 4001	 0.00183	 0.01416	 0.45138	 1014.678838	 1014.678838	 1014.678838	 0.0	 0.0	 1	 -30.0	 30.0;
	3778	 6404	 0.012504	 0.036397	 0.00317	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7978	 6404	 0.024488	 0.074198	 0.00619	 66.650614	 66.650614	 66.650614	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 7280	 0.010579	 0.045496	 0.00443	 65.112882	 65.112882	 65.112882	 0.0	 0.0	 1	 -30.0	 30.0;
	6556	 1593	 0.025372	 0.065512	 0.00643	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4581	 5977	 0.015058	 0.042124	 0.00381	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3244	 4581	 0.038248	 0.084099	 0.00968	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7443	 667	 0.045719	 0.113397	 0.01158	 58.887077	 58.887077	 58.887077	 0.0	 0.0	 1	 -30.0	 30.0;
	7443	 3559	 0.046603	 0.111041	 0.0118	 64.795466	 64.795466	 64.795466	 0.0	 0.0	 1	 -30.0	 30.0;
	685	 7512	 0.013843	 0.041934	 0.0035	 69.049903	 69.049903	 69.049903	 0.0	 0.0	 1	 -30.0	 30.0;
	8012	 7706	 0.052083	 0.134446	 0.01318	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 253	 0.013579	 0.03981	 0.00356	 71.998096	 71.998096	 71.998096	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 253	 0.013868	 0.039058	 0.00364	 72.752577	 72.752577	 72.752577	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 6339	 0.035099	 0.077182	 0.00889	 69.549461	 69.549461	 69.549461	 0.0	 0.0	 1	 -30.0	 30.0;
	8021	 677	 0.11376	 0.27386	 0.02307	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	253	 7321	 0.069628	 0.153091	 0.01762	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7373	 4001	 0.00296	 0.03263	 0.62953	 992.511358	 992.511358	 992.511358	 0.0	 0.0	 1	 -30.0	 30.0;
	3472	 4910	 0.048322	 0.115149	 0.01223	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1170	 4628	 0.009802	 0.028678	 0.00257	 76.850211	 76.850211	 76.850211	 0.0	 0.0	 1	 -30.0	 30.0;
	7293	 3338	 0.003132	 0.004347	 0.03379	 66.00397	 66.00397	 66.00397	 0.0	 0.0	 1	 -30.0	 30.0;
	3048	 4269	 0.00284	 0.02937	 0.7024	 1431.589356	 1431.589356	 1431.589356	 0.0	 0.0	 1	 -30.0	 30.0;
	4269	 6363	 0.00353	 0.03885	 0.74955	 1045.544814	 1045.544814	 1045.544814	 0.0	 0.0	 1	 -30.0	 30.0;
	1101	 4269	 0.00193	 0.02044	 0.41037	 1214.463243	 1214.463243	 1214.463243	 0.0	 0.0	 1	 -30.0	 30.0;
	3507	 1521	 0.00918	 0.065591	 0.08811	 465.142314	 465.142314	 465.142314	 0.0	 0.0	 1	 -30.0	 30.0;
	6959	 3507	 0.0	 0.000211	 0.0	 430.082557	 430.082557	 430.082557	 0.0	 0.0	 1	 -30.0	 30.0;
	3507	 7883	 0.01776	 0.09207	 0.17045	 436.878224	 436.878224	 436.878224	 0.0	 0.0	 1	 -30.0	 30.0;
	3507	 7883	 0.018081	 0.09007	 0.1736	 428.356395	 428.356395	 428.356395	 0.0	 0.0	 1	 -30.0	 30.0;
	3507	 3566	 0.0017	 0.0117	 0.01636	 289.342829	 289.342829	 289.342829	 0.0	 0.0	 1	 -30.0	 30.0;
	3507	 1027	 0.001669	 0.011919	 0.01601	 286.093986	 286.093986	 286.093986	 0.0	 0.0	 1	 -30.0	 30.0;
	3800	 8317	 0.009041	 0.023331	 0.00228	 71.972565	 71.972565	 71.972565	 0.0	 0.0	 1	 -30.0	 30.0;
	2232	 3051	 0.075851	 0.15557	 0.01538	 66.307668	 66.307668	 66.307668	 0.0	 0.0	 1	 -30.0	 30.0;
	1859	 2232	 0.012471	 0.036587	 0.0029	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2397	 6721	 0.003702	 0.011537	 0.00123	 73.060276	 73.060276	 73.060276	 0.0	 0.0	 1	 -30.0	 30.0;
	5402	 2045	 0.003661	 0.009066	 0.00093	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5402	 7072	 0.0	 0.000893	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4716	 4707	 0.00537	 0.032901	 0.04552	 377.858731	 377.858731	 377.858731	 0.0	 0.0	 1	 -30.0	 30.0;
	8261	 5899	 0.016661	 0.041331	 0.00421	 75.553875	 75.553875	 75.553875	 0.0	 0.0	 1	 -30.0	 30.0;
	8261	 6663	 0.002628	 0.007587	 0.00087	 102.923257	 102.923257	 102.923257	 0.0	 0.0	 1	 -30.0	 30.0;
	8261	 8300	 0.009446	 0.025388	 0.00252	 73.938027	 73.938027	 73.938027	 0.0	 0.0	 1	 -30.0	 30.0;
	7166	 7027	 0.023248	 0.060017	 0.00589	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1198	 667	 0.053711	 0.127983	 0.01359	 58.397617	 58.397617	 58.397617	 0.0	 0.0	 1	 -30.0	 30.0;
	7512	 505	 0.009851	 0.022537	 0.00249	 81.099503	 81.099503	 81.099503	 0.0	 0.0	 1	 -30.0	 30.0;
	2515	 7036	 0.007256	 0.021702	 0.00184	 78.329261	 78.329261	 78.329261	 0.0	 0.0	 1	 -30.0	 30.0;
	2515	 7470	 0.001058	 0.003149	 0.00027	 71.770227	 71.770227	 71.770227	 0.0	 0.0	 1	 -30.0	 30.0;
	7036	 6663	 0.014744	 0.048893	 0.00379	 100.255708	 100.255708	 100.255708	 0.0	 0.0	 1	 -30.0	 30.0;
	3058	 2518	 0.040901	 0.119017	 0.01035	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6243	 6909	 0.026653	 0.063504	 0.00674	 70.666131	 70.666131	 70.666131	 0.0	 0.0	 1	 -30.0	 30.0;
	4128	 1835	 0.005198	 0.011909	 0.00132	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4128	 888	 0.006603	 0.020793	 0.00167	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	837	 1229	 0.023909	 0.054744	 0.00605	 71.202461	 71.202461	 71.202461	 0.0	 0.0	 1	 -30.0	 30.0;
	4541	 1229	 0.01286	 0.038959	 0.00325	 71.14416	 71.14416	 71.14416	 0.0	 0.0	 1	 -30.0	 30.0;
	5916	 320	 0.0	 0.000826	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6884	 320	 0.005488	 0.011256	 0.00111	 77.047024	 77.047024	 77.047024	 0.0	 0.0	 1	 -30.0	 30.0;
	3365	 320	 0.018983	 0.055579	 0.00497	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5916	 4048	 0.013479	 0.038876	 0.00446	 76.397141	 76.397141	 76.397141	 0.0	 0.0	 1	 -30.0	 30.0;
	6704	 4414	 0.010041	 0.02205	 0.00254	 76.375231	 76.375231	 76.375231	 0.0	 0.0	 1	 -30.0	 30.0;
	4414	 6881	 0.01224	 0.037099	 0.0031	 60.168553	 60.168553	 60.168553	 0.0	 0.0	 1	 -30.0	 30.0;
	6704	 7474	 0.0	 0.00081	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 6704	 0.011	 0.030959	 0.00289	 57.202069	 57.202069	 57.202069	 0.0	 0.0	 1	 -30.0	 30.0;
	4635	 7474	 0.010777	 0.031554	 0.00283	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7474	 5357	 0.030521	 0.069868	 0.00772	 64.01736	 64.01736	 64.01736	 0.0	 0.0	 1	 -30.0	 30.0;
	7474	 6277	 0.016901	 0.051198	 0.00428	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5843	 3556	 0.008868	 0.027967	 0.00224	 73.242799	 73.242799	 73.242799	 0.0	 0.0	 1	 -30.0	 30.0;
	6881	 3031	 0.006322	 0.02319	 0.00265	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2529	 5104	 0.006488	 0.019008	 0.0017	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2975	 4635	 0.006347	 0.019372	 0.00167	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2494	 2975	 0.018339	 0.038967	 0.00481	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1130	 4756	 0.037793	 0.093752	 0.00957	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1169	 683	 0.018603	 0.048017	 0.0047	 57.250082	 57.250082	 57.250082	 0.0	 0.0	 1	 -30.0	 30.0;
	3819	 5938	 0.04086	 0.128893	 0.01034	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5938	 1251	 0.004587	 0.010083	 0.00117	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2518	 4967	 0.012529	 0.028661	 0.00316	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	39	 3671	 0.016339	 0.035909	 0.00414	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1169	 6528	 0.021702	 0.058653	 0.00569	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 7236	 0.037339	 0.109364	 0.00979	 66.487334	 66.487334	 66.487334	 0.0	 0.0	 1	 -30.0	 30.0;
	3312	 2695	 0.036554	 0.11143	 0.00959	 74.777293	 74.777293	 74.777293	 0.0	 0.0	 1	 -30.0	 30.0;
	5489	 5573	 0.027149	 0.062149	 0.00687	 65.802394	 65.802394	 65.802394	 0.0	 0.0	 1	 -30.0	 30.0;
	4673	 3501	 0.034281	 0.103876	 0.00868	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4673	 4591	 0.023479	 0.06843	 0.00592	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6836	 4673	 0.053149	 0.116868	 0.01345	 65.116121	 65.116121	 65.116121	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 6107	 0.004802	 0.013298	 0.00159	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6107	 459	 0.012669	 0.038231	 0.00435	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4459	 2234	 0.040339	 0.079496	 0.00818	 61.968257	 61.968257	 61.968257	 0.0	 0.0	 1	 -30.0	 30.0;
	7706	 1544	 0.054521	 0.171992	 0.0138	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 1544	 0.05514	 0.122	 0.01446	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2120	 1544	 0.056157	 0.119339	 0.01473	 58.352844	 58.352844	 58.352844	 0.0	 0.0	 1	 -30.0	 30.0;
	8189	 4082	 0.034248	 0.075289	 0.00867	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3048	 802	 0.0018	 0.01865	 0.44616	 1452.260793	 1452.260793	 1452.260793	 0.0	 0.0	 1	 -30.0	 30.0;
	6849	 3998	 0.0	 0.000793	 0.0	 64.943124	 64.943124	 64.943124	 0.0	 0.0	 1	 -30.0	 30.0;
	7111	 6660	 0.023231	 0.064983	 0.00588	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1545	 1960	 0.00163	 0.01087	 0.01558	 400.356755	 400.356755	 400.356755	 0.0	 0.0	 1	 -30.0	 30.0;
	5813	 32	 0.020727	 0.053512	 0.00524	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	459	 6516	 0.022364	 0.064488	 0.00741	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	837	 3986	 0.014579	 0.04805	 0.00416	 61.694091	 61.694091	 61.694091	 0.0	 0.0	 1	 -30.0	 30.0;
	837	 3986	 0.014281	 0.048992	 0.00407	 66.69253	 66.69253	 66.69253	 0.0	 0.0	 1	 -30.0	 30.0;
	5851	 2743	 0.00228	 0.02412	 0.48448	 1102.47535	 1102.47535	 1102.47535	 0.0	 0.0	 1	 -30.0	 30.0;
	6875	 1371	 0.004298	 0.009132	 0.00112	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3051	 6875	 0.003826	 0.010347	 0.001	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3051	 1371	 0.0	 0.000777	 0.0	 64.243133	 64.243133	 64.243133	 0.0	 0.0	 1	 -30.0	 30.0;
	7166	 1371	 0.042256	 0.092917	 0.01069	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3310	 6357	 0.005021	 0.029341	 0.04815	 423.561247	 423.561247	 423.561247	 0.0	 0.0	 1	 -30.0	 30.0;
	436	 1192	 0.066248	 0.151661	 0.01676	 69.01275	 69.01275	 69.01275	 0.0	 0.0	 1	 -30.0	 30.0;
	1192	 4054	 0.007587	 0.016702	 0.00193	 70.255549	 70.255549	 70.255549	 0.0	 0.0	 1	 -30.0	 30.0;
	2490	 4536	 0.008579	 0.019636	 0.00217	 59.575827	 59.575827	 59.575827	 0.0	 0.0	 1	 -30.0	 30.0;
	6836	 5300	 0.008942	 0.024992	 0.00226	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3591	 3244	 0.049124	 0.154983	 0.01243	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2001	 3591	 0.018289	 0.04186	 0.00462	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	802	 6807	 0.00064	 0.00617	 0.15715	 1432.40484	 1432.40484	 1432.40484	 0.0	 0.0	 1	 -30.0	 30.0;
	3472	 1377	 0.0	 0.00076	 0.0	 65.390478	 65.390478	 65.390478	 0.0	 0.0	 1	 -30.0	 30.0;
	3472	 4565	 0.024421	 0.073331	 0.00809	 69.214898	 69.214898	 69.214898	 0.0	 0.0	 1	 -30.0	 30.0;
	1377	 5959	 0.0	 0.000744	 0.0	 63.084737	 63.084737	 63.084737	 0.0	 0.0	 1	 -30.0	 30.0;
	6351	 7978	 0.025653	 0.056388	 0.00649	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3939	 4850	 0.003711	 0.02356	 0.03569	 431.469964	 431.469964	 431.469964	 0.0	 0.0	 1	 -30.0	 30.0;
	2756	 3962	 0.015777	 0.089537	 0.00941	 69.524121	 69.524121	 69.524121	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 2756	 0.001587	 0.005612	 0.00053	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	888	 3800	 0.008934	 0.027091	 0.00227	 78.025944	 78.025944	 78.025944	 0.0	 0.0	 1	 -30.0	 30.0;
	1859	 1835	 0.021298	 0.052603	 0.00432	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6949	 7830	 0.01036	 0.05943	 0.08779	 408.612609	 408.612609	 408.612609	 0.0	 0.0	 1	 -30.0	 30.0;
	7937	 845	 0.036438	 0.114909	 0.00922	 67.990962	 67.990962	 67.990962	 0.0	 0.0	 1	 -30.0	 30.0;
	511	 7937	 0.038876	 0.113207	 0.00984	 70.485894	 70.485894	 70.485894	 0.0	 0.0	 1	 -30.0	 30.0;
	3601	 6102	 0.045058	 0.127901	 0.01035	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6102	 2001	 0.014083	 0.042661	 0.00356	 75.79489	 75.79489	 75.79489	 0.0	 0.0	 1	 -30.0	 30.0;
	852	 436	 0.016537	 0.052157	 0.00419	 61.656938	 61.656938	 61.656938	 0.0	 0.0	 1	 -30.0	 30.0;
	6157	 5428	 0.045711	 0.136504	 0.01157	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 2905	 0.00579	 0.06394	 1.23343	 1088.198124	 1088.198124	 1088.198124	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 1203	 0.012512	 0.03381	 0.00328	 71.814048	 71.814048	 71.814048	 0.0	 0.0	 1	 -30.0	 30.0;
	1203	 111	 0.053149	 0.149512	 0.01394	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 4537	 0.012248	 0.034471	 0.00322	 72.885564	 72.885564	 72.885564	 0.0	 0.0	 1	 -30.0	 30.0;
	4537	 2941	 0.052041	 0.152388	 0.01365	 60.708883	 60.708883	 60.708883	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 3819	 0.024471	 0.056033	 0.0062	 66.76874	 66.76874	 66.76874	 0.0	 0.0	 1	 -30.0	 30.0;
	1719	 7452	 0.008752	 0.016322	 0.00166	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 6363	 0.00211	 0.01832	 0.44937	 1345.96681	 1345.96681	 1345.96681	 0.0	 0.0	 1	 -30.0	 30.0;
	6191	 6625	 0.0	 0.00086	 0.0	 77.086844	 77.086844	 77.086844	 0.0	 0.0	 1	 -30.0	 30.0;
	1694	 68	 0.0	 0.000876	 0.0	 91.493055	 91.493055	 91.493055	 0.0	 0.0	 1	 -30.0	 30.0;
	359	 68	 0.007248	 0.021107	 0.00183	 71.679918	 71.679918	 71.679918	 0.0	 0.0	 1	 -30.0	 30.0;
	1600	 1694	 0.036653	 0.106661	 0.00927	 74.815207	 74.815207	 74.815207	 0.0	 0.0	 1	 -30.0	 30.0;
	4312	 3708	 0.003107	 0.007727	 0.00079	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3708	 5057	 0.013612	 0.029917	 0.00344	 58.379898	 58.379898	 58.379898	 0.0	 0.0	 1	 -30.0	 30.0;
	6621	 4756	 0.064182	 0.141124	 0.01625	 78.312685	 78.312685	 78.312685	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 4756	 0.058331	 0.150579	 0.01476	 69.944611	 69.944611	 69.944611	 0.0	 0.0	 1	 -30.0	 30.0;
	6592	 4539	 0.00337	 0.03668	 0.08068	 414.726194	 414.726194	 414.726194	 0.0	 0.0	 1	 -30.0	 30.0;
	3705	 7111	 0.033959	 0.080934	 0.0086	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6384	 6836	 0.0	 0.000826	 0.0	 65.546328	 65.546328	 65.546328	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 6836	 0.07314	 0.181438	 0.01851	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6836	 5200	 0.01476	 0.04295	 0.00373	 91.749693	 91.749693	 91.749693	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 7321	 0.018488	 0.044091	 0.00469	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6079	 4460	 0.00025	 0.00227	 0.04956	 1306.109446	 1306.109446	 1306.109446	 0.0	 0.0	 1	 -30.0	 30.0;
	6079	 4460	 0.00025	 0.00222	 0.05051	 1416.97251	 1416.97251	 1416.97251	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 1101	 0.00179	 0.01494	 0.38153	 1033.683107	 1033.683107	 1033.683107	 0.0	 0.0	 1	 -30.0	 30.0;
	1414	 2633	 0.00133	 0.01403	 0.31953	 1240.365231	 1240.365231	 1240.365231	 0.0	 0.0	 1	 -30.0	 30.0;
	954	 1562	 0.027438	 0.076752	 0.00695	 67.84902	 67.84902	 67.84902	 0.0	 0.0	 1	 -30.0	 30.0;
	6881	 3533	 0.0	 0.00081	 0.0	 75.319338	 75.319338	 75.319338	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 6277	 0.014347	 0.03705	 0.00363	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6949	 4716	 0.00286	 0.015591	 0.02729	 421.498617	 421.498617	 421.498617	 0.0	 0.0	 1	 -30.0	 30.0;
	5774	 5057	 0.0	 0.000793	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5057	 3986	 0.008231	 0.021273	 0.00208	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1139	 6669	 0.013653	 0.031231	 0.00346	 73.370071	 73.370071	 73.370071	 0.0	 0.0	 1	 -30.0	 30.0;
	2876	 2397	 0.0	 0.000777	 0.0	 65.288356	 65.288356	 65.288356	 0.0	 0.0	 1	 -30.0	 30.0;
	7909	 960	 0.028364	 0.063479	 0.00642	 61.152808	 61.152808	 61.152808	 0.0	 0.0	 1	 -30.0	 30.0;
	3671	 960	 0.023636	 0.051983	 0.00598	 71.228182	 71.228182	 71.228182	 0.0	 0.0	 1	 -30.0	 30.0;
	422	 960	 0.022752	 0.066248	 0.00576	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5824	 5110	 0.004512	 0.013099	 0.00155	 61.72648	 61.72648	 61.72648	 0.0	 0.0	 1	 -30.0	 30.0;
	5824	 2120	 0.006331	 0.015124	 0.00133	 72.877562	 72.877562	 72.877562	 0.0	 0.0	 1	 -30.0	 30.0;
	4667	 852	 0.048058	 0.143504	 0.01216	 62.156687	 62.156687	 62.156687	 0.0	 0.0	 1	 -30.0	 30.0;
	6902	 2395	 0.02676	 0.077901	 0.00677	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2454	 521	 0.0	 0.000744	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4249	 1101	 0.00031	 0.00329	 0.06108	 1254.762245	 1254.762245	 1254.762245	 0.0	 0.0	 1	 -30.0	 30.0;
	4249	 1101	 0.00035	 0.00322	 0.06923	 1217.635667	 1217.635667	 1217.635667	 0.0	 0.0	 1	 -30.0	 30.0;
	5357	 635	 0.01276	 0.028033	 0.00322	 73.865247	 73.865247	 73.865247	 0.0	 0.0	 1	 -30.0	 30.0;
	6682	 7028	 0.049983	 0.088198	 0.0954	 64.238751	 64.238751	 64.238751	 0.0	 0.0	 1	 -30.0	 30.0;
	4425	 3365	 0.0	 0.000876	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3883	 3365	 0.020157	 0.04643	 0.00529	 59.020064	 59.020064	 59.020064	 0.0	 0.0	 1	 -30.0	 30.0;
	7268	 7426	 0.050554	 0.09781	 0.01052	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 7268	 0.050157	 0.093818	 0.01032	 94.134883	 94.134883	 94.134883	 0.0	 0.0	 1	 -30.0	 30.0;
	6900	 3565	 0.03338	 0.08238	 0.00676	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	19	 3565	 0.041554	 0.156107	 0.01409	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3412	 5960	 0.04676	 0.124372	 0.00908	 93.618749	 93.618749	 93.618749	 0.0	 0.0	 1	 -30.0	 30.0;
	1958	 5960	 0.043868	 0.116678	 0.00852	 83.014666	 83.014666	 83.014666	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 5199	 0.015529	 0.049017	 0.00534	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 1299	 0.019471	 0.052802	 0.00671	 67.944473	 67.944473	 67.944473	 0.0	 0.0	 1	 -30.0	 30.0;
	4332	 5042	 0.030339	 0.062124	 0.0062	 64.076613	 64.076613	 64.076613	 0.0	 0.0	 1	 -30.0	 30.0;
	1283	 4332	 0.043488	 0.11219	 0.00895	 63.007955	 63.007955	 63.007955	 0.0	 0.0	 1	 -30.0	 30.0;
	4332	 5319	 0.025934	 0.052198	 0.00517	 75.178921	 75.178921	 75.178921	 0.0	 0.0	 1	 -30.0	 30.0;
	7044	 6834	 0.024372	 0.057347	 0.00505	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7044	 6053	 0.023868	 0.058446	 0.00494	 80.333209	 80.333209	 80.333209	 0.0	 0.0	 1	 -30.0	 30.0;
	7006	 1299	 0.032636	 0.103934	 0.01125	 68.210447	 68.210447	 68.210447	 0.0	 0.0	 1	 -30.0	 30.0;
	8144	 7006	 0.02695	 0.081719	 0.00926	 61.261407	 61.261407	 61.261407	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 4041	 0.022521	 0.13874	 0.17178	 457.786883	 457.786883	 457.786883	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 2822	 0.0117	 0.053091	 0.11024	 439.967024	 439.967024	 439.967024	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 4586	 0.001401	 0.006789	 0.01068	 477.31385	 477.31385	 477.31385	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 2181	 0.00139	 0.0113	 0.01054	 460.288484	 460.288484	 460.288484	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 5205	 0.01818	 0.095349	 0.13858	 467.182462	 467.182462	 467.182462	 0.0	 0.0	 1	 -30.0	 30.0;
	7238	 5205	 0.005729	 0.043599	 0.06051	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 8319	 0.00095	 0.006409	 0.01072	 375.542321	 375.542321	 375.542321	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 1264	 0.00093	 0.006531	 0.0105	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 4457	 0.025659	 0.11894	 0.19536	 455.579834	 455.579834	 455.579834	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 629	 0.01036	 0.04869	 0.07802	 533.49756	 533.49756	 533.49756	 0.0	 0.0	 1	 -30.0	 30.0;
	4685	 2477	 0.022231	 0.051521	 0.0044	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 2477	 0.038099	 0.092579	 0.00752	 85.467493	 85.467493	 85.467493	 0.0	 0.0	 1	 -30.0	 30.0;
	3227	 1174	 0.018041	 0.066793	 0.0062	 61.243498	 61.243498	 61.243498	 0.0	 0.0	 1	 -30.0	 30.0;
	4350	 1174	 0.019942	 0.075554	 0.00688	 71.076714	 71.076714	 71.076714	 0.0	 0.0	 1	 -30.0	 30.0;
	165	 4013	 0.028347	 0.064727	 0.00569	 99.975826	 99.975826	 99.975826	 0.0	 0.0	 1	 -30.0	 30.0;
	165	 4244	 0.028124	 0.066826	 0.00565	 68.025447	 68.025447	 68.025447	 0.0	 0.0	 1	 -30.0	 30.0;
	5763	 1182	 0.017107	 0.031438	 0.00335	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6990	 1182	 0.028322	 0.109331	 0.00932	 72.873942	 72.873942	 72.873942	 0.0	 0.0	 1	 -30.0	 30.0;
	7641	 6886	 0.0	 0.000413	 0.0	 60.670587	 60.670587	 60.670587	 0.0	 0.0	 1	 -30.0	 30.0;
	7641	 1393	 0.002248	 0.008413	 0.00077	 116.393416	 116.393416	 116.393416	 0.0	 0.0	 1	 -30.0	 30.0;
	6886	 1920	 0.003421	 0.010397	 0.00119	 106.897049	 106.897049	 106.897049	 0.0	 0.0	 1	 -30.0	 30.0;
	2706	 6886	 0.039554	 0.071554	 0.00851	 66.955646	 66.955646	 66.955646	 0.0	 0.0	 1	 -30.0	 30.0;
	3089	 6886	 0.012612	 0.036818	 0.00439	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5380	 137	 0.004471	 0.014041	 0.00156	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	137	 3575	 0.013628	 0.050934	 0.0047	 97.941013	 97.941013	 97.941013	 0.0	 0.0	 1	 -30.0	 30.0;
	137	 792	 0.002438	 0.007959	 0.00083	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	137	 3084	 0.014579	 0.030132	 0.0031	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	137	 7630	 0.04186	 0.08719	 0.00828	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	137	 7304	 0.072653	 0.128339	 0.01538	 81.413299	 81.413299	 81.413299	 0.0	 0.0	 1	 -30.0	 30.0;
	7013	 851	 0.013612	 0.049421	 0.00467	 80.929554	 80.929554	 80.929554	 0.0	 0.0	 1	 -30.0	 30.0;
	7013	 7231	 0.037256	 0.107727	 0.00928	 58.816773	 58.816773	 58.816773	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 2668	 0.003349	 0.0237	 0.03732	 269.926366	 269.926366	 269.926366	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 2668	 0.003281	 0.024159	 0.03654	 253.174213	 253.174213	 253.174213	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 2668	 0.003599	 0.023469	 0.03965	 257.275086	 257.275086	 257.275086	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 2668	 0.003669	 0.02299	 0.04042	 586.939988	 586.939988	 586.939988	 0.0	 0.0	 1	 -30.0	 30.0;
	307	 830	 0.009124	 0.02781	 0.00303	 94.539559	 94.539559	 94.539559	 0.0	 0.0	 1	 -30.0	 30.0;
	307	 830	 0.008661	 0.026479	 0.00294	 96.752133	 96.752133	 96.752133	 0.0	 0.0	 1	 -30.0	 30.0;
	307	 830	 0.008488	 0.027033	 0.00289	 122.427361	 122.427361	 122.427361	 0.0	 0.0	 1	 -30.0	 30.0;
	307	 1643	 0.002248	 0.006554	 0.00077	 72.805162	 72.805162	 72.805162	 0.0	 0.0	 1	 -30.0	 30.0;
	307	 4600	 0.001612	 0.004636	 0.00055	 72.786491	 72.786491	 72.786491	 0.0	 0.0	 1	 -30.0	 30.0;
	307	 1393	 0.012223	 0.027331	 0.00324	 139.158937	 139.158937	 139.158937	 0.0	 0.0	 1	 -30.0	 30.0;
	307	 4901	 0.002099	 0.01181	 0.00146	 91.714636	 91.714636	 91.714636	 0.0	 0.0	 1	 -30.0	 30.0;
	307	 4901	 0.002058	 0.012058	 0.00144	 97.017916	 97.017916	 97.017916	 0.0	 0.0	 1	 -30.0	 30.0;
	830	 1253	 0.019008	 0.055876	 0.00634	 73.785797	 73.785797	 73.785797	 0.0	 0.0	 1	 -30.0	 30.0;
	830	 2595	 0.020727	 0.05795	 0.00708	 71.217894	 71.217894	 71.217894	 0.0	 0.0	 1	 -30.0	 30.0;
	2706	 1311	 0.004471	 0.010471	 0.00114	 104.183965	 104.183965	 104.183965	 0.0	 0.0	 1	 -30.0	 30.0;
	7814	 1311	 0.010479	 0.025967	 0.00213	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1643	 4600	 0.001636	 0.004537	 0.00056	 66.024547	 66.024547	 66.024547	 0.0	 0.0	 1	 -30.0	 30.0;
	1920	 5380	 0.001603	 0.005256	 0.00055	 85.635917	 85.635917	 85.635917	 0.0	 0.0	 1	 -30.0	 30.0;
	7677	 275	 0.001039	 0.00812	 0.01067	 601.598265	 601.598265	 601.598265	 0.0	 0.0	 1	 -30.0	 30.0;
	7677	 275	 0.001169	 0.007961	 0.0121	 639.832178	 639.832178	 639.832178	 0.0	 0.0	 1	 -30.0	 30.0;
	851	 3575	 0.001802	 0.006628	 0.00062	 80.825718	 80.825718	 80.825718	 0.0	 0.0	 1	 -30.0	 30.0;
	4840	 8188	 0.00022	 0.00217	 0.05257	 1305.474961	 1305.474961	 1305.474961	 0.0	 0.0	 1	 -30.0	 30.0;
	1538	 8188	 0.00067	 0.0072	 0.16078	 1154.383977	 1154.383977	 1154.383977	 0.0	 0.0	 1	 -30.0	 30.0;
	2326	 2706	 0.019826	 0.06962	 0.0067	 74.486932	 74.486932	 74.486932	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 4041	 0.005919	 0.02874	 0.04424	 551.146708	 551.146708	 551.146708	 0.0	 0.0	 1	 -30.0	 30.0;
	2131	 4041	 0.001271	 0.009651	 0.01349	 528.38995	 528.38995	 528.38995	 0.0	 0.0	 1	 -30.0	 30.0;
	7677	 4041	 0.00126	 0.00955	 0.0134	 572.874246	 572.874246	 572.874246	 0.0	 0.0	 1	 -30.0	 30.0;
	6676	 4840	 0.0009	 0.01149	 0.21324	 1269.081594	 1269.081594	 1269.081594	 0.0	 0.0	 1	 -30.0	 30.0;
	4840	 7576	 0.00115	 0.01172	 0.2706	 1211.061772	 1211.061772	 1211.061772	 0.0	 0.0	 1	 -30.0	 30.0;
	2131	 1602	 0.00431	 0.033729	 0.04495	 465.937186	 465.937186	 465.937186	 0.0	 0.0	 1	 -30.0	 30.0;
	7677	 5761	 0.001841	 0.0115	 0.01949	 368.87926	 368.87926	 368.87926	 0.0	 0.0	 1	 -30.0	 30.0;
	2822	 7238	 0.008401	 0.053719	 0.06392	 583.388972	 583.388972	 583.388972	 0.0	 0.0	 1	 -30.0	 30.0;
	3552	 2822	 0.0013	 0.006021	 0.01199	 432.715621	 432.715621	 432.715621	 0.0	 0.0	 1	 -30.0	 30.0;
	8205	 7678	 0.016083	 0.036347	 0.00333	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7678	 4006	 0.01576	 0.037058	 0.00326	 64.012025	 64.012025	 64.012025	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 7678	 0.039661	 0.101099	 0.00797	 70.586301	 70.586301	 70.586301	 0.0	 0.0	 1	 -30.0	 30.0;
	3409	 340	 0.015777	 0.058099	 0.00549	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4369	 340	 0.044901	 0.08681	 0.00894	 64.209981	 64.209981	 64.209981	 0.0	 0.0	 1	 -30.0	 30.0;
	4388	 2586	 0.00173	 0.01919	 0.41161	 1280.574063	 1280.574063	 1280.574063	 0.0	 0.0	 1	 -30.0	 30.0;
	2586	 7764	 0.00213	 0.02194	 0.5097	 1503.108436	 1503.108436	 1503.108436	 0.0	 0.0	 1	 -30.0	 30.0;
	202	 1847	 0.00395	 0.008331	 0.00078	 109.364355	 109.364355	 109.364355	 0.0	 0.0	 1	 -30.0	 30.0;
	7532	 1847	 0.157273	 0.234413	 0.02702	 69.634626	 69.634626	 69.634626	 0.0	 0.0	 1	 -30.0	 30.0;
	202	 3518	 0.003421	 0.009099	 0.00068	 61.606259	 61.606259	 61.606259	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 5579	 0.06795	 0.151058	 0.01395	 69.017514	 69.017514	 69.017514	 0.0	 0.0	 1	 -30.0	 30.0;
	202	 2877	 0.040099	 0.154554	 0.01253	 64.459951	 64.459951	 64.459951	 0.0	 0.0	 1	 -30.0	 30.0;
	202	 4251	 0.070769	 0.175471	 0.01365	 78.969046	 78.969046	 78.969046	 0.0	 0.0	 1	 -30.0	 30.0;
	202	 2914	 0.008504	 0.028322	 0.00301	 69.368271	 69.368271	 69.368271	 0.0	 0.0	 1	 -30.0	 30.0;
	202	 8278	 0.02738	 0.069876	 0.00626	 63.693466	 63.693466	 63.693466	 0.0	 0.0	 1	 -30.0	 30.0;
	898	 7969	 0.010347	 0.023041	 0.00189	 68.913296	 68.913296	 68.913296	 0.0	 0.0	 1	 -30.0	 30.0;
	8144	 7969	 0.044281	 0.083967	 0.00876	 72.971301	 72.971301	 72.971301	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 898	 0.055744	 0.101992	 0.01097	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1549	 4013	 0.015446	 0.026554	 0.00312	 133.616739	 133.616739	 133.616739	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 1361	 0.035388	 0.067603	 0.00635	 70.958779	 70.958779	 70.958779	 0.0	 0.0	 1	 -30.0	 30.0;
	2752	 6619	 0.007273	 0.013752	 0.00147	 92.451018	 92.451018	 92.451018	 0.0	 0.0	 1	 -30.0	 30.0;
	6619	 6336	 0.00362	 0.007033	 0.00073	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3798	 6336	 0.001182	 0.003727	 0.00041	 76.432579	 76.432579	 76.432579	 0.0	 0.0	 1	 -30.0	 30.0;
	3798	 4063	 0.013314	 0.052752	 0.0046	 62.718547	 62.718547	 62.718547	 0.0	 0.0	 1	 -30.0	 30.0;
	2752	 4137	 0.028372	 0.075868	 0.00971	 58.370181	 58.370181	 58.370181	 0.0	 0.0	 1	 -30.0	 30.0;
	4856	 2752	 0.033917	 0.080413	 0.0069	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7922	 3971	 0.004669	 0.03695	 0.04845	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	3971	 7238	 0.004229	 0.025271	 0.04386	 298.33678	 298.33678	 298.33678	 0.0	 0.0	 1	 -30.0	 30.0;
	6900	 2391	 0.041909	 0.072157	 0.00848	 69.176412	 69.176412	 69.176412	 0.0	 0.0	 1	 -30.0	 30.0;
	2841	 2391	 0.031174	 0.078554	 0.0069	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2312	 3227	 0.030777	 0.114017	 0.01058	 58.771047	 58.771047	 58.771047	 0.0	 0.0	 1	 -30.0	 30.0;
	1517	 6126	 0.021479	 0.05195	 0.00423	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6126	 1299	 0.04881	 0.09786	 0.01012	 73.720828	 73.720828	 73.720828	 0.0	 0.0	 1	 -30.0	 30.0;
	6566	 1072	 0.043992	 0.107769	 0.00913	 62.246044	 62.246044	 62.246044	 0.0	 0.0	 1	 -30.0	 30.0;
	6566	 1299	 0.017347	 0.059826	 0.00598	 62.191553	 62.191553	 62.191553	 0.0	 0.0	 1	 -30.0	 30.0;
	2705	 6336	 0.006281	 0.014802	 0.00127	 61.962732	 61.962732	 61.962732	 0.0	 0.0	 1	 -30.0	 30.0;
	4137	 2705	 0.045818	 0.086281	 0.00966	 62.5023	 62.5023	 62.5023	 0.0	 0.0	 1	 -30.0	 30.0;
	6053	 2705	 0.022521	 0.077653	 0.0078	 75.105187	 75.105187	 75.105187	 0.0	 0.0	 1	 -30.0	 30.0;
	1935	 5035	 0.014132	 0.053744	 0.00486	 83.361614	 83.361614	 83.361614	 0.0	 0.0	 1	 -30.0	 30.0;
	726	 1935	 0.025901	 0.082504	 0.00896	 69.004748	 69.004748	 69.004748	 0.0	 0.0	 1	 -30.0	 30.0;
	2243	 1935	 0.05905	 0.233421	 0.0198	 61.666274	 61.666274	 61.666274	 0.0	 0.0	 1	 -30.0	 30.0;
	6	 7619	 0.035174	 0.062992	 0.00712	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6	 6536	 0.015901	 0.059529	 0.00584	 60.652297	 60.652297	 60.652297	 0.0	 0.0	 1	 -30.0	 30.0;
	7619	 885	 0.005174	 0.015322	 0.00191	 90.444783	 90.444783	 90.444783	 0.0	 0.0	 1	 -30.0	 30.0;
	7619	 2133	 0.021471	 0.063207	 0.00788	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	885	 1860	 0.030033	 0.114521	 0.01029	 83.039244	 83.039244	 83.039244	 0.0	 0.0	 1	 -30.0	 30.0;
	885	 5107	 0.050537	 0.090521	 0.01023	 62.559077	 62.559077	 62.559077	 0.0	 0.0	 1	 -30.0	 30.0;
	885	 5107	 0.026446	 0.070959	 0.00873	 78.381275	 78.381275	 78.381275	 0.0	 0.0	 1	 -30.0	 30.0;
	3765	 3494	 0.028157	 0.075636	 0.00961	 59.785025	 59.785025	 59.785025	 0.0	 0.0	 1	 -30.0	 30.0;
	3765	 7575	 0.021413	 0.212132	 0.01103	 58.255676	 58.255676	 58.255676	 0.0	 0.0	 1	 -30.0	 30.0;
	3765	 7575	 0.046446	 0.096702	 0.00969	 61.165573	 61.165573	 61.165573	 0.0	 0.0	 1	 -30.0	 30.0;
	7169	 4215	 0.042562	 0.102702	 0.00883	 71.750031	 71.750031	 71.750031	 0.0	 0.0	 1	 -30.0	 30.0;
	6828	 4215	 0.034314	 0.071603	 0.00712	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4298	 7814	 0.034033	 0.077537	 0.00689	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1283	 4298	 0.01919	 0.035669	 0.00383	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6900	 7426	 0.046826	 0.094587	 0.00948	 118.139011	 118.139011	 118.139011	 0.0	 0.0	 1	 -30.0	 30.0;
	8164	 2677	 0.059909	 0.111868	 0.01185	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6780	 8164	 0.020909	 0.037934	 0.0042	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5329	 6208	 0.009727	 0.025347	 0.002	 90.438305	 90.438305	 90.438305	 0.0	 0.0	 1	 -30.0	 30.0;
	4379	 5329	 0.01981	 0.040331	 0.00399	 111.410791	 111.410791	 111.410791	 0.0	 0.0	 1	 -30.0	 30.0;
	2436	 5045	 1.7e-05	 0.000413	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	535	 2436	 0.017091	 0.04114	 0.00347	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2326	 792	 0.03014	 0.111744	 0.00973	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3308	 1549	 0.012628	 0.026339	 0.00262	 134.181647	 134.181647	 134.181647	 0.0	 0.0	 1	 -30.0	 30.0;
	1131	 779	 0.032934	 0.078298	 0.00705	 61.830507	 61.830507	 61.830507	 0.0	 0.0	 1	 -30.0	 30.0;
	1790	 1131	 0.025198	 0.050942	 0.00511	 77.935445	 77.935445	 77.935445	 0.0	 0.0	 1	 -30.0	 30.0;
	2538	 6640	 0.025529	 0.049421	 0.00482	 58.041144	 58.041144	 58.041144	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 6640	 0.026124	 0.06962	 0.00489	 79.937488	 79.937488	 79.937488	 0.0	 0.0	 1	 -30.0	 30.0;
	354	 5863	 0.00036	 0.00188	 0.00296	 225.306797	 225.306797	 225.306797	 0.0	 0.0	 1	 -30.0	 30.0;
	354	 5863	 0.00043	 0.00174	 0.00348	 231.842968	 231.842968	 231.842968	 0.0	 0.0	 1	 -30.0	 30.0;
	7597	 4789	 0.026091	 0.052298	 0.0052	 75.201784	 75.201784	 75.201784	 0.0	 0.0	 1	 -30.0	 30.0;
	7597	 4789	 0.015413	 0.048636	 0.00529	 92.031099	 92.031099	 92.031099	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 6010	 0.024463	 0.08705	 0.00841	 73.741214	 73.741214	 73.741214	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 3355	 0.00638	 0.04836	 0.06504	 239.351963	 239.351963	 239.351963	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 4548	 0.002081	 0.01214	 0.0213	 537.828588	 537.828588	 537.828588	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 4548	 0.002081	 0.01257	 0.02118	 521.324499	 521.324499	 521.324499	 0.0	 0.0	 1	 -30.0	 30.0;
	8118	 2592	 0.005314	 0.015017	 0.00194	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	8118	 4244	 0.004331	 0.011752	 0.00158	 58.023234	 58.023234	 58.023234	 0.0	 0.0	 1	 -30.0	 30.0;
	2592	 4244	 0.00386	 0.013322	 0.00141	 71.323635	 71.323635	 71.323635	 0.0	 0.0	 1	 -30.0	 30.0;
	4244	 3494	 0.02181	 0.080802	 0.00748	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4244	 1564	 0.036992	 0.107727	 0.01268	 81.002335	 81.002335	 81.002335	 0.0	 0.0	 1	 -30.0	 30.0;
	4244	 4720	 0.029273	 0.105248	 0.01011	 72.86613	 72.86613	 72.86613	 0.0	 0.0	 1	 -30.0	 30.0;
	6053	 4063	 0.016909	 0.05057	 0.00605	 80.965564	 80.965564	 80.965564	 0.0	 0.0	 1	 -30.0	 30.0;
	7680	 4388	 0.00302	 0.03553	 0.70958	 1253.3544	 1253.3544	 1253.3544	 0.0	 0.0	 1	 -30.0	 30.0;
	4251	 6903	 0.005983	 0.023132	 0.00207	 74.634779	 74.634779	 74.634779	 0.0	 0.0	 1	 -30.0	 30.0;
	6484	 6903	 0.003777	 0.011421	 0.00128	 64.303339	 64.303339	 64.303339	 0.0	 0.0	 1	 -30.0	 30.0;
	2914	 6903	 0.050041	 0.180397	 0.01652	 91.021885	 91.021885	 91.021885	 0.0	 0.0	 1	 -30.0	 30.0;
	6903	 8278	 0.056562	 0.179397	 0.01958	 94.948046	 94.948046	 94.948046	 0.0	 0.0	 1	 -30.0	 30.0;
	5850	 1998	 0.012818	 0.046769	 0.00438	 60.135782	 60.135782	 60.135782	 0.0	 0.0	 1	 -30.0	 30.0;
	7815	 5761	 0.00286	 0.017581	 0.03032	 516.972514	 516.972514	 516.972514	 0.0	 0.0	 1	 -30.0	 30.0;
	530	 8205	 0.012554	 0.029083	 0.00272	 79.639125	 79.639125	 79.639125	 0.0	 0.0	 1	 -30.0	 30.0;
	1839	 2710	 0.000909	 0.002876	 0.00032	 140.731155	 140.731155	 140.731155	 0.0	 0.0	 1	 -30.0	 30.0;
	6008	 530	 0.018719	 0.033769	 0.00401	 62.755318	 62.755318	 62.755318	 0.0	 0.0	 1	 -30.0	 30.0;
	2855	 6008	 0.032149	 0.059041	 0.00681	 104.60636	 104.60636	 104.60636	 0.0	 0.0	 1	 -30.0	 30.0;
	7342	 4535	 0.005198	 0.013488	 0.00103	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 7342	 0.018636	 0.044149	 0.00378	 69.637293	 69.637293	 69.637293	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 4535	 0.014554	 0.028438	 0.00287	 78.370796	 78.370796	 78.370796	 0.0	 0.0	 1	 -30.0	 30.0;
	6780	 2677	 0.032934	 0.155826	 0.01172	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 5995	 0.015231	 0.035843	 0.00317	 65.397527	 65.397527	 65.397527	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 8342	 0.037248	 0.089901	 0.00773	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 387	 0.04643	 0.09338	 0.00924	 58.830491	 58.830491	 58.830491	 0.0	 0.0	 1	 -30.0	 30.0;
	223	 7687	 0.075612	 0.155504	 0.0155	 59.267176	 59.267176	 59.267176	 0.0	 0.0	 1	 -30.0	 30.0;
	7687	 3955	 0.04057	 0.08876	 0.00821	 70.882568	 70.882568	 70.882568	 0.0	 0.0	 1	 -30.0	 30.0;
	7687	 296	 0.114628	 0.20105	 0.02273	 59.873809	 59.873809	 59.873809	 0.0	 0.0	 1	 -30.0	 30.0;
	3887	 8367	 0.018521	 0.090322	 0.00906	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2595	 8367	 0.013702	 0.052983	 0.00445	 72.732953	 72.732953	 72.732953	 0.0	 0.0	 1	 -30.0	 30.0;
	1581	 7120	 0.006017	 0.019198	 0.0022	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	1581	 6193	 0.052686	 0.090653	 0.01071	 99.210104	 99.210104	 99.210104	 0.0	 0.0	 1	 -30.0	 30.0;
	1581	 1998	 0.065826	 0.122818	 0.01331	 61.904241	 61.904241	 61.904241	 0.0	 0.0	 1	 -30.0	 30.0;
	6053	 6834	 0.04443	 0.105719	 0.00916	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7021	 6668	 0.00838	 0.018942	 0.00173	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7530	 6668	 0.058017	 0.142983	 0.01253	 61.32409	 61.32409	 61.32409	 0.0	 0.0	 1	 -30.0	 30.0;
	1398	 7102	 0.00085	 0.01148	 0.20153	 870.184127	 870.184127	 870.184127	 0.0	 0.0	 1	 -30.0	 30.0;
	7764	 7102	 0.00172	 0.0234	 0.4111	 1302.370329	 1302.370329	 1302.370329	 0.0	 0.0	 1	 -30.0	 30.0;
	6900	 7021	 0.04805	 0.152256	 0.01649	 59.51143	 59.51143	 59.51143	 0.0	 0.0	 1	 -30.0	 30.0;
	7021	 5290	 0.028372	 0.069471	 0.00588	 105.408282	 105.408282	 105.408282	 0.0	 0.0	 1	 -30.0	 30.0;
	6208	 7021	 0.038364	 0.12214	 0.01323	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3412	 5035	 0.013463	 0.05405	 0.00463	 73.970988	 73.970988	 73.970988	 0.0	 0.0	 1	 -30.0	 30.0;
	3084	 7630	 0.025083	 0.060273	 0.00528	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3202	 1248	 0.012438	 0.047124	 0.00428	 86.961976	 86.961976	 86.961976	 0.0	 0.0	 1	 -30.0	 30.0;
	8144	 3202	 0.022388	 0.084818	 0.00772	 93.658188	 93.658188	 93.658188	 0.0	 0.0	 1	 -30.0	 30.0;
	2312	 2737	 0.005471	 0.020281	 0.00188	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4350	 2737	 0.107174	 0.201248	 0.02141	 67.375373	 67.375373	 67.375373	 0.0	 0.0	 1	 -30.0	 30.0;
	4685	 2312	 0.035058	 0.124769	 0.01205	 65.50727	 65.50727	 65.50727	 0.0	 0.0	 1	 -30.0	 30.0;
	1860	 7120	 0.015934	 0.05876	 0.00584	 130.50698	 130.50698	 130.50698	 0.0	 0.0	 1	 -30.0	 30.0;
	535	 5045	 0.020099	 0.03862	 0.00408	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2020	 3676	 0.04176	 0.103083	 0.00845	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3377	 3676	 0.066719	 0.165537	 0.0132	 80.242329	 80.242329	 80.242329	 0.0	 0.0	 1	 -30.0	 30.0;
	4548	 4546	 0.00013	 0.00095	 0.00127	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	2538	 2999	 0.033777	 0.06776	 0.00705	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7488	 2999	 0.057388	 0.126289	 0.01177	 62.739314	 62.739314	 62.739314	 0.0	 0.0	 1	 -30.0	 30.0;
	1398	 8222	 0.0019	 0.0204	 0.45561	 1229.9219	 1229.9219	 1229.9219	 0.0	 0.0	 1	 -30.0	 30.0;
	7530	 7634	 0.007529	 0.025372	 0.00256	 61.620358	 61.620358	 61.620358	 0.0	 0.0	 1	 -30.0	 30.0;
	7530	 1514	 0.023917	 0.064636	 0.00824	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7530	 5319	 0.039612	 0.099818	 0.00788	 69.536315	 69.536315	 69.536315	 0.0	 0.0	 1	 -30.0	 30.0;
	7530	 6720	 0.012388	 0.038802	 0.00424	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7634	 6720	 0.004281	 0.015678	 0.00146	 61.059641	 61.059641	 61.059641	 0.0	 0.0	 1	 -30.0	 30.0;
	6891	 4856	 0.013463	 0.033289	 0.00273	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7771	 4856	 0.015893	 0.039901	 0.00327	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7771	 6891	 0.005934	 0.021686	 0.00216	 64.021933	 64.021933	 64.021933	 0.0	 0.0	 1	 -30.0	 30.0;
	3432	 6891	 0.009107	 0.02843	 0.00311	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7771	 3432	 0.005802	 0.020083	 0.00211	 82.090427	 82.090427	 82.090427	 0.0	 0.0	 1	 -30.0	 30.0;
	7771	 1651	 0.10495	 0.203661	 0.02123	 60.655345	 60.655345	 60.655345	 0.0	 0.0	 1	 -30.0	 30.0;
	7771	 927	 0.026372	 0.04995	 0.00542	 66.192591	 66.192591	 66.192591	 0.0	 0.0	 1	 -30.0	 30.0;
	600	 7922	 0.00738	 0.044	 0.05611	 262.673819	 262.673819	 262.673819	 0.0	 0.0	 1	 -30.0	 30.0;
	7922	 7238	 0.010591	 0.05825	 0.08047	 528.163225	 528.163225	 528.163225	 0.0	 0.0	 1	 -30.0	 30.0;
	4424	 600	 0.01318	 0.05764	 0.09902	 527.850001	 527.850001	 527.850001	 0.0	 0.0	 1	 -30.0	 30.0;
	600	 3999	 0.0143	 0.06869	 0.11738	 481.884178	 481.884178	 481.884178	 0.0	 0.0	 1	 -30.0	 30.0;
	6900	 2004	 0.022099	 0.080636	 0.00757	 58.728751	 58.728751	 58.728751	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 1517	 0.039843	 0.08557	 0.00784	 58.680167	 58.680167	 58.680167	 0.0	 0.0	 1	 -30.0	 30.0;
	1517	 7647	 0.007909	 0.022124	 0.00272	 61.377056	 61.377056	 61.377056	 0.0	 0.0	 1	 -30.0	 30.0;
	7562	 19	 0.051017	 0.111273	 0.01032	 63.280788	 63.280788	 63.280788	 0.0	 0.0	 1	 -30.0	 30.0;
	6208	 1514	 0.010331	 0.038289	 0.00355	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	779	 2326	 0.02343	 0.058603	 0.00485	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7764	 1807	 0.0009	 0.00851	 0.21417	 1271.872933	 1271.872933	 1271.872933	 0.0	 0.0	 1	 -30.0	 30.0;
	1807	 5534	 0.00157	 0.01488	 0.37481	 1112.208505	 1112.208505	 1112.208505	 0.0	 0.0	 1	 -30.0	 30.0;
	4424	 2823	 0.00682	 0.03224	 0.05114	 304.838275	 304.838275	 304.838275	 0.0	 0.0	 1	 -30.0	 30.0;
	6780	 7169	 0.01719	 0.033322	 0.00346	 92.839499	 92.839499	 92.839499	 0.0	 0.0	 1	 -30.0	 30.0;
	7169	 6828	 0.080446	 0.14995	 0.01599	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4369	 223	 0.055678	 0.123917	 0.01141	 66.910491	 66.910491	 66.910491	 0.0	 0.0	 1	 -30.0	 30.0;
	1116	 1564	 0.014463	 0.040066	 0.00478	 136.900447	 136.900447	 136.900447	 0.0	 0.0	 1	 -30.0	 30.0;
	1116	 7203	 0.013107	 0.048314	 0.00481	 60.539887	 60.539887	 60.539887	 0.0	 0.0	 1	 -30.0	 30.0;
	3955	 1790	 0.123174	 0.23414	 0.02442	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2877	 5579	 0.00557	 0.011256	 0.00114	 68.815747	 68.815747	 68.815747	 0.0	 0.0	 1	 -30.0	 30.0;
	2877	 2386	 0.007967	 0.018719	 0.00213	 67.231146	 67.231146	 67.231146	 0.0	 0.0	 1	 -30.0	 30.0;
	7532	 2386	 0.076711	 0.159554	 0.01609	 83.594817	 83.594817	 83.594817	 0.0	 0.0	 1	 -30.0	 30.0;
	497	 2133	 0.012669	 0.049364	 0.00465	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	497	 4725	 0.015719	 0.058826	 0.00576	 69.406757	 69.406757	 69.406757	 0.0	 0.0	 1	 -30.0	 30.0;
	6085	 1281	 0.007397	 0.027686	 0.00272	 68.21521	 68.21521	 68.21521	 0.0	 0.0	 1	 -30.0	 30.0;
	6085	 1998	 0.006967	 0.02505	 0.00255	 72.946913	 72.946913	 72.946913	 0.0	 0.0	 1	 -30.0	 30.0;
	5042	 7859	 0.037653	 0.076876	 0.00769	 77.052359	 77.052359	 77.052359	 0.0	 0.0	 1	 -30.0	 30.0;
	3409	 6990	 0.011	 0.029826	 0.00383	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4350	 4685	 0.042446	 0.107058	 0.00835	 85.928946	 85.928946	 85.928946	 0.0	 0.0	 1	 -30.0	 30.0;
	4251	 6484	 0.011008	 0.025711	 0.00217	 59.853804	 59.853804	 59.853804	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 6828	 0.014818	 0.04719	 0.00511	 89.611615	 89.611615	 89.611615	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 6828	 0.011802	 0.040711	 0.00407	 71.222466	 71.222466	 71.222466	 0.0	 0.0	 1	 -30.0	 30.0;
	6828	 5572	 0.010802	 0.039769	 0.00371	 87.830963	 87.830963	 87.830963	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 7270	 0.003331	 0.011496	 0.00117	 72.418967	 72.418967	 72.418967	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 7562	 0.041256	 0.083702	 0.00796	 101.621967	 101.621967	 101.621967	 0.0	 0.0	 1	 -30.0	 30.0;
	7270	 6828	 0.011223	 0.030413	 0.00393	 80.823241	 80.823241	 80.823241	 0.0	 0.0	 1	 -30.0	 30.0;
	6828	 1839	 0.105562	 0.208901	 0.02161	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6828	 2020	 0.021612	 0.065496	 0.0074	 73.84848	 73.84848	 73.84848	 0.0	 0.0	 1	 -30.0	 30.0;
	7764	 2178	 0.0056	 0.03178	 0.51847	 1065.337582	 1065.337582	 1065.337582	 0.0	 0.0	 1	 -30.0	 30.0;
	2595	 1253	 0.005364	 0.01443	 0.00182	 72.606444	 72.606444	 72.606444	 0.0	 0.0	 1	 -30.0	 30.0;
	5485	 7581	 0.007132	 0.016347	 0.00142	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7581	 1998	 0.035281	 0.111719	 0.01302	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1651	 5485	 0.027669	 0.067686	 0.00571	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5485	 2855	 0.086157	 0.181149	 0.01716	 87.389515	 87.389515	 87.389515	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 7597	 0.019983	 0.054711	 0.00647	 125.159689	 125.159689	 125.159689	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 3887	 0.007041	 0.032174	 0.00307	 82.688296	 82.688296	 82.688296	 0.0	 0.0	 1	 -30.0	 30.0;
	3402	 5763	 0.050587	 0.128397	 0.0103	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7597	 5871	 0.014983	 0.031364	 0.00303	 62.308345	 62.308345	 62.308345	 0.0	 0.0	 1	 -30.0	 30.0;
	5871	 5696	 0.010653	 0.019	 0.00227	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5159	 4367	 0.00189	 0.02064	 0.4428	 1354.850914	 1354.850914	 1354.850914	 0.0	 0.0	 1	 -30.0	 30.0;
	5159	 4367	 0.00227	 0.01922	 0.51608	 1264.233445	 1264.233445	 1264.233445	 0.0	 0.0	 1	 -30.0	 30.0;
	4367	 810	 0.00167	 0.02044	 0.38247	 1304.479135	 1304.479135	 1304.479135	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 3064	 0.016341	 0.07818	 0.12503	 508.429727	 508.429727	 508.429727	 0.0	 0.0	 1	 -30.0	 30.0;
	6822	 3064	 0.005409	 0.024729	 0.04162	 545.693484	 545.693484	 545.693484	 0.0	 0.0	 1	 -30.0	 30.0;
	3064	 1340	 0.00525	 0.04099	 0.05557	 560.339948	 560.339948	 560.339948	 0.0	 0.0	 1	 -30.0	 30.0;
	7597	 3098	 0.00714	 0.025347	 0.00246	 61.319708	 61.319708	 61.319708	 0.0	 0.0	 1	 -30.0	 30.0;
	7597	 3419	 0.00819	 0.025802	 0.00282	 77.652514	 77.652514	 77.652514	 0.0	 0.0	 1	 -30.0	 30.0;
	5696	 7597	 0.006322	 0.014314	 0.00134	 64.86196	 64.86196	 64.86196	 0.0	 0.0	 1	 -30.0	 30.0;
	4746	 992	 0.037678	 0.087512	 0.00743	 93.141101	 93.141101	 93.141101	 0.0	 0.0	 1	 -30.0	 30.0;
	4746	 6529	 0.010942	 0.034529	 0.00376	 105.92232	 105.92232	 105.92232	 0.0	 0.0	 1	 -30.0	 30.0;
	3098	 6529	 0.007041	 0.02714	 0.00243	 81.035106	 81.035106	 81.035106	 0.0	 0.0	 1	 -30.0	 30.0;
	6529	 3419	 0.002826	 0.010496	 0.00098	 89.651816	 89.651816	 89.651816	 0.0	 0.0	 1	 -30.0	 30.0;
	6676	 5159	 0.0001	 0.00124	 0.02313	 1351.311884	 1351.311884	 1351.311884	 0.0	 0.0	 1	 -30.0	 30.0;
	6676	 4051	 3e-05	 0.00027	 0.0031	 1391.42528	 1391.42528	 1391.42528	 0.0	 0.0	 1	 -30.0	 30.0;
	6676	 5670	 2e-05	 0.00021	 0.00447	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	6676	 5159	 0.00011	 0.00133	 0.02492	 1261.803447	 1261.803447	 1261.803447	 0.0	 0.0	 1	 -30.0	 30.0;
	6676	 8222	 0.00062	 0.00694	 0.14895	 1261.872556	 1261.872556	 1261.872556	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 420	 0.005281	 0.04189	 0.05579	 609.779814	 609.779814	 609.779814	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 3272	 0.00014	 0.000651	 0.00111	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 1037	 0.000229	 0.00107	 0.00176	 363.298765	 363.298765	 363.298765	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 2988	 0.000229	 0.001039	 0.00179	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 809	 0.00013	 0.00086	 0.00106	 647.787002	 647.787002	 647.787002	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 6921	 0.00013	 0.00087	 0.00104	 403.82775	 403.82775	 403.82775	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 5203	 0.001539	 0.012651	 0.01593	 215.929128	 215.929128	 215.929128	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 629	 0.00806	 0.047091	 0.0607	 327.380119	 327.380119	 327.380119	 0.0	 0.0	 1	 -30.0	 30.0;
	7647	 1072	 0.04943	 0.099331	 0.00959	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	160	 296	 0.050488	 0.104149	 0.01003	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6010	 6771	 0.003702	 0.008934	 0.00073	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 6771	 0.074446	 0.138033	 0.01444	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3412	 7630	 0.008479	 0.021653	 0.00165	 57.830423	 57.830423	 57.830423	 0.0	 0.0	 1	 -30.0	 30.0;
	3412	 7630	 0.005314	 0.019479	 0.00177	 65.49984	 65.49984	 65.49984	 0.0	 0.0	 1	 -30.0	 30.0;
	7680	 1538	 0.00104	 0.01121	 0.2445	 1463.243831	 1463.243831	 1463.243831	 0.0	 0.0	 1	 -30.0	 30.0;
	1340	 7815	 0.01118	 0.07193	 0.08404	 446.799272	 446.799272	 446.799272	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 2841	 0.002777	 0.008174	 0.00078	 66.752545	 66.752545	 66.752545	 0.0	 0.0	 1	 -30.0	 30.0;
	6536	 6193	 0.006058	 0.02362	 0.00223	 97.912243	 97.912243	 97.912243	 0.0	 0.0	 1	 -30.0	 30.0;
	2178	 6631	 0.00192	 0.01477	 0.1866	 1116.762448	 1116.762448	 1116.762448	 0.0	 0.0	 1	 -30.0	 30.0;
	7120	 6193	 0.025331	 0.098711	 0.00929	 145.315962	 145.315962	 145.315962	 0.0	 0.0	 1	 -30.0	 30.0;
	4369	 3568	 0.05886	 0.113157	 0.01016	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	456	 3568	 0.046851	 0.110231	 0.00972	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	726	 4350	 0.02895	 0.10819	 0.00997	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	969	 7532	 0.079438	 0.11481	 0.01301	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	969	 7532	 0.077967	 0.117314	 0.01277	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7532	 6208	 0.032669	 0.091388	 0.0112	 67.748613	 67.748613	 67.748613	 0.0	 0.0	 1	 -30.0	 30.0;
	791	 1839	 0.008421	 0.02657	 0.00289	 71.456813	 71.456813	 71.456813	 0.0	 0.0	 1	 -30.0	 30.0;
	2020	 791	 0.082727	 0.14876	 0.01614	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3999	 4548	 0.00637	 0.029669	 0.02107	 524.577533	 524.577533	 524.577533	 0.0	 0.0	 1	 -30.0	 30.0;
	3761	 969	 0.020223	 0.033198	 0.0034	 65.979011	 65.979011	 65.979011	 0.0	 0.0	 1	 -30.0	 30.0;
	3761	 969	 0.017843	 0.033876	 0.003	 68.196158	 68.196158	 68.196158	 0.0	 0.0	 1	 -30.0	 30.0;
	6053	 2538	 0.022058	 0.05405	 0.0046	 60.293537	 60.293537	 60.293537	 0.0	 0.0	 1	 -30.0	 30.0;
	6053	 8046	 0.019826	 0.073909	 0.0066	 62.78504	 62.78504	 62.78504	 0.0	 0.0	 1	 -30.0	 30.0;
	8342	 1361	 0.063107	 0.131711	 0.0131	 71.243043	 71.243043	 71.243043	 0.0	 0.0	 1	 -30.0	 30.0;
	4662	 1564	 0.012099	 0.029041	 0.00248	 61.15014	 61.15014	 61.15014	 0.0	 0.0	 1	 -30.0	 30.0;
	4662	 1564	 0.006273	 0.019033	 0.00201	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4662	 6973	 0.007603	 0.021273	 0.0026	 91.512108	 91.512108	 91.512108	 0.0	 0.0	 1	 -30.0	 30.0;
	4662	 6973	 0.011041	 0.027339	 0.00227	 72.397056	 72.397056	 72.397056	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 3389	 0.011636	 0.032562	 0.00399	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 1564	 0.007091	 0.019058	 0.00243	 81.083118	 81.083118	 81.083118	 0.0	 0.0	 1	 -30.0	 30.0;
	3389	 6973	 0.006653	 0.020967	 0.00227	 81.064065	 81.064065	 81.064065	 0.0	 0.0	 1	 -30.0	 30.0;
	2134	 4548	 0.00212	 0.01695	 0.02157	 516.980516	 516.980516	 516.980516	 0.0	 0.0	 1	 -30.0	 30.0;
	2134	 4548	 0.002349	 0.0155	 0.02411	 233.279912	 233.279912	 233.279912	 0.0	 0.0	 1	 -30.0	 30.0;
	1564	 7575	 0.053901	 0.092744	 0.01091	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1235	 5107	 0.003273	 0.010033	 0.0012	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	1235	 2269	 0.005066	 0.013769	 0.00186	 57.948548	 57.948548	 57.948548	 0.0	 0.0	 1	 -30.0	 30.0;
	5107	 2269	 0.007826	 0.028587	 0.00697	 89.727836	 89.727836	 89.727836	 0.0	 0.0	 1	 -30.0	 30.0;
	2269	 4725	 0.032769	 0.058711	 0.00661	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7304	 7231	 0.053702	 0.134017	 0.01304	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5159	 2342	 0.00147	 0.01305	 0.33639	 1249.527087	 1249.527087	 1249.527087	 0.0	 0.0	 1	 -30.0	 30.0;
	4188	 5159	 0.00019	 0.00195	 0.04578	 1446.129853	 1446.129853	 1446.129853	 0.0	 0.0	 1	 -30.0	 30.0;
	5432	 5159	 0.00019	 0.00191	 0.04666	 1470.597011	 1470.597011	 1470.597011	 0.0	 0.0	 1	 -30.0	 30.0;
	4380	 2742	 0.006413	 0.019917	 0.00217	 66.759785	 66.759785	 66.759785	 0.0	 0.0	 1	 -30.0	 30.0;
	3761	 2742	 0.011562	 0.044182	 0.00396	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5476	 4380	 0.002512	 0.008421	 0.00087	 74.748142	 74.748142	 74.748142	 0.0	 0.0	 1	 -30.0	 30.0;
	446	 3402	 0.041702	 0.098711	 0.00841	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	456	 446	 0.034347	 0.061636	 0.0069	 85.137312	 85.137312	 85.137312	 0.0	 0.0	 1	 -30.0	 30.0;
	4369	 4763	 0.004289	 0.01243	 0.00148	 73.378644	 73.378644	 73.378644	 0.0	 0.0	 1	 -30.0	 30.0;
	5442	 4763	 0.000686	 0.001471	 0.00016	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4369	 5241	 0.006612	 0.01886	 0.00245	 74.371854	 74.371854	 74.371854	 0.0	 0.0	 1	 -30.0	 30.0;
	7060	 5241	 0.008388	 0.023339	 0.00286	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4369	 5442	 0.004372	 0.012174	 0.00151	 61.22254	 61.22254	 61.22254	 0.0	 0.0	 1	 -30.0	 30.0;
	4369	 7060	 0.013413	 0.047793	 0.0046	 71.658008	 71.658008	 71.658008	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 1248	 0.08438	 0.183769	 0.01638	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	2538	 3657	 0.006372	 0.01681	 0.00217	 61.632551	 61.632551	 61.632551	 0.0	 0.0	 1	 -30.0	 30.0;
	7203	 4725	 0.028579	 0.084149	 0.01048	 103.447774	 103.447774	 103.447774	 0.0	 0.0	 1	 -30.0	 30.0;
	7203	 3861	 0.007008	 0.022388	 0.00258	 95.491235	 95.491235	 95.491235	 0.0	 0.0	 1	 -30.0	 30.0;
	7304	 7767	 0.003	 0.005058	 0.00063	 100.378788	 100.378788	 100.378788	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 7767	 0.002669	 0.005727	 0.00056	 58.778097	 58.778097	 58.778097	 0.0	 0.0	 1	 -30.0	 30.0;
	7767	 2086	 0.003661	 0.008818	 0.0011	 81.776631	 81.776631	 81.776631	 0.0	 0.0	 1	 -30.0	 30.0;
	7767	 3761	 0.029843	 0.069744	 0.0073	 73.16316	 73.16316	 73.16316	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 3152	 0.006438	 0.01824	 0.00218	 57.990083	 57.990083	 57.990083	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 3152	 0.006322	 0.018636	 0.00214	 57.20588	 57.20588	 57.20588	 0.0	 0.0	 1	 -30.0	 30.0;
	7576	 7680	 0.00068	 0.00797	 0.15917	 1247.394586	 1247.394586	 1247.394586	 0.0	 0.0	 1	 -30.0	 30.0;
	3152	 7859	 0.032364	 0.088289	 0.01098	 117.505704	 117.505704	 117.505704	 0.0	 0.0	 1	 -30.0	 30.0;
	3152	 3761	 0.027066	 0.084496	 0.00915	 80.201556	 80.201556	 80.201556	 0.0	 0.0	 1	 -30.0	 30.0;
	3152	 3761	 0.026554	 0.086256	 0.00898	 65.376188	 65.376188	 65.376188	 0.0	 0.0	 1	 -30.0	 30.0;
	3761	 2086	 0.029901	 0.071322	 0.00679	 74.569429	 74.569429	 74.569429	 0.0	 0.0	 1	 -30.0	 30.0;
	535	 456	 0.011901	 0.023818	 0.00242	 76.754948	 76.754948	 76.754948	 0.0	 0.0	 1	 -30.0	 30.0;
	6990	 456	 0.012132	 0.023322	 0.00247	 62.553552	 62.553552	 62.553552	 0.0	 0.0	 1	 -30.0	 30.0;
	4457	 6822	 0.0098	 0.062349	 0.07457	 410.221407	 410.221407	 410.221407	 0.0	 0.0	 1	 -30.0	 30.0;
	535	 6258	 0.004182	 0.012678	 0.00144	 64.686676	 64.686676	 64.686676	 0.0	 0.0	 1	 -30.0	 30.0;
	6990	 6258	 0.003636	 0.014636	 0.00125	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7859	 4379	 0.01919	 0.045041	 0.00385	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5199	 4736	 0.009793	 0.037174	 0.00337	 81.246398	 81.246398	 81.246398	 0.0	 0.0	 1	 -30.0	 30.0;
	4736	 1299	 0.004281	 0.010339	 0.00089	 102.487334	 102.487334	 102.487334	 0.0	 0.0	 1	 -30.0	 30.0;
	4736	 1299	 0.005521	 0.021471	 0.0019	 62.74122	 62.74122	 62.74122	 0.0	 0.0	 1	 -30.0	 30.0;
	810	 231	 0.0011	 0.01325	 0.26238	 1375.137317	 1375.137317	 1375.137317	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 7647	 0.018421	 0.051372	 0.00634	 69.199465	 69.199465	 69.199465	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 912	 0.011521	 0.042529	 0.00397	 73.093999	 73.093999	 73.093999	 0.0	 0.0	 1	 -30.0	 30.0;
	2326	 3089	 0.025182	 0.071554	 0.00867	 69.405805	 69.405805	 69.405805	 0.0	 0.0	 1	 -30.0	 30.0;
	8144	 2938	 0.0	 0.000413	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 3844	 0.014603	 0.03386	 0.003	 94.753329	 94.753329	 94.753329	 0.0	 0.0	 1	 -30.0	 30.0;
	3991	 2326	 0.022066	 0.054521	 0.00448	 67.296877	 67.296877	 67.296877	 0.0	 0.0	 1	 -30.0	 30.0;
	1790	 3991	 0.041471	 0.090793	 0.0084	 61.636552	 61.636552	 61.636552	 0.0	 0.0	 1	 -30.0	 30.0;
	3761	 5476	 0.008843	 0.031901	 0.00302	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	3414	 4548	 0.00038	 0.003091	 0.00406	 536.215979	 536.215979	 536.215979	 0.0	 0.0	 1	 -30.0	 30.0;
	3414	 4548	 0.0005	 0.002901	 0.00509	 531.306135	 531.306135	 531.306135	 0.0	 0.0	 1	 -30.0	 30.0;
	6973	 7575	 0.032132	 0.318198	 0.01653	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6973	 1998	 0.058554	 0.146124	 0.01127	 74.532467	 74.532467	 74.532467	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 6973	 0.023917	 0.073289	 0.00826	 80.321587	 80.321587	 80.321587	 0.0	 0.0	 1	 -30.0	 30.0;
	6973	 3844	 0.040818	 0.089273	 0.00807	 82.866819	 82.866819	 82.866819	 0.0	 0.0	 1	 -30.0	 30.0;
	2178	 2052	 2e-05	 0.00025	 0.00456	 1213.870881	 1213.870881	 1213.870881	 0.0	 0.0	 1	 -30.0	 30.0;
	2178	 2052	 2e-05	 0.00026	 0.00446	 1101.24982	 1101.24982	 1101.24982	 0.0	 0.0	 1	 -30.0	 30.0;
	2052	 2482	 0.00082	 0.00822	 0.19419	 1110.170124	 1110.170124	 1110.170124	 0.0	 0.0	 1	 -30.0	 30.0;
	2004	 927	 0.014339	 0.031777	 0.00294	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	4350	 5769	 0.011364	 0.034364	 0.00392	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	5769	 2716	 0.000347	 0.001066	 0.00012	 79.85118	 79.85118	 79.85118	 0.0	 0.0	 1	 -30.0	 30.0;
	3861	 7575	 0.012752	 0.036041	 0.00468	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	4720	 7575	 0.000669	 0.001281	 0.00014	 171.47303	 171.47303	 171.47303	 0.0	 0.0	 1	 -30.0	 30.0;
	4720	 7575	 0.000661	 0.001314	 0.00014	 160.016155	 160.016155	 160.016155	 0.0	 0.0	 1	 -30.0	 30.0;
	8046	 3657	 0.005289	 0.014942	 0.00183	 61.598638	 61.598638	 61.598638	 0.0	 0.0	 1	 -30.0	 30.0;
	1790	 7488	 0.004256	 0.007364	 0.00087	 59.340909	 59.340909	 59.340909	 0.0	 0.0	 1	 -30.0	 30.0;
	160	 7488	 0.003992	 0.009107	 0.00081	 117.314036	 117.314036	 117.314036	 0.0	 0.0	 1	 -30.0	 30.0;
	5995	 3308	 0.041488	 0.08662	 0.00826	 68.869856	 68.869856	 68.869856	 0.0	 0.0	 1	 -30.0	 30.0;
	3308	 8342	 0.00486	 0.010132	 0.00101	 91.970512	 91.970512	 91.970512	 0.0	 0.0	 1	 -30.0	 30.0;
	3308	 387	 0.00495	 0.009934	 0.00103	 68.607121	 68.607121	 68.607121	 0.0	 0.0	 1	 -30.0	 30.0;
	387	 8342	 0.00505	 0.009719	 0.00105	 72.531186	 72.531186	 72.531186	 0.0	 0.0	 1	 -30.0	 30.0;
	912	 7647	 0.00776	 0.027521	 0.00268	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	1958	 2243	 0.00262	 0.007628	 0.0009	 78.157217	 78.157217	 78.157217	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 3844	 0.001793	 0.005471	 0.00061	 76.785813	 76.785813	 76.785813	 0.0	 0.0	 1	 -30.0	 30.0;
	8278	 3377	 0.000537	 0.015661	 0.00184	 90.598728	 90.598728	 90.598728	 0.0	 0.0	 1	 -30.0	 30.0;
	4350	 2716	 0.01124	 0.036826	 0.00388	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	7758	 1757	 0.00156	 0.01791	 0.37415	 1166.705094	 1166.705094	 1166.705094	 0.0	 0.0	 1	 -30.0	 30.0;
	1757	 6266	 0.00155	 0.01686	 0.40732	 1299.100494	 1299.100494	 1299.100494	 0.0	 0.0	 1	 -30.0	 30.0;
	1757	 6266	 0.00152	 0.01719	 0.399	 1246.288187	 1246.288187	 1246.288187	 0.0	 0.0	 1	 -30.0	 30.0;
	7489	 1757	 0.00068	 0.00644	 0.23404	 1435.512763	 1435.512763	 1435.512763	 0.0	 0.0	 1	 -30.0	 30.0;
	7489	 1757	 0.00069	 0.0063	 0.23845	 1449.749839	 1449.749839	 1449.749839	 0.0	 0.0	 1	 -30.0	 30.0;
	1757	 5285	 0.00112	 0.01064	 0.27169	 1725.270279	 1725.270279	 1725.270279	 0.0	 0.0	 1	 -30.0	 30.0;
	3132	 4518	 0.00151	 0.011539	 0.01729	 481.34461	 481.34461	 481.34461	 0.0	 0.0	 1	 -30.0	 30.0;
	7381	 3132	 0.00788	 0.05236	 0.08792	 479.500703	 479.500703	 479.500703	 0.0	 0.0	 1	 -30.0	 30.0;
	1406	 6266	 0.00128	 0.0126	 0.30891	 1282.333376	 1282.333376	 1282.333376	 0.0	 0.0	 1	 -30.0	 30.0;
	740	 1406	 0.00037	 0.00409	 0.09538	 1072.436704	 1072.436704	 1072.436704	 0.0	 0.0	 1	 -30.0	 30.0;
	740	 1406	 0.00036	 0.00417	 0.09344	 1152.643093	 1152.643093	 1152.643093	 0.0	 0.0	 1	 -30.0	 30.0;
	1406	 5285	 0.00122	 0.0112	 0.29771	 1041.281787	 1041.281787	 1041.281787	 0.0	 0.0	 1	 -30.0	 30.0;
	7381	 7546	 0.006591	 0.04075	 0.073	 436.572621	 436.572621	 436.572621	 0.0	 0.0	 1	 -30.0	 30.0;
	2616	 4518	 0.007961	 0.05756	 0.08822	 423.668322	 423.668322	 423.668322	 0.0	 0.0	 1	 -30.0	 30.0;
	4632	 2398	 0.00059	 0.0085	 0.22559	 1083.562567	 1083.562567	 1083.562567	 0.0	 0.0	 1	 -30.0	 30.0;
	2398	 4994	 0.00084	 0.0118	 0.32178	 970.642693	 970.642693	 970.642693	 0.0	 0.0	 1	 -30.0	 30.0;
	2398	 5848	 0.00178	 0.01804	 0.63425	 809.359803	 809.359803	 809.359803	 0.0	 0.0	 1	 -30.0	 30.0;
	4513	 2257	 0.00937	 0.073969	 0.0931	 426.43323	 426.43323	 426.43323	 0.0	 0.0	 1	 -30.0	 30.0;
	4513	 2909	 0.011081	 0.06593	 0.07966	 410.138338	 410.138338	 410.138338	 0.0	 0.0	 1	 -30.0	 30.0;
	4513	 2577	 0.009669	 0.04251	 0.09891	 385.804791	 385.804791	 385.804791	 0.0	 0.0	 1	 -30.0	 30.0;
	6286	 8201	 0.00073	 0.00713	 0.20473	 797.794934	 797.794934	 797.794934	 0.0	 0.0	 1	 -30.0	 30.0;
	4783	 4994	 0.00034	 0.00345	 0.13025	 1081.333972	 1081.333972	 1081.333972	 0.0	 0.0	 1	 -30.0	 30.0;
	6751	 6406	 0.00012	 0.00128	 0.04699	 1013.602714	 1013.602714	 1013.602714	 0.0	 0.0	 1	 -30.0	 30.0;
	6751	 232	 0.00012	 0.00123	 0.04941	 1033.599518	 1033.599518	 1033.599518	 0.0	 0.0	 1	 -30.0	 30.0;
	1573	 1873	 9e-05	 0.00112	 0.02573	 938.008188	 938.008188	 938.008188	 0.0	 0.0	 1	 -30.0	 30.0;
	1217	 766	 0.00062	 0.00866	 0.23108	 1456.003201	 1456.003201	 1456.003201	 0.0	 0.0	 1	 -30.0	 30.0;
	6751	 1217	 0.00157	 0.01614	 0.59842	 1471.350626	 1471.350626	 1471.350626	 0.0	 0.0	 1	 -30.0	 30.0;
	6751	 1217	 0.0014	 0.01829	 0.53314	 1434.355684	 1434.355684	 1434.355684	 0.0	 0.0	 1	 -30.0	 30.0;
	261	 2543	 0.00078	 0.00805	 0.29614	 1361.858549	 1361.858549	 1361.858549	 0.0	 0.0	 1	 -30.0	 30.0;
	2543	 3741	 0.00094	 0.01427	 0.3911	 1484.72088	 1484.72088	 1484.72088	 0.0	 0.0	 1	 -30.0	 30.0;
	7037	 4994	 0.00024	 0.00283	 0.1308	 1354.947667	 1354.947667	 1354.947667	 0.0	 0.0	 1	 -30.0	 30.0;
	4994	 766	 0.00099	 0.00865	 0.27607	 1267.800119	 1267.800119	 1267.800119	 0.0	 0.0	 1	 -30.0	 30.0;
	6751	 4994	 0.0011	 0.01426	 0.32867	 1321.732648	 1321.732648	 1321.732648	 0.0	 0.0	 1	 -30.0	 30.0;
	2257	 625	 0.006919	 0.050521	 0.06011	 420.229717	 420.229717	 420.229717	 0.0	 0.0	 1	 -30.0	 30.0;
	3694	 4645	 0.0006	 0.00646	 0.22339	 1370.416197	 1370.416197	 1370.416197	 0.0	 0.0	 1	 -30.0	 30.0;
	3694	 5280	 0.00127	 0.0128	 0.32653	 824.764489	 824.764489	 824.764489	 0.0	 0.0	 1	 -30.0	 30.0;
	3694	 8263	 0.00052	 0.00496	 0.19362	 1360.331573	 1360.331573	 1360.331573	 0.0	 0.0	 1	 -30.0	 30.0;
	3694	 1019	 0.00064	 0.00886	 0.24217	 1454.680261	 1454.680261	 1454.680261	 0.0	 0.0	 1	 -30.0	 30.0;
	3694	 1019	 0.00072	 0.00868	 0.27446	 1555.438298	 1555.438298	 1555.438298	 0.0	 0.0	 1	 -30.0	 30.0;
	261	 7475	 0.00232	 0.02522	 0.6334	 833.099014	 833.099014	 833.099014	 0.0	 0.0	 1	 -30.0	 30.0;
	6751	 261	 0.0003	 0.00304	 0.08304	 1468.67052	 1468.67052	 1468.67052	 0.0	 0.0	 1	 -30.0	 30.0;
	6751	 261	 0.00032	 0.00306	 0.10801	 1335.890743	 1335.890743	 1335.890743	 0.0	 0.0	 1	 -30.0	 30.0;
	6751	 261	 0.00028	 0.00307	 0.10697	 1460.454468	 1460.454468	 1460.454468	 0.0	 0.0	 1	 -30.0	 30.0;
	8201	 6861	 0.00092	 0.00969	 0.33431	 951.156636	 951.156636	 951.156636	 0.0	 0.0	 1	 -30.0	 30.0;
	8201	 5280	 0.00181	 0.01696	 0.50006	 1044.676018	 1044.676018	 1044.676018	 0.0	 0.0	 1	 -30.0	 30.0;
	8201	 5848	 0.00132	 0.01148	 0.34945	 1291.52485	 1291.52485	 1291.52485	 0.0	 0.0	 1	 -30.0	 30.0;
	6861	 3741	 0.00108	 0.01087	 0.39137	 1365.395605	 1365.395605	 1365.395605	 0.0	 0.0	 1	 -30.0	 30.0;
	4645	 7475	 0.00209	 0.01924	 0.53053	 849.76543	 849.76543	 849.76543	 0.0	 0.0	 1	 -30.0	 30.0;
	8263	 4645	 0.00036	 0.00457	 0.13461	 1061.057442	 1061.057442	 1061.057442	 0.0	 0.0	 1	 -30.0	 30.0;
	4645	 1573	 0.0017	 0.01986	 0.48822	 767.876077	 767.876077	 767.876077	 0.0	 0.0	 1	 -30.0	 30.0;
	766	 2085	 0.00059	 0.00982	 0.23966	 966.362553	 966.362553	 966.362553	 0.0	 0.0	 1	 -30.0	 30.0;
	7948	 2577	 0.00494	 0.03182	 0.04985	 276.410714	 276.410714	 276.410714	 0.0	 0.0	 1	 -30.0	 30.0;
	7948	 2577	 0.004841	 0.03245	 0.04884	 279.901524	 279.901524	 279.901524	 0.0	 0.0	 1	 -30.0	 30.0;
	3741	 5848	 0.00036	 0.00391	 0.09835	 1623.830368	 1623.830368	 1623.830368	 0.0	 0.0	 1	 -30.0	 30.0;
	1019	 1573	 0.00071	 0.00983	 0.2685	 944.591956	 944.591956	 944.591956	 0.0	 0.0	 1	 -30.0	 30.0;
	1019	 1573	 0.00081	 0.00963	 0.3043	 1038.411467	 1038.411467	 1038.411467	 0.0	 0.0	 1	 -30.0	 30.0;
	4894	 719	 0.006271	 0.03645	 0.05313	 359.078624	 359.078624	 359.078624	 0.0	 0.0	 1	 -30.0	 30.0;
	7008	 4479	 0.186281	 0.374281	 0.0	 73.493912	 73.493912	 73.493912	 0.0	 0.0	 1	 -30.0	 30.0;
	7295	 4479	 0.089612	 0.230339	 0.0	 67.299163	 67.299163	 67.299163	 0.0	 0.0	 1	 -30.0	 30.0;
	7141	 3818	 0.00393	 0.04552	 0.95789	 1344.749178	 1344.749178	 1344.749178	 0.0	 0.0	 1	 -30.0	 30.0;
	3590	 5527	 0.004169	 0.02651	 0.15434	 455.923543	 455.923543	 455.923543	 0.0	 0.0	 1	 -30.0	 30.0;
	3590	 5527	 0.003831	 0.02438	 0.14132	 469.075143	 469.075143	 469.075143	 0.0	 0.0	 1	 -30.0	 30.0;
	3590	 4894	 0.00789	 0.04725	 0.08625	 601.261415	 601.261415	 601.261415	 0.0	 0.0	 1	 -30.0	 30.0;
	3590	 4894	 0.008039	 0.046219	 0.08785	 395.129113	 395.129113	 395.129113	 0.0	 0.0	 1	 -30.0	 30.0;
	867	 7318	 0.040174	 0.084397	 0.0	 64.977037	 64.977037	 64.977037	 0.0	 0.0	 1	 -30.0	 30.0;
	3198	 550	 0.00166	 0.01276	 0.14114	 1428.941916	 1428.941916	 1428.941916	 0.0	 0.0	 1	 -30.0	 30.0;
	6965	 5527	 0.00094	 0.00599	 0.03533	 399.647618	 399.647618	 399.647618	 0.0	 0.0	 1	 -30.0	 30.0;
	6965	 5527	 0.00107	 0.00587	 0.04005	 411.050575	 411.050575	 411.050575	 0.0	 0.0	 1	 -30.0	 30.0;
	981	 3701	 0.011901	 0.028364	 0.00244	 70.917625	 70.917625	 70.917625	 0.0	 0.0	 1	 -30.0	 30.0;
	3701	 7318	 0.059091	 0.102636	 0.0	 68.529387	 68.529387	 68.529387	 0.0	 0.0	 1	 -30.0	 30.0;
	7295	 3701	 0.090471	 0.19919	 0.0	 74.524465	 74.524465	 74.524465	 0.0	 0.0	 1	 -30.0	 30.0;
	543	 1535	 0.00755	 0.050919	 0.35194	 456.220762	 456.220762	 456.220762	 0.0	 0.0	 1	 -30.0	 30.0;
	543	 1535	 0.0077	 0.04988	 0.35884	 519.602529	 519.602529	 519.602529	 0.0	 0.0	 1	 -30.0	 30.0;
	3863	 7008	 0.238893	 0.453901	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	402	 3863	 0.062719	 0.104479	 0.0	 57.841092	 57.841092	 57.841092	 0.0	 0.0	 1	 -30.0	 30.0;
	4894	 1535	 0.000979	 0.074909	 0.45818	 491.050364	 491.050364	 491.050364	 0.0	 0.0	 1	 -30.0	 30.0;
	4894	 1535	 0.000961	 0.076349	 0.44863	 505.951371	 505.951371	 505.951371	 0.0	 0.0	 1	 -30.0	 30.0;
	4596	 1535	 0.002159	 0.079031	 0.05909	 430.889242	 430.889242	 430.889242	 0.0	 0.0	 1	 -30.0	 30.0;
	4596	 1535	 0.001961	 0.09125	 0.05467	 472.693605	 472.693605	 472.693605	 0.0	 0.0	 1	 -30.0	 30.0;
	402	 7008	 0.066636	 0.183934	 0.0	 57.157677	 57.157677	 57.157677	 0.0	 0.0	 1	 -30.0	 30.0;
	6317	 4211	 0.00431	 0.09324	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	6317	 4211	 0.0044	 0.091339	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	1216	 6469	 0.006356	 0.142878	 0.0	 119.999944	 119.999944	 119.999944	 1.026667	 0.0	 1	 -30.0	 30.0;
	2244	 6477	 0.00523	 0.10214	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	2244	 6477	 0.00532	 0.099917	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	2244	 6477	 0.00442	 0.105388	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	7486	 5134	 0.001002	 0.059033	 0.0	 119.999909	 119.999909	 119.999909	 1.052632	 0.0	 1	 -30.0	 30.0;
	7486	 5134	 0.000812	 0.056028	 0.0	 145.199621	 145.199621	 145.199621	 1.052632	 0.0	 1	 -30.0	 30.0;
	6630	 7196	 0.000921	 0.058347	 0.0	 119.999909	 119.999909	 119.999909	 1.052632	 0.0	 1	 -30.0	 30.0;
	7196	 3934	 0.0016	 0.07243	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	7196	 3934	 0.00182	 0.07098	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	7196	 3934	 0.00185	 0.06953	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	248	 7559	 0.00349	 0.07969	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	248	 7559	 0.00355	 0.07799	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	1408	 248	 0.001101	 0.048618	 0.0	 119.999909	 119.999909	 119.999909	 1.052632	 0.0	 1	 -30.0	 30.0;
	1408	 248	 0.000984	 0.055107	 0.0	 119.999909	 119.999909	 119.999909	 1.052632	 0.0	 1	 -30.0	 30.0;
	5901	 8007	 0.00175	 0.07752	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	5901	 8007	 0.00171	 0.07901	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	5423	 3941	 0.00302	 0.091446	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	5423	 3941	 0.00295	 0.084678	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	5436	 4207	 0.0018	 0.07815	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	5436	 4207	 0.00185	 0.07724	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	5436	 4207	 0.00193	 0.07007	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	95	 2305	 0.00205	 0.094653	 0.0	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	4709	 466	 0.000454	 0.028943	 -0.00528	 710.594074	 710.594074	 710.594074	 1.013237	 0.61829	 1	 -30.0	 30.0;
	4709	 466	 0.0004	 0.032807	 -0.00528	 710.594074	 710.594074	 710.594074	 1.013237	 0.61829	 1	 -30.0	 30.0;
	2006	 6931	 0.000342	 0.033341	 -0.006005	 733.486867	 733.486867	 733.486867	 0.981613	 0.0	 1	 -30.0	 30.0;
	1240	 6931	 0.000342	 0.03398	 -0.006005	 733.486867	 733.486867	 733.486867	 0.981613	 0.0	 1	 -30.0	 30.0;
	4061	 6931	 0.000121	 0.025184	 -0.001154	 720.000011	 720.000011	 720.000011	 0.966268	 14.9238	 1	 -30.0	 30.0;
	4061	 3482	 0.000121	 0.015705	 -0.001154	 720.000011	 720.000011	 720.000011	 0.992741	 6.90758	 1	 -30.0	 30.0;
	6313	 1672	 0.000347	 0.031821	 -0.006411	 706.071724	 706.071724	 706.071724	 1.019726	 1.22888	 1	 -30.0	 30.0;
	6313	 1672	 0.000356	 0.031175	 -0.006411	 706.071724	 706.071724	 706.071724	 1.019726	 1.22888	 1	 -30.0	 30.0;
	3923	 604	 0.0	 0.026157	 0.0	 360.000005	 360.000005	 360.000005	 1.0	 -1.357277	 1	 -30.0	 30.0;
	3923	 1672	 0.0	 0.025592	 0.0	 360.000005	 360.000005	 360.000005	 1.0	 1.35728	 1	 -30.0	 30.0;
	7457	 5080	 0.000431	 0.03159	 -0.005565	 737.077893	 737.077893	 737.077893	 0.976831	 -3.20845	 1	 -30.0	 30.0;
	7457	 5080	 0.00038	 0.034638	 -0.005565	 732.760237	 732.760237	 732.760237	 0.982587	 -2.55126	 1	 -30.0	 30.0;
	3188	 5303	 0.0004	 0.03334	 -0.00514	 715.090755	 715.090755	 715.090755	 1.006865	 0.0	 1	 -30.0	 30.0;
	3188	 5303	 0.0004	 0.033979	 -0.00514	 715.090755	 715.090755	 715.090755	 1.006865	 0.0	 1	 -30.0	 30.0;
	3745	 5303	 0.000121	 0.021666	 -0.001154	 842.44471	 842.44471	 842.44471	 0.977039	 12.3017	 1	 -30.0	 30.0;
	3745	 3367	 0.000121	 0.020058	 -0.001154	 842.44471	 842.44471	 842.44471	 0.977039	 12.3017	 1	 -30.0	 30.0;
	311	 271	 0.000131	 0.022842	 -0.001154	 810.322096	 810.322096	 810.322096	 0.966268	 14.9238	 1	 -30.0	 30.0;
	311	 6133	 0.000141	 0.019261	 -0.001154	 810.322096	 810.322096	 810.322096	 0.977039	 -12.30169	 1	 -30.0	 30.0;
	2751	 3539	 0.000194	 0.013059	 -0.009884	 1200.00041	 1200.00041	 1200.00041	 1.093651	 0.0	 1	 -30.0	 30.0;
	7249	 240	 0.000463	 0.031001	 -0.006163	 762.926569	 762.926569	 762.926569	 0.943734	 0.0	 1	 -30.0	 30.0;
	7249	 240	 0.000472	 0.030331	 -0.006163	 762.926569	 762.926569	 762.926569	 0.943734	 0.0	 1	 -30.0	 30.0;
	413	 6700	 0.000163	 0.015501	 -0.012037	 1439.999571	 1439.999571	 1439.999571	 0.954768	 0.0	 1	 -30.0	 30.0;
	5190	 3652	 0.001987	 0.071722	 0.0	 199.999664	 199.999664	 199.999664	 0.9	 0.0	 1	 -30.0	 30.0;
	2275	 5757	 0.000756	 0.051399	 0.0	 310.591524	 310.591524	 310.591524	 1.159079	 0.0	 1	 -30.0	 30.0;
	2275	 5757	 0.000746	 0.05345	 0.0	 310.591524	 310.591524	 310.591524	 1.159079	 0.0	 1	 -30.0	 30.0;
	6584	 8328	 0.00069	 0.04333	 0.0	 342.000499	 342.000499	 342.000499	 1.052632	 0.0	 1	 -30.0	 30.0;
	2483	 6697	 0.0022	 0.065399	 0.0	 199.999664	 199.999664	 199.999664	 0.9	 0.0	 1	 -30.0	 30.0;
	2483	 6697	 0.002235	 0.064019	 0.0	 199.999664	 199.999664	 199.999664	 0.9	 0.0	 1	 -30.0	 30.0;
	7809	 4613	 0.00168	 0.07424	 0.0	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	874	 3149	 0.002036	 0.070048	 0.0	 163.63595	 163.63595	 163.63595	 1.1	 0.0	 1	 -30.0	 30.0;
	874	 3149	 0.001997	 0.071368	 0.0	 163.63595	 163.63595	 163.63595	 1.1	 0.0	 1	 -30.0	 30.0;
	3296	 874	 0.00035	 0.032859	 0.0	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	3296	 874	 0.0004	 0.0322	 0.0	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	2369	 3459	 0.00205	 0.06915	 0.0	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	2369	 3459	 0.00082	 0.07342	 0.0	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	318	 7777	 0.002658	 0.07732	 0.0	 195.513549	 195.513549	 195.513549	 0.920652	 0.0	 1	 -30.0	 30.0;
	318	 7777	 0.002712	 0.075649	 0.0	 195.513549	 195.513549	 195.513549	 0.920652	 0.0	 1	 -30.0	 30.0;
	3664	 3510	 0.00065	 0.04604	 0.0	 342.000499	 342.000499	 342.000499	 1.052632	 0.0	 1	 -30.0	 30.0;
	6445	 2378	 0.00062	 0.03629	 0.0	 342.000499	 342.000499	 342.000499	 1.052632	 0.0	 1	 -30.0	 30.0;
	6445	 7407	 0.00019	 0.03263	 0.0	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	2432	 884	 0.001797	 0.07284	 0.0	 173.096689	 173.096689	 173.096689	 1.039882	 0.0	 1	 -30.0	 30.0;
	2942	 7610	 0.002712	 0.072578	 0.0	 190.958463	 190.958463	 190.958463	 0.942614	 0.0	 1	 -30.0	 30.0;
	6604	 318	 0.00047	 0.0307	 0.0	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	6980	 3587	 0.002601	 0.071481	 0.0	 191.999876	 191.999876	 191.999876	 0.9375	 0.0	 1	 -30.0	 30.0;
	6980	 3587	 0.002653	 0.06993	 0.0	 191.999876	 191.999876	 191.999876	 0.9375	 0.0	 1	 -30.0	 30.0;
	5103	 6980	 0.00037	 0.034169	 0.0	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	5103	 6980	 0.00037	 0.034831	 0.0	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	6065	 3450	 0.0004	 0.03524	 0.0	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	6065	 4726	 0.00069	 0.04525	 0.0	 342.000499	 342.000499	 342.000499	 1.052632	 0.0	 1	 -30.0	 30.0;
	8075	 7047	 0.00069	 0.04231	 0.0	 342.000499	 342.000499	 342.000499	 1.052632	 0.0	 1	 -30.0	 30.0;
	2817	 6831	 0.00119	 0.073146	 0.0	 167.44189	 167.44189	 167.44189	 1.075	 0.0	 1	 -30.0	 30.0;
	2817	 6831	 0.002764	 0.071607	 0.0	 175.609722	 175.609722	 175.609722	 1.025	 0.0	 1	 -30.0	 30.0;
	8195	 5933	 0.000742	 0.067219	 -0.009597	 353.959617	 353.959617	 353.959617	 1.017065	 0.0	 1	 -30.0	 30.0;
	8195	 5933	 0.000793	 0.06388	 -0.009676	 360.57037	 360.57037	 360.57037	 0.998417	 0.0	 1	 -30.0	 30.0;
	5509	 8341	 0.000609	 0.046809	 -0.018347	 707.746132	 707.746132	 707.746132	 0.941014	 0.0	 1	 -30.0	 30.0;
	5509	 1798	 0.00059	 0.04521	 -0.01719	 692.523103	 692.523103	 692.523103	 0.901053	 0.0	 1	 -30.0	 30.0;
	7101	 1798	 0.519194	 5.108058	 0.0	 11998.800121	 11998.800121	 11998.800121	 1.0	 0.0	 1	 -30.0	 30.0;
	7775	 2089	 0.000559	 0.039982	 -0.016839	 609.157454	 609.157454	 609.157454	 0.931778	 0.0	 1	 -30.0	 30.0;
	7775	 5074	 0.000537	 0.045312	 -0.016839	 610.095359	 610.095359	 610.095359	 0.930347	 0.0	 1	 -30.0	 30.0;
	4483	 1659	 0.000889	 0.061549	 -0.009676	 358.807766	 358.807766	 358.807766	 1.003323	 0.0	 1	 -30.0	 30.0;
	1659	 718	 1.467822	 7.764888	 0.0	 11687.139887	 11687.139887	 11687.139887	 1.0	 0.0	 1	 -30.0	 30.0;
	6080	 4172	 0.000586	 0.049031	 -0.01719	 667.676834	 667.676834	 667.676834	 0.934584	 0.0	 1	 -30.0	 30.0;
	2216	 3186	 0.000417	 0.047801	 -0.018156	 671.216523	 671.216523	 671.216523	 0.911778	 0.0	 1	 -30.0	 30.0;
	1244	 6192	 0.000755	 0.05143	 -0.016859	 618.265997	 618.265997	 618.265997	 0.989866	 0.0	 1	 -30.0	 30.0;
	1528	 207	 0.000733	 0.052399	 -0.01686	 662.331102	 662.331102	 662.331102	 0.924009	 0.0	 1	 -30.0	 30.0;
	7101	 6192	 0.00078	 0.064311	 0.0	 11687.139887	 11687.139887	 11687.139887	 1.0	 0.0	 1	 -30.0	 30.0;
	596	 2981	 0.00089	 0.048632	 -0.016223	 568.416813	 568.416813	 568.416813	 0.950007	 0.0	 1	 -30.0	 30.0;
	4738	 718	 0.00855	 0.08972	 0.0	 11687.139887	 11687.139887	 11687.139887	 1.0	 0.0	 1	 -30.0	 30.0;
	1313	 718	 0.00223	 0.04836	 0.0	 11687.139887	 11687.139887	 11687.139887	 1.0	 0.0	 1	 -30.0	 30.0;
	6511	 1975	 0.000581	 0.043111	 -0.01686	 678.413055	 678.413055	 678.413055	 0.902105	 0.0	 1	 -30.0	 30.0;
	6199	 8139	 0.000579	 0.043272	 -0.01719	 692.559961	 692.559961	 692.559961	 0.901005	 0.0	 1	 -30.0	 30.0;
	3328	 2948	 0.000586	 0.049031	 -0.018347	 721.242757	 721.242757	 721.242757	 0.923407	 0.0	 1	 -30.0	 30.0;
	7415	 4032	 0.000559	 0.049192	 -0.01686	 654.555372	 654.555372	 654.555372	 0.934985	 0.0	 1	 -30.0	 30.0;
	8196	 6862	 0.000573	 0.051129	 -0.01686	 662.331102	 662.331102	 662.331102	 0.924009	 0.0	 1	 -30.0	 30.0;
	2062	 4738	 0.000417	 0.039229	 -0.019195	 739.615174	 739.615174	 739.615174	 0.973479	 0.0	 1	 -30.0	 30.0;
	4738	 6599	 0.230542	 1.197733	 0.0	 11687.139887	 11687.139887	 11687.139887	 1.0	 0.0	 1	 -30.0	 30.0;
	4738	 7555	 0.02284	 0.2644	 0.0	 11687.139887	 11687.139887	 11687.139887	 1.0	 0.0	 1	 -30.0	 30.0;
	4738	 2222	 0.08537	 0.736798	 0.0	 11998.800121	 11998.800121	 11998.800121	 1.0	 0.0	 1	 -30.0	 30.0;
	4738	 4239	 1.402768	 3.640289	 0.0	 11998.800121	 11998.800121	 11998.800121	 1.0	 0.0	 1	 -30.0	 30.0;
	4738	 4091	 1.050227	 4.450207	 0.0	 11998.800121	 11998.800121	 11998.800121	 1.0	 0.0	 1	 -30.0	 30.0;
	7413	 6599	 0.000716	 0.04371	 -0.01686	 654.555372	 654.555372	 654.555372	 0.934985	 0.0	 1	 -30.0	 30.0;
	1313	 6599	 0.518622	 2.317689	 0.0	 11687.139887	 11687.139887	 11687.139887	 1.0	 0.0	 1	 -30.0	 30.0;
	5000	 7555	 0.00059	 0.045662	 -0.016839	 586.169225	 586.169225	 586.169225	 0.968322	 0.0	 1	 -30.0	 30.0;
	5000	 1395	 0.000603	 0.050959	 -0.01719	 652.079959	 652.079959	 652.079959	 0.956938	 0.0	 1	 -30.0	 30.0;
	1313	 7555	 0.047769	 0.554178	 0.0	 11687.139887	 11687.139887	 11687.139887	 1.0	 0.0	 1	 -30.0	 30.0;
	7041	 4687	 0.000591	 0.045153	 -0.017622	 646.447261	 646.447261	 646.447261	 0.918868	 0.0	 1	 -30.0	 30.0;
	7041	 246	 0.0006	 0.047778	 -0.018347	 719.929689	 719.929689	 719.929689	 0.925091	 0.0	 1	 -30.0	 30.0;
	7101	 5242	 0.02436	 0.270151	 0.0	 11687.139887	 11687.139887	 11687.139887	 1.0	 0.0	 1	 -30.0	 30.0;
	7549	 1313	 0.000802	 0.05727	 -0.010077	 390.891374	 390.891374	 390.891374	 0.967021	 0.0	 1	 -30.0	 30.0;
	7549	 1313	 0.000823	 0.056059	 -0.010077	 390.891374	 390.891374	 390.891374	 0.967021	 0.0	 1	 -30.0	 30.0;
	1313	 2222	 0.188099	 1.291901	 0.0	 11998.800121	 11998.800121	 11998.800121	 1.0	 0.0	 1	 -30.0	 30.0;
	1313	 4239	 2.466323	 7.26343	 0.0	 11998.800121	 11998.800121	 11998.800121	 1.0	 0.0	 1	 -30.0	 30.0;
	2063	 2637	 0.000523	 0.050352	 -0.018347	 730.017604	 730.017604	 730.017604	 0.912306	 0.0	 1	 -30.0	 30.0;
	8028	 5242	 0.000682	 0.049638	 -0.017851	 654.634353	 654.634353	 654.634353	 0.989866	 0.0	 1	 -30.0	 30.0;
	8028	 7348	 0.00099	 0.04736	 -0.006657	 213.408058	 213.408058	 213.408058	 1.012146	 0.0	 1	 -30.0	 30.0;
	288	 2222	 0.000616	 0.048759	 -0.018347	 662.879365	 662.879365	 662.879365	 1.004708	 0.0	 1	 -30.0	 30.0;
	6930	 7781	 9e-05	 0.008834	 -0.056	 1680.000048	 1680.000048	 1680.000048	 1.0	 -4.394626	 1	 -30.0	 30.0;
	5304	 6827	 9e-05	 0.00866	 -0.056	 1680.000048	 1680.000048	 1680.000048	 1.0	 -4.394626	 1	 -30.0	 30.0;
	78	 4091	 0.000664	 0.045609	 -0.01686	 654.555372	 654.555372	 654.555372	 0.934985	 0.0	 1	 -30.0	 30.0;
	2282	 4239	 0.000649	 0.044862	 -0.018347	 713.786902	 713.786902	 713.786902	 0.933053	 0.0	 1	 -30.0	 30.0;
	5443	 7632	 0.00067	 0.04326	 -0.018347	 730.080131	 730.080131	 730.080131	 0.91223	 0.0	 1	 -30.0	 30.0;
	1962	 5443	 9e-05	 0.009385	 -0.056	 1680.000048	 1680.000048	 1680.000048	 1.0	 5.8573	 1	 -30.0	 30.0;
	6347	 3650	 0.000246	 0.018417	 -0.015389	 1394.521356	 1394.521356	 1394.521356	 0.987971	 3.94703	 1	 -30.0	 30.0;
	3650	 5011	 0.00131	 0.07578	 -0.006612	 229.565425	 229.565425	 229.565425	 1.045455	 0.0	 1	 -30.0	 30.0;
	3650	 5011	 0.00128	 0.07077	 -0.006612	 229.565425	 229.565425	 229.565425	 1.045455	 0.0	 1	 -30.0	 30.0;
	2886	 7955	 0.00131	 0.062651	 -0.01093	 240.000131	 240.000131	 240.000131	 1.0	 0.0	 1	 -30.0	 30.0;
	2886	 7955	 0.00133	 0.0577	 -0.01091	 240.000131	 240.000131	 240.000131	 1.0	 0.0	 1	 -30.0	 30.0;
	4599	 1318	 0.001495	 0.059475	 -0.00682	 240.000131	 240.000131	 240.000131	 0.974576	 0.0	 1	 -30.0	 30.0;
	4599	 8383	 0.001453	 0.061392	 -0.00327	 240.000131	 240.000131	 240.000131	 0.974576	 0.0	 1	 -30.0	 30.0;
	5956	 4924	 0.001475	 0.074554	 0.0	 329.999915	 329.999915	 329.999915	 0.981267	 0.0	 1	 -30.0	 30.0;
	5956	 4924	 0.001309	 0.084508	 0.0	 329.999915	 329.999915	 329.999915	 0.981267	 0.0	 1	 -30.0	 30.0;
	803	 4439	 0.00119	 0.084099	 -0.00722	 240.000131	 240.000131	 240.000131	 1.0	 0.0	 1	 -30.0	 30.0;
	3995	 979	 0.00117	 0.064859	 -0.0109	 240.000131	 240.000131	 240.000131	 1.0	 0.0	 1	 -30.0	 30.0;
	3995	 979	 0.00114	 0.066091	 -0.0109	 240.000131	 240.000131	 240.000131	 1.0	 0.0	 1	 -30.0	 30.0;
	6869	 5401	 0.001225	 0.083401	 0.0	 329.999915	 329.999915	 329.999915	 0.973021	 0.0	 1	 -30.0	 30.0;
	6869	 5401	 0.001394	 0.082574	 0.0	 329.999915	 329.999915	 329.999915	 0.973021	 0.0	 1	 -30.0	 30.0;
	3125	 4185	 0.001415	 0.080475	 0.0	 329.999915	 329.999915	 329.999915	 0.973021	 0.0	 1	 -30.0	 30.0;
	3125	 4185	 0.001447	 0.078793	 0.0	 329.999915	 329.999915	 329.999915	 0.973021	 0.0	 1	 -30.0	 30.0;
	8182	 8011	 0.001444	 0.074683	 -0.00459	 329.999915	 329.999915	 329.999915	 0.981267	 0.0	 1	 -30.0	 30.0;
	8182	 8011	 0.001475	 0.073051	 -0.00459	 329.999915	 329.999915	 329.999915	 0.981267	 0.0	 1	 -30.0	 30.0;
	833	 4158	 0.001316	 0.070415	 -0.01036	 240.000131	 240.000131	 240.000131	 0.974576	 0.0	 1	 -30.0	 30.0;
	7065	 3123	 0.00128	 0.065919	 -0.00353	 240.000131	 240.000131	 240.000131	 1.0	 0.0	 1	 -30.0	 30.0;
	8066	 434	 0.001056	 0.075919	 -0.01919	 329.999915	 329.999915	 329.999915	 1.052632	 0.0	 1	 -30.0	 30.0;
	1148	 434	 0.001451	 0.078431	 -0.00591	 240.000131	 240.000131	 240.000131	 0.905512	 0.0	 1	 -30.0	 30.0;
	1148	 434	 0.001415	 0.075297	 -0.00589	 240.000131	 240.000131	 240.000131	 0.905512	 0.0	 1	 -30.0	 30.0;
	2427	 1534	 0.001411	 0.061844	 -0.00683	 240.000131	 240.000131	 240.000131	 0.974576	 0.0	 1	 -30.0	 30.0;
	2427	 1534	 0.001432	 0.058938	 -0.01037	 240.000131	 240.000131	 240.000131	 0.974576	 0.0	 1	 -30.0	 30.0;
	2167	 1888	 0.00229	 0.085231	 -0.005908	 220.557375	 220.557375	 220.557375	 0.979339	 0.0	 1	 -30.0	 30.0;
	4692	 517	 0.001474	 0.06058	 -0.00514	 240.000131	 240.000131	 240.000131	 0.974576	 0.0	 1	 -30.0	 30.0;
	1309	 1206	 0.00125	 0.064651	 -0.0035	 240.000131	 240.000131	 240.000131	 1.0	 0.0	 1	 -30.0	 30.0;
	1309	 1206	 0.00123	 0.065919	 -0.00352	 240.000131	 240.000131	 240.000131	 1.0	 0.0	 1	 -30.0	 30.0;
	1309	 1206	 0.0012	 0.06718	 -0.00352	 240.000131	 240.000131	 240.000131	 1.0	 0.0	 1	 -30.0	 30.0;
	2195	 6652	 0.001221	 0.069631	 -0.01052	 240.000131	 240.000131	 240.000131	 0.982906	 0.0	 1	 -30.0	 30.0;
	2195	 6652	 0.00119	 0.065604	 -0.01054	 240.000131	 240.000131	 240.000131	 0.982906	 0.0	 1	 -30.0	 30.0;
	1520	 8297	 0.001039	 0.045925	 -0.01168	 329.999915	 329.999915	 329.999915	 0.981267	 0.0	 1	 -30.0	 30.0;
	3537	 8296	 0.000406	 0.016466	 -0.00659	 1322.869323	 1322.869323	 1322.869323	 1.054276	 2.34996	 1	 -30.0	 30.0;
	8296	 1714	 0.001563	 0.060356	 -0.00697	 240.000131	 240.000131	 240.000131	 0.982906	 0.0	 1	 -30.0	 30.0;
	8296	 1714	 0.001459	 0.05904	 -0.01054	 240.000131	 240.000131	 240.000131	 0.982906	 0.0	 1	 -30.0	 30.0;
	5487	 1001	 0.001531	 0.068989	 -0.00644	 240.000131	 240.000131	 240.000131	 0.942623	 0.0	 1	 -30.0	 30.0;
	7544	 5836	 0.000318	 0.014328	 -0.00671	 959.999933	 959.999933	 959.999933	 1.002506	 0.0	 1	 -30.0	 30.0;
	1864	 5451	 0.000246	 0.018417	 -0.015389	 959.999933	 959.999933	 959.999933	 0.987971	 3.94703	 1	 -30.0	 30.0;
	5451	 3336	 0.00121	 0.066091	 -0.0109	 240.000131	 240.000131	 240.000131	 1.0	 0.0	 1	 -30.0	 30.0;
	5451	 3336	 0.00118	 0.062289	 -0.01091	 240.000131	 240.000131	 240.000131	 1.0	 0.0	 1	 -30.0	 30.0;
	7753	 5680	 0.001646	 0.071174	 -0.00895	 240.000131	 240.000131	 240.000131	 0.905512	 0.0	 1	 -30.0	 30.0;
	7753	 5680	 0.00229	 0.087099	 -0.004416	 206.608616	 206.608616	 206.608616	 1.045455	 0.0	 1	 -30.0	 30.0;
	1759	 989	 0.001421	 0.061107	 -0.01036	 240.000131	 240.000131	 240.000131	 0.974576	 0.0	 1	 -30.0	 30.0;
	8343	 2858	 0.001573	 0.080941	 -0.00441	 329.999915	 329.999915	 329.999915	 0.956938	 0.0	 1	 -30.0	 30.0;
	8343	 2858	 0.001594	 0.078385	 -0.00436	 329.999915	 329.999915	 329.999915	 0.956938	 0.0	 1	 -30.0	 30.0;
	4988	 7620	 0.001369	 0.06454	 -0.00684	 240.000131	 240.000131	 240.000131	 0.974576	 0.0	 1	 -30.0	 30.0;
	4988	 7620	 0.001348	 0.065203	 -0.00685	 240.000131	 240.000131	 240.000131	 0.974576	 0.0	 1	 -30.0	 30.0;
	1041	 4623	 0.001295	 0.071353	 -0.00511	 240.000131	 240.000131	 240.000131	 0.974576	 0.0	 1	 -30.0	 30.0;
	1041	 4623	 0.001295	 0.070826	 -0.00512	 240.000131	 240.000131	 240.000131	 0.974576	 0.0	 1	 -30.0	 30.0;
	1372	 3919	 0.001441	 0.084934	 0.0	 329.999915	 329.999915	 329.999915	 0.956938	 0.0	 1	 -30.0	 30.0;
	1372	 3919	 0.001463	 0.083626	 0.0	 329.999915	 329.999915	 329.999915	 0.956938	 0.0	 1	 -30.0	 30.0;
	3627	 31	 0.000448	 0.016447	 -0.00528	 755.99989	 755.99989	 755.99989	 1.002506	 0.0	 1	 -30.0	 30.0;
	3627	 1495	 0.001134	 0.053193	 -0.00475	 329.999915	 329.999915	 329.999915	 0.998185	 0.0	 1	 -30.0	 30.0;
	31	 1495	 0.00136	 0.057539	 -0.00722	 240.000131	 240.000131	 240.000131	 1.0	 0.0	 1	 -30.0	 30.0;
	1924	 3812	 0.001432	 0.06454	 -0.00506	 240.000131	 240.000131	 240.000131	 0.974576	 0.0	 1	 -30.0	 30.0;
	602	 3670	 0.00195	 0.114628	 0.0	 220.557375	 220.557375	 220.557375	 0.979339	 0.0	 1	 -30.0	 30.0;
	1664	 6759	 0.001295	 0.067067	 0.0	 240.000131	 240.000131	 240.000131	 0.974576	 0.0	 1	 -30.0	 30.0;
	4354	 8153	 0.001242	 0.074563	 -0.00861	 240.000131	 240.000131	 240.000131	 0.974576	 0.0	 1	 -30.0	 30.0;
	5587	 4112	 0.00126	 0.060099	 -0.00535	 240.000131	 240.000131	 240.000131	 1.0	 0.0	 1	 -30.0	 30.0;
	5587	 4112	 0.00135	 0.06051	 -0.00721	 240.000131	 240.000131	 240.000131	 1.0	 0.0	 1	 -30.0	 30.0;
	6758	 3185	 0.00036	 0.042469	 -0.023005	 718.511971	 718.511971	 718.511971	 1.052174	 0.0	 1	 -30.0	 30.0;
	1091	 5409	 0.001278	 0.05335	 -0.013671	 479.999638	 479.999638	 479.999638	 0.973021	 0.0	 1	 -30.0	 30.0;
	6146	 4933	 0.000503	 0.028042	 -0.00085	 479.999638	 479.999638	 479.999638	 0.977126	 -1.493575	 1	 -30.0	 30.0;
	6146	 4933	 0.000503	 0.02743	 -0.00085	 479.999638	 479.999638	 479.999638	 0.977126	 -1.493575	 1	 -30.0	 30.0;
	3119	 4130	 0.000333	 0.021103	 -0.00228	 720.000115	 720.000115	 720.000115	 1.011235	 0.0	 1	 -30.0	 30.0;
	8085	 4208	 0.00044	 0.030928	 -0.00085	 479.999638	 479.999638	 479.999638	 0.977126	 0.0	 1	 -30.0	 30.0;
	3175	 5270	 0.000164	 0.013858	 -0.003881	 1200.00041	 1200.00041	 1200.00041	 1.030625	 0.0	 1	 -30.0	 30.0;
	4492	 2715	 0.000353	 0.026265	 -0.00236	 943.750145	 943.750145	 943.750145	 0.937567	 -1.77827	 1	 -30.0	 30.0;
	1421	 3246	 0.000159	 0.016777	 -0.00329	 1200.00041	 1200.00041	 1200.00041	 0.937567	 0.86289	 1	 -30.0	 30.0;
	2979	 2254	 0.000273	 0.016238	 -0.0112	 990.270258	 990.270258	 990.270258	 0.956938	 0.0	 1	 -30.0	 30.0;
	1246	 5914	 0.000289	 0.015803	 -0.011017	 720.000115	 720.000115	 720.000115	 0.972469	 1.65217	 1	 -30.0	 30.0;
	5244	 5835	 0.00142	 0.02765	 0.0	 480.000261	 480.000261	 480.000261	 1.0	 0.0	 1	 -30.0	 30.0;
	5244	 5835	 0.00145	 0.02707	 0.0	 480.000261	 480.000261	 480.000261	 1.0	 0.0	 1	 -30.0	 30.0;
	1531	 342	 0.000469	 0.030842	 0.0	 479.999638	 479.999638	 479.999638	 1.024958	 0.0	 1	 -30.0	 30.0;
	1472	 342	 0.00435	 0.044132	 0.0	 480.000036	 480.000036	 480.000036	 1.0	 -5.914401	 1	 -30.0	 30.0;
	3826	 6545	 0.000352	 0.020852	 -0.002327	 720.000115	 720.000115	 720.000115	 1.02738	 0.0	 1	 -30.0	 30.0;
	3714	 135	 0.0003	 0.01099	 -0.00127	 214.038594	 214.038594	 214.038594	 1.0	 0.0	 1	 -30.0	 30.0;
	3714	 135	 0.00029	 0.0112	 -0.00127	 210.036206	 210.036206	 210.036206	 1.0	 0.0	 1	 -30.0	 30.0;
	4394	 3804	 0.000375	 0.018768	 -0.00203	 720.000115	 720.000115	 720.000115	 1.061268	 0.0	 1	 -30.0	 30.0;
	6046	 1994	 0.000537	 0.028553	 -0.002479	 720.000115	 720.000115	 720.000115	 0.998185	 0.0	 1	 -30.0	 30.0;
	6046	 1994	 0.000537	 0.028002	 -0.001951	 720.000115	 720.000115	 720.000115	 0.998185	 0.0	 1	 -30.0	 30.0;
	1507	 3621	 0.000622	 0.033296	 -0.00278	 360.000386	 360.000386	 360.000386	 0.956938	 0.0	 1	 -30.0	 30.0;
	1507	 3621	 0.000622	 0.029468	 -0.00117	 479.999638	 479.999638	 479.999638	 0.956938	 0.55119	 1	 -30.0	 30.0;
	2463	 343	 0.00072	 0.026242	 -0.00704	 479.999638	 479.999638	 479.999638	 0.957131	 0.0	 1	 -30.0	 30.0;
	2463	 343	 0.000644	 0.029735	 -0.00704	 479.999638	 479.999638	 479.999638	 0.957131	 0.0	 1	 -30.0	 30.0;
	5785	 4331	 0.00314	 0.168899	 0.0	 169.092984	 169.092984	 169.092984	 1.0	 1.43228	 1	 -30.0	 30.0;
	5785	 4331	 0.00307	 0.172155	 0.0	 165.899775	 165.899775	 165.899775	 1.0	 1.43228	 1	 -30.0	 30.0;
	554	 5356	 0.000188	 0.016506	 -0.001192	 959.999933	 959.999933	 959.999933	 1.016322	 0.0	 1	 -30.0	 30.0;
	1961	 5458	 0.000259	 0.027074	 0.0	 414.000049	 414.000049	 414.000049	 1.002506	 0.0	 1	 -30.0	 30.0;
	2990	 265	 0.000437	 0.02611	 0.0	 461.99975	 461.99975	 461.99975	 1.047869	 0.0	 1	 -30.0	 30.0;
	4855	 3033	 0.000446	 0.025573	 0.0	 405.600365	 405.600365	 405.600365	 1.047869	 0.0	 1	 -30.0	 30.0;
	1724	 2345	 0.00032	 0.02243	 0.0	 531.442274	 531.442274	 531.442274	 1.034211	 0.0	 1	 -30.0	 30.0;
	950	 5657	 6.091942	 8.676029	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 5657	 6.444008	 8.676035	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 5657	 23.9876	 40.776864	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 5657	 35.24587	 57.202482	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 5657	 45.97521	 69.597103	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 5657	 0.081469	 0.775971	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 5657	 32.03719	 50.568181	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 5657	 0.628884	 2.485744	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 6716	 12.31426	 19.110329	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 6716	 13.03616	 19.128307	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 6716	 0.197581	 1.393719	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 6716	 1.415165	 4.81467	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4904	 2487	 0.13108	 0.821607	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5701	 2487	 0.129079	 0.839681	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5691	 2384	 0.069591	 0.599051	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5691	 1042	 0.04983	 0.471267	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5691	 3026	 0.00502	 0.310928	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 7063	 5.68843	 10.297518	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 7063	 48.32851	 56.749998	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 7063	 23.27066	 28.824377	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2470	 7063	 50.96074	 55.43596	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 5636	 5.967355	 9.180988	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 5636	 44.27686	 58.522723	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 5636	 20.49132	 30.954553	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2470	 5636	 43.12397	 61.993787	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8032	 3654	 -0.04093	 0.365413	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8032	 937	 0.140533	 1.138574	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8032	 3117	 0.151053	 1.206163	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8032	 3675	 3.496607	 8.23892	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8032	 1124	 3.21482	 7.345568	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8032	 394	 0.136738	 1.1482	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8032	 1744	 0.138539	 1.094044	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8032	 3024	 0.077251	 0.917036	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8032	 1447	 0.954778	 3.73151	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8032	 8114	 0.745845	 4.144945	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8032	 1071	 0.723892	 4.195776	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7755	 3654	 0.47093	 3.07252	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	172	 3654	 0.45124	 2.967768	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3041	 3654	 0.460083	 2.907231	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4986	 3654	 2.286777	 7.419422	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6254	 3654	 3.438636	 9.067975	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8258	 3654	 0.885579	 3.747314	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5189	 3654	 0.788967	 4.246901	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5646	 3654	 1.804731	 7.772521	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6379	 5599	 0.000716	 0.032505	 -0.00219	 396.000162	 396.000162	 396.000162	 1.089681	 0.0	 1	 -30.0	 30.0;
	6379	 5599	 0.00056	 0.04105	 -0.005327	 431.044919	 431.044919	 431.044919	 1.113574	 0.0	 1	 -30.0	 30.0;
	6379	 5599	 0.00057	 0.040211	 -0.005327	 431.044919	 431.044919	 431.044919	 1.113574	 0.0	 1	 -30.0	 30.0;
	6803	 5599	 10.24442	 15.278311	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3733	 5599	 10.4376	 14.953303	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2274	 5599	 31.55372	 31.927684	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1387	 5599	 0.02494	 0.501983	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4429	 5599	 2.458264	 5.693595	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6100	 5599	 21.7686	 29.266527	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7640	 5599	 0.260764	 1.554236	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7088	 5599	 0.41095	 2.453926	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4927	 5599	 1.358636	 3.804546	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7950	 7703	 0.00445	 0.11669	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2096	 162	 0.02812	 0.471488	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1519	 162	 0.109781	 0.670062	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3194	 162	 0.11731	 0.676136	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6442	 6996	 0.000443	 0.034282	 -0.002535	 733.141323	 733.141323	 733.141323	 0.982076	 0.0	 1	 -30.0	 30.0;
	4220	 6996	 0.000407	 0.0336	 -0.006729	 733.141323	 733.141323	 733.141323	 0.982076	 0.0	 1	 -30.0	 30.0;
	81	 6996	 0.05005	 0.961922	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 6996	 20.2438	 55.378103	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 6996	 20.42293	 51.698341	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 6996	 7.97376	 20.509093	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 6996	 1.402252	 5.36219	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 6996	 4.842562	 10.371072	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 6996	 0.593884	 2.602686	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 6996	 9.390701	 21.464872	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2470	 6996	 1.334504	 5.801447	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7755	 937	 1.754986	 5.357133	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7755	 3117	 1.766898	 5.923268	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7755	 3675	 1.832964	 7.959834	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7755	 1124	 1.611565	 6.707825	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7755	 394	 -0.019578	 0.602618	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7755	 1744	 -0.018109	 0.575138	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7755	 3024	 2.305263	 5.580056	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7755	 1447	 0.324709	 1.981648	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7755	 8114	 11.49377	 18.997923	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7755	 1071	 10.16551	 21.393357	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7755	 3514	 0.00083	 0.06663	 -0.001184	 433.38343	 433.38343	 433.38343	 0.969119	 0.0	 1	 -30.0	 30.0;
	5971	 4836	 0.220599	 1.426839	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8206	 4836	 0.215413	 1.319979	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5894	 4836	 0.07932	 0.491198	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4335	 4836	 0.05112	 0.388202	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3912	 4836	 7.957025	 11.110533	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5092	 4836	 8.10723	 10.874171	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4222	 4836	 0.19505	 0.651797	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6785	 4836	 0.273698	 1.122666	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5971	 6091	 -0.016694	 0.279194	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5971	 6091	 0.00066	 0.04694	 -0.001327	 390.13381	 390.13381	 390.13381	 1.076552	 0.0	 1	 -30.0	 30.0;
	5971	 4815	 0.262431	 2.115858	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5971	 2039	 0.251911	 2.002563	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5971	 3961	 0.086669	 0.634127	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8206	 6091	 -0.018471	 0.253657	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8206	 6091	 0.000299	 0.012803	 -0.00998	 1576.194641	 1576.194641	 1576.194641	 1.110134	 0.0	 1	 -30.0	 30.0;
	8206	 4815	 0.307389	 1.800831	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8206	 2039	 0.307181	 1.800693	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8206	 3961	 0.083082	 0.659398	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5894	 6091	 2.852479	 6.564463	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4335	 6091	 0.610723	 2.391322	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3912	 6091	 0.796095	 2.828719	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5092	 6091	 0.778781	 2.619215	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4222	 6091	 5.253512	 8.690912	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6785	 6091	 0.14057	 0.924359	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	381	 4934	 0.00012	 0.01369	 -0.01718	 2712.786057	 2712.786057	 2712.786057	 1.0	 -23.00651	 1	 -30.0	 30.0;
	5894	 2024	 0.00012	 0.013772	 -0.01718	 2113.687557	 2113.687557	 2113.687557	 1.0	 -23.7279	 1	 -30.0	 30.0;
	5894	 4815	 34.83864	 37.361505	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5894	 2039	 31.4626	 43.434901	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5894	 3961	 9.837258	 14.382266	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1840	 8106	 0.12436	 1.222541	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7722	 8106	 0.121719	 1.24562	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1840	 6760	 0.11651	 1.13624	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7722	 6760	 0.13205	 1.113513	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3946	 742	 0.000447	 0.03387	 -0.007813	 980.876065	 980.876065	 980.876065	 0.905313	 0.0	 1	 -30.0	 30.0;
	3946	 2487	 0.188878	 0.872161	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3946	 6617	 0.000399	 0.010683	 -0.016427	 791.999665	 791.999665	 791.999665	 1.202334	 0.0	 1	 -30.0	 30.0;
	7633	 2364	 0.01902	 0.177292	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7633	 8241	 0.079771	 0.509993	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7633	 6638	 0.00919	 0.137159	 0.0	 148.80052	 148.80052	 148.80052	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 4590	 10.8518	 37.942518	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 5156	 20.41343	 54.805408	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 2624	 20.30263	 51.706374	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 7277	 0.787812	 4.341828	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 236	 0.590422	 4.326316	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 220	 0.712119	 2.758379	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 973	 0.891274	 4.745083	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 3212	 27.32618	 53.325484	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 4355	 0.072382	 1.414889	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 6888	 0.070083	 1.331163	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 5823	 0.02163	 0.743629	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 1441	 3.623961	 20.259003	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 990	 0.851039	 4.324031	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 3564	 1.040443	 4.789612	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4335	 4815	 8.633058	 14.86384	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3912	 4815	 0.05238	 0.529835	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5092	 4815	 0.05337	 0.518554	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4222	 4815	 56.80165	 51.109504	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6785	 4815	 2.452686	 6.967768	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4335	 2039	 8.052273	 16.496276	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3912	 2039	 0.044141	 0.60938	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5092	 2039	 0.0432	 0.620868	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4222	 2039	 47.16736	 58.301649	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6785	 2039	 2.566529	 6.851652	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 4590	 21.60319	 36.731304	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 5156	 38.25416	 49.701504	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 2624	 39.65235	 49.572723	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 7277	 13.37881	 27.533241	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 236	 11.70014	 34.83726	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 220	 0.03578	 2.06572	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 6094	 44.92382	 57.412053	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 4274	 5.792867	 13.966068	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 6801	 5.68705	 12.979224	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 973	 23.49307	 56.524238	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 3212	 0.817382	 3.615513	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 4355	 1.090651	 5.780887	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 6888	 1.04626	 5.209279	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 4935	 0.644758	 1.803532	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 2361	 0.580852	 2.069945	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 5823	 15.32341	 41.617723	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 1801	 37.75623	 69.158594	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 1441	 4.031925	 12.920362	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 4590	 19.41759	 39.081025	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 5156	 38.13227	 52.87396	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 2624	 39.55609	 52.783939	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 7277	 13.35596	 29.188359	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 236	 13.38227	 31.89335	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 220	 0.06002	 1.808379	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 6094	 48.46122	 56.359411	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 4274	 6.294598	 13.758307	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 6801	 6.185319	 14.074795	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 973	 21.89474	 63.064402	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 3212	 0.750554	 3.860318	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 4355	 1.114889	 6.088781	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 6888	 1.069114	 5.491413	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 4935	 0.653109	 1.929778	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 2361	 0.672888	 1.912604	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 5823	 18.13504	 36.319253	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 1801	 40.86842	 68.019379	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 1441	 4.398892	 12.729917	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5388	 2487	 0.0384	 0.48786	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	172	 937	 0.17575	 1.589628	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	172	 3117	 0.16178	 1.59079	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	172	 3675	 22.34695	 35.318561	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	172	 1124	 20.61288	 31.520779	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	172	 394	 1.071953	 3.96018	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	172	 1744	 1.073546	 3.773961	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	172	 3024	 1.477701	 3.981233	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	172	 1447	 5.635665	 13.348342	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	172	 8114	 13.41828	 27.828945	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	172	 1071	 13.04432	 28.183522	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3041	 937	 0.17575	 1.589628	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3041	 3117	 0.161789	 1.590785	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3041	 3675	 22.34695	 35.318561	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3041	 1124	 20.61288	 31.520779	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3041	 394	 1.071953	 3.96018	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3041	 1744	 1.073546	 3.773961	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3041	 3024	 1.477701	 3.981233	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3041	 1447	 5.635665	 13.348342	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3041	 8114	 13.41828	 27.828945	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3041	 1071	 13.04432	 28.183522	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4986	 937	 7.514876	 17.076863	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6254	 937	 10.18967	 19.679343	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8258	 937	 1.403533	 4.891322	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5189	 937	 1.431054	 4.791528	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5646	 937	 7.830992	 14.143185	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4986	 3117	 9.209711	 15.822724	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6254	 3117	 13.04525	 19.283055	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8258	 3117	 1.367066	 5.515496	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5189	 3117	 1.339153	 5.62376	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5646	 3117	 7.23719	 17.339673	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5942	 1128	 0.00696	 0.20656	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1840	 1128	 0.085711	 0.903781	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7722	 1128	 0.09713	 0.885702	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4335	 3961	 2.771122	 4.936011	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1840	 6527	 0.296032	 1.447438	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1840	 87	 0.281413	 1.320152	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7722	 6527	 0.307202	 1.385873	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7722	 87	 0.25536	 1.463643	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	985	 6527	 0.00046	 0.03669	 -0.031571	 742.180099	 742.180099	 742.180099	 0.970115	 0.0	 1	 -30.0	 30.0;
	6212	 87	 0.000808	 0.04562	 -0.013474	 396.000162	 396.000162	 396.000162	 0.975485	 0.0	 1	 -30.0	 30.0;
	6212	 87	 0.000438	 0.03862	 -0.007885	 749.334508	 749.334508	 749.334508	 0.960852	 0.0	 1	 -30.0	 30.0;
	2096	 2641	 0.037081	 0.480186	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1519	 2641	 0.074531	 0.583946	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3194	 2641	 0.08	 0.590186	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4641	 2526	 0.105789	 0.434903	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4641	 8241	 0.09937	 0.415727	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1656	 2526	 0.095997	 0.482181	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1656	 8241	 0.086717	 0.480388	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4986	 3675	 0.873905	 3.992149	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6254	 3675	 0.120211	 1.173533	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8258	 3675	 7.082025	 15.591937	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5189	 3675	 7.220868	 15.273755	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5646	 3675	 0.872831	 3.28905	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4986	 1124	 0.921508	 3.094834	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6254	 1124	 0.129919	 0.960764	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8258	 1124	 6.142769	 14.777069	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5189	 1124	 6.017355	 15.066946	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5646	 1124	 0.694463	 3.375206	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4986	 394	 7.254848	 17.556091	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4986	 1744	 6.944598	 15.819948	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4986	 3024	 0.962188	 3.649169	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4986	 1447	 2.525	 6.52029	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4986	 8114	 0.00154	 0.39572	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4986	 1071	 0.0014	 0.384758	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3912	 3961	 0.590782	 1.406718	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5092	 3961	 0.526337	 1.594252	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 4590	 0.836859	 5.618595	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 4590	 1.237665	 7.884711	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 4590	 3.449174	 20.571071	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 4590	 5.302273	 16.162393	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 4590	 0.789525	 4.620455	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 4590	 2.372521	 10.507644	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1359	 2624	 0.000495	 0.033881	 -0.003463	 733.141323	 733.141323	 733.141323	 0.982076	 0.0	 1	 -30.0	 30.0;
	2620	 5156	 2.23905	 7.164463	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 5156	 3.327273	 9.634503	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 5156	 8.134091	 27.90289	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 5156	 10.55806	 23.307847	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 5156	 1.718843	 7.201859	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 5156	 4.571488	 16.921905	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 2624	 1.894649	 7.933677	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 2624	 3.133678	 10.68802	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 2624	 8.769008	 26.754135	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 2624	 11.85517	 21.464873	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 2624	 2.005517	 6.368182	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 2624	 5.553718	 14.366735	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6254	 394	 4.540289	 12.081814	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8258	 394	 0.14887	 1.547789	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5189	 394	 0.145641	 1.433141	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5646	 394	 7.255165	 15.148962	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6254	 1744	 4.918802	 10.649998	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8258	 1744	 0.170281	 1.312108	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5189	 1744	 0.17349	 1.284174	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5646	 1744	 7.658058	 13.540087	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6434	 3026	 1.803947	 6.514197	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6434	 5562	 1.414404	 5.42687	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6434	 1143	 0.097091	 1.338712	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6434	 3720	 0.069813	 0.61338	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6535	 3026	 1.656925	 6.386704	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6535	 5562	 1.503047	 5.113989	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6535	 1143	 0.107382	 1.212396	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6535	 3720	 0.080478	 0.53394	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6254	 3024	 1.566157	 4.554339	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8258	 3024	 3.21405	 6.727273	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5189	 3024	 2.86343	 7.62438	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5646	 3024	 0.784091	 3.66529	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 7277	 -0.013061	 0.68473	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 236	 0.02627	 0.92126	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 220	 5.225831	 17.344184	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 570	 37.01108	 55.722988	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 3111	 38.53255	 55.73961	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 973	 0.00421	 0.609432	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 3212	 3.373338	 12.718144	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 4355	 5.841413	 14.22646	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 6888	 4.851247	 14.847647	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 4935	 15.98753	 46.096945	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 2361	 15.83449	 47.580335	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 5823	 5.167521	 17.612876	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 1441	 0.170402	 3.131509	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 6035	 13.13227	 24.978533	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2620	 5721	 11.55748	 21.738223	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 7277	 0.071828	 1.118006	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 236	 0.01624	 0.986219	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 220	 1.180471	 4.696329	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 973	 0.01296	 0.834834	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 3212	 4.962535	 20.238919	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 4355	 0.872438	 4.821676	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 6888	 0.801593	 4.526524	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 4935	 20.20014	 50.806099	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 2361	 23.16066	 50.423823	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 5823	 0.96662	 4.164474	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 1441	 0.448781	 4.337397	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 990	 11.58657	 23.771465	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 3564	 13.00554	 26.333102	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 6035	 17.94044	 35.608035	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4308	 5721	 15.18213	 32.262468	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6254	 1447	 0.430249	 2.466066	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6254	 8114	 0.0683	 0.916828	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6254	 1071	 0.06612	 0.843352	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8258	 1447	 1.444298	 4.757438	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5189	 1447	 1.472603	 4.660331	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5646	 1447	 2.284917	 6.055578	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	444	 8111	 0.000504	 0.031781	 -0.002425	 638.598472	 638.598472	 638.598472	 1.127469	 0.0	 1	 -30.0	 30.0;
	444	 3026	 0.086683	 1.502285	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	444	 5562	 0.05572	 1.389266	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	444	 1143	 0.40606	 1.910249	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	444	 3720	 0.0265	 0.438137	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6845	 5601	 0.000669	 0.032368	 -0.007657	 396.000162	 396.000162	 396.000162	 1.225528	 0.0	 1	 -30.0	 30.0;
	8258	 8114	 16.48554	 31.878094	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5189	 8114	 18.68347	 31.239671	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5646	 8114	 -0.006983	 0.380578	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8258	 1071	 19.27748	 29.774788	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5189	 1071	 19.64132	 29.142565	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5646	 1071	 -0.0075	 0.354442	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	292	 3026	 0.979504	 4.164463	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5317	 3026	 0.241095	 2.041488	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3691	 3026	 0.239525	 2.084091	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	292	 5562	 0.733492	 3.60186	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5317	 5562	 0.176539	 1.602479	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3691	 5562	 0.203141	 1.572934	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 7277	 3.658471	 11.068597	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 7277	 0.10706	 1.950682	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 7277	 10.14339	 24.185954	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 7277	 0.07038	 1.132707	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2470	 7277	 3.802686	 12.010955	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 7277	 3.583058	 17.321278	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 236	 2.938636	 13.075416	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 236	 0.00024	 2.372521	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 236	 9.23781	 30.750005	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 236	 0.041469	 1.048347	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2470	 236	 3.576446	 11.947316	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 236	 4.138017	 18.151449	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	292	 2487	 0.107147	 0.58482	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	292	 1143	 7.159972	 13.527699	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	292	 3720	 1.77874	 5.115028	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 5360	 7.195455	 16.568181	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 5360	 40.97313	 63.811985	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 2560	 7.423554	 18.762807	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 2560	 42.39256	 65.737609	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 220	 -0.016674	 0.278698	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 973	 5.349861	 16.166202	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 3212	 9.134349	 25.279081	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 4355	 0.197001	 1.168768	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 6888	 0.18955	 1.05277	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 4935	 6.030263	 16.006928	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 2361	 5.975346	 16.528394	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 5823	 3.107895	 9.123269	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 1441	 11.81025	 37.443907	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 990	 27.31856	 49.591409	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 3564	 34.37812	 55.136426	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 220	 0.231281	 1.502872	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 220	 7.048967	 19.24607	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2470	 220	 0.229277	 1.235537	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 220	 2.544835	 7.532231	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 5082	 35.47521	 51.481404	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 3731	 34.64256	 52.336781	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4222	 3961	 15.75277	 20.093496	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5929	 1776	 0.000283	 0.012832	 -0.019399	 791.999665	 791.999665	 791.999665	 1.182689	 0.0	 1	 -30.0	 30.0;
	7553	 1792	 0.000292	 0.01188	 -0.01885	 791.999665	 791.999665	 791.999665	 1.182689	 0.0	 1	 -30.0	 30.0;
	6472	 570	 0.000398	 0.034511	 -0.005899	 697.908984	 697.908984	 697.908984	 1.031654	 0.0	 1	 -30.0	 30.0;
	7556	 570	 33.09298	 47.6281	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 3111	 34.44215	 47.623971	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 973	 0.161039	 2.815236	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 3212	 9.489612	 27.308865	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 4355	 0.246808	 1.61939	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 6888	 0.228082	 1.521121	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 4935	 18.28047	 42.772855	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 2361	 18.10111	 44.135045	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 5823	 0.331281	 2.194459	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 1441	 0.752078	 9.020083	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 990	 4.985803	 12.659968	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 3564	 5.581648	 14.030467	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5883	 4029	 0.000476	 0.03161	 -0.010507	 752.125188	 752.125188	 752.125188	 0.957287	 0.0	 1	 -30.0	 30.0;
	5883	 6518	 0.000457	 0.030901	 -0.007587	 752.125188	 752.125188	 752.125188	 0.957287	 0.0	 1	 -30.0	 30.0;
	6425	 7416	 1.305041	 5.872521	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 7416	 12.81343	 30.764465	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 6094	 0.657355	 3.229132	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 6094	 6.467975	 16.903509	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 4274	 -0.017839	 0.427271	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 6801	 -0.020298	 0.420457	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 3212	 0.05596	 1.32043	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 4935	 0.430997	 2.378602	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 2361	 0.443573	 2.357341	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 1801	 0.073677	 2.231025	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 1441	 0.927909	 4.907895	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 6035	 42.82895	 57.943892	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 5721	 36.44598	 52.531845	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4412	 6801	 0.00037	 0.03817	 -0.010751	 733.141323	 733.141323	 733.141323	 0.982076	 0.0	 1	 -30.0	 30.0;
	4412	 4274	 0.000309	 0.035711	 -0.00968	 733.141323	 733.141323	 733.141323	 0.982076	 0.0	 1	 -30.0	 30.0;
	1153	 4274	 0.529731	 3.305372	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 6801	 0.54188	 3.249793	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 973	 -0.008016	 0.233843	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 3212	 5.680748	 16.603181	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 4355	 6.552285	 16.597649	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 6888	 5.444182	 17.322713	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 4935	 24.32756	 59.210516	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 2361	 24.09903	 61.117023	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 5823	 5.625068	 20.064407	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 1441	 0.456198	 4.138435	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 6035	 11.52632	 21.784622	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 5721	 10.14543	 18.959839	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7556	 973	 0.000476	 0.031631	 -0.003303	 902.151896	 902.151896	 902.151896	 0.969681	 0.0	 1	 -30.0	 30.0;
	2470	 973	 5.521694	 14.730582	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 973	 19.34525	 41.508264	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2470	 3212	 32.73967	 68.105374	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 3212	 -0.083244	 0.946591	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4125	 4355	 0.000447	 0.035271	 -0.002408	 752.125188	 752.125188	 752.125188	 0.957287	 0.0	 1	 -30.0	 30.0;
	2470	 4355	 -0.015103	 0.337521	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2470	 6888	 -0.012686	 0.286488	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2470	 4935	 27.97992	 45.335871	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2470	 2361	 28.86773	 44.978518	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2470	 5823	 0.994044	 4.152008	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2470	 1441	 19.05609	 41.630194	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2470	 990	 11.95776	 23.687676	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2470	 3564	 11.73892	 30.398894	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 4355	 10.39773	 25.376037	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 6888	 9.457438	 23.791321	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 4935	 0.000409	 0.036341	 -0.003303	 752.125188	 752.125188	 752.125188	 0.957287	 0.0	 1	 -30.0	 30.0;
	1153	 4935	 -0.006942	 0.494855	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 2361	 -0.008161	 0.491033	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 1801	 4.701801	 16.907201	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 1441	 0.18313	 2.973269	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 6035	 30.6392	 44.945983	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1153	 5721	 27.01524	 39.081706	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5646	 4674	 0.000757	 0.064121	 -0.001346	 417.676639	 417.676639	 417.676639	 1.005563	 0.0	 1	 -30.0	 30.0;
	5317	 1143	 2.158264	 7.671693	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3691	 1143	 2.128512	 7.829339	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5317	 3720	 0.536593	 2.637604	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3691	 3720	 0.529488	 2.445638	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6785	 6328	 0.00039	 0.017471	 -0.005272	 887.333647	 887.333647	 887.333647	 1.049501	 -5.042515	 1	 -30.0	 30.0;
	6785	 3961	 0.856787	 2.082133	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7427	 1999	 0.000515	 0.03175	 -0.009652	 718.199994	 718.199994	 718.199994	 1.002506	 0.0	 1	 -30.0	 30.0;
	7427	 1999	 0.000408	 0.036729	 -0.007329	 718.199994	 718.199994	 718.199994	 1.002506	 0.0	 1	 -30.0	 30.0;
	6941	 3281	 0.00648	 0.148407	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2292	 3281	 0.00055	 0.038349	 -0.001095	 412.748192	 412.748192	 412.748192	 1.162937	 0.0	 1	 -30.0	 30.0;
	1516	 2612	 0.114331	 0.894649	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7227	 2612	 3.931818	 5.960743	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4639	 2612	 1.022872	 2.477479	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1448	 2612	 1.145744	 2.668595	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2619	 2612	 0.115521	 0.652645	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1516	 5623	 0.342335	 1.036053	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5990	 7087	 0.08144	 0.487603	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8036	 48	 0.492025	 1.533306	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2196	 4629	 0.00079	 0.058401	 0.0	 183.599776	 183.599776	 183.599776	 1.0	 0.0	 1	 -30.0	 30.0;
	2196	 4629	 0.00077	 0.05951	 0.0	 179.999535	 179.999535	 179.999535	 1.0	 0.0	 1	 -30.0	 30.0;
	1516	 3593	 0.000209	 0.016646	 -0.00512	 1200.00041	 1200.00041	 1200.00041	 1.002506	 0.0	 1	 -30.0	 30.0;
	1516	 358	 -0.020062	 0.263393	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1516	 4523	 0.02611	 0.389661	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1516	 1021	 0.02953	 0.274197	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1516	 358	 0.000249	 0.015313	 -0.00531	 1200.00041	 1200.00041	 1200.00041	 1.002506	 0.0	 1	 -30.0	 30.0;
	4213	 1527	 0.01135	 0.389938	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4213	 3218	 0.03467	 0.4241	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8036	 1480	 0.000159	 0.018964	 -0.00178	 1200.00041	 1200.00041	 1200.00041	 0.988772	 0.0	 1	 -30.0	 30.0;
	8036	 1480	 -0.01126	 0.214855	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8036	 6466	 0.20036	 1.026385	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8036	 8316	 0.117071	 0.511302	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3490	 375	 0.093303	 0.945014	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3976	 375	 0.01297	 0.327971	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2166	 375	 0.05929	 0.601787	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5990	 4838	 0.05013	 0.919979	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5990	 3796	 0.0477	 0.865888	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7227	 3216	 0.749308	 2.45464	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7227	 5323	 2.902839	 5.007549	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2635	 1527	 0.03282	 0.444566	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7187	 375	 0.186479	 0.852913	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1898	 375	 0.185979	 0.818905	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6730	 375	 1.207107	 3.026033	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5619	 375	 0.414669	 1.672355	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4639	 3216	 0.129612	 0.934834	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4639	 5323	 0.796053	 2.21392	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1448	 3216	 0.136461	 1.06849	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1448	 5323	 0.838366	 2.528809	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6912	 1226	 0.000298	 0.01635	 -0.022906	 791.999665	 791.999665	 791.999665	 1.009423	 0.69199	 1	 -30.0	 30.0;
	4210	 5100	 0.01604	 0.374051	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1948	 5100	 0.01635	 0.36626	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2635	 5100	 0.024141	 0.327376	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5693	 5100	 0.02194	 0.458409	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1821	 8094	 0.00046	 0.03512	 -0.002666	 724.004478	 724.004478	 724.004478	 0.99447	 0.0	 1	 -30.0	 30.0;
	1821	 5973	 0.000328	 0.017373	 -0.00429	 791.999665	 791.999665	 791.999665	 1.002506	 0.0	 1	 -30.0	 30.0;
	2635	 3218	 0.00056	 0.05575	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5990	 2414	 0.09537	 0.774091	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5990	 4370	 0.325393	 1.201922	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5990	 6898	 0.367459	 1.167149	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5693	 2630	 0.0008	 0.04856	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7181	 1482	 0.00033	 0.038031	 -0.014431	 725.453788	 725.453788	 725.453788	 0.992481	 0.0	 1	 -30.0	 30.0;
	7181	 1482	 0.00034	 0.037211	 -0.014431	 725.453788	 725.453788	 725.453788	 0.992481	 0.0	 1	 -30.0	 30.0;
	2619	 3216	 -0.016405	 0.249504	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2619	 5323	 0.087209	 0.621302	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7914	 4402	 0.15538	 0.761901	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6316	 4402	 0.15969	 0.749463	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6265	 4402	 1.428926	 3.608884	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5223	 4402	 0.861798	 2.342768	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5651	 2632	 0.119958	 0.657978	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3445	 5820	 0.172789	 1.348017	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2186	 5820	 0.00088	 0.381756	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4165	 5820	 0.0061	 0.418244	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5918	 6437	 0.05995	 0.76688	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5416	 6437	 0.0653	 0.750992	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2205	 6437	 -0.003347	 0.292562	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2835	 7029	 1.83593	 3.666115	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8311	 7029	 0.052409	 0.497211	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1046	 7355	 0.436797	 1.36533	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6455	 7355	 0.094151	 0.896736	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1274	 6905	 0.00721	 0.237881	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1274	 4359	 0.140762	 0.856856	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7421	 6905	 0.05419	 0.633158	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7421	 4359	 0.0291	 0.36903	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2865	 2632	 0.143641	 0.91531	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1103	 2632	 0.025969	 0.445888	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1138	 2632	 0.270372	 0.785723	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5018	 2632	 0.05175	 0.49312	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4352	 2632	 0.08601	 0.600496	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5470	 2632	 0.531591	 1.712665	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3910	 2632	 0.43593	 1.756797	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4885	 3780	 0.01926	 0.358289	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6706	 3557	 0.01795	 0.317397	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3445	 140	 0.00761	 0.279277	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2186	 140	 0.260062	 1.120476	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4165	 140	 0.158651	 0.983822	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3445	 4179	 0.00395	 0.366116	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5522	 4179	 0.083409	 0.606219	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2186	 4179	 0.195669	 1.120144	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4165	 4179	 0.104969	 1.02188	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2875	 4179	 0.042831	 0.74374	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2835	 7447	 0.000242	 0.018374	 -0.003495	 1200.00041	 1200.00041	 1200.00041	 1.009443	 0.69399	 1	 -30.0	 30.0;
	2835	 5245	 -0.003203	 0.14994	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2835	 5245	 0.000451	 0.034969	 -0.007773	 724.004478	 724.004478	 724.004478	 0.99447	 0.0	 1	 -30.0	 30.0;
	2835	 6345	 0.113213	 0.498338	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5870	 4064	 0.00055	 0.0343	 -0.007793	 737.108169	 737.108169	 737.108169	 0.97679	 0.0	 1	 -30.0	 30.0;
	6316	 8130	 0.000264	 0.016372	 -0.003379	 1200.00041	 1200.00041	 1200.00041	 0.988494	 -1.359277	 1	 -30.0	 30.0;
	7914	 3585	 0.01862	 0.220201	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6316	 3585	 0.0168	 0.250561	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1046	 4359	 0.202902	 0.952701	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1046	 7981	 0.949862	 3.139543	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1046	 1511	 0.00261	 0.215422	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6748	 3783	 -0.02155	 0.439897	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5522	 3783	 0.07045	 1.003492	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6748	 7835	 0.00807	 0.465263	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6748	 5747	 0.194723	 1.065305	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6748	 3160	 0.7241	 1.639128	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6748	 4757	 0.514127	 1.973476	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6748	 7889	 0.06643	 0.866482	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6748	 3439	 0.55937	 2.088574	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6748	 4782	 0.522202	 2.029502	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6748	 6915	 0.30876	 1.923338	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2933	 6754	 0.06357	 0.598203	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3751	 6754	 0.000445	 0.035961	 -0.008241	 728.252367	 728.252367	 728.252367	 0.988668	 0.0	 1	 -30.0	 30.0;
	5974	 6754	 0.01179	 0.332211	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	723	 6754	 0.02131	 0.372955	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4096	 6754	 0.00274	 0.381756	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6265	 3585	 0.29314	 1.107872	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5223	 3585	 0.144281	 0.82905	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2253	 2217	 0.00458	 0.288905	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7638	 281	 0.365888	 1.746611	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1982	 281	 1.44438	 5.252272	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1667	 281	 0.059581	 0.615888	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3260	 281	 3.709298	 8.934297	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6227	 281	 0.140919	 0.944236	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5816	 148	 0.0005	 0.0343	 -0.003612	 755.481903	 755.481903	 755.481903	 0.953034	 0.0	 1	 -30.0	 30.0;
	8311	 148	 0.01962	 0.216178	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5522	 7835	 0.398678	 1.516364	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5522	 801	 0.09755	 0.839897	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2875	 801	 0.499525	 2.142562	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1205	 3780	 0.01537	 0.348347	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3324	 3780	 0.01946	 0.372727	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5974	 5735	 0.01679	 0.350455	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	723	 5735	 0.0005	 0.324174	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4096	 5735	 0.049469	 0.557004	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1103	 5349	 0.0005	 0.031271	 0.0	 334.799359	 334.799359	 334.799359	 1.0	 0.0	 1	 -30.0	 30.0;
	7638	 5349	 0.422748	 2.328099	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1982	 5349	 1.022934	 4.279959	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1667	 5349	 0.256612	 1.738141	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3260	 5349	 2.300207	 9.353099	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6227	 5349	 0.0157	 0.997789	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5522	 7253	 0.022021	 0.625496	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2875	 7253	 0.223988	 1.463946	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7638	 5555	 -0.037934	 0.385868	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1982	 5555	 2.334711	 7.437397	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1667	 5555	 0.137849	 1.103905	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3260	 5555	 5.726446	 13.392563	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6227	 5555	 0.183531	 1.402418	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7878	 7638	 3.1e-05	 0.002308	 -0.00826	 2687.34611	 2687.34611	 2687.34611	 0.997785	 -3.813636	 1	 -30.0	 30.0;
	7638	 4684	 2.374861	 8.881579	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7638	 7372	 0.158643	 1.604501	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7638	 7362	 0.204162	 1.92777	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7638	 7659	 0.169439	 2.010873	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1982	 4684	 -0.011343	 0.25657	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1982	 4684	 0.000423	 0.033381	 -0.024024	 761.990638	 761.990638	 761.990638	 0.944892	 0.0	 1	 -30.0	 30.0;
	1667	 4684	 6.533884	 12.310123	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3260	 4684	 0.04751	 0.576054	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6227	 4684	 0.21343	 1.602582	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1982	 7372	 7.076177	 15.615651	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1982	 7362	 6.591413	 15.880881	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1982	 7659	 0.187507	 2.209903	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	750	 3775	 0.0004	 0.149419	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5223	 3775	 0.027469	 0.320806	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6706	 3775	 0.00659	 0.53155	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4097	 5584	 0.45281	 1.969855	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8249	 5584	 0.561302	 2.344629	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7602	 5584	 0.03438	 0.839277	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7014	 375	 -0.00126	 0.238202	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7014	 375	 0.000426	 0.017203	 -0.004064	 938.505772	 938.505772	 938.505772	 1.002506	 0.0	 1	 -30.0	 30.0;
	7014	 114	 0.01628	 0.291863	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6327	 7708	 -0.010145	 0.227045	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4097	 3291	 0.00079	 0.680124	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8249	 3291	 -6.2e-05	 0.76438	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7602	 3291	 0.288988	 1.328967	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4097	 269	 0.289174	 0.947893	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8249	 269	 0.357831	 1.127893	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7602	 269	 0.00434	 0.222459	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8244	 7311	 0.162281	 0.824401	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1614	 7311	 0.510455	 1.73717	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	565	 7311	 0.218822	 1.471838	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1351	 7311	 0.029581	 0.641756	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4290	 7311	 0.269194	 1.398492	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	723	 6248	 0.01824	 0.407147	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	723	 6494	 0.01992	 0.388733	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6327	 1780	 0.504669	 1.26314	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	528	 5020	 0.180042	 0.913089	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	528	 2025	 0.28705	 1.359279	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8305	 4115	 0.02939	 0.690041	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7207	 4115	 0.106211	 0.857975	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8305	 1557	 0.03057	 0.640372	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7207	 1557	 0.11774	 0.83438	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1667	 7362	 0.000416	 0.031501	 -0.041226	 742.51248	 742.51248	 742.51248	 0.969681	 0.0	 1	 -30.0	 30.0;
	1667	 7372	 -0.02392	 0.308892	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1667	 7362	 -0.021129	 0.40847	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1667	 7659	 0.801523	 3.248477	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3260	 7372	 15.18223	 29.541321	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6227	 7372	 0.810744	 3.364049	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3260	 7362	 13.91921	 30.6467	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6227	 7362	 0.716322	 3.154132	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6706	 488	 0.00489	 0.406095	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8244	 5405	 0.447909	 1.098823	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8244	 5988	 0.01056	 0.353927	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8244	 1542	 0.7509	 1.841551	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1614	 5405	 0.37579	 0.752493	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1614	 5988	 0.190388	 1.261149	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1614	 1542	 0.05324	 0.584501	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4653	 5020	 0.01773	 0.615173	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4653	 6329	 0.01987	 0.600173	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2058	 5020	 0.466918	 1.296815	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2058	 2025	 0.815443	 1.930956	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4097	 3886	 0.02061	 0.308595	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8249	 3886	 0.02549	 0.367231	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7602	 3886	 0.00824	 0.278492	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3260	 7659	 0.716621	 3.572645	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2933	 2965	 0.045599	 0.50595	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8305	 619	 0.00887	 0.706717	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8305	 6673	 0.04089	 0.90831	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8305	 4146	 0.04322	 0.911288	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	297	 5020	 0.032849	 0.6625	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7058	 5020	 0.03726	 0.637562	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	788	 5020	 0.074341	 0.632975	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5754	 5020	 0.07781	 0.62157	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	565	 5405	 0.534411	 1.302908	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	565	 5988	 0.02355	 0.61356	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	565	 1542	 0.420249	 1.970499	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1351	 5405	 0.229855	 0.963099	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4290	 5405	 0.074669	 0.41343	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6327	 745	 0.06182	 0.403213	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6227	 7659	 -0.029256	 0.40562	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5522	 5747	 0.0033	 0.455227	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2933	 5747	 0.00124	 0.284731	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	69	 6248	 0.04584	 0.400152	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	69	 6494	 0.03961	 0.441877	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5522	 2366	 0.282149	 1.82343	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2875	 2366	 -0.001467	 0.288285	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7947	 3160	 0.000203	 0.018291	 -0.003547	 1200.00041	 1200.00041	 1200.00041	 0.995521	 -0.684388	 1	 -30.0	 30.0;
	5522	 3160	 3.246901	 6.102273	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4982	 5149	 0.000187	 0.016035	 -0.003253	 1200.00041	 1200.00041	 1200.00041	 1.009443	 -0.693988	 1	 -30.0	 30.0;
	4982	 5149	 0.000198	 0.015708	 -0.003253	 1200.00041	 1200.00041	 1200.00041	 1.009443	 -0.693988	 1	 -30.0	 30.0;
	5365	 5149	 0.046659	 0.29938	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5918	 7721	 0.02508	 0.489778	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5918	 6945	 0.0359	 0.39268	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5416	 7721	 0.01931	 0.550478	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5416	 6945	 0.0365	 0.48437	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1351	 5988	 -0.015393	 0.242665	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1351	 5988	 0.00024	 0.016571	 -0.003032	 1200.00041	 1200.00041	 1200.00041	 1.031152	 0.0	 1	 -30.0	 30.0;
	4290	 5988	 0.778884	 2.360744	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1351	 1542	 0.834349	 2.163366	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2205	 7721	 0.02768	 0.486653	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2205	 7721	 0.0005	 0.0343	 -0.003612	 728.252367	 728.252367	 728.252367	 0.988668	 0.0	 1	 -30.0	 30.0;
	2205	 6945	 0.170748	 0.871399	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5522	 4757	 3.440496	 6.966735	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5522	 7889	 -0.025	 0.350744	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5522	 3439	 3.294252	 7.269391	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5522	 4782	 3.075277	 7.063712	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5522	 6915	 2.188573	 6.820568	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5365	 2025	 0.03254	 0.295443	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2875	 7754	 0.000216	 0.016549	 -0.003511	 1200.00041	 1200.00041	 1200.00041	 0.988772	 0.0	 1	 -30.0	 30.0;
	6455	 4359	 0.00914	 0.394959	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7207	 619	 0.11943	 0.839463	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6706	 619	 0.02832	 0.560682	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6706	 3508	 0.025289	 0.560351	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6455	 7981	 0.203901	 1.623181	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5593	 7288	 0.000184	 0.017384	 -0.004008	 1200.00041	 1200.00041	 1200.00041	 0.995521	 -0.684388	 1	 -30.0	 30.0;
	4096	 6248	 0.0086	 0.46804	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4096	 6494	 0.00772	 0.464148	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8311	 7836	 0.08261	 0.429463	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8311	 5068	 0.09332	 0.419277	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	297	 6329	 0.06593	 0.705471	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7058	 6329	 0.070298	 0.687417	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	8079	 1374	 0.000348	 0.015847	 -0.004506	 791.999665	 791.999665	 791.999665	 1.023085	 -2.104465	 1	 -30.0	 30.0;
	8311	 4837	 0.000239	 0.01504	 -0.003577	 1200.00041	 1200.00041	 1200.00041	 0.995521	 0.68439	 1	 -30.0	 30.0;
	7207	 6673	 0.0275	 0.64187	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7207	 4146	 0.02423	 0.621711	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6455	 1511	 0.021711	 0.411839	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6455	 1511	 0.000216	 0.018022	 -0.003539	 1200.00041	 1200.00041	 1200.00041	 0.988772	 0.0	 1	 -30.0	 30.0;
	6455	 7964	 0.000173	 0.017112	 -0.003742	 1200.00041	 1200.00041	 1200.00041	 0.988772	 0.0	 1	 -30.0	 30.0;
	7076	 6915	 0.000179	 0.016813	 -0.00407	 1200.00041	 1200.00041	 1200.00041	 0.995521	 -0.684388	 1	 -30.0	 30.0;
	7076	 6915	 0.000209	 0.016263	 -0.00399	 1200.00041	 1200.00041	 1200.00041	 0.995521	 -0.684388	 1	 -30.0	 30.0;
	4290	 1542	 -0.024793	 0.19232	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4097	 1363	 0.000274	 0.015682	 -0.036281	 1200.00041	 1200.00041	 1200.00041	 0.995521	 -0.684388	 1	 -30.0	 30.0;
	7602	 1621	 0.000476	 0.030991	 -0.015068	 733.141323	 733.141323	 733.141323	 0.982076	 0.0	 1	 -30.0	 30.0;
	788	 2025	 0.11386	 1.025723	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5754	 2025	 0.111979	 1.046363	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5754	 2871	 0.00022	 0.018311	 -0.003316	 1200.00041	 1200.00041	 1200.00041	 0.995521	 -0.684388	 1	 -30.0	 30.0;
	7965	 7626	 0.383282	 2.185803	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7965	 6163	 0.497389	 1.835595	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4243	 6354	 0.000615	 0.029917	 -0.000168	 479.999638	 479.999638	 479.999638	 1.193503	 0.0	 1	 -30.0	 30.0;
	4243	 6354	 0.000634	 0.029307	 -0.000168	 479.999638	 479.999638	 479.999638	 1.193503	 0.0	 1	 -30.0	 30.0;
	1738	 8120	 -0.02062	 0.218202	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1738	 2583	 0.20759	 1.109002	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1738	 395	 0.275429	 1.015166	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1738	 438	 1.042036	 2.256095	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	462	 8120	 0.10976	 0.74593	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3086	 8120	 0.287831	 1.163678	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7073	 7431	 0.07	 0.46124	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6307	 7431	 0.068479	 0.427066	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6967	 6004	 0.103857	 0.477763	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6967	 3752	 1.274515	 2.49626	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5867	 6004	 0.107943	 0.458262	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5867	 3752	 1.323546	 2.392243	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7484	 7626	 0.209488	 1.002909	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7484	 6163	 0.126607	 0.574751	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1995	 3842	 0.00044	 0.03688	 -0.024975	 760.322154	 760.322154	 760.322154	 0.946967	 0.0	 1	 -30.0	 30.0;
	1995	 2194	 0.01559	 0.151898	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6260	 2481	 0.20449	 0.679959	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5860	 2583	 0.105249	 0.487299	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	462	 2583	 0.000246	 0.018653	 -0.015389	 959.999933	 959.999933	 959.999933	 0.9278	 -2.469858	 1	 -30.0	 30.0;
	462	 2583	 -0.01905	 0.247025	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	462	 395	 1.418837	 2.394528	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	462	 438	 0.205332	 0.854986	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7627	 2583	 1.852727	 2.747521	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3086	 2583	 1.359979	 2.972315	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3086	 395	 0.02269	 0.199771	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6260	 3422	 0.00688	 0.14088	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	7199	 6004	 0.00021	 0.037302	 -0.015744	 959.999933	 959.999933	 959.999933	 0.884187	 -6.484691	 1	 -30.0	 30.0;
	7199	 6004	 0.00021	 0.034539	 -0.015744	 959.999933	 959.999933	 959.999933	 0.884187	 -6.484691	 1	 -30.0	 30.0;
	1459	 173	 0.021781	 0.193349	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	3086	 438	 0.037729	 0.222665	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5433	 2194	 0.05599	 0.311752	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4303	 5071	 0.000687	 0.037873	 -0.00016	 479.999638	 479.999638	 479.999638	 1.027811	 0.0	 1	 -30.0	 30.0;
	2661	 5071	 0.000697	 0.03705	 -0.00016	 479.999638	 479.999638	 479.999638	 1.027811	 0.0	 1	 -30.0	 30.0;
	1459	 5334	 0.000258	 0.015179	 -0.015882	 959.999933	 959.999933	 959.999933	 1.031474	 0.0	 1	 -30.0	 30.0;
	1459	 5334	 -0.008698	 0.24938	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	1459	 5334	 0.000218	 0.015068	 -0.015881	 959.999933	 959.999933	 959.999933	 1.031407	 0.0	 1	 -30.0	 30.0;
	7073	 5334	 0.055651	 0.515413	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6307	 5334	 0.05444	 0.477231	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	6260	 2902	 0.153248	 0.626697	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2781	 7023	 -0.003823	 0.150277	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2781	 7023	 0.00069	 0.03981	 -0.000161	 417.175106	 417.175106	 417.175106	 1.150597	 0.0	 1	 -30.0	 30.0;
	177	 7023	 0.056219	 0.23343	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2099	 7626	 0.000243	 0.023724	 -0.0143	 959.999933	 959.999933	 959.999933	 1.004859	 -6.027998	 1	 -30.0	 30.0;
	2099	 7626	 -0.011591	 0.366818	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	2099	 6163	 0.145519	 0.713643	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	455	 7626	 0.000231	 0.022812	 -0.0143	 959.999933	 959.999933	 959.999933	 1.004859	 -6.027998	 1	 -30.0	 30.0;
	455	 7626	 -0.010888	 0.388409	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	455	 6163	 0.157909	 0.659799	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	5859	 6815	 0.00297	 0.141711	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4094	 2902	 0.000245	 0.011573	 -0.015462	 959.999933	 959.999933	 959.999933	 1.108025	 0.0	 1	 -30.0	 30.0;
	4094	 2902	 0.000255	 0.011329	 -0.015462	 959.999933	 959.999933	 959.999933	 1.108025	 0.0	 1	 -30.0	 30.0;
	177	 782	 0.000697	 0.027473	 -0.00016	 479.999638	 479.999638	 479.999638	 1.193503	 0.0	 1	 -30.0	 30.0;
	177	 782	 0.000627	 0.031139	 -0.00016	 479.999638	 479.999638	 479.999638	 1.193503	 0.0	 1	 -30.0	 30.0;
	6977	 3992	 0.00203	 0.101959	 -0.00371	 218.490935	 218.490935	 218.490935	 0.939167	 0.0	 1	 -30.0	 30.0;
	6977	 3992	 0.00195	 0.103917	 -0.003729	 214.366818	 214.366818	 214.366818	 0.939167	 0.0	 1	 -30.0	 30.0;
	7115	 4433	 0.00341	 0.25873	 -0.00261	 214.45827	 214.45827	 214.45827	 0.923255	 -9.72034	 1	 -30.0	 30.0;
	5588	 2290	 0.001812	 0.100668	 -0.003932	 182.124172	 182.124172	 182.124172	 0.988338	 2.88795	 1	 -30.0	 30.0;
	5588	 2290	 0.001982	 0.098657	 -0.003952	 182.124172	 182.124172	 182.124172	 0.988338	 2.88795	 1	 -30.0	 30.0;
	4157	 5175	 0.00153	 0.094124	 -0.004491	 220.971959	 220.971959	 220.971959	 0.9775	 0.0	 1	 -30.0	 30.0;
	4157	 5175	 0.00156	 0.092157	 -0.004491	 220.971959	 220.971959	 220.971959	 0.9775	 0.0	 1	 -30.0	 30.0;
	1981	 4110	 0.00512	 0.156934	 -0.00202	 109.477909	 109.477909	 109.477909	 1.03	 0.0	 1	 -30.0	 30.0;
	1981	 3050	 0.00513	 0.153636	 -0.00203	 111.839664	 111.839664	 111.839664	 1.03	 0.0	 1	 -30.0	 30.0;
	7147	 5258	 0.001473	 0.055275	 -0.006378	 240.000477	 240.000477	 240.000477	 1.189316	 0.0	 1	 -30.0	 30.0;
	5084	 6993	 0.000628	 0.026981	 -0.012755	 479.999638	 479.999638	 479.999638	 1.189316	 0.0	 1	 -30.0	 30.0;
	6033	 7949	 0.000768	 0.027532	 -0.012755	 479.999638	 479.999638	 479.999638	 1.189316	 0.0	 1	 -30.0	 30.0;
	1491	 3850	 0.000778	 0.05467	 -0.012755	 479.999638	 479.999638	 479.999638	 0.850261	 0.0	 1	 -30.0	 30.0;
	1491	 3850	 0.000767	 0.055473	 -0.012755	 479.999638	 479.999638	 479.999638	 0.809534	 0.0	 1	 -30.0	 30.0;
	1784	 7808	 0.000905	 0.055047	 -0.012755	 479.999638	 479.999638	 479.999638	 0.809534	 0.0	 1	 -30.0	 30.0;
	6722	 1889	 0.000902	 0.025704	 -0.012755	 479.999638	 479.999638	 479.999638	 1.189316	 0.0	 1	 -30.0	 30.0;
	6722	 1889	 0.000902	 0.024552	 -0.012755	 479.999638	 479.999638	 479.999638	 1.189316	 0.0	 1	 -30.0	 30.0;
	4589	 1889	 0.000437	 0.013336	 -0.010039	 360.000005	 360.000005	 360.000005	 1.104097	 0.0	 1	 -30.0	 30.0;
	260	 7287	 0.001665	 0.048767	 -0.006378	 295.200001	 295.200001	 295.200001	 1.189316	 0.0	 1	 -30.0	 30.0;
	3841	 2078	 0.00083	 0.05142	 -0.012755	 479.999638	 479.999638	 479.999638	 0.850261	 0.0	 1	 -30.0	 30.0;
	3841	 2078	 0.000754	 0.045701	 -0.012755	 479.999638	 479.999638	 479.999638	 0.911396	 0.0	 1	 -30.0	 30.0;
	7437	 6858	 0.000798	 0.052223	 -0.012755	 479.999638	 479.999638	 479.999638	 0.864763	 0.0	 1	 -30.0	 30.0;
	5889	 1525	 0.000748	 0.052717	 -0.012755	 533.228573	 533.228573	 533.228573	 0.864763	 0.0	 1	 -30.0	 30.0;
	3204	 201	 0.000435	 0.02158	 -0.009566	 360.000005	 360.000005	 360.000005	 1.129615	 0.0	 1	 -30.0	 30.0;
	4640	 7434	 0.000871	 0.0262	 -0.012755	 479.999638	 479.999638	 479.999638	 1.189316	 0.0	 1	 -30.0	 30.0;
	5523	 4187	 0.000881	 0.047183	 -0.012755	 479.999638	 479.999638	 479.999638	 0.864763	 0.0	 1	 -30.0	 30.0;
	3862	 2047	 0.000214	 0.018189	 0.0	 720.000115	 720.000115	 720.000115	 1.026094	 0.0	 1	 -30.0	 30.0;
	4289	 5252	 0.000544	 0.028951	 0.0	 479.999638	 479.999638	 479.999638	 1.027754	 0.0	 1	 -30.0	 30.0;
	4925	 6736	 0.000433	 0.016641	 0.0	 720.000115	 720.000115	 720.000115	 1.046093	 0.0	 1	 -30.0	 30.0;
	4925	 6736	 0.000271	 0.019483	 0.0	 720.000115	 720.000115	 720.000115	 1.033258	 0.0	 1	 -30.0	 30.0;
	6014	 3320	 0.000292	 0.041885	 0.0	 450.000483	 450.000483	 450.000483	 1.026094	 0.0	 1	 -30.0	 30.0;
	6014	 3320	 0.000283	 0.025435	 0.0	 599.999547	 599.999547	 599.999547	 1.026094	 0.0	 1	 -30.0	 30.0;
	6276	 4511	 0.00019	 0.020772	 0.0	 720.000115	 720.000115	 720.000115	 1.046072	 0.0	 1	 -30.0	 30.0;
	2691	 8069	 0.000567	 0.0487	 0.0	 389.999541	 389.999541	 389.999541	 0.988334	 0.0	 1	 -30.0	 30.0;
	2691	 8069	 0.000292	 0.024683	 0.0	 599.999547	 599.999547	 599.999547	 0.988343	 0.0	 1	 -30.0	 30.0;
	4132	 6811	 0.000238	 0.020505	 0.0	 720.000115	 720.000115	 720.000115	 0.988343	 0.0	 1	 -30.0	 30.0;
	4132	 6811	 0.000302	 0.024253	 0.0	 599.999547	 599.999547	 599.999547	 0.988324	 0.0	 1	 -30.0	 30.0;
	1413	 2984	 0.000394	 0.025662	 0.0	 539.999921	 539.999921	 539.999921	 1.016389	 0.0	 1	 -30.0	 30.0;
	1413	 2984	 0.000403	 0.026263	 0.0	 539.999921	 539.999921	 539.999921	 1.016389	 0.0	 1	 -30.0	 30.0;
	1413	 2984	 0.000358	 0.02845	 0.0	 539.999921	 539.999921	 539.999921	 1.016389	 0.0	 1	 -30.0	 30.0;
	1092	 3228	 0.000184	 0.020004	 0.0	 720.000115	 720.000115	 720.000115	 1.046072	 0.0	 1	 -30.0	 30.0;
	6142	 4372	 0.000287	 0.030676	 0.0	 599.999547	 599.999547	 599.999547	 0.982307	 0.0	 1	 -30.0	 30.0;
	991	 5845	 0.000183	 0.021447	 0.0	 720.000115	 720.000115	 720.000115	 0.997518	 0.0	 1	 -30.0	 30.0;
	991	 5845	 0.000183	 0.019858	 0.0	 720.000115	 720.000115	 720.000115	 0.997518	 0.0	 1	 -30.0	 30.0;
	8310	 5895	 0.000196	 0.019264	 0.0	 720.000115	 720.000115	 720.000115	 1.016389	 0.0	 1	 -30.0	 30.0;
	8310	 5895	 0.000205	 0.018521	 0.0	 720.000115	 720.000115	 720.000115	 1.026094	 0.0	 1	 -30.0	 30.0;
	5160	 3070	 0.000205	 0.018131	 0.0	 720.000115	 720.000115	 720.000115	 1.026094	 0.0	 1	 -30.0	 30.0;
	628	 6342	 0.000224	 0.01875	 0.0	 720.000115	 720.000115	 720.000115	 1.016389	 0.0	 1	 -30.0	 30.0;
	628	 6342	 0.000685	 0.016451	 0.0	 720.000115	 720.000115	 720.000115	 1.043383	 0.0	 1	 -30.0	 30.0;
	4845	 3305	 0.00021	 0.024641	 0.0	 720.000115	 720.000115	 720.000115	 0.988343	 0.0	 1	 -30.0	 30.0;
	4845	 3305	 0.00021	 0.025112	 0.0	 720.000115	 720.000115	 720.000115	 0.988343	 0.0	 1	 -30.0	 30.0;
	7289	 3662	 0.0	 0.00554	 0.0	 1523.999705	 1523.999705	 1523.999705	 0.0	 0.0	 1	 -30.0	 30.0;
	1812	 932	 0.0	 0.00471	 0.0	 900.000204	 900.000204	 900.000204	 0.0	 0.0	 1	 -30.0	 30.0;
	431	 6140	 0.000205	 0.016639	 0.0	 720.000115	 720.000115	 720.000115	 1.077541	 0.0	 1	 -30.0	 30.0;
	431	 6140	 0.000214	 0.017035	 0.0	 720.000115	 720.000115	 720.000115	 1.077541	 0.0	 1	 -30.0	 30.0;
	431	 6140	 0.000214	 0.016674	 0.0	 720.000115	 720.000115	 720.000115	 1.077541	 0.0	 1	 -30.0	 30.0;
	1991	 4702	 0.000224	 0.018397	 0.0	 720.000115	 720.000115	 720.000115	 1.026094	 0.0	 1	 -30.0	 30.0;
	2784	 634	 0.000522	 0.027299	 0.0	 450.000483	 450.000483	 450.000483	 1.026052	 0.0	 1	 -30.0	 30.0;
	2784	 634	 0.000646	 0.037462	 0.0	 450.000483	 450.000483	 450.000483	 1.026052	 0.0	 1	 -30.0	 30.0;
	5284	 6450	 0.000244	 0.033945	 0.0	 381.599857	 381.599857	 381.599857	 1.033258	 0.0	 1	 -30.0	 30.0;
	5284	 6450	 0.000196	 0.023262	 0.0	 720.000115	 720.000115	 720.000115	 0.979336	 0.0	 1	 -30.0	 30.0;
	4799	 6450	 0.00091	 0.002213	 0.0	 462.000166	 462.000166	 462.000166	 0.999807	 1.12568	 1	 -30.0	 30.0;
	1779	 3930	 0.000179	 0.016955	 0.0	 720.000115	 720.000115	 720.000115	 1.099594	 0.0	 1	 -30.0	 30.0;
	6620	 386	 0.000206	 0.01883	 0.0	 720.000115	 720.000115	 720.000115	 1.035987	 0.0	 1	 -30.0	 30.0;
	5481	 7234	 0.000233	 0.018474	 0.0	 720.000115	 720.000115	 720.000115	 1.026094	 0.0	 1	 -30.0	 30.0;
	5481	 7234	 0.000421	 0.031827	 0.0	 539.999921	 539.999921	 539.999921	 1.033268	 0.0	 1	 -30.0	 30.0;
	966	 8156	 0.000219	 0.016973	 0.0	 720.000115	 720.000115	 720.000115	 1.056355	 0.0	 1	 -30.0	 30.0;
	7289	 1601	 0.000213	 0.020004	 0.0	 720.000115	 720.000115	 720.000115	 1.035987	 0.0	 1	 -30.0	 30.0;
	669	 1267	 0.000556	 0.033053	 0.0	 479.999638	 479.999638	 479.999638	 1.020472	 0.0	 1	 -30.0	 30.0;
	2037	 7717	 0.000508	 0.028375	 0.0	 479.999638	 479.999638	 479.999638	 1.037269	 0.0	 1	 -30.0	 30.0;
	3114	 1310	 0.000179	 0.022003	 0.0	 720.000115	 720.000115	 720.000115	 1.016389	 0.0	 1	 -30.0	 30.0;
	2476	 5559	 0.000209	 0.02019	 0.0	 720.000115	 720.000115	 720.000115	 0.997518	 0.0	 1	 -30.0	 30.0;
	2476	 5559	 0.000214	 0.020311	 0.0	 720.000115	 720.000115	 720.000115	 0.997518	 0.0	 1	 -30.0	 30.0;
	6702	 4930	 0.000616	 0.030505	 0.0	 479.999638	 479.999638	 479.999638	 1.023738	 0.0	 1	 -30.0	 30.0;
	6702	 4930	 0.000626	 0.029369	 0.0	 479.999638	 479.999638	 479.999638	 1.023738	 0.0	 1	 -30.0	 30.0;
	2212	 3452	 0.000214	 0.019409	 0.0	 720.000115	 720.000115	 720.000115	 0.970491	 0.0	 1	 -30.0	 30.0;
	2212	 3452	 0.000192	 0.022	 0.0	 720.000115	 720.000115	 720.000115	 0.970491	 0.0	 1	 -30.0	 30.0;
	4764	 7648	 0.000531	 0.03466	 0.0	 561.956125	 561.956125	 561.956125	 1.001309	 0.0	 1	 -30.0	 30.0;
	5327	 7383	 0.000531	 0.035228	 0.0	 479.999638	 479.999638	 479.999638	 1.001309	 0.0	 1	 -30.0	 30.0;
	5327	 7383	 0.00049	 0.031535	 0.0	 479.999638	 479.999638	 479.999638	 0.998185	 0.0	 1	 -30.0	 30.0;
	5327	 7383	 0.000209	 0.020964	 0.0	 720.000115	 720.000115	 720.000115	 0.997518	 0.0	 1	 -30.0	 30.0;
	6809	 1126	 0.000393	 0.02663	 0.0	 539.999921	 539.999921	 539.999921	 1.016389	 0.0	 1	 -30.0	 30.0;
	6809	 1126	 0.000402	 0.026088	 0.0	 539.999921	 539.999921	 539.999921	 1.016389	 0.0	 1	 -30.0	 30.0;
	2972	 5804	 0.000201	 0.017787	 0.0	 720.000115	 720.000115	 720.000115	 1.035987	 0.0	 1	 -30.0	 30.0;
	3907	 722	 0.000289	 0.018121	 0.0	 720.000115	 720.000115	 720.000115	 1.020734	 0.0	 1	 -30.0	 30.0;
	7194	 4178	 0.000643	 0.024464	 0.0	 539.999921	 539.999921	 539.999921	 1.056355	 0.0	 1	 -30.0	 30.0;
	7194	 4178	 0.000568	 0.027771	 0.0	 539.999921	 539.999921	 539.999921	 1.056355	 0.0	 1	 -30.0	 30.0;
	768	 3495	 0.000506	 0.031833	 0.0	 479.999638	 479.999638	 479.999638	 1.007616	 0.0	 1	 -30.0	 30.0;
	768	 3495	 0.000196	 0.024118	 0.0	 720.000115	 720.000115	 720.000115	 0.961805	 0.0	 1	 -30.0	 30.0;
	5370	 8052	 0.000205	 0.022593	 0.0	 720.000115	 720.000115	 720.000115	 1.016389	 0.0	 1	 -30.0	 30.0;
	5370	 8052	 0.000186	 0.01968	 0.0	 720.000115	 720.000115	 720.000115	 1.016389	 0.0	 1	 -30.0	 30.0;
	5370	 8052	 0.000205	 0.01997	 0.0	 720.000115	 720.000115	 720.000115	 1.016389	 0.0	 1	 -30.0	 30.0;
	1063	 2435	 0.000215	 0.018787	 0.0	 720.000115	 720.000115	 720.000115	 1.026094	 0.0	 1	 -30.0	 30.0;
	1063	 2435	 0.000215	 0.018388	 0.0	 720.000115	 720.000115	 720.000115	 1.026094	 0.0	 1	 -30.0	 30.0;
	2977	 5665	 0.000224	 0.018834	 0.0	 720.000115	 720.000115	 720.000115	 0.997518	 0.0	 1	 -30.0	 30.0;
	3458	 1022	 0.000433	 0.043546	 0.0	 360.000386	 360.000386	 360.000386	 1.008509	 0.0	 1	 -30.0	 30.0;
	5338	 7438	 0.000234	 0.018757	 0.0	 720.000115	 720.000115	 720.000115	 1.054309	 0.0	 1	 -30.0	 30.0;
	5338	 7438	 0.000197	 0.019207	 0.0	 720.000115	 720.000115	 720.000115	 1.054309	 0.0	 1	 -30.0	 30.0;
	5338	 7438	 0.000197	 0.019495	 0.0	 720.000115	 720.000115	 720.000115	 1.054309	 0.0	 1	 -30.0	 30.0;
	6058	 7091	 0.00018	 0.021226	 0.0	 720.000115	 720.000115	 720.000115	 1.014585	 0.0	 1	 -30.0	 30.0;
	6058	 7091	 0.000812	 0.03849	 0.0	 381.599857	 381.599857	 381.599857	 1.046093	 0.0	 1	 -30.0	 30.0;
	2059	 3829	 0.000205	 0.02035	 0.0	 720.000115	 720.000115	 720.000115	 1.006865	 0.0	 1	 -30.0	 30.0;
	662	 3392	 0.000593	 0.031521	 0.0	 479.999638	 479.999638	 479.999638	 1.014004	 0.0	 1	 -30.0	 30.0;
	662	 3392	 0.000612	 0.031123	 0.0	 479.999638	 479.999638	 479.999638	 1.014004	 0.0	 1	 -30.0	 30.0;
	662	 3392	 0.000427	 0.024994	 0.0	 539.999921	 539.999921	 539.999921	 1.016389	 0.0	 1	 -30.0	 30.0;
	2505	 373	 0.000667	 0.027207	 0.0	 539.999921	 539.999921	 539.999921	 1.006865	 0.0	 1	 -30.0	 30.0;
	2505	 373	 0.000621	 0.030836	 0.0	 539.999921	 539.999921	 539.999921	 1.006865	 0.0	 1	 -30.0	 30.0;
	272	 858	 0.000192	 0.020791	 0.0	 720.000115	 720.000115	 720.000115	 1.026094	 0.0	 1	 -30.0	 30.0;
	272	 858	 0.000192	 0.02119	 0.0	 720.000115	 720.000115	 720.000115	 1.026094	 0.0	 1	 -30.0	 30.0;
	7989	 27	 0.000686	 0.030987	 0.0	 381.599857	 381.599857	 381.599857	 1.072746	 0.0	 1	 -30.0	 30.0;
	2734	 5146	 0.000194	 0.020764	 0.0	 720.000115	 720.000115	 720.000115	 1.006865	 0.0	 1	 -30.0	 30.0;
	159	 1691	 0.000717	 0.038087	 0.0	 360.000386	 360.000386	 360.000386	 1.006865	 0.0	 1	 -30.0	 30.0;
	7185	 6040	 0.000206	 0.01883	 0.0	 720.000115	 720.000115	 720.000115	 1.035987	 0.0	 1	 -30.0	 30.0;
	7185	 67	 0.000206	 0.018439	 0.0	 720.000115	 720.000115	 720.000115	 1.035987	 0.0	 1	 -30.0	 30.0;
	6374	 28	 0.000219	 0.017019	 0.0	 720.000115	 720.000115	 720.000115	 1.066843	 0.0	 1	 -30.0	 30.0;
	6374	 28	 0.000224	 0.016641	 0.0	 720.000115	 720.000115	 720.000115	 1.066843	 0.0	 1	 -30.0	 30.0;
	5992	 8208	 0.000676	 0.047085	 0.0	 389.999541	 389.999541	 389.999541	 1.016389	 0.0	 1	 -30.0	 30.0;
	5992	 8208	 0.000667	 0.048014	 0.0	 389.999541	 389.999541	 389.999541	 1.016389	 0.0	 1	 -30.0	 30.0;
	6658	 7558	 0.000196	 0.019215	 0.0	 720.000115	 720.000115	 720.000115	 1.077541	 0.0	 1	 -30.0	 30.0;
	3614	 5343	 0.000253	 0.025528	 0.0	 599.999547	 599.999547	 599.999547	 0.997508	 0.0	 1	 -30.0	 30.0;
	7441	 6291	 0.00021	 0.017884	 0.0	 720.000115	 720.000115	 720.000115	 1.046072	 0.0	 1	 -30.0	 30.0;
	7441	 6291	 0.00021	 0.017518	 0.0	 720.000115	 720.000115	 720.000115	 1.046072	 0.0	 1	 -30.0	 30.0;
	1566	 5935	 0.000219	 0.017358	 0.0	 720.000115	 720.000115	 720.000115	 1.056355	 0.0	 1	 -30.0	 30.0;
	1566	 5935	 0.000219	 0.016973	 0.0	 720.000115	 720.000115	 720.000115	 1.056355	 0.0	 1	 -30.0	 30.0;
	3223	 785	 0.000295	 0.027995	 0.0	 599.999547	 599.999547	 599.999547	 0.979536	 0.0	 1	 -30.0	 30.0;
	3223	 785	 0.000277	 0.027486	 0.0	 599.999547	 599.999547	 599.999547	 0.979307	 0.0	 1	 -30.0	 30.0;
	3330	 7471	 0.000489	 0.032074	 0.0	 479.999638	 479.999638	 479.999638	 1.020618	 0.0	 1	 -30.0	 30.0;
	5528	 2828	 0.00018	 0.02129	 0.0	 720.000115	 720.000115	 720.000115	 1.033258	 0.0	 1	 -30.0	 30.0;
	980	 1618	 0.000366	 0.029147	 0.0	 599.999547	 599.999547	 599.999547	 0.988334	 0.0	 1	 -30.0	 30.0;
	980	 1618	 0.000366	 0.028067	 0.0	 599.999547	 599.999547	 599.999547	 0.993101	 0.0	 1	 -30.0	 30.0;
	980	 1618	 0.00042	 0.026331	 0.0	 599.999547	 599.999547	 599.999547	 1.013197	 0.0	 1	 -30.0	 30.0;
	4510	 1379	 0.000441	 0.01916	 0.0	 720.000115	 720.000115	 720.000115	 1.022456	 0.0	 1	 -30.0	 30.0;
	6734	 5566	 0.000391	 0.024766	 0.0	 539.999921	 539.999921	 539.999921	 1.035987	 0.0	 1	 -30.0	 30.0;
	6734	 5566	 0.000401	 0.024225	 0.0	 539.999921	 539.999921	 539.999921	 1.035987	 0.0	 1	 -30.0	 30.0;
	6734	 4226	 0.000408	 0.028237	 0.0	 539.999921	 539.999921	 539.999921	 1.026094	 0.0	 1	 -30.0	 30.0;
	6320	 4209	 0.000199	 0.018609	 0.0	 720.000115	 720.000115	 720.000115	 1.066843	 0.0	 1	 -30.0	 30.0;
	2448	 8128	 0.000196	 0.021597	 0.0	 720.000115	 720.000115	 720.000115	 1.016389	 0.0	 1	 -30.0	 30.0;
	2448	 8128	 0.000186	 0.022003	 0.0	 720.000115	 720.000115	 720.000115	 1.016389	 0.0	 1	 -30.0	 30.0;
	2580	 2991	 0.000186	 0.019718	 0.0	 720.000115	 720.000115	 720.000115	 1.016389	 0.0	 1	 -30.0	 30.0;
	4050	 1325	 0.000205	 0.022703	 0.0	 720.000115	 720.000115	 720.000115	 0.953272	 0.0	 1	 -30.0	 30.0;
	738	 7092	 0.000228	 0.021908	 0.0	 720.000115	 720.000115	 720.000115	 1.006865	 0.0	 1	 -30.0	 30.0;
	6740	 6923	 0.000322	 0.028734	 0.0	 599.999547	 599.999547	 599.999547	 1.04286	 0.0	 1	 -30.0	 30.0;
	6740	 8262	 0.000319	 0.026574	 0.0	 599.999547	 599.999547	 599.999547	 1.072735	 0.0	 1	 -30.0	 30.0;
	3264	 1127	 0.000289	 0.018298	 0.0	 720.000115	 720.000115	 720.000115	 1.008509	 0.0	 1	 -30.0	 30.0;
	3264	 1127	 0.000199	 0.02111	 0.0	 720.000115	 720.000115	 720.000115	 1.008509	 0.0	 1	 -30.0	 30.0;
	6974	 7526	 0.000196	 0.02119	 0.0	 720.000115	 720.000115	 720.000115	 1.016389	 0.0	 1	 -30.0	 30.0;
	6974	 7526	 0.000196	 0.021597	 0.0	 720.000115	 720.000115	 720.000115	 1.016389	 0.0	 1	 -30.0	 30.0;
	4103	 1369	 0.001097	 0.082091	 0.0	 240.000477	 240.000477	 240.000477	 1.052931	 0.0	 1	 -30.0	 30.0;
	4103	 1369	 0.000406	 0.048834	 0.0	 360.000386	 360.000386	 360.000386	 1.052632	 0.0	 1	 -30.0	 30.0;
	4103	 1369	 7.2e-05	 0.017798	 0.0	 720.000115	 720.000115	 720.000115	 1.056355	 0.0	 1	 -30.0	 30.0;
	4103	 1369	 0.000424	 0.04684	 0.0	 360.000386	 360.000386	 360.000386	 1.052632	 0.0	 1	 -30.0	 30.0;
	7487	 3716	 0.000224	 0.01875	 0.0	 720.000115	 720.000115	 720.000115	 1.016389	 0.0	 1	 -30.0	 30.0;
	7487	 3716	 0.000224	 0.018334	 0.0	 720.000115	 720.000115	 720.000115	 1.016389	 0.0	 1	 -30.0	 30.0;
	1165	 3896	 0.000379	 0.018492	 0.0	 720.000115	 720.000115	 720.000115	 1.052632	 0.0	 1	 -30.0	 30.0;
	1165	 3896	 0.000253	 0.019711	 0.0	 720.000115	 720.000115	 720.000115	 1.052632	 0.0	 1	 -30.0	 30.0;
	346	 8199	 0.000196	 0.016483	 0.0	 1080.000501	 1080.000501	 1080.000501	 1.006865	 0.0	 1	 -30.0	 30.0;
	346	 8199	 0.000186	 0.022421	 0.0	 720.000115	 720.000115	 720.000115	 1.006865	 0.0	 1	 -30.0	 30.0;
	6139	 3729	 0.00046	 0.030794	 0.0	 479.999638	 479.999638	 479.999638	 1.008509	 0.0	 1	 -30.0	 30.0;
	8352	 2202	 0.000695	 0.049098	 -0.0077	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	8352	 2202	 0.000355	 0.024893	 -0.01105	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	105	 2202	 0.000365	 0.024372	 -0.011029	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	2861	 7048	 0.000411	 0.023652	 -0.01075	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6588	 4474	 0.000386	 0.025673	 -0.001838	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	6588	 4474	 0.000344	 0.029336	 -0.002013	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	759	 4102	 0.000653	 0.052104	 -0.0077	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	759	 4102	 0.000767	 0.043531	 -0.00182	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	3130	 5549	 0.000323	 0.028314	 -0.002516	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3130	 5549	 0.000323	 0.025999	 -0.002352	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3130	 6585	 0.000365	 0.025478	 -0.002932	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	806	 5720	 0.00086	 0.039291	 -0.00222	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	653	 1561	 0.000355	 0.026586	 -0.012724	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	653	 1561	 0.000375	 0.026313	 -0.001904	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	5631	 2946	 0.000344	 0.023329	 -0.001411	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	5631	 2946	 0.000302	 0.026375	 -0.001379	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	8325	 2653	 0.000788	 0.04323	 -0.00201	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	8325	 2653	 0.000767	 0.04407	 -0.00201	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	1233	 5311	 0.000767	 0.043562	 -0.00157	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	1233	 5311	 0.000788	 0.041281	 -0.00138	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	1233	 5311	 0.000892	 0.040524	 -0.00123	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	2916	 4256	 0.000975	 0.043562	 -0.00821	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	2916	 4256	 0.000757	 0.042649	 -0.00905	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	4860	 2145	 0.000261	 0.030762	 -0.010678	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	4860	 2145	 0.000261	 0.030088	 -0.010678	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	4563	 5547	 0.000323	 0.026447	 -0.010864	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	4563	 8041	 0.000323	 0.026885	 -0.010722	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6774	 495	 0.000323	 0.02748	 -0.013074	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6774	 495	 0.000292	 0.028158	 -0.010678	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	495	 4550	 0.0	 0.008286	 0.0	 668.077215	 668.077215	 668.077215	 1.0	 0.69159	 1	 -30.0	 30.0;
	4981	 3474	 0.000736	 0.044526	 -0.009	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	2585	 8268	 0.00086	 0.039488	 -0.00194	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	2647	 5925	 0.000365	 0.024372	 -0.009573	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	2647	 5925	 0.000375	 0.023986	 -0.013775	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	4090	 6603	 0.000386	 0.025673	 -0.001816	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	2408	 1623	 0.000809	 0.042318	 -0.00206	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	3199	 5119	 0.000705	 0.042038	 -0.00174	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	3222	 330	 0.000334	 0.028022	 -0.002615	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3222	 1676	 0.000353	 0.022403	 -0.00391	 720.000115	 720.000115	 720.000115	 0.982143	 0.0	 1	 -30.0	 30.0;
	2155	 330	 0.000313	 0.026354	 -0.002516	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	2155	 330	 0.000323	 0.025478	 -0.00244	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	1717	 7032	 0.000344	 0.024622	 -0.001543	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	101	 7032	 0.000355	 0.024038	 -0.001685	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3180	 6607	 0.000881	 0.038244	 -0.00201	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	3180	 6607	 0.000757	 0.040959	 -0.00807	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	2803	 1900	 0.000354	 0.028765	 -0.00951	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	5648	 1900	 0.000354	 0.027114	 -0.01203	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	1980	 1900	 0.000695	 0.04748	 -0.00661	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	4205	 1467	 0.000323	 0.028314	 -0.002309	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	4205	 1467	 0.000323	 0.026354	 -0.001751	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	4205	 1467	 0.000323	 0.025696	 -0.001707	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	5076	 910	 0.000355	 0.027305	 -0.001783	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	5076	 910	 0.000355	 0.026666	 -0.009179	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	5076	 910	 0.000923	 0.037456	 -0.00171	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	5076	 910	 0.000788	 0.035217	 -0.00325	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	1090	 6776	 0.000323	 0.026739	 -0.001597	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	1090	 6776	 0.000323	 0.02749	 -0.001433	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	2248	 4626	 0.000313	 0.027324	 -0.013217	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	2248	 4626	 0.000313	 0.028074	 -0.011357	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	7103	 5015	 0.000601	 0.024984	 -0.00685	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	7103	 5015	 0.000715	 0.022797	 -0.00574	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	7103	 5015	 0.000344	 0.024893	 -0.009486	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	4522	 7218	 0.000365	 0.024163	 -0.002298	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	4522	 7218	 0.000344	 0.02385	 -0.00895	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	4555	 6679	 0.000757	 0.040182	 -0.00771	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	686	 3421	 0.000323	 0.028937	 -0.010525	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	3362	 6303	 0.000354	 0.026958	 -0.00928	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3362	 6303	 0.000778	 0.045656	 -0.00178	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	3362	 6303	 0.000695	 0.048932	 -0.00786	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	3362	 6303	 0.000302	 0.025926	 -0.010438	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6112	 7414	 0.000355	 0.027328	 -0.002484	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	6112	 7414	 0.000365	 0.027156	 -0.011182	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	8369	 5382	 0.000355	 0.024299	 -0.012538	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	7245	 729	 0.000375	 0.026313	 -0.002538	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	7245	 729	 0.000375	 0.025605	 -0.012112	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	2945	 1403	 0.000334	 0.026291	 -0.001707	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	2945	 1403	 0.000705	 0.046735	 -0.00703	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	1878	 3719	 0.000313	 0.026875	 -0.011794	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	1878	 3719	 0.000302	 0.027376	 -0.011794	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	4184	 4648	 0.000664	 0.044868	 -0.00859	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	1941	 4648	 0.000809	 0.044526	 -0.00642	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	5135	 5038	 0.00086	 0.034253	 -0.00325	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	5135	 5038	 0.000355	 0.024372	 -0.009311	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	2579	 1391	 0.000365	 0.023788	 -0.009683	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	4131	 6767	 0.000375	 0.023204	 -0.010799	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	4131	 6767	 0.000302	 0.026593	 -0.010678	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	1603	 3511	 0.000323	 0.029256	 -0.001958	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	1603	 3511	 0.000334	 0.029986	 -0.003195	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	1603	 3511	 0.000355	 0.030979	 -0.002341	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	2280	 4134	 0.000302	 0.025707	 -0.01267	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	2280	 4134	 0.000344	 0.025405	 -0.011247	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	2791	 5550	 0.00012	 0.010515	 0.0	 603.600307	 603.600307	 603.600307	 1.0	 6.90708	 1	 -30.0	 30.0;
	4610	 6934	 0.000365	 0.023715	 -0.010131	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	5478	 7864	 0.000365	 0.023517	 -0.001411	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	5478	 5012	 0.000334	 0.026812	 -0.001882	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	7692	 7976	 0.000695	 0.047253	 -0.00681	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	6830	 7976	 0.000778	 0.043759	 -0.00215	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	6823	 6868	 0.000313	 0.030636	 -0.002626	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	6823	 6868	 0.000313	 0.028286	 -0.003096	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	6823	 6868	 0.000344	 0.028115	 -0.001521	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	2286	 1349	 0.000902	 0.039425	 -0.00145	 599.999547	 599.999547	 599.999547	 0.982143	 0.0	 1	 -30.0	 30.0;
	2149	 7539	 0.000355	 0.024237	 -0.010164	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	7866	 1701	 0.000375	 0.023986	 -0.001915	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	7866	 1701	 0.000375	 0.023861	 -0.001969	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	1360	 527	 0.000819	 0.04153	 -0.00145	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	1360	 527	 0.000809	 0.042701	 -0.00271	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	1368	 2531	 0.000334	 0.028022	 -0.002407	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	7429	 844	 0.000632	 0.048237	 -0.00767	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	7429	 844	 0.000632	 0.045159	 -0.00813	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	7429	 844	 0.000715	 0.044039	 -0.00692	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	3569	 6170	 0.00074	 0.044479	 -0.00682	 360.000386	 360.000386	 360.000386	 0.986547	 0.0	 1	 -30.0	 30.0;
	3569	 3667	 0.00074	 0.043811	 -0.00745	 360.000386	 360.000386	 360.000386	 0.986547	 0.0	 1	 -30.0	 30.0;
	4039	 1897	 0.000375	 0.02385	 -0.014836	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	4039	 1897	 0.000365	 0.023267	 -0.010569	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	4039	 1897	 0.000323	 0.026739	 -0.000952	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	986	 6674	 0.000684	 0.047025	 -0.008	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	8259	 1983	 0.000313	 0.02748	 -0.0093	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	5943	 7681	 0.000323	 0.028554	 -0.002407	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	5943	 7681	 0.000302	 0.026437	 -0.002418	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6400	 6874	 0.000365	 0.02555	 -0.001794	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6400	 6874	 0.000344	 0.024893	 -0.009694	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6400	 8220	 0.000375	 0.024508	 -0.001794	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6251	 6154	 0.000778	 0.041157	 -0.00807	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	6251	 6154	 0.000923	 0.03702	 -0.00252	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	6251	 6154	 0.000302	 0.026593	 -0.010678	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	935	 6483	 0.000344	 0.029667	 -0.001926	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	935	 37	 0.000334	 0.02748	 -0.002134	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	4822	 6483	 0.000323	 0.030636	 -0.002134	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	4822	 37	 0.000323	 0.028526	 -0.001926	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	8361	 5654	 0.000344	 0.025332	 -0.009595	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	8361	 7517	 0.000334	 0.024674	 -0.012145	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	8361	 6207	 0.000344	 0.02457	 -0.00139	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3283	 6044	 0.000365	 0.023788	 -0.013709	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3951	 5958	 0.000365	 0.023601	 -0.001313	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3951	 5958	 0.000344	 0.02652	 -0.002615	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6814	 5958	 0.000344	 0.027272	 -0.002385	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6814	 5958	 0.000334	 0.027563	 -0.002637	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	8068	 6021	 0.000313	 0.030636	 -0.010678	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	8068	 6021	 0.000313	 0.028286	 -0.010646	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	4955	 4381	 0.000881	 0.036803	 -0.00289	 431.999937	 431.999937	 431.999937	 0.982143	 0.0	 1	 -30.0	 30.0;
	4955	 4381	 0.000902	 0.036668	 -0.00288	 433.200456	 433.200456	 433.200456	 0.982143	 0.0	 1	 -30.0	 30.0;
	4955	 4381	 0.000881	 0.034014	 -0.00297	 466.799852	 466.799852	 466.799852	 0.982143	 0.0	 1	 -30.0	 30.0;
	4954	 3446	 0.000365	 0.026027	 -0.013534	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	4954	 3446	 0.000386	 0.025673	 -0.001619	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	6578	 4087	 0.00012	 0.017443	 0.0	 699.564236	 699.564236	 699.564236	 1.0	 -11.03971	 1	 -30.0	 30.0;
	5582	 49	 0.00017	 0.00629	 0.0	 1341.59979	 1341.59979	 1341.59979	 1.0	 -3.738837	 1	 -30.0	 30.0;
	5582	 6175	 0.000664	 0.047107	 -0.00615	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	1332	 1147	 0.000313	 0.028314	 -0.001718	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	1332	 1147	 0.000334	 0.025707	 -0.00233	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	1332	 1415	 0.000344	 0.025478	 -0.001871	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6837	 1415	 0.000344	 0.027236	 -0.01198	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	6837	 1415	 0.000375	 0.026518	 -0.002593	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	6261	 4436	 0.000386	 0.02646	 -0.001422	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	4765	 3	 0.000788	 0.040317	 -0.00684	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	6821	 506	 0.000323	 0.025863	 -0.011794	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	679	 3936	 1e-05	 0.041006	 0.0	 1053.599647	 1053.599647	 1053.599647	 1.0	 -42.80168	 1	 -30.0	 30.0;
	3770	 6463	 0.000334	 0.030306	 -0.012166	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	3770	 6463	 0.000302	 0.030636	 -0.012615	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	6769	 3319	 0.00011	 0.015095	 0.0	 590.399933	 590.399933	 590.399933	 1.0	 8.42776	 1	 -30.0	 30.0;
	7453	 5944	 0.000344	 0.024841	 -0.011783	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	7453	 5944	 0.000365	 0.025029	 -0.014201	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	7453	 5944	 0.000355	 0.024101	 -0.012112	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3755	 144	 0.000344	 0.02385	 -0.012177	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3755	 144	 0.000411	 0.02313	 -0.01075	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3755	 144	 0.000829	 0.042764	 -0.00201	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	5297	 8365	 0.000705	 0.04748	 -0.00871	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	5297	 1316	 0.000323	 0.029986	 -0.001991	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	5297	 1316	 0.000302	 0.029952	 -0.002319	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	7493	 4873	 0.000746	 0.041064	 -0.00233	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	7493	 4873	 0.000881	 0.042214	 -0.00159	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	2143	 7261	 0.00086	 0.041209	 -0.00184	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	2143	 7261	 0.000912	 0.038669	 -0.0021	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	7352	 151	 0.000375	 0.026244	 -0.001772	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	7352	 151	 0.000375	 0.025457	 -0.010011	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	3166	 1052	 0.000302	 0.029096	 -0.001346	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	4305	 3140	 0.000302	 0.029667	 -0.010678	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	1559	 6987	 0.000334	 0.027563	 -0.011915	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	1559	 6987	 0.000323	 0.028074	 -0.013392	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	818	 7423	 0.000736	 0.041064	 -0.00163	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	7554	 7423	 0.001234	 0.040109	 -0.00191	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	7554	 7423	 0.000757	 0.043209	 -0.00937	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	7254	 6108	 0.000323	 0.026586	 -0.010394	 957.600212	 957.600212	 957.600212	 0.93617	 0.0	 1	 -30.0	 30.0;
	3823	 255	 0.000788	 0.040296	 -0.00613	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	3823	 255	 0.000912	 0.040514	 -0.00706	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	5874	 3183	 0.000798	 0.042183	 -0.00162	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	5874	 3183	 0.000778	 0.043147	 -0.00187	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	6644	 3857	 0.000323	 0.027793	 -0.002155	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6644	 3857	 0.000302	 0.027918	 -0.012626	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6644	 3857	 0.000302	 0.025926	 -0.013162	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6279	 2679	 0.000344	 0.024956	 -0.012068	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6279	 2679	 0.000355	 0.024435	 -0.011291	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3485	 278	 0.000386	 0.026392	 -0.001718	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	5126	 278	 0.000365	 0.025525	 -0.009256	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	1580	 102	 0.000344	 0.029986	 -0.002451	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	1580	 102	 0.000323	 0.029838	 -0.001827	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	2467	 5193	 0.000323	 0.02748	 -0.013074	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	2467	 5193	 0.000313	 0.028001	 -0.013074	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	389	 2952	 0.000179	 0.012988	 -0.025464	 1282.799367	 1282.799367	 1282.799367	 1.03004	 0.0	 1	 -30.0	 30.0;
	389	 8027	 0.000198	 0.012724	 -0.025464	 1282.799367	 1282.799367	 1282.799367	 1.03004	 0.0	 1	 -30.0	 30.0;
	389	 2174	 0.000207	 0.01247	 -0.025464	 1282.799367	 1282.799367	 1282.799367	 1.03004	 0.0	 1	 -30.0	 30.0;
	389	 1733	 0.000207	 0.012206	 -0.025464	 1282.799367	 1282.799367	 1282.799367	 1.03004	 0.0	 1	 -30.0	 30.0;
	389	 3100	 0.000217	 0.012912	 -0.025464	 1282.799367	 1282.799367	 1282.799367	 0.990991	 0.0	 1	 -30.0	 30.0;
	389	 5073	 0.000217	 0.012627	 -0.025464	 1282.799367	 1282.799367	 1282.799367	 0.990991	 0.0	 1	 -30.0	 30.0;
	389	 2831	 0.000198	 0.014317	 -0.025464	 1282.799367	 1282.799367	 1282.799367	 0.990991	 0.0	 1	 -30.0	 30.0;
	389	 2831	 0.000189	 0.014592	 -0.025464	 1282.799367	 1282.799367	 1282.799367	 0.990991	 0.0	 1	 -30.0	 30.0;
	389	 7128	 0.000354	 0.02725	 -0.01155	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	871	 7702	 0.000628	 0.042428	 -0.00827	 360.000386	 360.000386	 360.000386	 1.009174	 0.0	 1	 -30.0	 30.0;
	871	 7702	 0.000726	 0.044039	 -0.00722	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	3254	 5358	 0.000365	 0.024893	 -0.001586	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3254	 5358	 0.000438	 0.02457	 -0.001958	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3254	 5358	 0.000365	 0.023986	 -0.009486	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6497	 5369	 0.000375	 0.023267	 -0.014431	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	6497	 5369	 0.000323	 0.026375	 -0.011674	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	1646	 2237	 0.000334	 0.029735	 -0.012713	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	1646	 2237	 0.000313	 0.030237	 -0.012079	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	3038	 1944	 0.000767	 0.044049	 -0.00236	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	3038	 1944	 0.000302	 0.026072	 -0.002188	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3038	 1944	 0.00085	 0.039892	 -0.00134	 360.000386	 360.000386	 360.000386	 0.982143	 0.0	 1	 -30.0	 30.0;
	3164	 8166	 0.000344	 0.024956	 -0.013447	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	8067	 8166	 0.000334	 0.026666	 -0.01221	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	1908	 730	 0.000365	 0.023788	 -0.010153	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	1908	 730	 0.000365	 0.023465	 -0.001663	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	200	 1405	 0.000334	 0.026447	 -0.011029	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	7566	 4888	 0.000323	 0.027042	 -0.011773	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	7566	 4888	 0.000313	 0.02748	 -0.008797	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	7566	 4888	 0.000302	 0.028314	 -0.001893	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	7566	 6808	 0.000323	 0.025853	 -0.002254	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	7566	 6808	 0.000365	 0.026197	 -0.002155	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	7566	 6808	 0.000365	 0.025165	 -0.002221	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3644	 4415	 0.000355	 0.024237	 -0.010274	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	3644	 1836	 0.000375	 0.024247	 -0.001608	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	1987	 4415	 0.000365	 0.023267	 -0.009486	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	1987	 1836	 0.000342	 0.023139	 -0.01616	 720.000115	 720.000115	 720.000115	 0.982143	 0.0	 1	 -30.0	 30.0;
	1496	 6438	 0.000344	 0.026666	 -0.002287	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	1496	 623	 0.000334	 0.027021	 -0.002254	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	734	 6438	 0.000302	 0.027615	 -0.002418	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	734	 623	 0.000313	 0.026135	 -0.002221	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	4180	 7987	 0.000365	 0.025905	 -0.002626	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	4180	 7987	 0.000355	 0.025238	 -0.002232	 720.000115	 720.000115	 720.000115	 0.979227	 0.0	 1	 -30.0	 30.0;
	2648	 3839	 0.000334	 0.026814	 -0.010678	 720.000115	 720.000115	 720.000115	 0.93617	 0.0	 1	 -30.0	 30.0;
	1040	 5965	 0.001242	 0.083148	 -0.00264	 409.199948	 409.199948	 409.199948	 0.945477	 0.0	 1	 -30.0	 30.0;
	1040	 3766	 0.0017	 0.090508	 -0.00122	 374.400033	 374.400033	 374.400033	 0.945477	 0.0	 1	 -30.0	 30.0;
	1765	 3133	 0.001648	 0.071935	 -0.00389	 211.199867	 211.199867	 211.199867	 1.018676	 0.0	 1	 -30.0	 30.0;
	1765	 5847	 0.001742	 0.073131	 -0.00388	 119.999909	 119.999909	 119.999909	 0.999334	 0.0	 1	 -30.0	 30.0;
	146	 7173	 0.000914	 0.088676	 -0.0012	 202.800183	 202.800183	 202.800183	 0.986842	 0.0	 1	 -30.0	 30.0;
	146	 4672	 0.000955	 0.085404	 -0.00187	 265.200188	 265.200188	 265.200188	 0.986842	 0.0	 1	 -30.0	 30.0;
	1634	 3531	 0.001479	 0.088626	 -0.00123	 235.199717	 235.199717	 235.199717	 0.986842	 0.0	 1	 -30.0	 30.0;
	1634	 3835	 0.00153	 0.084928	 -0.00123	 274.800391	 274.800391	 274.800391	 0.986842	 0.0	 1	 -30.0	 30.0;
	6552	 5556	 0.00151	 0.102577	 -0.00122	 178.799674	 178.799674	 178.799674	 0.945477	 0.0	 1	 -30.0	 30.0;
	7406	 2288	 0.000884	 0.108054	 -0.00173	 163.200166	 163.200166	 163.200166	 0.945477	 0.0	 1	 -30.0	 30.0;
	7564	 5041	 0.001099	 0.069265	 -0.00245	 406.799568	 406.799568	 406.799568	 1.018676	 0.0	 1	 -30.0	 30.0;
	11	 2654	 0.000904	 0.088121	 -0.00177	 249.600022	 249.600022	 249.600022	 0.986842	 0.0	 1	 -30.0	 30.0;
	3958	 2590	 0.001386	 0.094158	 -0.00123	 391.20006	 391.20006	 391.20006	 0.986842	 0.0	 1	 -30.0	 30.0;
	3958	 2590	 0.001355	 0.096007	 -0.00123	 384.000237	 384.000237	 384.000237	 0.986842	 0.0	 1	 -30.0	 30.0;
	4534	 1061	 0.001456	 0.098925	 -0.00123	 266.400049	 266.400049	 266.400049	 0.962773	 0.0	 1	 -30.0	 30.0;
	4534	 1061	 0.001424	 0.100867	 -0.00123	 261.599947	 261.599947	 261.599947	 0.962773	 0.0	 1	 -30.0	 30.0;
	1802	 1628	 0.001442	 0.086424	 -0.00122	 119.999909	 119.999909	 119.999909	 0.999334	 0.0	 1	 -30.0	 30.0;
	1031	 7653	 0.001317	 0.070127	 -0.00122	 119.999909	 119.999909	 119.999909	 1.074114	 0.0	 1	 -30.0	 30.0;
	547	 2373	 0.000991	 0.083602	 -0.00112	 280.799696	 280.799696	 280.799696	 0.999334	 0.0	 1	 -30.0	 30.0;
	547	 2373	 0.001272	 0.097228	 -0.00122	 242.399541	 242.399541	 242.399541	 0.999334	 0.0	 1	 -30.0	 30.0;
	547	 5262	 0.000968	 0.088836	 -0.0012	 227.999894	 227.999894	 227.999894	 0.974659	 0.0	 1	 -30.0	 30.0;
	547	 5262	 0.001537	 0.08896	 -0.00123	 227.999894	 227.999894	 227.999894	 0.974659	 0.0	 1	 -30.0	 30.0;
	547	 5262	 0.0018	 0.078579	 -0.0039	 258.000365	 258.000365	 258.000365	 0.974659	 0.0	 1	 -30.0	 30.0;
	392	 2334	 0.001071	 0.079233	 -0.00234	 292.800279	 292.800279	 292.800279	 0.999334	 0.0	 1	 -30.0	 30.0;
	5337	 3562	 0.001301	 0.088365	 -0.00123	 119.999909	 119.999909	 119.999909	 1.018676	 0.0	 1	 -30.0	 30.0;
	5337	 4362	 0.001436	 0.082886	 -0.00389	 212.400386	 212.400386	 212.400386	 1.018676	 0.0	 1	 -30.0	 30.0;
	5337	 3304	 0.001701	 0.102782	 -0.0039	 370.799792	 370.799792	 370.799792	 0.923361	 0.0	 1	 -30.0	 30.0;
	8026	 7940	 0.001352	 0.091819	 -0.00122	 188.399878	 188.399878	 188.399878	 0.999334	 0.0	 1	 -30.0	 30.0;
	1397	 1796	 0.001737	 0.085791	 -0.00391	 266.400049	 266.400049	 266.400049	 0.962773	 0.0	 1	 -30.0	 30.0;
	1397	 2879	 0.001331	 0.087657	 -0.00128	 304.800204	 304.800204	 304.800204	 0.945477	 0.0	 1	 -30.0	 30.0;
	1397	 1796	 0.001877	 0.07879	 -0.00391	 290.399899	 290.399899	 290.399899	 0.962773	 0.0	 1	 -30.0	 30.0;
	1397	 4176	 0.001672	 0.089295	 -0.00391	 119.999909	 119.999909	 119.999909	 0.962773	 0.0	 1	 -30.0	 30.0;
	1397	 2879	 0.001421	 0.10862	 -0.00122	 245.999781	 245.999781	 245.999781	 0.945477	 0.0	 1	 -30.0	 30.0;
	1397	 4176	 0.001338	 0.09699	 -0.00123	 119.999909	 119.999909	 119.999909	 0.962773	 0.0	 1	 -30.0	 30.0;
	2780	 4987	 0.001224	 0.093571	 -0.00123	 260.399428	 260.399428	 260.399428	 1.018676	 0.0	 1	 -30.0	 30.0;
	1826	 2306	 0.001667	 0.092522	 -0.00122	 411.600328	 411.600328	 411.600328	 0.945477	 0.0	 1	 -30.0	 30.0;
	1826	 977	 0.0017	 0.090508	 -0.00122	 421.199873	 421.199873	 421.199873	 0.945477	 0.0	 1	 -30.0	 30.0;
	2600	 2031	 0.001177	 0.089984	 -0.00123	 218.39969	 218.39969	 218.39969	 1.038781	 0.0	 1	 -30.0	 30.0;
	5512	 8252	 0.000975	 0.083762	 -0.00187	 388.79968	 388.79968	 388.79968	 0.986842	 0.0	 1	 -30.0	 30.0;
	5512	 2083	 0.001221	 0.074424	 -0.00112	 469.200232	 469.200232	 469.200232	 0.974659	 0.0	 1	 -30.0	 30.0;
	4752	 7560	 0.001205	 0.088315	 -0.00123	 344.399562	 344.399562	 344.399562	 1.038781	 0.0	 1	 -30.0	 30.0;
	2283	 7600	 0.000951	 0.081618	 -0.00112	 289.200038	 289.200038	 289.200038	 0.999334	 0.0	 1	 -30.0	 30.0;
	2283	 5400	 0.0011	 0.085679	 -0.00113	 378.000274	 378.000274	 378.000274	 0.962773	 0.0	 1	 -30.0	 30.0;
	2283	 5400	 0.000895	 0.099866	 -0.00129	 324.000611	 324.000611	 324.000611	 0.962773	 0.0	 1	 -30.0	 30.0;
	4086	 2561	 0.0	 0.064	 0.0	 112.941283	 112.941283	 112.941283	 1.0625	 0.0	 1	 -30.0	 30.0;
	4086	 2561	 0.0	 0.06267	 0.0	 112.941283	 112.941283	 112.941283	 1.0625	 0.0	 1	 -30.0	 30.0;
	4086	 2561	 0.0	 0.06134	 0.0	 112.941283	 112.941283	 112.941283	 1.0625	 0.0	 1	 -30.0	 30.0;
	1435	 4177	 0.0	 0.06295	 0.0	 111.62818	 111.62818	 111.62818	 1.075	 0.0	 1	 -30.0	 30.0;
	1435	 4177	 0.0	 0.07135	 0.0	 111.62818	 111.62818	 111.62818	 1.075	 0.0	 1	 -30.0	 30.0;
	2919	 1829	 0.0	 0.04729	 0.0	 286.323795	 286.323795	 286.323795	 0.972326	 0.0	 1	 -30.0	 30.0;
	2919	 1829	 0.0	 0.0482	 0.0	 281.38745	 281.38745	 281.38745	 0.972326	 0.0	 1	 -30.0	 30.0;
	2919	 1829	 0.0	 0.04911	 0.0	 276.451105	 276.451105	 276.451105	 0.972326	 0.0	 1	 -30.0	 30.0;
	3063	 5194	 0.0	 0.06744	 0.0	 125.454622	 125.454622	 125.454622	 0.956522	 0.0	 1	 -30.0	 30.0;
	6946	 668	 0.0	 0.145661	 0.0	 114.049761	 114.049761	 114.049761	 1.052174	 0.0	 1	 -30.0	 30.0;
	8149	 747	 0.0	 0.03024	 0.0	 149.339568	 149.339568	 149.339568	 1.052632	 0.0	 1	 -30.0	 30.0;
	8149	 747	 0.0	 0.029729	 0.0	 151.62016	 151.62016	 151.62016	 1.052632	 0.0	 1	 -30.0	 30.0;
	747	 6451	 0.0	 0.07191	 0.0	 225.802926	 225.802926	 225.802926	 0.8875	 0.0	 1	 -30.0	 30.0;
	747	 6451	 0.0	 0.0815	 0.0	 198.760486	 198.760486	 198.760486	 0.8875	 0.0	 1	 -30.0	 30.0;
	8238	 2552	 0.0	 0.07843	 0.0	 133.818315	 133.818315	 133.818315	 0.896739	 0.0	 1	 -30.0	 30.0;
	2266	 4755	 0.0	 0.03389	 0.0	 369.093792	 369.093792	 369.093792	 1.052632	 0.0	 1	 -30.0	 30.0;
	2266	 4755	 0.0	 0.035419	 0.0	 353.161903	 353.161903	 353.161903	 1.052632	 0.0	 1	 -30.0	 30.0;
	4755	 7183	 0.0	 0.07323	 0.0	 118.074804	 118.074804	 118.074804	 1.016304	 0.0	 1	 -30.0	 30.0;
	4755	 7183	 0.0	 0.07177	 0.0	 118.074804	 118.074804	 118.074804	 1.016304	 0.0	 1	 -30.0	 30.0;
	4992	 116	 0.0	 0.06789	 0.0	 127.042844	 127.042844	 127.042844	 0.944565	 0.0	 1	 -30.0	 30.0;
	4992	 116	 0.0	 0.06524	 0.0	 127.042844	 127.042844	 127.042844	 0.944565	 0.0	 1	 -30.0	 30.0;
	4992	 116	 0.0	 0.06385	 0.0	 127.042844	 127.042844	 127.042844	 0.944565	 0.0	 1	 -30.0	 30.0;
	2401	 5072	 0.0	 0.04033	 0.0	 167.653408	 167.653408	 167.653408	 1.052174	 0.0	 1	 -30.0	 30.0;
	4693	 3493	 0.0	 0.07024	 0.0	 114.049761	 114.049761	 114.049761	 1.052173	 0.0	 1	 -30.0	 30.0;
	4693	 3493	 0.0	 0.07161	 0.0	 114.049761	 114.049761	 114.049761	 1.052173	 0.0	 1	 -30.0	 30.0;
	5608	 778	 0.0	 0.06784	 0.0	 118.588842	 118.588842	 118.588842	 1.0119	 0.0	 1	 -30.0	 30.0;
	2910	 7994	 0.0	 0.071916	 0.0	 119.999875	 119.999875	 119.999875	 0.928269	 0.0	 1	 -30.0	 30.0;
	6356	 4169	 0.0	 0.07323	 0.0	 119.480502	 119.480502	 119.480502	 1.004348	 0.0	 1	 -30.0	 30.0;
	6356	 4169	 0.0	 0.07177	 0.0	 119.480502	 119.480502	 119.480502	 1.004348	 0.0	 1	 -30.0	 30.0;
	6424	 1764	 0.0	 0.0447	 0.0	 114.049968	 114.049968	 114.049968	 1.052174	 0.0	 1	 -30.0	 30.0;
	6424	 1764	 0.0	 0.04377	 0.0	 114.049968	 114.049968	 114.049968	 1.052174	 0.0	 1	 -30.0	 30.0;
	6424	 1764	 0.0	 0.04123	 0.0	 114.049968	 114.049968	 114.049968	 1.052174	 0.0	 1	 -30.0	 30.0;
	2170	 7259	 0.0	 0.06295	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	2170	 7259	 0.0	 0.07135	 0.0	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	2249	 161	 0.0	 0.07014	 0.0	 127.042844	 127.042844	 127.042844	 0.944565	 0.0	 1	 -30.0	 30.0;
	2249	 161	 0.0	 0.07149	 0.0	 127.042844	 127.042844	 127.042844	 0.944565	 0.0	 1	 -30.0	 30.0;
	1301	 4023	 0.0	 0.034531	 0.0	 113.683363	 113.683363	 113.683363	 1.055562	 0.0	 1	 -30.0	 30.0;
	1301	 6219	 0.0	 0.04656	 0.0	 239.317287	 239.317287	 239.317287	 1.007866	 0.0	 1	 -30.0	 30.0;
	1301	 6219	 0.0	 0.04563	 0.0	 244.079872	 244.079872	 244.079872	 1.007866	 0.0	 1	 -30.0	 30.0;
	1654	 7628	 0.000229	 0.01234	 -0.016755	 1492.674025	 1492.674025	 1492.674025	 0.884318	 0.0	 1	 -30.0	 30.0;
	1654	 7628	 0.000229	 0.0122	 -0.016755	 1518.193628	 1518.193628	 1518.193628	 0.869455	 0.0	 1	 -30.0	 30.0;
	7729	 2571	 0.001485	 0.065805	 -0.00413	 300.000103	 300.000103	 300.000103	 0.956938	 0.0	 1	 -30.0	 30.0;
	7729	 2571	 0.001583	 0.06586	 -0.00413	 300.000103	 300.000103	 300.000103	 0.956938	 0.0	 1	 -30.0	 30.0;
	4802	 2571	 0.00175	 0.070701	 -0.002893	 201.599698	 201.599698	 201.599698	 0.952381	 0.0	 1	 -30.0	 30.0;
	4802	 2571	 0.00169	 0.0715	 -0.002893	 201.599698	 201.599698	 201.599698	 0.952381	 0.0	 1	 -30.0	 30.0;
	6116	 5994	 0.001228	 0.060916	 -0.004443	 300.000103	 300.000103	 300.000103	 1.072151	 0.0	 1	 -30.0	 30.0;
	6116	 5994	 0.00116	 0.063798	 -0.00194	 300.000103	 300.000103	 300.000103	 1.062377	 0.0	 1	 -30.0	 30.0;
	6116	 5994	 0.00113	 0.059295	 -0.00194	 300.000103	 300.000103	 300.000103	 1.062171	 0.0	 1	 -30.0	 30.0;
	4547	 5994	 0.00177	 0.06853	 -0.002893	 326.417584	 326.417584	 326.417584	 0.838191	 0.0	 1	 -30.0	 30.0;
	6761	 1979	 0.001363	 0.063835	 -0.004335	 300.000103	 300.000103	 300.000103	 0.992489	 0.0	 1	 -30.0	 30.0;
	6761	 1979	 0.001457	 0.067155	 -0.004335	 300.000103	 300.000103	 300.000103	 0.968502	 0.0	 1	 -30.0	 30.0;
	6966	 1979	 0.00193	 0.06377	 -0.002893	 195.216329	 195.216329	 195.216329	 0.983524	 0.0	 1	 -30.0	 30.0;
	6966	 1979	 0.00194	 0.06188	 -0.002893	 195.216329	 195.216329	 195.216329	 0.983524	 0.0	 1	 -30.0	 30.0;
	7904	 4469	 0.00045	 0.02807	 -0.009065	 598.499556	 598.499556	 598.499556	 1.002506	 0.0	 1	 -30.0	 30.0;
	7904	 1953	 0.00042	 0.028021	 -0.000884	 598.499556	 598.499556	 598.499556	 1.002506	 0.0	 1	 -30.0	 30.0;
	7780	 5102	 0.001208	 0.06631	 -0.004443	 300.000103	 300.000103	 300.000103	 1.030783	 0.0	 1	 -30.0	 30.0;
	7780	 5102	 0.001228	 0.066264	 -0.004443	 300.000103	 300.000103	 300.000103	 1.030783	 0.0	 1	 -30.0	 30.0;
	5306	 2589	 0.00047	 0.026469	 -0.009065	 598.499556	 598.499556	 598.499556	 1.002506	 0.0	 1	 -30.0	 30.0;
	8119	 6487	 0.00186	 0.06826	 -0.002893	 229.064724	 229.064724	 229.064724	 0.838191	 0.0	 1	 -30.0	 30.0;
	514	 130	 0.001431	 0.068667	 -0.00413	 300.000103	 300.000103	 300.000103	 0.956938	 0.0	 1	 -30.0	 30.0;
	514	 130	 0.001529	 0.068787	 -0.00413	 300.000103	 300.000103	 300.000103	 0.956938	 0.0	 1	 -30.0	 30.0;
	2951	 130	 0.00193	 0.06377	 -0.002893	 201.599698	 201.599698	 201.599698	 0.952381	 0.0	 1	 -30.0	 30.0;
	2951	 130	 0.00194	 0.06188	 -0.002893	 201.599698	 201.599698	 201.599698	 0.952381	 0.0	 1	 -30.0	 30.0;
	3052	 4670	 0.0	 0.00898	 0.0	 527.999996	 527.999996	 527.999996	 0.0	 0.0	 1	 -30.0	 30.0;
	2336	 5745	 0.0	 0.00433	 -0.00549	 180.000193	 180.000193	 180.000193	 0.0	 0.0	 1	 -30.0	 30.0;
	5745	 4384	 0.007955	 0.151636	 -0.004741	 180.000193	 180.000193	 180.000193	 0.929293	 0.0	 1	 -30.0	 30.0;
	6388	 363	 0.000271	 0.030694	 -0.016	 479.999638	 479.999638	 479.999638	 1.052632	 0.0	 1	 -30.0	 30.0;
	6388	 363	 0.000271	 0.02842	 -0.016	 479.999638	 479.999638	 479.999638	 1.052632	 0.0	 1	 -30.0	 30.0;
	2007	 608	 0.00064	 0.0518	 -0.006678	 221.999931	 221.999931	 221.999931	 0.0	 0.0	 1	 -30.0	 30.0;
	8178	 6540	 0.00072	 0.05075	 -0.006678	 221.999931	 221.999931	 221.999931	 0.0	 0.0	 1	 -30.0	 30.0;
	1608	 7405	 0.0	 0.23657	 0.0	 72.000001	 72.000001	 72.000001	 0.0	 0.0	 1	 -30.0	 30.0;
	7735	 6051	 0.0	 0.020113	 0.0	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	7735	 7912	 0.0	 0.019669	 0.0	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	3242	 6005	 0.000326	 0.028508	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	3242	 6005	 0.000316	 0.031545	 0.0	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	8291	 3147	 0.000355	 0.023171	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	2498	 1335	 0.000296	 0.032897	 0.0	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	2498	 1335	 0.000296	 0.030461	 0.0	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	2105	 1	 5.9e-05	 0.022767	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	978	 5635	 0.000335	 0.029237	 0.0	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	5217	 8235	 0.000385	 0.027846	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	3536	 6226	 0.000444	 0.020064	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	7590	 42	 0.00033	 0.02558	 -0.016	 479.999638	 479.999638	 479.999638	 1.0	 0.0	 1	 -30.0	 30.0;
	6932	 5186	 0.0	 0.026909	 0.0	 126.000288	 126.000288	 126.000288	 0.0	 0.0	 1	 -30.0	 30.0;
	6628	 6838	 0.000385	 0.022737	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	2790	 642	 0.000375	 0.022441	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	7189	 5561	 -0.002742	 0.00908	 0.0	 527.999996	 527.999996	 527.999996	 0.0	 0.0	 1	 -30.0	 30.0;
	7189	 2685	 -0.00268	 0.00837	 0.0	 527.999996	 527.999996	 527.999996	 0.0	 0.0	 1	 -30.0	 30.0;
	7189	 6236	 -0.00304	 0.00824	 0.0	 527.999996	 527.999996	 527.999996	 0.0	 0.0	 1	 -30.0	 30.0;
	6526	 4902	 -0.003927	 0.00795	 0.0	 527.999996	 527.999996	 527.999996	 0.0	 0.0	 1	 -30.0	 30.0;
	6526	 5671	 -0.00401	 0.00794	 0.0	 527.999996	 527.999996	 527.999996	 0.0	 0.0	 1	 -30.0	 30.0;
	4194	 8172	 0.0	 0.00765	 0.0	 527.999996	 527.999996	 527.999996	 0.0	 0.0	 1	 -30.0	 30.0;
	4194	 1410	 0.0	 0.00748	 0.0	 527.999996	 527.999996	 527.999996	 0.0	 0.0	 1	 -30.0	 30.0;
	6672	 8318	 -0.000111	 0.00565	 -0.012274	 408.000087	 408.000087	 408.000087	 0.0	 0.0	 1	 -30.0	 30.0;
	6672	 3669	 -0.000339	 0.00645	 -0.012274	 408.000087	 408.000087	 408.000087	 0.0	 0.0	 1	 -30.0	 30.0;
	6672	 5299	 -0.000332	 0.00657	 -0.012274	 408.000087	 408.000087	 408.000087	 0.0	 0.0	 1	 -30.0	 30.0;
	6672	 4005	 -0.000118	 0.00525	 -0.012274	 408.000087	 408.000087	 408.000087	 0.0	 0.0	 1	 -30.0	 30.0;
	4399	 313	 9.8e-05	 0.060488	 0.0	 455.999787	 455.999787	 455.999787	 0.0	 0.0	 1	 -30.0	 30.0;
	4399	 2934	 8e-05	 0.00811	 0.0	 527.999996	 527.999996	 527.999996	 0.0	 0.0	 1	 -30.0	 30.0;
	4399	 4543	 -0.003927	 0.00835	 0.0	 527.999996	 527.999996	 527.999996	 0.0	 0.0	 1	 -30.0	 30.0;
	2371	 7033	 0.0	 0.028951	 0.0	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	2371	 3075	 0.0	 0.02833	 0.0	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	88	 2750	 0.000424	 0.020212	 0.0	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	4153	 1592	 0.00128	 0.05539	 -0.00429	 159.599856	 159.599856	 159.599856	 0.0	 0.0	 1	 -30.0	 30.0;
	4153	 5060	 0.00126	 0.056469	 -0.00429	 159.599856	 159.599856	 159.599856	 0.0	 0.0	 1	 -30.0	 30.0;
	4153	 3711	 0.00123	 0.05756	 -0.00429	 159.599856	 159.599856	 159.599856	 0.0	 0.0	 1	 -30.0	 30.0;
	1336	 263	 0.0	 0.046831	 0.0	 180.000193	 180.000193	 180.000193	 0.0	 0.0	 1	 -30.0	 30.0;
	2842	 688	 0.0	 0.03197	 0.0	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	4647	 6443	 0.0	 0.027151	 0.0	 459.496036	 459.496036	 459.496036	 1.044622	 0.0	 1	 -30.0	 30.0;
	3364	 838	 0.0	 0.0197	 0.0	 69.600141	 69.600141	 69.600141	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 3900	 0.000335	 0.028458	 0.0	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	6570	 3900	 0.000375	 0.027846	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	6863	 1064	 0.00073	 0.01489	 -0.002306	 75.599792	 75.599792	 75.599792	 0.0	 0.0	 1	 -30.0	 30.0;
	8057	 7392	 0.0	 0.00864	 0.0	 527.999996	 527.999996	 527.999996	 0.0	 0.0	 1	 -30.0	 30.0;
	8057	 1242	 0.0	 0.00881	 0.0	 527.999996	 527.999996	 527.999996	 0.0	 0.0	 1	 -30.0	 30.0;
	6513	 1863	 0.000326	 0.028961	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	2908	 5507	 0.000296	 0.025084	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	1112	 6796	 0.000326	 0.025765	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	1112	 6796	 0.000375	 0.020301	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	1112	 6796	 0.000345	 0.021109	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	2818	 112	 0.000385	 0.02101	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	1468	 6889	 0.000424	 0.019472	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	1468	 6889	 0.000434	 0.019048	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	5730	 3959	 0.000326	 0.025637	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	5730	 3959	 0.000355	 0.026564	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	597	 5022	 0.000355	 0.021553	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	597	 5022	 0.000128	 0.022007	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	756	 4253	 6e-05	 0.008289	 0.0	 1956.0003	 1956.0003	 1956.0003	 0.993813	 6.37679	 1	 -30.0	 30.0;
	3134	 4253	 7e-05	 0.007859	 0.0	 1956.0003	 1956.0003	 1956.0003	 0.995845	 5.22451	 1	 -30.0	 30.0;
	4253	 942	 0.000395	 0.021454	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	3776	 2985	 -0.000388	 0.0074	 -0.009168	 335.999878	 335.999878	 335.999878	 0.0	 0.0	 1	 -30.0	 30.0;
	2119	 4602	 -0.000402	 0.00724	 -0.009168	 335.999878	 335.999878	 335.999878	 0.0	 0.0	 1	 -30.0	 30.0;
	4659	 1477	 -0.000589	 0.01411	 -0.009168	 335.999878	 335.999878	 335.999878	 0.0	 0.0	 1	 -30.0	 30.0;
	3040	 7212	 -0.00036	 0.00803	 -0.009168	 335.999878	 335.999878	 335.999878	 0.0	 0.0	 1	 -30.0	 30.0;
	7481	 5773	 0.0	 0.040449	 0.0	 552.000505	 552.000505	 552.000505	 0.956938	 0.0	 1	 -30.0	 30.0;
	3611	 4984	 0.000345	 0.026071	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	2387	 7419	 0.0	 0.00046	 0.0	 371.999653	 371.999653	 371.999653	 0.0	 0.0	 1	 -30.0	 30.0;
	2387	 6269	 0.0	 0.00043	 0.0	 371.999653	 371.999653	 371.999653	 0.0	 0.0	 1	 -30.0	 30.0;
	790	 1708	 0.000375	 0.022007	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	857	 6710	 0.000385	 0.020196	 -0.014264	 479.999638	 479.999638	 479.999638	 0.993901	 0.0	 1	 -30.0	 30.0;
	4864	 6409	 0.000375	 0.026624	 -0.014264	 479.999638	 479.999638	 479.999638	 0.993901	 0.0	 1	 -30.0	 30.0;
	4020	 1295	 0.000425	 0.021208	 0.0	 479.999638	 479.999638	 479.999638	 0.993901	 0.0	 1	 -30.0	 30.0;
	7358	 2425	 0.000466	 0.020185	 -0.014264	 479.999638	 479.999638	 479.999638	 0.993901	 0.0	 1	 -30.0	 30.0;
	3526	 1470	 0.000324	 0.022139	 0.0	 479.999638	 479.999638	 479.999638	 0.993901	 0.0	 1	 -30.0	 30.0;
	3526	 1470	 0.000324	 0.022706	 0.0	 479.999638	 479.999638	 479.999638	 0.993901	 0.0	 1	 -30.0	 30.0;
	3526	 1470	 0.000314	 0.023142	 0.0	 479.999638	 479.999638	 479.999638	 0.993901	 0.0	 1	 -30.0	 30.0;
	8181	 6637	 0.000344	 0.024832	 -0.014264	 479.999638	 479.999638	 479.999638	 0.993901	 0.0	 1	 -30.0	 30.0;
	8181	 7690	 0.000334	 0.023071	 -0.014264	 479.999638	 479.999638	 479.999638	 0.993901	 0.0	 1	 -30.0	 30.0;
	2458	 331	 0.000335	 0.022767	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	2430	 305	 0.00071	 0.030845	 -0.009149	 300.000103	 300.000103	 300.000103	 1.006865	 0.0	 1	 -30.0	 30.0;
	3620	 6314	 0.000385	 0.019472	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	3620	 3756	 0.000395	 0.019057	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	3620	 1186	 0.000404	 0.018643	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	3620	 4651	 0.0	 0.027866	 0.0	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	1536	 6871	 0.000326	 0.032245	 0.0	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	3942	 7714	 0.000365	 0.022599	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	3942	 7714	 0.000355	 0.023023	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	7727	 3659	 0.0	 0.032004	 0.0	 300.000068	 300.000068	 300.000068	 1.045455	 0.0	 1	 -30.0	 30.0;
	5621	 3659	 0.00141	 0.06647	 0.0	 386.864979	 386.864979	 386.864979	 0.997125	 4.34603	 1	 -30.0	 30.0;
	2433	 2106	 0.000434	 0.019018	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	5862	 7960	 0.000404	 0.020497	 -0.014639	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	5101	 6927	 0.00074	 0.029553	 -0.009149	 300.000103	 300.000103	 300.000103	 1.006865	 0.0	 1	 -30.0	 30.0;
	939	 1540	 0.000454	 0.019669	 0.0	 479.999638	 479.999638	 479.999638	 1.006865	 0.0	 1	 -30.0	 30.0;
	4376	 2475	 0.00206	 0.09005	 -0.00452	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2966	 224	 0.00039	 0.03411	 -0.007169	 400.0	 400.0	 400.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	2966	 224	 0.0004	 0.034469	 -0.007158	 400.0	 400.0	 400.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	7701	 3888	 0.00183	 0.090471	 -0.005433	 150.0	 150.0	 150.0	 1.026087	 0.0	 1	 -30.0	 30.0;
	7701	 3888	 0.00187	 0.07429	 -0.005464	 150.0	 150.0	 150.0	 1.026087	 0.0	 1	 -30.0	 30.0;
	6962	 1715	 0.00077	 0.04355	 -0.005363	 300.0	 300.0	 300.0	 0.999313	 0.0	 1	 -30.0	 30.0;
	6962	 1715	 0.00077	 0.04266	 -0.005363	 300.0	 300.0	 300.0	 0.999313	 0.0	 1	 -30.0	 30.0;
	6646	 6377	 0.00116	 0.04106	 0.0	 342.000499	 342.000499	 342.000499	 1.052632	 0.0	 1	 -30.0	 30.0;
	6646	 6377	 0.00118	 0.04119	 0.0	 342.000499	 342.000499	 342.000499	 1.052632	 0.0	 1	 -30.0	 30.0;
	7563	 2680	 0.0012	 0.03931	 0.0	 342.000499	 342.000499	 342.000499	 1.052632	 0.0	 1	 -30.0	 30.0;
	7563	 2680	 0.00107	 0.04567	 0.0	 342.000499	 342.000499	 342.000499	 1.052632	 0.0	 1	 -30.0	 30.0;
	6223	 5961	 0.002282	 0.077224	 0.0	 185.400832	 185.400832	 185.400832	 0.97087	 0.0	 1	 -30.0	 30.0;
	3833	 5961	 0.00102	 0.04862	 0.0	 342.000499	 342.000499	 342.000499	 1.052632	 0.0	 1	 -30.0	 30.0;
	3833	 5961	 0.001	 0.04954	 0.0	 342.000499	 342.000499	 342.000499	 1.052632	 0.0	 1	 -30.0	 30.0;
	2964	 1560	 0.00098	 0.04477	 0.0	 342.000499	 342.000499	 342.000499	 1.052632	 0.0	 1	 -30.0	 30.0;
	2964	 1560	 0.00111	 0.04387	 0.0	 342.000499	 342.000499	 342.000499	 1.052632	 0.0	 1	 -30.0	 30.0;
	2862	 5079	 0.00113	 0.04193	 0.0	 342.000499	 342.000499	 342.000499	 1.052632	 0.0	 1	 -30.0	 30.0;
	8040	 4773	 0.002522	 0.074933	 0.0	 170.300154	 170.300154	 170.300154	 1.056957	 0.0	 1	 -30.0	 30.0;
	1266	 4549	 0.001252	 0.073601	 0.0	 127.659766	 127.659766	 127.659766	 0.94	 0.0	 1	 -30.0	 30.0;
	3217	 4549	 0.001271	 0.072001	 0.0	 127.659766	 127.659766	 127.659766	 0.94	 0.0	 1	 -30.0	 30.0;
	7478	 5570	 0.000442	 0.040802	 0.0	 942.570029	 942.570029	 942.570029	 0.895	 0.0	 1	 -30.0	 30.0;
	731	 80	 0.00048	 0.041601	 0.0	 456.648752	 456.648752	 456.648752	 0.925	 0.0	 1	 -30.0	 30.0;
	1596	 6346	 0.000543	 0.04261	 0.0	 261.599947	 261.599947	 261.599947	 1.0	 0.0	 1	 -30.0	 30.0;
	537	 6346	 0.000534	 0.04342	 0.0	 253.199605	 253.199605	 253.199605	 1.0	 0.0	 1	 -30.0	 30.0;
	7643	 5710	 0.003895	 0.040564	 0.0	 222.408002	 222.408002	 222.408002	 0.955	 0.0	 1	 -30.0	 30.0;
	7643	 5710	 0.004413	 0.039762	 0.0	 227.434518	 227.434518	 227.434518	 0.955	 0.0	 1	 -30.0	 30.0;
	7643	 5710	 0.004498	 0.038954	 0.0	 231.203911	 231.203911	 231.203911	 0.955	 0.0	 1	 -30.0	 30.0;
	2903	 6431	 0.000621	 0.0376	 0.0	 216.494919	 216.494919	 216.494919	 0.97	 0.0	 1	 -30.0	 30.0;
	3165	 6431	 0.00063	 0.0368	 0.0	 218.969015	 218.969015	 218.969015	 0.97	 0.0	 1	 -30.0	 30.0;
	3165	 7116	 0.00064	 0.036	 0.0	 223.917207	 223.917207	 223.917207	 0.97	 0.0	 1	 -30.0	 30.0;
	256	 3608	 0.000555	 0.040801	 0.0	 310.515175	 310.515175	 310.515175	 0.97	 0.0	 1	 -30.0	 30.0;
	7333	 1343	 0.000546	 0.0416	 0.0	 304.330264	 304.330264	 304.330264	 0.97	 0.0	 1	 -30.0	 30.0;
	7333	 7292	 0.000527	 0.0424	 0.0	 299.380756	 299.380756	 299.380756	 0.97	 0.0	 1	 -30.0	 30.0;
	4556	 5765	 0.000456	 0.043201	 0.0	 354.345968	 354.345968	 354.345968	 0.955	 0.0	 1	 -30.0	 30.0;
	4556	 5765	 0.000447	 0.040001	 0.0	 381.989499	 381.989499	 381.989499	 0.955	 0.0	 1	 -30.0	 30.0;
	831	 5765	 0.000505	 0.039202	 0.0	 389.528943	 389.528943	 389.528943	 0.955	 0.0	 1	 -30.0	 30.0;
	831	 5765	 0.000513	 0.038402	 0.0	 397.068387	 397.068387	 397.068387	 0.955	 0.0	 1	 -30.0	 30.0;
	4389	 7155	 0.000513	 0.037602	 0.0	 382.978742	 382.978742	 382.978742	 0.94	 0.0	 1	 -30.0	 30.0;
	2749	 7155	 0.00052	 0.036802	 0.0	 389.362423	 389.362423	 389.362423	 0.94	 0.0	 1	 -30.0	 30.0;
	5756	 7155	 0.000529	 0.036002	 0.0	 395.744788	 395.744788	 395.744788	 0.94	 0.0	 1	 -30.0	 30.0;
	7356	 7926	 0.000473	 0.040802	 0.0	 380.733035	 380.733035	 380.733035	 0.955	 0.0	 1	 -30.0	 30.0;
	7959	 7926	 0.000465	 0.041601	 0.0	 374.450713	 374.450713	 374.450713	 0.955	 0.0	 1	 -30.0	 30.0;
	3698	 5699	 7e-05	 0.0212	 0.0	 808.086226	 808.086226	 808.086226	 0.94	 0.0	 1	 -30.0	 30.0;
	1827	 3952	 7e-05	 0.021599	 0.0	 805.53249	 805.53249	 805.53249	 0.94	 0.0	 1	 -30.0	 30.0;
	4697	 3055	 0.00054	 0.04	 0.0	 420.642395	 420.642395	 420.642395	 0.984211	 0.0	 1	 -30.0	 30.0;
	4697	 3055	 0.000472	 0.039202	 0.0	 513.19162	 513.19162	 513.19162	 0.94	 0.0	 1	 -30.0	 30.0;
	2468	 3055	 0.00048	 0.038402	 0.0	 528.511402	 528.511402	 528.511402	 0.94	 0.0	 1	 -30.0	 30.0;
	2468	 3055	 0.00064	 0.0376	 0.0	 451.123337	 451.123337	 451.123337	 0.984211	 0.0	 1	 -30.0	 30.0;
	1450	 1025	 0.000333	 0.029441	 0.0	 278.967325	 278.967325	 278.967325	 1.015	 0.0	 1	 -30.0	 30.0;
	5046	 7715	 0.000353	 0.028801	 0.0	 278.099186	 278.099186	 278.099186	 1.015	 0.0	 1	 -30.0	 30.0;
	5046	 7715	 0.000312	 0.032641	 0.0	 245.385042	 245.385042	 245.385042	 1.015	 0.0	 1	 -30.0	 30.0;
	1541	 7997	 0.000529	 0.041601	 0.0	 596.170918	 596.170918	 596.170918	 0.94	 0.0	 1	 -30.0	 30.0;
	7459	 7997	 0.000511	 0.042401	 0.0	 592.340973	 592.340973	 592.340973	 0.94	 0.0	 1	 -30.0	 30.0;
	7605	 6864	 0.000633	 0.051521	 0.0	 302.827641	 302.827641	 302.827641	 0.955	 0.0	 1	 -30.0	 30.0;
	7605	 6864	 0.000616	 0.047701	 0.0	 327.958243	 327.958243	 327.958243	 0.955	 0.0	 1	 -30.0	 30.0;
	123	 6864	 0.000701	 0.046752	 0.0	 335.497687	 335.497687	 335.497687	 0.955	 0.0	 1	 -30.0	 30.0;
	2962	 5498	 0.000811	 0.04579	 0.0	 241.297229	 241.297229	 241.297229	 0.95484	 0.0	 1	 -30.0	 30.0;
	332	 5498	 0.000831	 0.04484	 0.0	 245.067349	 245.067349	 245.067349	 0.95484	 0.0	 1	 -30.0	 30.0;
	332	 5498	 0.000841	 0.043881	 0.0	 250.094176	 250.094176	 250.094176	 0.95484	 0.0	 1	 -30.0	 30.0;
	5508	 6753	 0.000621	 0.036001	 0.0	 146.600884	 146.600884	 146.600884	 1.015	 0.0	 1	 -30.0	 30.0;
	5508	 2066	 0.000555	 0.040801	 0.0	 118.226774	 118.226774	 118.226774	 1.015	 0.0	 1	 -30.0	 30.0;
	5685	 3500	 0.000563	 0.0416	 0.0	 118.226774	 118.226774	 118.226774	 1.015	 0.0	 1	 -30.0	 30.0;
	1636	 929	 0.000543	 0.0424	 0.0	 559.162154	 559.162154	 559.162154	 0.955	 0.0	 1	 -30.0	 30.0;
	2557	 190	 0.001026	 0.086398	 0.0	 123.711313	 123.711313	 123.711313	 0.97	 0.0	 1	 -30.0	 30.0;
	124	 190	 0.001007	 0.080001	 0.0	 150.927894	 150.927894	 150.927894	 0.97	 0.0	 1	 -30.0	 30.0;
	2921	 1522	 0.000522	 0.039201	 0.0	 591.56827	 591.56827	 591.56827	 0.925	 0.0	 1	 -30.0	 30.0;
	5150	 1522	 0.00053	 0.038401	 0.0	 547.66047	 547.66047	 547.66047	 0.94	 0.0	 1	 -30.0	 30.0;
	3949	 1522	 0.000548	 0.037601	 0.0	 639.568629	 639.568629	 639.568629	 0.925	 0.0	 1	 -30.0	 30.0;
	4345	 1787	 3e-05	 0.00658	 0.0	 3026.318984	 3026.318984	 3026.318984	 0.99548	 5.44941	 1	 -30.0	 30.0;
	3932	 3918	 0.000907	 0.042929	 0.0	 180.886518	 180.886518	 180.886518	 1.015	 0.0	 1	 -30.0	 30.0;
	4421	 3869	 7.7e-05	 0.0204	 0.0	 729.011248	 729.011248	 729.011248	 0.97	 0.0	 1	 -30.0	 30.0;
	6559	 4421	 3e-05	 0.007638	 0.0	 3212.352049	 3212.352049	 3212.352049	 0.989916	 8.14356	 1	 -30.0	 30.0;
	3869	 3918	 0.000773	 0.05056	 0.0	 157.24115	 157.24115	 157.24115	 1.015	 0.0	 1	 -30.0	 30.0;
	5350	 2466	 0.000728	 0.043197	 0.0	 114.832544	 114.832544	 114.832544	 1.045	 0.0	 1	 -30.0	 30.0;
	378	 221	 0.000447	 0.040001	 0.0	 114.832544	 114.832544	 114.832544	 1.045	 0.0	 1	 -30.0	 30.0;
	8078	 5492	 0.00061	 0.0392	 0.0	 119.999909	 119.999909	 119.999909	 1.0	 0.0	 1	 -30.0	 30.0;
	4825	 7862	 0.001203	 0.076801	 0.0	 123.711313	 123.711313	 123.711313	 0.97	 0.0	 1	 -30.0	 30.0;
	3543	 7862	 0.001223	 0.075201	 0.0	 123.711313	 123.711313	 123.711313	 0.97	 0.0	 1	 -30.0	 30.0;
	599	 6416	 0.004533	 0.037356	 0.0	 212.783446	 212.783446	 212.783446	 0.97	 0.0	 1	 -30.0	 30.0;
	5461	 314	 0.004615	 0.036549	 0.0	 216.494919	 216.494919	 216.494919	 0.97	 0.0	 1	 -30.0	 30.0;
	6137	 6491	 0.004113	 0.041392	 0.0	 196.700835	 196.700835	 196.700835	 0.97	 0.0	 1	 -30.0	 30.0;
	3713	 6746	 0.000627	 0.041599	 0.0	 112.149805	 112.149805	 112.149805	 1.07	 0.0	 1	 -30.0	 30.0;
	959	 7503	 0.001048	 0.084802	 0.0	 114.83244	 114.83244	 114.83244	 1.045	 0.0	 1	 -30.0	 30.0;
	3530	 7503	 0.001029	 0.086397	 0.0	 114.83244	 114.83244	 114.83244	 1.045	 0.0	 1	 -30.0	 30.0;
	66	 4857	 0.000808	 0.047709	 0.0	 148.134026	 148.134026	 148.134026	 1.045	 0.0	 1	 -30.0	 30.0;
	4081	 2727	 0.00061	 0.0392	 0.0	 118.226774	 118.226774	 118.226774	 1.015	 0.0	 1	 -30.0	 30.0;
	4081	 2727	 0.00062	 0.0384	 0.0	 118.226774	 118.226774	 118.226774	 1.015	 0.0	 1	 -30.0	 30.0;
	5700	 2727	 0.00064	 0.0376	 0.0	 118.226774	 118.226774	 118.226774	 1.015	 0.0	 1	 -30.0	 30.0;
	356	 3717	 0.00063	 0.0368	 0.0	 217.731638	 217.731638	 217.731638	 0.97	 0.0	 1	 -30.0	 30.0;
	5301	 4768	 0.00064	 0.036	 0.0	 220.205734	 220.205734	 220.205734	 0.97	 0.0	 1	 -30.0	 30.0;
	5301	 4768	 0.000573	 0.0408	 0.0	 194.226739	 194.226739	 194.226739	 0.97	 0.0	 1	 -30.0	 30.0;
	5875	 2247	 0.001067	 0.083199	 0.0	 194.226739	 194.226739	 194.226739	 0.97	 0.0	 1	 -30.0	 30.0;
	4809	 2247	 0.001048	 0.084802	 0.0	 190.5153	 190.5153	 190.5153	 0.97	 0.0	 1	 -30.0	 30.0;
	1312	 5689	 6e-05	 0.11487	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	4214	 5689	 0.20187	 1.758347	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	1197	 3502	 0.03911	 0.342562	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	2725	 4181	 0.01564	 0.58593	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	2725	 4168	 -0.000248	 0.227727	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	5616	 887	 0.01414	 0.513223	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	3343	 887	 -0.007335	 0.347624	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	4996	 887	 -0.006901	 0.404112	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	6919	 3124	 0.051021	 0.452583	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	3457	 577	 0.586797	 1.843698	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	193	 577	 0.487562	 1.572644	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	4410	 577	 0.129359	 0.588864	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	5660	 3792	 0.000246	 0.025121	 0.0	 599.999547	 599.999547	 599.999547	 0.996999	 0.0	 1	 -30.0	 30.0;
	4214	 6611	 0.10005	 1.276798	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	3343	 6611	 0.21936	 1.401591	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	4996	 6611	 0.22688	 1.394834	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	1312	 2272	 0.04986	 0.379174	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	3457	 877	 0.02303	 0.62419	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	3457	 2360	 0.03435	 0.639633	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	226	 7657	 0.01742	 0.603616	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	3865	 7657	 0.14245	 1.97967	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	1013	 7657	 -0.000145	 0.32938	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	4123	 2928	 -0.000298	 0.102701	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	2863	 6016	 0.000708	 0.03271	 0.0	 479.999638	 479.999638	 479.999638	 1.002888	 0.0	 1	 -30.0	 30.0;
	2863	 7125	 0.06719	 0.834339	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	5545	 2069	 0.050909	 0.307686	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	902	 2069	 0.212521	 0.943657	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	3877	 7601	 -0.002652	 0.490201	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	3877	 5118	 0.02628	 0.438469	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	4956	 7601	 -0.008241	 0.388947	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	6853	 7601	 0.000226	 0.024837	 0.0	 396.000162	 396.000162	 396.000162	 1.052632	 0.0	 1	 -30.0	 30.0;
	2500	 7601	 0.10611	 0.699359	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	2500	 5118	 0.02855	 0.418988	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	1013	 295	 0.292479	 1.229545	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	193	 2928	 0.757066	 1.631798	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	4410	 2928	 0.384752	 1.021653	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 4267	 -0.014297	 0.212851	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 4267	 0.000444	 0.031171	 0.0	 599.999547	 599.999547	 599.999547	 0.979739	 0.0	 1	 -30.0	 30.0;
	4737	 3195	 -0.014091	 0.217459	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	6919	 5536	 0.00894	 0.300393	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	8004	 8146	 0.049771	 0.546674	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	2018	 7848	 0.000737	 0.026925	 -0.007642	 396.000162	 396.000162	 396.000162	 1.002888	 0.0	 1	 -30.0	 30.0;
	2018	 7848	 0.000845	 0.026029	 -0.007262	 396.000162	 396.000162	 396.000162	 1.014878	 0.0	 1	 -30.0	 30.0;
	8004	 2805	 0.05157	 0.475537	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	6919	 2510	 0.054781	 0.446446	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	3139	 1837	 0.000452	 0.023578	 0.0	 599.999547	 599.999547	 599.999547	 0.952263	 0.0	 1	 -30.0	 30.0;
	3060	 2593	 -0.010579	 0.27814	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	3060	 4617	 -0.007004	 0.324483	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	3865	 7807	 -0.034029	 0.423698	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	2566	 1358	 0.000384	 0.0242	 0.0	 599.999547	 599.999547	 599.999547	 1.008848	 0.0	 1	 -30.0	 30.0;
	1312	 1358	 0.299587	 1.849794	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	1312	 4819	 0.301095	 1.740868	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	1006	 4407	 0.000759	 0.019191	 0.0	 943.199907	 943.199907	 943.199907	 1.313163	 0.0	 1	 -30.0	 30.0;
	226	 6371	 0.170173	 0.568199	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	6919	 6084	 0.000413	 0.453868	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	8004	 6084	 0.057719	 0.644008	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	6430	 6371	 0.07761	 0.938223	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	1013	 6371	 0.200409	 0.618946	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	6919	 3092	 0.152771	 0.863657	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	8004	 3092	 -0.001921	 0.311818	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	1013	 523	 0.305992	 1.948119	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	8004	 5004	 0.17005	 0.993099	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	4971	 1569	 0.000257	 0.029742	 0.0	 706.047372	 706.047372	 706.047372	 0.916288	 0.0	 1	 -30.0	 30.0;
	4971	 2957	 0.000268	 0.029134	 0.0	 707.242625	 707.242625	 707.242625	 0.916288	 0.0	 1	 -30.0	 30.0;
	3425	 3581	 -0.014277	 0.154039	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	3425	 3581	 0.000738	 0.031616	 0.0	 479.999638	 479.999638	 479.999638	 1.002277	 0.0	 1	 -30.0	 30.0;
	451	 3581	 0.251178	 0.958099	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	3425	 339	 0.08599	 0.668788	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	4660	 7125	 0.000241	 0.02217	 0.0	 599.999547	 599.999547	 599.999547	 1.093302	 0.0	 1	 -30.0	 30.0;
	451	 2049	 -0.003678	 0.380909	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	7876	 2049	 -0.011302	 0.627045	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	451	 3099	 0.00797	 0.426157	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	7876	 3099	 0.058159	 0.835806	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	451	 2298	 0.00907	 0.406178	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	7876	 2298	 0.059789	 0.790103	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	451	 339	 0.04738	 0.355028	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	451	 4891	 0.00166	 0.210118	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	902	 699	 0.000234	 0.03334	 0.0	 396.000162	 396.000162	 396.000162	 0.882932	 0.0	 1	 -30.0	 30.0;
	902	 7160	 -0.007978	 0.33365	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	902	 1373	 -0.007673	 0.339439	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	7876	 2741	 0.000213	 0.026084	 0.0	 599.999547	 599.999547	 599.999547	 1.027158	 0.0	 1	 -30.0	 30.0;
	7876	 339	 0.079162	 0.676053	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	7876	 3444	 -0.012742	 0.556163	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	7876	 4891	 0.05625	 0.586697	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	1197	 3602	 0.11012	 1.389876	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	3865	 3020	 0.12839	 0.634174	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	3865	 3020	 0.000265	 0.029415	 0.0	 599.999547	 599.999547	 599.999547	 0.882932	 0.0	 1	 -30.0	 30.0;
	2678	 2331	 0.01031	 0.165651	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	717	 6292	 0.000906	 0.032368	 0.0	 479.999638	 479.999638	 479.999638	 1.03341	 0.0	 1	 -30.0	 30.0;
	3060	 6292	 0.258574	 1.91281	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	2725	 7740	 0.114169	 0.69781	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	1013	 6616	 0.215475	 0.921488	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	1013	 238	 0.000388	 0.026559	 0.0	 599.999547	 599.999547	 599.999547	 0.985426	 0.0	 1	 -30.0	 30.0;
	1013	 238	 -0.012727	 0.168081	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	1013	 5598	 0.11171	 0.548317	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	2678	 3444	 0.04893	 0.453587	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	2725	 3027	 0.000427	 0.025869	 0.0	 599.999547	 599.999547	 599.999547	 0.985426	 0.0	 1	 -30.0	 30.0;
	2725	 7946	 0.000379	 0.029319	 0.0	 599.999547	 599.999547	 599.999547	 0.985426	 0.0	 1	 -30.0	 30.0;
	6919	 2729	 0.086233	 0.611399	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	6919	 3635	 0.03295	 0.399238	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	8004	 5133	 0.034401	 0.560661	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	5283	 2311	 0.04848	 0.4525	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	5283	 3690	 0.05627	 0.448553	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	22	 153	 0.000262	 0.020993	 0.0	 599.999547	 599.999547	 599.999547	 1.079401	 0.0	 1	 -30.0	 30.0;
	4410	 153	 0.093521	 0.726302	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	4410	 5986	 0.170831	 0.824835	 0.0	 1439.998913	 1439.998913	 1439.998913	 1.0	 0.0	 1	 -30.0	 30.0;
	1197	 3635	 0.05836	 0.35759	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	7613	 2729	 0.000563	 0.031553	 -0.013861	 479.999638	 479.999638	 479.999638	 1.014878	 0.0	 1	 -30.0	 30.0;
	4410	 3282	 0.04447	 0.619827	 0.0	 1439.999571	 1439.999571	 1439.999571	 1.0	 0.0	 1	 -30.0	 30.0;
	5900	 3034	 0.001519	 0.050701	 -0.004109	 119.999875	 119.999875	 119.999875	 1.013514	 0.0	 1	 -30.0	 30.0;
	115	 4946	 0.000821	 0.051524	 -0.00383	 119.999909	 119.999909	 119.999909	 1.052632	 0.0	 1	 -30.0	 30.0;
	115	 4946	 0.000803	 0.047869	 -0.00553	 119.999909	 119.999909	 119.999909	 1.052632	 0.0	 1	 -30.0	 30.0;
	397	 2035	 0.000466	 0.029318	 -0.003795	 360.000386	 360.000386	 360.000386	 1.02529	 0.0	 1	 -30.0	 30.0;
	7335	 4293	 0.000463	 0.028006	 -0.003895	 272.400012	 272.400012	 272.400012	 1.038781	 0.0	 1	 -30.0	 30.0;
	7335	 4293	 0.000463	 0.026569	 -0.00973	 286.800317	 286.800317	 286.800317	 1.038781	 0.0	 1	 -30.0	 30.0;
	2801	 7975	 0.000556	 0.030088	 -0.00596	 119.999909	 119.999909	 119.999909	 1.081471	 0.0	 1	 -30.0	 30.0;
	2801	 7975	 0.000581	 0.029019	 -0.00285	 119.999909	 119.999909	 119.999909	 1.081471	 0.0	 1	 -30.0	 30.0;
	5286	 637	 0.0017	 0.077979	 -0.0006	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	7455	 5008	 0.000569	 0.046371	 -0.00583	 119.999909	 119.999909	 119.999909	 1.052632	 0.0	 1	 -30.0	 30.0;
	7455	 5008	 0.00056	 0.047255	 -0.00547	 119.999909	 119.999909	 119.999909	 1.052632	 0.0	 1	 -30.0	 30.0;
	484	 3956	 0.000799	 0.050159	 -0.00393	 148.80052	 148.80052	 148.80052	 1.066856	 0.0	 1	 -30.0	 30.0;
	5519	 4554	 0.000379	 0.039836	 -0.00999	 340.79998	 340.79998	 340.79998	 1.052632	 0.0	 1	 -30.0	 30.0;
	5519	 4554	 0.000433	 0.039042	 -0.00999	 347.999803	 347.999803	 347.999803	 1.052632	 0.0	 1	 -30.0	 30.0;
	1737	 6671	 0.000448	 0.032183	 -0.004109	 119.999909	 119.999909	 119.999909	 1.066856	 0.0	 1	 -30.0	 30.0;
	4284	 1135	 0.000498	 0.034255	 -0.00036	 119.999875	 119.999875	 119.999875	 1.041667	 0.0	 1	 -30.0	 30.0;
	4284	 1135	 0.000507	 0.033509	 -0.00036	 119.999875	 119.999875	 119.999875	 1.041667	 0.0	 1	 -30.0	 30.0;
	5613	 2185	 0.000415	 0.040631	 -0.00999	 119.999909	 119.999909	 119.999909	 1.052632	 0.0	 1	 -30.0	 30.0;
	5613	 2185	 0.000406	 0.041434	 -0.00999	 119.999909	 119.999909	 119.999909	 1.052632	 0.0	 1	 -30.0	 30.0;
	5050	 1280	 0.000397	 0.037986	 -0.004	 251.999744	 251.999744	 251.999744	 1.052632	 0.0	 1	 -30.0	 30.0;
	7099	 1804	 0.000322	 0.035886	 -0.00088	 220.80007	 220.80007	 220.80007	 1.043148	 0.0	 1	 -30.0	 30.0;
	933	 8104	 0.000408	 0.039074	 -0.0008	 335.999878	 335.999878	 335.999878	 0.989654	 0.0	 1	 -30.0	 30.0;
	5713	 6164	 0.000417	 0.026115	 -0.00463	 119.999909	 119.999909	 119.999909	 1.062289	 0.0	 1	 -30.0	 30.0;
	5713	 6164	 0.000443	 0.02577	 -0.004074	 119.999909	 119.999909	 119.999909	 1.062289	 0.0	 1	 -30.0	 30.0;
	2733	 5676	 0.000396	 0.033918	 -0.00086	 199.199942	 199.199942	 199.199942	 1.02924	 0.0	 1	 -30.0	 30.0;
	7230	 157	 0.000406	 0.023438	 -0.00405	 219.600209	 219.600209	 219.600209	 1.052632	 0.0	 1	 -30.0	 30.0;
	7230	 157	 0.000352	 0.026759	 -0.00333	 192.000118	 192.000118	 192.000118	 1.052632	 0.0	 1	 -30.0	 30.0;
	1553	 6804	 0.000334	 0.036651	 -0.0009	 119.999909	 119.999909	 119.999909	 1.052632	 0.0	 1	 -30.0	 30.0;
	1553	 6804	 0.000334	 0.037354	 -0.0009	 119.999909	 119.999909	 119.999909	 1.052632	 0.0	 1	 -30.0	 30.0;
	4276	 3799	 0.000305	 0.035675	 -0.00096	 241.200338	 241.200338	 241.200338	 1.087225	 0.0	 1	 -30.0	 30.0;
	4276	 3799	 0.000296	 0.033035	 -0.00096	 260.399428	 260.399428	 260.399428	 1.087225	 0.0	 1	 -30.0	 30.0;
	4276	 3799	 0.000338	 0.032376	 -0.00096	 265.200188	 265.200188	 265.200188	 1.087225	 0.0	 1	 -30.0	 30.0;
	1854	 7698	 0.000285	 0.02604	 -0.00117	 447.600103	 447.600103	 447.600103	 1.199891	 0.0	 1	 -30.0	 30.0;
	933	 1125	 0.000419	 0.02814	 -0.00382	 361.199589	 361.199589	 361.199589	 0.989654	 0.0	 1	 -30.0	 30.0;
	2733	 8289	 0.000453	 0.025129	 -0.00361	 204.000043	 204.000043	 204.000043	 1.02924	 0.0	 1	 -30.0	 30.0;
	2733	 4225	 0.000453	 0.02528	 -0.00439	 196.799562	 196.799562	 196.799562	 1.02924	 0.0	 1	 -30.0	 30.0;
	4594	 1822	 0.00174	 0.07467	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	4594	 189	 0.00171	 0.07614	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	1237	 5212	 0.00172	 0.099322	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	1237	 5212	 0.00168	 0.101198	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	8002	 5630	 0.00363	 0.146413	 -0.007293	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	8002	 5630	 0.00182	 0.07175	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	1582	 411	 0.0019	 0.08995	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	4317	 4942	 0.00189	 0.06882	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	4317	 769	 0.00192	 0.06735	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	3815	 6800	 0.00196	 0.06589	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	3395	 689	 0.00171	 0.07614	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	5026	 5503	 0.00167	 0.0776	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	6724	 2839	 0.000646	 0.034336	 -0.003628	 199.199942	 199.199942	 199.199942	 1.002441	 -0.0065	 1	 -30.0	 30.0;
	6724	 2839	 0.000636	 0.034445	 -0.003628	 215.999969	 215.999969	 215.999969	 1.002246	 -0.0258	 1	 -30.0	 30.0;
	2839	 104	 0.00182	 0.07175	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	2839	 3022	 0.00185	 0.07028	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	2203	 5687	 0.00194	 0.088083	 -0.003306	 153.900093	 153.900093	 153.900093	 1.052632	 0.0	 1	 -30.0	 30.0;
	2203	 6141	 0.00198	 0.086207	 -0.003306	 152.759468	 152.759468	 152.759468	 1.052632	 0.0	 1	 -30.0	 30.0;
	3247	 6213	 0.00196	 0.06589	 -0.003306	 156.632992	 156.632992	 156.632992	 1.049587	 0.0	 1	 -30.0	 30.0;
	4003	 5731	 0.000697	 0.032338	 -0.003628	 278.400632	 278.400632	 278.400632	 1.002506	 0.0	 1	 -30.0	 30.0;
	5731	 3120	 0.00171	 0.07614	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	2455	 2293	 0.000667	 0.033601	 -0.003628	 291.59976	 291.59976	 291.59976	 1.002506	 0.0	 1	 -30.0	 30.0;
	2455	 2293	 0.000647	 0.034238	 -0.003628	 285.600456	 285.600456	 285.600456	 1.002506	 0.0	 1	 -30.0	 30.0;
	2293	 2755	 0.0016	 0.07553	 -0.003306	 112.996154	 112.996154	 112.996154	 1.061983	 0.0	 1	 -30.0	 30.0;
	2293	 1070	 0.00182	 0.07402	 -0.003306	 112.996154	 112.996154	 112.996154	 1.061983	 0.0	 1	 -30.0	 30.0;
	3947	 5305	 0.0019	 0.08995	 -0.003306	 178.980015	 178.980015	 178.980015	 1.052632	 0.0	 1	 -30.0	 30.0;
	5097	 3461	 0.00189	 0.06882	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	5097	 559	 0.00192	 0.06735	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	5667	 76	 0.00201	 0.084331	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	5667	 76	 0.00179	 0.095579	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	8373	 1883	 0.00171	 0.07614	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	6156	 834	 0.00167	 0.0776	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	761	 1815	 0.00168	 0.101198	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	6104	 7942	 0.00165	 0.093702	 -0.003306	 191.519647	 191.519647	 191.519647	 1.052632	 0.0	 1	 -30.0	 30.0;
	6104	 1285	 0.00187	 0.091826	 -0.003306	 196.080172	 196.080172	 196.080172	 1.052632	 0.0	 1	 -30.0	 30.0;
	5733	 8100	 0.0019	 0.08995	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	3460	 8224	 0.00189	 0.06882	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	3460	 8224	 0.00192	 0.06735	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	4528	 6659	 0.00196	 0.06589	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	4528	 5866	 0.00174	 0.07467	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	7159	 2869	 0.00171	 0.07614	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	1977	 4443	 0.00167	 0.0776	 -0.006378	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	1922	 7124	 0.00164	 0.07907	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	8366	 2848	 0.00045	 0.04299	 -0.003199	 300.586887	 300.586887	 300.586887	 1.113821	 0.0	 1	 -30.0	 30.0;
	8177	 2918	 0.00051	 0.04213	 -0.003199	 199.313772	 199.313772	 199.313772	 1.113821	 0.0	 1	 -30.0	 30.0;
	1088	 1089	 0.00185	 0.07028	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	1088	 1089	 0.00189	 0.06882	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	183	 611	 0.00192	 0.06735	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	183	 2255	 0.00196	 0.06589	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	4557	 4753	 0.00179	 0.095579	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	4557	 4753	 0.00176	 0.097446	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	1851	 1159	 0.00167	 0.0776	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	1851	 1159	 0.00164	 0.07907	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	58	 5026	 0.000637	 0.031701	 -0.003628	 211.199867	 211.199867	 211.199867	 1.002506	 0.0	 1	 -30.0	 30.0;
	58	 7211	 0.000716	 0.031064	 -0.003628	 241.200338	 241.200338	 241.200338	 1.002506	 0.0	 1	 -30.0	 30.0;
	7211	 8124	 0.00185	 0.07028	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	7211	 194	 0.00189	 0.06882	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	2164	 1758	 0.00192	 0.06735	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	2164	 1758	 0.00196	 0.06589	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	5879	 8204	 0.00174	 0.07467	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	1425	 4835	 0.00171	 0.07614	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	5678	 1605	 0.00084	 0.0322	 -0.003628	 264.48014	 264.48014	 264.48014	 1.052632	 0.0	 1	 -30.0	 30.0;
	1605	 2712	 0.00238	 0.123248	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	4978	 6449	 0.00269	 0.109562	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	5551	 7663	 0.00275	 0.107281	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	4307	 2774	 0.000766	 0.029164	 -0.003628	 172.799712	 172.799712	 172.799712	 1.002506	 0.0	 1	 -30.0	 30.0;
	4307	 2774	 0.000776	 0.028526	 -0.003628	 176.399952	 176.399952	 176.399952	 1.002506	 0.0	 1	 -30.0	 30.0;
	2774	 7569	 0.00174	 0.07467	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	2774	 5940	 0.00171	 0.07614	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	3191	 1631	 0.00167	 0.0776	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	3393	 3083	 0.00168	 0.101198	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	3393	 3396	 0.00165	 0.093702	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	881	 6598	 0.000716	 0.031064	 -0.003628	 250.800541	 250.800541	 250.800541	 1.002506	 0.0	 1	 -30.0	 30.0;
	881	 3126	 0.000736	 0.030437	 -0.003628	 151.199583	 151.199583	 151.199583	 1.002506	 0.0	 1	 -30.0	 30.0;
	3126	 433	 0.00189	 0.06882	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	3126	 433	 0.00192	 0.06735	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	6045	 3974	 0.00196	 0.06589	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	7100	 4127	 0.00174	 0.07467	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	1521	 3467	 0.00171	 0.07614	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	1521	 3467	 0.00167	 0.0776	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	4001	 677	 0.00168	 0.101198	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	4269	 3507	 0.00062	 0.03068	 -0.003724	 194.400498	 194.400498	 194.400498	 1.015697	 0.0	 1	 -30.0	 30.0;
	4269	 6959	 0.000458	 0.027443	 -0.003628	 207.599626	 207.599626	 207.599626	 1.002506	 0.0	 1	 -30.0	 30.0;
	4269	 6959	 0.000468	 0.026875	 -0.003628	 212.400386	 212.400386	 212.400386	 1.002506	 0.0	 1	 -30.0	 30.0;
	4707	 8261	 0.001543	 0.057853	 -0.00572	 194.400117	 194.400117	 194.400117	 0.892857	 0.0	 1	 -30.0	 30.0;
	2028	 4328	 0.00198	 0.086207	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	6816	 3270	 0.00196	 0.06589	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	3057	 5411	 0.00174	 0.07467	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	1545	 6107	 0.00171	 0.07614	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	3048	 7883	 0.000667	 0.033601	 -0.003628	 135.865322	 135.865322	 135.865322	 1.002506	 0.0	 1	 -30.0	 30.0;
	3048	 6849	 0.00168	 0.101198	 -0.009296	 285.000196	 285.000196	 285.000196	 1.052632	 0.0	 1	 -30.0	 30.0;
	7883	 6849	 0.0016	 0.07321	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	5851	 6875	 0.0019	 0.08995	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	7373	 3310	 0.000746	 0.029801	 -0.003628	 360.000386	 360.000386	 360.000386	 1.002506	 0.0	 1	 -30.0	 30.0;
	6807	 3472	 0.00198	 0.086207	 -0.009296	 285.000196	 285.000196	 285.000196	 1.052632	 0.0	 1	 -30.0	 30.0;
	4850	 2756	 0.00196	 0.06589	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	7830	 4541	 0.00174	 0.07467	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	2905	 6459	 0.000677	 0.032965	 -0.003628	 431.999937	 431.999937	 431.999937	 1.002506	 0.0	 1	 -30.0	 30.0;
	2905	 7783	 0.000667	 0.033601	 -0.003628	 435.59952	 435.59952	 435.59952	 1.002506	 0.0	 1	 -30.0	 30.0;
	2905	 1203	 0.00168	 0.101198	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	2905	 4537	 0.00165	 0.093702	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	6363	 4288	 0.000716	 0.031064	 -0.003628	 268.800429	 268.800429	 268.800429	 1.002506	 0.0	 1	 -30.0	 30.0;
	6363	 4288	 0.000736	 0.030437	 -0.003628	 274.800391	 274.800391	 274.800391	 1.002506	 0.0	 1	 -30.0	 30.0;
	6363	 4288	 0.000746	 0.029801	 -0.003628	 280.799696	 280.799696	 280.799696	 1.002506	 0.0	 1	 -30.0	 30.0;
	4288	 6191	 0.00192	 0.06735	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	4288	 6191	 0.00196	 0.06589	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	1404	 1907	 0.00179	 0.095578	 -0.003306	 177.840049	 177.840049	 177.840049	 1.052632	 0.0	 1	 -30.0	 30.0;
	1404	 3572	 0.00176	 0.097446	 -0.003306	 114.000605	 114.000605	 114.000605	 1.052632	 0.0	 1	 -30.0	 30.0;
	7401	 4756	 0.00167	 0.0776	 -0.006378	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	4539	 32	 0.00164	 0.07907	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	1960	 459	 0.0016	 0.07321	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	1960	 459	 0.00182	 0.07175	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	2743	 6836	 0.0019	 0.08995	 -0.009296	 285.000196	 285.000196	 285.000196	 1.052632	 0.0	 1	 -30.0	 30.0;
	2743	 6836	 0.00194	 0.088083	 -0.009296	 285.000196	 285.000196	 285.000196	 1.052632	 0.0	 1	 -30.0	 30.0;
	364	 6836	 0.00192	 0.06735	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	6592	 6881	 0.00196	 0.06589	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	4716	 4312	 0.00174	 0.07467	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	3939	 3962	 0.00387	 0.152273	 -0.007293	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	802	 7030	 0.000667	 0.033601	 -0.003628	 119.999909	 119.999909	 119.999909	 1.002506	 0.0	 1	 -30.0	 30.0;
	802	 2876	 0.00168	 0.101198	 -0.009296	 285.000196	 285.000196	 285.000196	 1.052632	 0.0	 1	 -30.0	 30.0;
	802	 2397	 0.00165	 0.093702	 -0.009296	 285.000196	 285.000196	 285.000196	 1.052632	 0.0	 1	 -30.0	 30.0;
	2050	 960	 0.00182	 0.07175	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	2050	 960	 0.00185	 0.07028	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	6550	 852	 0.00189	 0.06882	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	6550	 852	 0.00192	 0.06735	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	3566	 3346	 0.00196	 0.07015	 -0.003306	 111.692578	 111.692578	 111.692578	 1.07438	 0.0	 1	 -30.0	 30.0;
	1027	 3346	 0.00174	 0.0795	 -0.003306	 111.692578	 111.692578	 111.692578	 1.07438	 0.0	 1	 -30.0	 30.0;
	2633	 2454	 0.00136	 0.05901	 -0.003306	 169.860283	 169.860283	 169.860283	 1.052632	 0.0	 1	 -30.0	 30.0;
	2633	 521	 0.00133	 0.06014	 -0.003306	 166.440383	 166.440383	 166.440383	 1.052632	 0.0	 1	 -30.0	 30.0;
	2923	 5110	 0.00164	 0.07907	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	2923	 2120	 0.0016	 0.07321	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	1101	 6949	 0.000716	 0.031064	 -0.003628	 301.199963	 301.199963	 301.199963	 1.002506	 0.0	 1	 -30.0	 30.0;
	6949	 3986	 0.00185	 0.07028	 -0.006378	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	6357	 2001	 0.00189	 0.06882	 -0.003306	 114.330976	 114.330976	 114.330976	 1.049587	 0.0	 1	 -30.0	 30.0;
	4041	 137	 0.00158	 0.05564	 -0.00386	 240.000131	 240.000131	 240.000131	 1.0	 0.0	 1	 -30.0	 30.0;
	4041	 7013	 0.00179	 0.0695	 -0.00069	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	2668	 307	 0.00084	 0.04445	 -0.00392	 300.000068	 300.000068	 300.000068	 1.0	 0.0	 1	 -30.0	 30.0;
	2668	 307	 0.0008	 0.04546	 -0.00517	 300.000068	 300.000068	 300.000068	 1.0	 0.0	 1	 -30.0	 30.0;
	2668	 307	 0.00219	 0.08229	 -0.00286	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	2668	 307	 0.00069	 0.04566	 0.0	 286.306994	 286.306994	 286.306994	 1.047826	 0.0	 1	 -30.0	 30.0;
	8188	 3575	 0.00072	 0.04835	 -0.003815	 360.247862	 360.247862	 360.247862	 0.999313	 0.0	 1	 -30.0	 30.0;
	8188	 3575	 0.00082	 0.04738	 -0.003815	 360.247862	 360.247862	 360.247862	 0.999313	 0.0	 1	 -30.0	 30.0;
	4840	 2131	 0.00045	 0.03151	 -0.002925	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	4840	 7677	 0.00048	 0.026419	 -0.00297	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	2822	 7678	 0.0022	 0.07023	 -0.00201	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	2586	 202	 0.00241	 0.0727	 -0.00352	 171.074624	 171.074624	 171.074624	 1.052174	 0.0	 1	 -30.0	 30.0;
	2586	 202	 0.00081	 0.04644	 -0.007395	 342.149247	 342.149247	 342.149247	 1.052174	 0.0	 1	 -30.0	 30.0;
	3971	 2752	 0.00158	 0.08045	 -0.00072	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	7102	 7021	 0.00069	 0.04707	 -0.004229	 342.149247	 342.149247	 342.149247	 1.052174	 0.0	 1	 -30.0	 30.0;
	1398	 7530	 0.00075	 0.04866	 -0.002657	 342.149247	 342.149247	 342.149247	 1.052174	 0.0	 1	 -30.0	 30.0;
	1398	 7530	 0.00076	 0.04586	 -0.002602	 342.149247	 342.149247	 342.149247	 1.052174	 0.0	 1	 -30.0	 30.0;
	7922	 7771	 0.00189	 0.07781	 -0.00369	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	7922	 7771	 0.00205	 0.07804	 -0.0037	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	600	 6900	 0.00207	 0.091083	 -0.0037	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	600	 6900	 0.00211	 0.06802	 -0.0037	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	1807	 6780	 0.0008	 0.03997	 -0.004229	 342.149247	 342.149247	 342.149247	 1.052174	 0.0	 1	 -30.0	 30.0;
	2823	 6780	 0.00159	 0.086876	 -0.0014	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	2823	 6780	 0.0026	 0.07998	 -0.0037	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	4424	 6828	 0.00154	 0.086488	 -0.00288	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	7764	 4424	 0.00052	 0.033159	 -0.008266	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	7764	 6828	 0.00072	 0.0451	 -0.003598	 342.149247	 342.149247	 342.149247	 1.052174	 0.0	 1	 -30.0	 30.0;
	7764	 6828	 0.00068	 0.04531	 -0.001738	 342.149247	 342.149247	 342.149247	 1.052174	 0.0	 1	 -30.0	 30.0;
	4367	 3064	 0.00042	 0.030281	 -0.004199	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	4367	 7597	 0.00079	 0.04086	 -0.004229	 342.149247	 342.149247	 342.149247	 1.052174	 0.0	 1	 -30.0	 30.0;
	3064	 4746	 0.00168	 0.07343	 -0.0032	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	6676	 1794	 0.00038	 0.033591	 -0.007479	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	6676	 1794	 0.00037	 0.03405	 -0.005861	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	1538	 7815	 0.00039	 0.034849	 -0.00585	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	1538	 3412	 0.00063	 0.04764	 -0.002015	 342.149247	 342.149247	 342.149247	 1.052174	 0.0	 1	 -30.0	 30.0;
	1538	 3412	 0.00074	 0.044626	 -0.00328	 360.000386	 360.000386	 360.000386	 1.006865	 0.0	 1	 -30.0	 30.0;
	6631	 7120	 0.00069	 0.04232	 -0.002659	 342.000499	 342.000499	 342.000499	 1.052632	 0.0	 1	 -30.0	 30.0;
	7238	 6053	 0.00228	 0.07286	 -0.00201	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	7238	 6053	 0.00189	 0.07059	 -0.0037	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	2134	 1564	 0.00195	 0.07374	 -0.0037	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	2134	 1564	 0.00199	 0.07214	 -0.0037	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	3355	 5107	 0.00177	 0.07931	 -0.0014	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	3355	 5107	 0.00174	 0.08086	 -0.0014	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	420	 4369	 0.0015	 0.08239	 -0.00083	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	420	 4369	 0.00149	 0.091992	 -0.0014	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	7576	 3152	 0.00066	 0.04441	 -0.004229	 342.149247	 342.149247	 342.149247	 1.052174	 0.0	 1	 -30.0	 30.0;
	1602	 3152	 0.00171	 0.07418	 -0.0037	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	1602	 3152	 0.00175	 0.07267	 -0.0037	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	2342	 4457	 0.00053	 0.03038	 -0.005884	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	4457	 535	 0.00165	 0.07003	 -0.0037	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	4457	 6990	 0.00217	 0.07323	 -0.0037	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	231	 1299	 0.00072	 0.0453	 -0.004229	 342.149247	 342.149247	 342.149247	 1.052174	 0.0	 1	 -30.0	 30.0;
	6822	 992	 0.0021	 0.08257	 -0.0037	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	6822	 992	 0.00186	 0.087719	 -0.00365	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	810	 8144	 0.00076	 0.04796	 -0.007395	 342.149247	 342.149247	 342.149247	 1.052174	 0.0	 1	 -30.0	 30.0;
	810	 2938	 0.00075	 0.04466	 -0.007395	 342.149247	 342.149247	 342.149247	 1.052174	 0.0	 1	 -30.0	 30.0;
	3414	 6973	 0.00401	 0.10005	 -0.00243	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	3414	 6973	 0.00272	 0.07842	 -0.00243	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	3414	 6973	 0.00278	 0.07679	 -0.00243	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	3414	 6973	 0.00283	 0.07515	 -0.00243	 119.999875	 119.999875	 119.999875	 1.0	 0.0	 1	 -30.0	 30.0;
	2178	 4548	 0.00045	 0.029271	 -0.005928	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	2178	 4548	 0.0004	 0.033169	 -0.005928	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	2178	 4548	 0.00039	 0.03382	 -0.005928	 455.999787	 455.999787	 455.999787	 1.052632	 0.0	 1	 -30.0	 30.0;
	2482	 4720	 0.00064	 0.04577	 -0.002659	 342.000499	 342.000499	 342.000499	 1.052632	 0.0	 1	 -30.0	 30.0;
	629	 1790	 0.00147	 0.08395	 -0.00083	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	629	 160	 0.00184	 0.07633	 -0.00201	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	5534	 8342	 0.00074	 0.04352	 -0.004229	 342.149247	 342.149247	 342.149247	 1.052174	 0.0	 1	 -30.0	 30.0;
	1340	 4350	 0.00176	 0.08177	 -0.00155	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	1340	 4350	 0.00242	 0.06613	 -0.00334	 180.000193	 180.000193	 180.000193	 1.0	 0.0	 1	 -30.0	 30.0;
	1757	 3132	 0.00042	 0.030031	 -0.006382	 472.888668	 472.888668	 472.888668	 1.015038	 0.0	 1	 -30.0	 30.0;
	1757	 3132	 0.00043	 0.02938	 -0.006382	 472.888668	 472.888668	 472.888668	 1.015038	 0.0	 1	 -30.0	 30.0;
	7758	 8286	 0.00014	 0.01857	 -0.01473	 2302.026882	 2302.026882	 2302.026882	 0.0	 0.0	 1	 -30.0	 30.0;
	5285	 7381	 0.00037	 0.03395	 -0.004935	 472.888668	 472.888668	 472.888668	 1.015038	 0.0	 1	 -30.0	 30.0;
	3741	 3604	 1.8e-05	 0.052587	 -0.00965	 599.999547	 599.999547	 599.999547	 1.052632	 0.0	 1	 -30.0	 30.0;
	2577	 3604	 5.5e-05	 0.082396	 -0.00321	 600.000136	 600.000136	 600.000136	 1.047619	 0.0	 1	 -30.0	 30.0;
	719	 4479	 0.001416	 0.043162	 -0.004272	 150.000034	 150.000034	 150.000034	 0.92437	 0.0	 1	 -30.0	 30.0;
	719	 4479	 0.001603	 0.042296	 -0.004272	 150.000034	 150.000034	 150.000034	 0.92437	 0.0	 1	 -30.0	 30.0;
	3818	 3590	 0.000806	 0.025741	 -0.0232	 479.999638	 479.999638	 479.999638	 1.002506	 0.0	 1	 -30.0	 30.0;
	3818	 3590	 0.000826	 0.025204	 -0.0232	 479.999638	 479.999638	 479.999638	 1.002506	 0.0	 1	 -30.0	 30.0;
	3818	 3198	 0.000107	 0.01357	 -0.0128	 755.99989	 755.99989	 755.99989	 1.05905	 0.0	 1	 -30.0	 30.0;
	3590	 867	 0.00228	 0.07939	 -0.00387	 150.000034	 150.000034	 150.000034	 1.0	 0.0	 1	 -30.0	 30.0;
	3198	 3590	 0.001087	 0.065195	 -0.0096	 287.999814	 287.999814	 287.999814	 0.995672	 -2.273462	 1	 -30.0	 30.0;
	3198	 3590	 0.001067	 0.046326	 -0.0096	 287.999814	 287.999814	 287.999814	 0.998557	 -0.854786	 1	 -30.0	 30.0;
	5527	 3701	 0.001301	 0.061931	 -0.00554	 240.000131	 240.000131	 240.000131	 0.948276	 0.0	 1	 -30.0	 30.0;
	5527	 3701	 0.001268	 0.063098	 -0.00554	 240.000131	 240.000131	 240.000131	 0.948276	 0.0	 1	 -30.0	 30.0;
	6965	 981	 0.002358	 0.088053	 -0.00675	 150.000034	 150.000034	 150.000034	 0.948276	 0.0	 1	 -30.0	 30.0;
	6965	 981	 0.00268	 0.086295	 -0.00675	 150.000034	 150.000034	 150.000034	 0.948276	 0.0	 1	 -30.0	 30.0;
	7141	 543	 0.00078	 0.030576	 -0.034641	 479.999638	 479.999638	 479.999638	 1.057818	 -0.198597	 1	 -30.0	 30.0;
	543	 3863	 0.001565	 0.062128	 -0.00582	 240.000131	 240.000131	 240.000131	 0.932203	 0.0	 1	 -30.0	 30.0;
	543	 3863	 0.001588	 0.060806	 -0.00582	 240.000131	 240.000131	 240.000131	 0.932203	 0.0	 1	 -30.0	 30.0;
	4894	 7295	 0.002713	 0.092944	 -0.004201	 150.000034	 150.000034	 150.000034	 0.916667	 0.0	 1	 -30.0	 30.0;
	4894	 7295	 0.002464	 0.122138	 -0.004201	 150.000034	 150.000034	 150.000034	 0.916667	 0.0	 1	 -30.0	 30.0;
	4596	 402	 0.002739	 0.116189	 -0.00218	 150.000034	 150.000034	 150.000034	 0.932203	 0.0	 1	 -30.0	 30.0;
	4596	 402	 0.002681	 0.118434	 -0.00218	 150.000034	 150.000034	 150.000034	 0.932203	 0.0	 1	 -30.0	 30.0;
	5805	 550	 0.000212	 0.011512	 -0.007263	 1079.999496	 1079.999496	 1079.999496	 0.970907	 2.77215	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Gen Active Cost Model:       stat
% INFO    : Setting Voltage Flat Start
% INFO    : 
% INFO    : === Generator Classification Notes ===
% INFO    : PEL    97  -     1.88
% INFO    : SYNC   2   -    -0.00
% INFO    : NUC    121 -     7.61
% INFO    : COW    879 -    60.94
% INFO    : NG     766 -    29.56
% INFO    : 
% INFO    : === Generator Active Cost Stat Model Notes ===
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.1306458562 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.8991310832 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7149747182 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5641373637 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.3114479459 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.442460948 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.4975069438 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.74787885156 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6085248204 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4250281254 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.16916575 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0960075069 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.50274387918 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3007369559 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3320689145 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.315452348 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0890042662 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.9645147544 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5042956998 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.75285008418 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.2585536613 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.4046427374 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.1645133848 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.9094211457 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.6191258211 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.9072843859 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.3081742282 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.21863635574 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.831524812 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.8661805638 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.2890717451 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2946257283 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.1143661713 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.1889959514 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.99795591869 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1991325058 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.9609164018 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.8794559083 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.0751902215 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.7742214092 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8221360053 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.4967125479 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.4597893347 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.7780739713 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.4975247959 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8219460201 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.6521055992 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.7810251989 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.355020489 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.3293353569 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8579655369 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.4321932241 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.3723109897 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.9299652762 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.1938588305 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0482464098 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2449338677 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.279794676 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.33309138447 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.5432141331 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0692471903 0
% INFO    : Updated Generator Cost: SYNC - 0.0 1.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.61305278746 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9456457226 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 7.10344341583 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7528584492 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.4367800009 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.591305232 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6487919592 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2528072526 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.9169471615 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.4288800448 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.662180533 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.2832713272 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.3622412216 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.1813413352 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.673744916 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.732707098 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3143916184 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.6036155206 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.709033286 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.818856654 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.4912832743 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.7046114124 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.4047213922 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.09137920973 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.1817334802 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.3143818709 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.5764260218 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 8.46554294288 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.7889356251 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.5842290725 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3222015015 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.263223231 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.568688211 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.5257444046 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.00059017486 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.127710278 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.9960322003 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2380712942 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.224555898 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.042402504 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2266127037 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.4460386051 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0864065607 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.4190195204 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4463146573 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.6896148872 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.9171163584 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6578840954 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.1731510399 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.1084506714 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.5308061045 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.5328130605 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.816016344 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.8504289815 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 43.127372789 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.7269593837 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.2244547224 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.6229336143 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.6538282893 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.5390020938 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.6120769537 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3449354631 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.5838141 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.4456414013 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.1104354269 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.48063781442 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.3100110128 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.5162690165 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.3033150749 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.417375281 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.0513252545 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7686446601 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.6005830522 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.708149775 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.1655339193 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.4830649289 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.409557399 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.91101138639 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.8569918437 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.207234029 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.7164511915 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5145164154 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.5153366341 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.27017926 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.5089104241 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 2.88146047796 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.4367719444 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7924695125 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.6351190558 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.4222397814 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.0218254794 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2728326788 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.8821085997 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.7834144973 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0794741866 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.861316328 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.5751381809 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2695001252 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.5299457161 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.8120251375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6321798971 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0514025292 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6791249649 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.0144908526 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.0265150606 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.4397848359 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7489607265 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.097730506 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.789745133 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.8197449453 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.5829856996 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.9213078391 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.3044137531 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.07245440723 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.7130510923 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.5580188471 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.436487191 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9906165764 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1374779021 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.4995285145 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.4996992621 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.34503785395 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.1949179113 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.9990217287 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.9527914604 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0336569952 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3647879091 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.4036883822 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8470289486 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2899161053 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.7658484592 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 4.82523716607 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.8377778296 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.283237134 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.489572375 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.1872053675 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.4031889492 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.4895892272 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.1634358701 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.312194872 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.4233467075 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1157112368 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.7343895541 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.2130953073 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5743643589 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.6833822562 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.959305154 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.4074819357 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3904959652 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8886166489 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.2746576625 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.46720497434 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.6094183422 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.2232767336 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.5343970582 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.8633715876 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.0249941894 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8264038085 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1295595496 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.3133768657 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.64145335138 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.3605313698 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.5326895539 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.134541788 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.7552738934 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.6871757959 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1905880142 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2192807032 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.8037287166 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7952120161 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1772325825 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.219263212 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.8831164455 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.52882627597 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2972330633 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.2037457742 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.86422233 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7985292525 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.8174491486 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.2365657583 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.0631056523 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.65208849576 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7447683719 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8781304541 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1780953511 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0710981022 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5120991516 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.2431673893 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1703579612 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.910098456 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.4599952405 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.442501115 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.0638936424 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0368745773 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.97808883 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8442504898 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.106392503 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 97.6776224329 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3205293565 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.1501059604 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.1853619357 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.501804878 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1603836398 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.9043766604 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.4981955603 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.9583103469 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1731992449 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.8848178933 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8264655044 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8596661957 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7589358339 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.3133989421 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7535597203 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.9756159127 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.4147275723 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 6.97340744023 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.8723055845 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.8382641514 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.1469510568 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.1024754187 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.4443529589 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7678636152 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.08212901522 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3099858458 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1942670544 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.8037364764 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.0810916484 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.610338249 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3498125598 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.177532727 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.4217054265 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.240764341 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.85819781 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.82444205708 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.8398161547 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.1675311843 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.3705868502 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9418608064 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.5265623164 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.6223989239 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.1149406045 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.8781686584 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.24196842 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2610415774 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.2639374581 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.8107636301 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.6203820864 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.52692942 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.9130194562 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.44004824171 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.14753058364 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.2311592808 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.2205650573 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 41.672904637 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8549823935 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.9518224484 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.492634316 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.7168409403 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5322966828 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.2884799348 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.5598478087 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1487502683 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3084756935 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.9336221481 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7351840513 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.4230809684 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.830875233 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.4679660472 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2448450996 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.27750356615 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.8039468403 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.4406352449 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.1322107218 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.02474547442 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.4937316654 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.10408311216 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.0274888457 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7361807968 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.9890749807 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.8414277858 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7814906463 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.4975712048 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1624637935 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6400791347 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.5768758956 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.96588409 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.3177275086 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.9254369946 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8445308804 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.219542364 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2462338417 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4281249952 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.2289838474 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.2018651801 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8968395002 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0997753951 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7699743005 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.2310802133 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.002586523 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.0496646553 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.4198625566 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.5664142016 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.918479899 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2776279343 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.75867581 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.40789204246 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.1529465803 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2650839175 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8977195315 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.5601066341 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7535714667 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.5364628588 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7632733204 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.9435749587 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.3735153194 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.4022465916 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.562999021 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.4300895423 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 2.83284868503 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.269667304 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.115073643 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.1580094746 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.045075328 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.5322487298 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3334328206 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.4289528786 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.588483576 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.6423957262 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5228997904 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.1096837324 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.7425786799 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.6372042289 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.0680988755 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 4.24883643435 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.8560313259 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.2849989994 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.22182359313 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.048633126 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.258387401 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.539690793 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.6732058264 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.6221208313 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9974188829 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9907127553 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.6765613788 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.3509179986 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.31673028185 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.2710454198 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4737471653 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6705534078 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.6101141944 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.7065074159 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.885748493 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.1848008287 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.2696417604 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3713252305 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.983831575 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.881458464 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5182672087 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.2635906958 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.4273700209 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.9510931205 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.060015121 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.1544421836 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4882066256 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0996369631 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.0807541118 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.29939069916 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.86154159873 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.87528203688 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0748295884 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8655342571 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.0616276617 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.005609532 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.7419107549 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.25775630198 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9572403857 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.5092636857 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6614982497 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5035086479 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1455263178 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.9589684777 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.549093662 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5391301174 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9523033796 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.412505019 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9324706071 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.0019395485 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.6948401029 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.9244910554 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.990044169 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.0838274987 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 1.21475505334 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1344419818 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.5277447195 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.6084501438 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0207361908 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.9410403372 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8376377869 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.79412341 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.5824770247 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8870330004 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3191392823 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.7297395003 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.4134220215 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0373498328 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.26272498471 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.2356649664 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.81928670277 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6431927775 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.1777421856 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.1251032052 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.7280793879 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.2781813366 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.9502146255 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2552587754 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.4476150481 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8730986985 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.9539319495 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.9090967469 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.91093795514 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3650257328 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.021550489 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1453581909 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.0095758186 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.450888643 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7271093745 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.5909114809 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.14966818165 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.935476727 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.292178073 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0491483682 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.8564342373 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.0873515764 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3406582311 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7946207123 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.5240704354 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4824385553 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.4766048321 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.6577831123 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7126553013 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.4130400702 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.815636812 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.87071524382 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.9653930302 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1896074105 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.3391246301 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.40175894 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.3076085429 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8926954615 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.9532084053 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.8293263196 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4035510161 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.0966177115 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.3609301402 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.51194976279 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.5199105305 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4329550886 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.2657037483 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8872593244 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.6894044133 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.0514237188 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9713072258 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3057713477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5775549281 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.7919797554 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.78369421968 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 6.02206214021 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.6943288378 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2454417357 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4252749428 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 6.95547301119 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.9037405336 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8509164718 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4766066253 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.1719214908 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.0077860989 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.0867186489 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1259182553 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.2974593459 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.51157491609 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1793017751 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.0019301222 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8605832024 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.2361997032 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.7648901917 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.350685254 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.0898630779 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.8972120492 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1833255001 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.3952103269 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4325393644 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.38906053345 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.868274178 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.6116220347 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.695053507 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8353892565 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.308373308 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.13158732689 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0232026358 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.5490720105 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.235073611 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3779875194 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.0025150573 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9306470203 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2263772131 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.7673937112 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.487329854 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.165645182 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8904218047 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7045445137 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.0620086183 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.0499826756 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.3701196393 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.3122334366 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2502255251 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.9368896799 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.2146759336 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.7365740354 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 95.9486678367 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8644631925 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8884712801 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.2051621856 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1122784248 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0769215907 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6639648049 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.8234461338 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.881018433 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9313178861 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.0856664028 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8113005573 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.088044192 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.3798712886 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.2693590515 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.0953426773 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.365074182 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5377189827 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.1187952049 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4781392972 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.190560361 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1803740463 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3411438011 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6914087134 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.761222668 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.826573706 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7332623718 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4066079038 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.332106368 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3212317052 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0625716048 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.42253528062 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.4964401088 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5543391962 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1583753024 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.2282614885 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2647483982 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.210377868 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.2102815549 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.651667449 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8963302463 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.074793116 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8711413135 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.5775965399 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0234647436 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.027303994 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.8373675779 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.7240557911 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8962415107 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9944695038 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.05881262072 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7753265039 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.2880443734 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6640030749 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.4168496929 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.4360442722 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.9786144838 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.8578610899 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.5797954795 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.8083251903 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.4835839816 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.6683513977 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8614497126 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.8035201718 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2662544426 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.803152028 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3782061845 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1956062382 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.2130203435 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.6627752489 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3486377088 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.3264827841 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.460693695 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.534843599 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7937635226 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.928541369 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2912359143 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0197938509 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.7413669828 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.3487867728 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.2630316339 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.2711569907 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3395268995 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3231119125 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6791959469 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 93.8476944422 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4167594989 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.9718478639 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.8687209154 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.4783146233 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.7763494218 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.8911031256 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0410246548 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2171775927 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.077154043 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.3805453892 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.600091754 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.3305888782 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.4649014425 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.0473024082 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7656513457 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4717766743 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.9260668378 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.972867846 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 94.8493921009 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 8.05641336357 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.382444707 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6164979572 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6867349072 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.9654166205 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1733076333 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1470724318 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2220707098 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2442232491 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.478918135 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.8359929265 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6398548307 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1494756069 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.4417673946 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5423050232 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.8841355738 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 130.905926256 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4762493703 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.91487375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.6697512661 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.9131035548 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.0226561869 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6698595871 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.8597589173 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.9889480337 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1966437087 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.5027692665 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.6062957907 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2501335604 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0969636181 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.9524607627 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.9262162927 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.5842235237 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.3158873974 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.1964195514 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.9173998507 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.6648185408 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.483480804 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.9743044805 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.7784108017 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.4463713947 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6609003075 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.0285696195 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.2431237773 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.9943675847 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.2546805361 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6545026922 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1606088108 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.015588215 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7791339547 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2159090056 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.9061458827 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.9894480894 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.0048814205 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.34504778599 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4204080481 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.8187950454 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.0718207828 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.5784197616 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1769300523 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.5418323931 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0320351842 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.36745528791 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.8184942884 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.02226561262 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.71399812601 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.7002057347 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.0096218262 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.030947348 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.6697839139 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.5349404285 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3380493657 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.843993644 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8110234698 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.832937249 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.7592411869 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0230577305 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.282078622 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.499053118 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4429519391 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2415273063 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.67593930424 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.8235089422 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.2011936768 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.3387738388 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.4266924536 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7363217472 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.347896757 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.32965682 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1034998572 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.4292762659 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.9603403578 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7156347746 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3060629565 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.3417541397 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.66034699244 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4419461556 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.7473132104 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0673811337 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5737430456 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.6458174243 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5842787889 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.8829227307 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.7734968452 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.46980669 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.22528658489 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.9971874231 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.83082808004 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.8871424762 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.4408383073 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.9915715395 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 8.91391648674 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5689247738 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0759373587 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4245233948 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.2299711062 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.1432509465 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.8757132574 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9767364051 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.5592272663 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7749524893 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2321109869 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.683051385 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.9260846084 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8090018884 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.285631355 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.1982661474 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.0740718278 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8402930715 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.3557076064 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.4225303862 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9133942453 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 6.15766497533 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.0228957138 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.89902334402 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4071293788 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9715570761 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1029116765 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.1509059923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4930357247 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.0395000696 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.0875394787 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.6206056656 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.2215831447 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.1820179619 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1401177988 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.4922998801 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9696667479 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1152760702 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.6555326945 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.412158981 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.580806206 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.1760176197 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.0835908006 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1254309489 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.8055006833 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.9655025152 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.1468606461 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.9786959475 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1182786509 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.7728565884 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6373986304 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.4058621477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.5348196136 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1241382097 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5790707334 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.0719626623 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.4900872944 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5360441266 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.8219796925 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.3982023923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.694552454 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.535407858 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.663809663 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.7513769093 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.28624898576 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1317688117 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9655299468 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.4665330701 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.4366385531 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.6326026946 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.4535824943 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.334048158 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1631686695 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.2053090931 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.68471500675 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7031472057 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1103146051 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.8448915775 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.217086609 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.7599416536 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.7696559401 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8123802785 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.9916967193 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8861955294 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 126.357977448 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.6381396313 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.5384122252 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0906424057 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 46.2016305194 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.160210046 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.71840645423 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.1954283642 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.923803912 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 7.21820099636 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.0738164939 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.0376236982 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.9880165487 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.9774099407 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4014795083 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.6536528441 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.6364548518 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.545679243 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.8397415139 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5964168299 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.1635715825 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.9257182285 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2996267125 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1585007071 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4067065098 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7526716775 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7056337478 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3466914998 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.3389404895 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.6870701956 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.7536047242 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.0344970331 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.5675158508 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.56024242301 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.9313988234 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.6002294751 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4591552998 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9071017422 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5988341448 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.4248875797 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2258136424 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.1896800526 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2413741487 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.819104002 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.9246034836 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7537819194 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.421989288 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.6360444066 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4614850103 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.5371495014 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 43.1271294898 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.1512005265 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.5959844799 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2293438517 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1793859633 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.1016853245 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.0687734793 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.6977211398 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2976929875 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.065476096 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.1722115514 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.0214389522 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.460927616 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.5199900997 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0152082046 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.3541330389 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2907447597 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.4975301603 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 7.69456145046 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.0244642857 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 44.4330834521 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.0184178935 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.3635154621 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.4723999306 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7710245285 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 126.952295414 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7350888647 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1988176586 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8168116437 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.221812225 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.2339995363 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0254787271 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1315126338 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0230605776 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.9950877648 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.01739892813 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.6208859232 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.8178061865 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8108885432 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0790637171 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0799056649 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.1217732761 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.4466342974 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.4397629769 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0959252063 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1229902391 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.29132195972 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.0138010632 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.2019041001 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.9219391088 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.5233742121 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8247394648 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8571038799 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.1107539749 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.8423945058 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.6583856259 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.8304297108 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0963711249 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.9790294517 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.8365155377 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.8666184072 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.423330444 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.6228558135 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.6332364284 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.621876699 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1708094553 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.3663974103 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.0699165677 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.7113043104 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.5379237726 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.3476409303 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.87343784862 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.16233796195 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.9743759188 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 46.5805062451 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.739354979 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.650414055 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8724652227 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.7059340276 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7335307854 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.7016628296 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3817443631 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7403351048 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.709427265 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.7377118022 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 1.78314887137 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.2271720779 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.2327178018 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.5540631318 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.8748015729 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8524146924 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.7092870813 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7226750175 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.2257395136 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.97188168477 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.88510233222 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.6755777453 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.0805769263 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.1653540082 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2980614444 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.4772375337 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.0962122133 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.6171012411 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.439556046 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.3273118901 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.860209072 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8183699755 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.5683113636 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.4157806783 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.85021803981 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.198247212 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1418600704 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4088973842 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.2000985687 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.23683150469 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4431216341 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.430938954 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.702589895 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.7097638292 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.3811139833 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.52851235908 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.3719818207 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.6746157444 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.83945317138 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.674919841 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 44.6533062749 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6546236582 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.9698957164 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.131873198 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.2693572223 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.072279332 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.8695989112 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.01557343123 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.9753439676 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.6298943217 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5164791479 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 96.8183335958 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8157624868 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.2710217519 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.4589285424 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1988778455 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8463349779 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.8856472215 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3905559397 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1598175718 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.91637416 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9189048598 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.4320359271 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7550675228 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.3361498561 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0245683664 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3632603796 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.71640683556 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.690824041 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7458372358 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.0999284961 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8682357119 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7455189691 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 60.7145197857 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.2956667159 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.5440917239 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.1115037815 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6275870225 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 6.21902165596 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.4502774613 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 8.44207569297 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.7651731129 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.775483752 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3769608446 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9523235317 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.6632855229 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1411220524 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6920048803 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8723761551 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.5999104116 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.6701299154 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.590010325 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.7864530364 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2199216711 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.67653705163 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.9708792324 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0564981979 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.3674062844 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2596261321 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.9870234288 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.9517491631 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.3572585346 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.91612398486 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.8985059196 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.39012153716 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.7120018133 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7981594354 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.52032423927 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.8439557631 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2044465654 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7004041132 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.17649316398 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5649473913 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.23599511887 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.366406188 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.2579335214 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.064542717 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.7526078067 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.2048271016 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.9687303792 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.9606161726 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5752879524 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.49372173 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.4369563874 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.261991836 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 63.9145332917 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.6995955705 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3477315019 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7243835048 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6134173183 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.8560382589 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.6779699011 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.715872544 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2130625606 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7098018615 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2056312114 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.6073738572 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4641826877 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5273861227 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3120724738 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.4111354485 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.07738474898 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9199742544 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.9724938873 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.1917120827 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.319393261 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.1171980335 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.214755011 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.45351907095 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.2827662263 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.8868774443 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5418203739 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.3842184282 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1749694939 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.590709022 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.3629700373 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.7311369186 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.2335711512 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.0392116409 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.3732226435 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.8206610887 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.72781563 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.5141349864 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0444167424 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.0445862635 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 43.373546091 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.64573826975 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.2330751366 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.522068587 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.361603764 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7089339689 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.7893820246 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.6548531221 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.7630088021 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4137970812 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.3930801163 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4049231724 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.4445379474 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.2456192482 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1289154754 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.909561847 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.8531848483 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3913586297 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.5777245701 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1387703073 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1577810049 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.1448921248 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0943321064 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.9179958524 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.8111983367 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.7745400965 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.9093253854 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.55705358999 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.518238685 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.0756179967 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0313014597 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.8821404992 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5471469228 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1123812498 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2165225811 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7697072874 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3809881981 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.9631287 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9003647887 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.8951032292 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6784891892 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.680633204 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.5148072206 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.0351431151 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.8357456928 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.7648532698 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.3589988335 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.1765940573 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.2615773848 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.3199990646 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7054388983 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.4351853424 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.9354951489 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.4831108066 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.0307518316 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.49306194105 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.5484115555 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.8101357389 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.7857306014 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.8235861823 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2501448201 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.9743186254 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.62111295838 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.8956976738 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5157209258 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.231174427 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.4106304963 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.0561235041 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.49690730061 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.6330136368 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.08826954 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.631071072 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.705598748 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.0139280588 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7583860507 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.359487782 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3735019366 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.67551503 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.1521566886 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.9550792987 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 46.3233170486 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5476762295 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.1847612457 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0909974437 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.1221370729 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.1890815152 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1088149851 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3573262454 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 6.05178778793 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.98351828079 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.0116456782 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6610511697 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.9373313319 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8064318064 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.9794226146 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 5.89539310771 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.8104629141 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.57146125073 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.2545968676 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.75570560772 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.81180556054 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.2497243357 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.5808657393 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.4623744482 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.4432586787 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 89.0771122578 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.0455633087 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.0821050462 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.4088189408 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7225555655 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.288181875 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.42347992208 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.398881686 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.8175302029 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.2646293684 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.996478111 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1656567071 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.98583729162 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.3998477203 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5169512327 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9379566894 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.4729419618 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4608602021 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.3943400536 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1215646146 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1585497427 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1996792865 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.5238502904 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.0025498817 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8340207343 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8282510393 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.7256990293 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.2229804608 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.4045469997 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.2746961066 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.0058331332 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.883224411 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 2.3541574521 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.6853571507 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.5441330941 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.2487266119 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.2663385163 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.20072944774 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8697301674 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.6413173278 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.33228874151 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.509102833 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2128624837 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.3611128872 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8910285883 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.6458263725 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.0571576413 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.6527420599 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9383209333 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.3096556516 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.3025923508 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8729765694 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.48535208536 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1456405063 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.7352239337 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.3611749848 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.179536641 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.7837215661 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9493488155 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0078951836 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.64675618608 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.854731431 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.474678292 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.6548996541 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.6798555536 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.6739788315 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.0284677039 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.9313354071 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.2524019041 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.8907986221 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.675832045 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.45234974613 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.394915642 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.1845595622 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 50.4152780176 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7950098806 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.9928114554 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.2013487526 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.4204543827 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.8468022208 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.2252556854 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.1954956951 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5327406163 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3670208297 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0072547618 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.764579837 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.1037276118 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9720052464 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.1881549496 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.4619741918 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.6021407404 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.2108858727 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.0043615651 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.4833995911 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8773631255 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.9988759885 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1761572241 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.4319051342 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1621987264 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8855347865 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0737461926 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.974192467 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.2027274193 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.947551333 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0000748179 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.276275335 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.0257236597 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7574575597 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.7339367468 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.22486352513 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.444835323 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.9213111327 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5306507653 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.7024367951 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.1660187578 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.6932535773 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.324354721 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9869033735 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.5847101965 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5511712833 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5497612075 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.4941583177 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.9298470494 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.98677921039 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.7228254112 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7723707155 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.6686373186 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.362852776 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.5869270936 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3112196046 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.249611909 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6598564203 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0318768929 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.2275302386 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.5586185544 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.1721123096 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.72233653087 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.6757370843 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.2479469186 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.9626854382 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5961442887 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.5019241864 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 47.7940375522 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4466167915 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.6561806076 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.9962658323 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5297081992 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 47.1703813836 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.7165132054 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 2.83624120074 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.2307600475 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.6648209849 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8705312218 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.8278491077 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.3189956338 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.479863168 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.3305219536 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2984060874 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.5460349233 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.59212933854 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.462935463 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0520544659 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.5582025721 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.53408375557 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.9697045149 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.8466994514 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.4302458162 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.7009561902 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.8817979709 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8038564637 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.1480311804 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 60.442235818 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4046308546 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5182221559 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.7910156453 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.7368525367 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7442636738 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5496599649 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.7290356855 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8748487107 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4749864544 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.5091000308 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.40076818635 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.890471449 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.200070532 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.3626321164 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5440661892 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3115036063 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4987856238 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.8245181513 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.2447484505 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.5291713564 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.40135292234 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8463136064 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.364483554 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0274728222 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.6845629376 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.7763430288 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8909755874 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.0684534039 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.2807381698 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.4255041323 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8020820585 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.9077541902 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0447822572 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8561461143 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.97078089383 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.7204986348 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.8763358505 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.8058426031 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.7580958658 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.2211634391 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.6933940282 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3372764567 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 5.09666277303 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0512868727 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.6129151741 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.7295088471 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.6132958902 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.3174054626 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3392262808 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.7518803527 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.9599006778 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.847854714 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.8669334093 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.4208005325 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.4099924455 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.711295878 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.966967678 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.3307762785 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5242974615 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7816155193 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1249383944 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.2900025001 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.907945028 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.5359819262 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.728515195 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1495197685 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1645811069 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.3582505351 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.35033356552 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2672899032 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.36923600417 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8686281763 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.1943109455 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.9911007038 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0192866773 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.536700948 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.0777012377 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.4112346727 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8064499409 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.9381290942 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.1523805988 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.4215208616 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.5086905275 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.8675536164 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.6041516655 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.2761107487 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.8481132962 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.2914411792 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.7337174466 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.681098773 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.6329695001 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.9419317515 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.9261815437 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9218019284 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.3301813652 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.5501421231 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.291981085 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.0664655651 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.267570863 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.3816426808 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.1770807209 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7276636944 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.59896765822 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.043041455 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.773397574 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1900501066 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.8659387105 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.344623026 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1747492876 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.0336270841 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.9517360421 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3599739939 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.3695248309 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8559889347 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2807840142 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.39614308205 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.6148031097 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.124258535 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.4364307455 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.3421194214 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7880320825 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2715432868 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.6262625853 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.402796471 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.0748338559 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.7861790319 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.8146192437 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.453013163 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.5133436897 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.3683082715 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.0098200808 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.8562720734 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5192966553 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.3695795829 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.99878080763 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0425166735 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8950019583 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.7301689594 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.8617911048 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.2569646948 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.7018592132 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8935691651 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2789399642 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.673184409 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.6967786233 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.5236978498 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.4599176724 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.1711234366 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.4945703018 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.4525094169 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1489783832 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8101797561 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.9799892231 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2111889805 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.0247232774 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.5481219565 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.7617878689 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3066423439 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5035480411 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.1773183554 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7500177569 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.9141103003 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.6532707918 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2150075209 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8591868538 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 92.6696654627 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.5174402702 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.3577245499 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.8606463916 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0728496917 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.3270803116 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.3248892948 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.481272878 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8831059426 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.217559062 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.460956201 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.7222574546 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.97830924244 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.6028653109 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.6529902372 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.669332916 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.1230416847 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.3898081153 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.6678999228 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.6929390887 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.9274024664 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.214681491 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.9901790431 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.764369336 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2566627696 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9741955177 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.4720740665 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.1991331098 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.1762855851 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.08815098913 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.0048437246 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7903612045 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.6809633734 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.3138083145 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2819409516 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.5238362897 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.998402943 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.5632526136 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.838526592 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.511853277 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.2926965832 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.4172737662 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.1863647128 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.2730539 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.0421378625 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4669921741 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.9714953787 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.7512723912 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9943766892 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.1212981073 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.4134326393 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.6958990882 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.84419505737 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.3179583146 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2810088093 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.8449432911 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.2740748498 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.998217595 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.4705250837 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.5391979741 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.7463623623 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.4431414094 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7947794748 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7425461411 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 45.0891830527 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.9559606867 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.8648462194 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.4360150816 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.5447540638 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.51876434666 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.4667275102 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 2.06800122178 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.3475300938 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8952319238 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4450294109 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.7355319533 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.4320341602 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1951319052 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.02330925 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.2539054019 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3693043915 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.10900210597 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.84724553197 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1004004966 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.0996055683 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.0933164959 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.7501688859 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7139459972 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5099131962 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.8515815218 0
% INFO    : Updated Generator Cost: SYNC - 0.0 1.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.0556659453 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.2663693422 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.8801995051 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.37829033159 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6080371249 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.9934646595 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.0522232132 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.0991402148 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9680311967 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1442654799 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.6541860146 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0125525731 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2548313985 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.5763641647 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.9758256024 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3642262612 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.7032968236 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.526198085 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3114068893 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.1309232867 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.80061943497 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.6368551769 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.8926977038 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1136511178 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.396551381 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.292399822 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6800348534 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.6126426817 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.6421722817 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.9296354587 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.577245529 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.4394384724 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.8952336164 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.8812052159 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.1303465641 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8522528504 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.7562997757 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.6546683114 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.0822378586 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0655180683 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2639567605 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 90.8696299981 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6442691161 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.5138463181 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.4447403252 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.633220685 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.5246937127 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.7951969613 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8672486348 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.6122649278 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.6836399598 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.349366187 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2240187434 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.211130519 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.1933184756 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0210496902 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.4133029761 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 8.93593980806 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.5396381843 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.784559516 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.28418632 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.9507337056 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.9094456494 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6028430151 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.8997849018 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.736095897 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5106013232 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.6692480747 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.9775095602 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.3936228862 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.4459669189 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.175479 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.6905931734 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.7847531366 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1235770416 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.5402076363 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 47.5467545421 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2719470665 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.83293780807 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2880921997 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.2599619353 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0292181253 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.930803247 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.1402681426 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.4860260727 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.3193336189 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3812417809 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.94188837652 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.5107124132 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8158406824 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9909836358 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.9655901115 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0811900193 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.08927098 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.21918094021 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.8370788201 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.5556687873 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.5162185635 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.2380858605 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.442039169 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.4240678275 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.51882383992 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8585013287 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.8429927477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.2822749808 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.6416404243 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9469704071 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.6547370873 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.4430858059 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8277430398 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.859943855 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.04518045799 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3822557875 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.2190821284 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.7008891181 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.9357203778 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.24265048822 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.5529874301 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2520920428 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.97699635 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.5523968689 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.7386796849 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5954876409 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.8570998123 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2230289692 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.5810313099 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0302848113 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.5152150343 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.7141901146 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.1494026976 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5221418001 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.2822722131 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.7952091583 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.9930725015 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.7852386378 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.560233546 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.3641013059 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1453645299 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.931047846 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.4897330025 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 58.9550235121 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7682380213 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.9270052039 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.5591202093 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.6248291534 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.1106181179 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.995008051 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.7554343356 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.4815318235 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 7.42036383768 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.3342005487 0
% INFO    : 
% INFO    : === Generator Bounds Update Notes ===
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% WARNING : Transformer 7289-3662 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1812-932 connects the same voltage levels (220.0, 220.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3052-4670 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2336-5745 connects the same voltage levels (220.0, 220.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2007-608 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 8178-6540 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1608-7405 connects the same voltage levels (220.0, 220.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6932-5186 connects the same voltage levels (220.0, 220.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 7189-5561 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 7189-2685 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 7189-6236 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6526-4902 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6526-5671 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4194-8172 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4194-1410 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6672-8318 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6672-3669 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6672-5299 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6672-4005 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4399-313 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4399-2934 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4399-4543 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4153-1592 connects the same voltage levels (220.0, 220.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4153-5060 connects the same voltage levels (220.0, 220.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4153-3711 connects the same voltage levels (220.0, 220.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1336-263 connects the same voltage levels (220.0, 220.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3364-838 connects the same voltage levels (220.0, 220.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6863-1064 connects the same voltage levels (220.0, 220.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 8057-7392 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 8057-1242 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3776-2985 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2119-4602 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4659-1477 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3040-7212 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2387-7419 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2387-6269 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 7758-8286 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 1	: V=1.038963, theta=-34.89481 -> V=1.0, theta=0.0
% INFO    : Bus 2	: V=1.026375, theta=-20.392332 -> V=1.0, theta=0.0
% INFO    : Bus 3	: V=1.040071, theta=-6.609053 -> V=1.0139425, theta=0.0
% INFO    : Bus 4	: V=1.01637, theta=-46.441272 -> V=1.0, theta=0.0
% INFO    : Bus 5	: V=1.060105, theta=-39.700511 -> V=1.0132805, theta=0.0
% INFO    : Bus 6	: V=0.901905, theta=-32.067072 -> V=1.0, theta=0.0
% INFO    : Bus 7	: V=1.075492, theta=-22.993847 -> V=1.030475, theta=0.0
% INFO    : Bus 8	: V=1.030663, theta=-24.28533 -> V=1.0, theta=0.0
% INFO    : Bus 9	: V=1.03402, theta=-18.796018 -> V=1.0025235, theta=0.0
% INFO    : Bus 10	: V=1.045776, theta=-45.266112 -> V=1.0, theta=0.0
% INFO    : Bus 11	: V=1.098764, theta=-14.368752 -> V=1.0334475, theta=0.0
% INFO    : Bus 12	: V=1.064712, theta=-44.0377 -> V=1.0066845, theta=0.0
% INFO    : Bus 13	: V=1.010989, theta=7.736285 -> V=1.0, theta=0.0
% INFO    : Bus 14	: V=1.040474, theta=18.686769 -> V=1.0, theta=0.0
% INFO    : Bus 15	: V=0.993806, theta=-34.020232 -> V=1.0, theta=0.0
% INFO    : Bus 16	: V=1.074018, theta=-20.85146 -> V=1.0268015, theta=0.0
% INFO    : Bus 17	: V=1.081379, theta=-17.543279 -> V=1.0230795, theta=0.0
% INFO    : Bus 18	: V=1.017163, theta=-21.39745 -> V=1.0, theta=0.0
% INFO    : Bus 19	: V=0.927816, theta=-27.872689 -> V=1.0, theta=0.0
% INFO    : Bus 20	: V=1.012955, theta=14.035448 -> V=1.0, theta=0.0
% INFO    : Bus 21	: V=1.079094, theta=-3.040599 -> V=1.020041, theta=0.0
% INFO    : Bus 22	: V=1.074452, theta=14.420626 -> V=1.021053, theta=0.0
% INFO    : Bus 23	: V=0.96616, theta=-25.110965 -> V=1.0, theta=0.0
% INFO    : Bus 24	: V=1.067288, theta=-12.812268 -> V=1.0109295, theta=0.0
% INFO    : Bus 25	: V=1.014514, theta=-22.601714 -> V=1.0, theta=0.0
% INFO    : Bus 26	: V=0.935328, theta=-28.779899 -> V=0.9898635, theta=0.0
% INFO    : Bus 27	: V=1.020864, theta=-38.450258 -> V=1.0, theta=0.0
% INFO    : Bus 28	: V=1.025773, theta=-34.375097 -> V=1.0, theta=0.0
% INFO    : Bus 29	: V=1.044666, theta=-20.014722 -> V=1.0031025, theta=0.0
% INFO    : Bus 30	: V=1.054655, theta=-32.269646 -> V=1.0117225, theta=0.0
% INFO    : Bus 31	: V=1.06255, theta=-16.574001 -> V=1.007561, theta=0.0
% INFO    : Bus 32	: V=0.942396, theta=-25.378952 -> V=1.0, theta=0.0
% INFO    : Bus 33	: V=1.079439, theta=20.319468 -> V=1.028857, theta=0.0
% INFO    : Bus 34	: V=1.023133, theta=-34.021096 -> V=1.0, theta=0.0
% INFO    : Bus 35	: V=0.952528, theta=-26.572018 -> V=1.0, theta=0.0
% INFO    : Bus 36	: V=1.087429, theta=-44.289567 -> V=1.019303, theta=0.0
% INFO    : Bus 37	: V=1.077563, theta=-21.020443 -> V=1.0306955, theta=0.0
% INFO    : Bus 38	: V=1.055964, theta=-20.284863 -> V=1.0068885, theta=0.0
% INFO    : Bus 39	: V=0.939617, theta=-24.979801 -> V=1.0, theta=0.0
% INFO    : Bus 40	: V=0.96251, theta=-23.689017 -> V=1.0, theta=0.0
% INFO    : Bus 41	: V=0.989708, theta=-20.928223 -> V=1.0, theta=0.0
% INFO    : Bus 42	: V=1.051136, theta=-33.838556 -> V=1.006522, theta=0.0
% INFO    : Bus 43	: V=1.026, theta=-42.739462 -> V=1.0, theta=0.0
% INFO    : Bus 44	: V=1.058132, theta=0.522482 -> V=1.0098615, theta=0.0
% INFO    : Bus 45	: V=1.069015, theta=-8.755465 -> V=1.020789, theta=0.0
% INFO    : Bus 46	: V=1.063422, theta=-33.39153 -> V=1.014246, theta=0.0
% INFO    : Bus 47	: V=0.993101, theta=10.688212 -> V=1.0, theta=0.0
% INFO    : Bus 48	: V=1.023887, theta=-15.442695 -> V=1.0, theta=0.0
% INFO    : Bus 49	: V=1.074444, theta=-15.666053 -> V=1.0178495, theta=0.0
% INFO    : Bus 50	: V=1.018017, theta=-23.197334 -> V=1.0129335, theta=0.0
% INFO    : Bus 51	: V=1.030763, theta=-16.065598 -> V=1.0, theta=0.0
% INFO    : Bus 52	: V=1.078773, theta=46.429599 -> V=1.0, theta=0.0
% INFO    : Bus 53	: V=0.95334, theta=-23.586564 -> V=1.0, theta=0.0
% INFO    : Bus 54	: V=1.059872, theta=6.237875 -> V=1.0066325, theta=0.0
% INFO    : Bus 55	: V=1.00326, theta=-17.973502 -> V=1.0, theta=0.0
% INFO    : Bus 56	: V=0.94589, theta=-27.327121 -> V=1.0, theta=0.0
% INFO    : Bus 57	: V=1.038632, theta=-15.021604 -> V=1.017555, theta=0.0
% INFO    : Bus 58	: V=1.079305, theta=-18.429678 -> V=1.024645, theta=0.0
% INFO    : Bus 59	: V=0.919535, theta=-28.937152 -> V=1.0, theta=0.0
% INFO    : Bus 60	: V=1.059071, theta=-0.602036 -> V=1.0109365, theta=0.0
% INFO    : Bus 61	: V=1.084891, theta=2.141781 -> V=1.0281515, theta=0.0
% INFO    : Bus 62	: V=1.02866, theta=-36.521106 -> V=1.0, theta=0.0
% INFO    : Bus 63	: V=0.933539, theta=-34.456554 -> V=1.0, theta=0.0
% INFO    : Bus 64	: V=1.024338, theta=-23.11119 -> V=1.0, theta=0.0
% INFO    : Bus 65	: V=1.054835, theta=-48.187327 -> V=1.0037745, theta=0.0
% INFO    : Bus 66	: V=1.079567, theta=20.328447 -> V=1.0289055, theta=0.0
% INFO    : Bus 67	: V=1.048413, theta=-45.550599 -> V=1.0, theta=0.0
% INFO    : Bus 68	: V=0.99755, theta=-16.514886 -> V=1.0, theta=0.0
% INFO    : Bus 69	: V=1.014697, theta=14.350572 -> V=1.0, theta=0.0
% INFO    : Bus 70	: V=1.022545, theta=-21.297375 -> V=1.004122, theta=0.0
% INFO    : Bus 71	: V=1.048726, theta=61.695204 -> V=1.0, theta=0.0
% INFO    : Bus 72	: V=1.016103, theta=-29.430561 -> V=1.0, theta=0.0
% INFO    : Bus 73	: V=1.016746, theta=14.422022 -> V=1.0, theta=0.0
% INFO    : Bus 74	: V=1.037164, theta=-22.840921 -> V=1.016418, theta=0.0
% INFO    : Bus 75	: V=1.077496, theta=-17.641439 -> V=1.0, theta=0.0
% INFO    : Bus 76	: V=1.035786, theta=-10.805746 -> V=1.0, theta=0.0
% INFO    : Bus 77	: V=1.052622, theta=-36.234527 -> V=1.0175, theta=0.0
% INFO    : Bus 78	: V=1.027193, theta=-5.300984 -> V=1.0, theta=0.0
% INFO    : Bus 79	: V=1.031659, theta=-27.564002 -> V=1.0054775, theta=0.0
% INFO    : Bus 80	: V=1.088263, theta=1.178574 -> V=1.0285725, theta=0.0
% INFO    : Bus 81	: V=1.060148, theta=4.664268 -> V=1.013096, theta=0.0
% INFO    : Bus 82	: V=1.055871, theta=-16.94169 -> V=1.017598, theta=0.0
% INFO    : Bus 83	: V=1.010453, theta=-20.40704 -> V=1.0, theta=0.0
% INFO    : Bus 84	: V=1.043878, theta=-23.359092 -> V=1.0, theta=0.0
% INFO    : Bus 85	: V=1.068345, theta=-14.0534 -> V=1.012068, theta=0.0
% INFO    : Bus 86	: V=1.07894, theta=2.524891 -> V=1.013404, theta=0.0
% INFO    : Bus 87	: V=1.038032, theta=-1.648397 -> V=1.0074335, theta=0.0
% INFO    : Bus 88	: V=1.075423, theta=-32.825831 -> V=1.025619, theta=0.0
% INFO    : Bus 89	: V=1.010047, theta=-23.837407 -> V=1.0, theta=0.0
% INFO    : Bus 90	: V=1.030319, theta=-24.295172 -> V=1.0, theta=0.0
% INFO    : Bus 91	: V=1.01282, theta=-47.531793 -> V=1.0, theta=0.0
% INFO    : Bus 92	: V=0.998755, theta=-26.993988 -> V=1.0, theta=0.0
% INFO    : Bus 93	: V=0.986974, theta=-51.973397 -> V=1.0, theta=0.0
% INFO    : Bus 94	: V=1.068183, theta=-32.344945 -> V=1.0144905, theta=0.0
% INFO    : Bus 95	: V=1.101714, theta=-15.920408 -> V=1.041554, theta=0.0
% INFO    : Bus 96	: V=1.103763, theta=42.095641 -> V=1.0095395, theta=0.0
% INFO    : Bus 97	: V=1.022916, theta=-14.269525 -> V=1.0, theta=0.0
% INFO    : Bus 98	: V=0.960682, theta=-25.230096 -> V=1.0, theta=0.0
% INFO    : Bus 99	: V=1.054988, theta=-22.53124 -> V=1.0, theta=0.0
% INFO    : Bus 100	: V=1.066066, theta=-8.275109 -> V=1.014265, theta=0.0
% INFO    : Bus 101	: V=1.075399, theta=-13.687413 -> V=1.022975, theta=0.0
% INFO    : Bus 102	: V=1.081257, theta=-19.059926 -> V=1.0421765, theta=0.0
% INFO    : Bus 103	: V=1.005392, theta=-18.555746 -> V=1.0, theta=0.0
% INFO    : Bus 104	: V=0.984345, theta=-19.661056 -> V=1.0, theta=0.0
% INFO    : Bus 105	: V=1.071027, theta=-9.623723 -> V=1.0098025, theta=0.0
% INFO    : Bus 106	: V=1.070813, theta=-14.444565 -> V=1.011502, theta=0.0
% INFO    : Bus 107	: V=1.006189, theta=-19.974072 -> V=1.0, theta=0.0
% INFO    : Bus 108	: V=1.004673, theta=9.721829 -> V=1.0, theta=0.0
% INFO    : Bus 109	: V=1.066727, theta=-18.880729 -> V=1.006654, theta=0.0
% INFO    : Bus 110	: V=1.066, theta=8.596379 -> V=1.01601, theta=0.0
% INFO    : Bus 111	: V=1.0287, theta=-16.101178 -> V=1.0, theta=0.0
% INFO    : Bus 112	: V=1.060106, theta=-26.65192 -> V=1.0110945, theta=0.0
% INFO    : Bus 113	: V=1.056511, theta=-15.772611 -> V=1.014543, theta=0.0
% INFO    : Bus 114	: V=1.049178, theta=-10.846798 -> V=1.00959, theta=0.0
% INFO    : Bus 115	: V=1.098262, theta=-42.669422 -> V=1.0271905, theta=0.0
% INFO    : Bus 116	: V=1.035033, theta=-35.673812 -> V=1.0, theta=0.0
% INFO    : Bus 117	: V=1.09848, theta=-39.509301 -> V=1.0273405, theta=0.0
% INFO    : Bus 118	: V=1.057885, theta=2.038552 -> V=1.0088005, theta=0.0
% INFO    : Bus 119	: V=1.05183, theta=-20.341738 -> V=1.0, theta=0.0
% INFO    : Bus 120	: V=1.027787, theta=-31.846971 -> V=1.0, theta=0.0
% INFO    : Bus 121	: V=1.029075, theta=61.886161 -> V=1.0, theta=0.0
% INFO    : Bus 122	: V=1.095416, theta=-37.547369 -> V=1.0293425, theta=0.0
% INFO    : Bus 123	: V=1.037056, theta=14.583899 -> V=1.0, theta=0.0
% INFO    : Bus 124	: V=1.025318, theta=13.046206 -> V=1.0, theta=0.0
% INFO    : Bus 125	: V=1.002727, theta=-0.386041 -> V=1.002626, theta=0.0
% INFO    : Bus 126	: V=1.080818, theta=-28.948979 -> V=1.0165535, theta=0.0
% INFO    : Bus 127	: V=1.067289, theta=3.229482 -> V=1.01901, theta=0.0
% INFO    : Bus 128	: V=1.057126, theta=19.944335 -> V=1.0, theta=0.0
% INFO    : Bus 129	: V=1.079405, theta=-8.263213 -> V=1.0229795, theta=0.0
% INFO    : Bus 130	: V=1.096744, theta=-22.741628 -> V=1.030241, theta=0.0
% INFO    : Bus 131	: V=1.095727, theta=-11.840449 -> V=1.0224525, theta=0.0
% INFO    : Bus 132	: V=1.042972, theta=-7.650175 -> V=1.016048, theta=0.0
% INFO    : Bus 133	: V=1.050753, theta=-38.483146 -> V=1.0078055, theta=0.0
% INFO    : Bus 134	: V=1.0975, theta=2.372802 -> V=1.031885, theta=0.0
% INFO    : Bus 135	: V=1.058294, theta=-27.663837 -> V=1.014748, theta=0.0
% INFO    : Bus 136	: V=1.003067, theta=-35.970977 -> V=1.0, theta=0.0
% INFO    : Bus 137	: V=0.980759, theta=-25.149654 -> V=1.0, theta=0.0
% INFO    : Bus 138	: V=1.014528, theta=-24.673955 -> V=1.0, theta=0.0
% INFO    : Bus 139	: V=1.034794, theta=-8.963928 -> V=1.003621, theta=0.0
% INFO    : Bus 140	: V=1.016031, theta=8.161181 -> V=1.0, theta=0.0
% INFO    : Bus 141	: V=0.992829, theta=-23.492907 -> V=1.0, theta=0.0
% INFO    : Bus 142	: V=1.038358, theta=-21.671873 -> V=1.007455, theta=0.0
% INFO    : Bus 143	: V=1.098909, theta=-17.161843 -> V=1.033523, theta=0.0
% INFO    : Bus 144	: V=1.073994, theta=-10.278393 -> V=1.0177745, theta=0.0
% INFO    : Bus 145	: V=1.063202, theta=-1.710233 -> V=1.019547, theta=0.0
% INFO    : Bus 146	: V=1.070647, theta=-16.970903 -> V=1.009047, theta=0.0
% INFO    : Bus 147	: V=1.030091, theta=13.653817 -> V=1.0, theta=0.0
% INFO    : Bus 148	: V=1.035723, theta=-4.054882 -> V=1.0, theta=0.0
% INFO    : Bus 149	: V=1.021161, theta=-23.284148 -> V=1.0, theta=0.0
% INFO    : Bus 150	: V=0.937285, theta=38.058108 -> V=1.0, theta=0.0
% INFO    : Bus 151	: V=1.095539, theta=-24.360315 -> V=1.043905, theta=0.0
% INFO    : Bus 152	: V=1.0096, theta=-42.882955 -> V=1.0, theta=0.0
% INFO    : Bus 153	: V=1.0196, theta=15.723856 -> V=1.0, theta=0.0
% INFO    : Bus 154	: V=1.046899, theta=-27.358917 -> V=1.028271, theta=0.0
% INFO    : Bus 155	: V=0.990146, theta=-37.281745 -> V=1.0, theta=0.0
% INFO    : Bus 156	: V=1.008891, theta=-22.243841 -> V=1.0, theta=0.0
% INFO    : Bus 157	: V=0.988844, theta=-38.857087 -> V=1.0, theta=0.0
% INFO    : Bus 158	: V=1.004099, theta=-23.31839 -> V=1.0, theta=0.0
% INFO    : Bus 159	: V=1.089842, theta=-45.007732 -> V=1.016445, theta=0.0
% INFO    : Bus 160	: V=0.991367, theta=-23.761052 -> V=1.0, theta=0.0
% INFO    : Bus 161	: V=1.03332, theta=-35.055506 -> V=1.0, theta=0.0
% INFO    : Bus 162	: V=1.049309, theta=40.294048 -> V=1.0, theta=0.0
% INFO    : Bus 163	: V=1.021022, theta=-22.119247 -> V=1.0, theta=0.0
% INFO    : Bus 164	: V=1.0523, theta=-11.912149 -> V=1.012139, theta=0.0
% INFO    : Bus 165	: V=0.958234, theta=-25.691252 -> V=1.0, theta=0.0
% INFO    : Bus 166	: V=0.992219, theta=-33.930735 -> V=1.0, theta=0.0
% INFO    : Bus 167	: V=1.07593, theta=-25.498546 -> V=1.032986, theta=0.0
% INFO    : Bus 168	: V=1.088144, theta=-18.434766 -> V=1.030774, theta=0.0
% INFO    : Bus 169	: V=0.998323, theta=-23.519367 -> V=1.0, theta=0.0
% INFO    : Bus 170	: V=0.993364, theta=-16.827852 -> V=1.0, theta=0.0
% INFO    : Bus 171	: V=1.047656, theta=-34.236842 -> V=1.0051175, theta=0.0
% INFO    : Bus 172	: V=1.087684, theta=66.734724 -> V=1.0, theta=0.0
% INFO    : Bus 173	: V=1.038146, theta=25.439384 -> V=1.0, theta=0.0
% INFO    : Bus 174	: V=1.075867, theta=11.667964 -> V=1.00389, theta=0.0
% INFO    : Bus 175	: V=1.092354, theta=-8.438261 -> V=1.0266175, theta=0.0
% INFO    : Bus 176	: V=1.076831, theta=-25.438083 -> V=1.0334115, theta=0.0
% INFO    : Bus 177	: V=1.105553, theta=45.754712 -> V=1.0097955, theta=0.0
% INFO    : Bus 178	: V=1.054374, theta=-15.988696 -> V=1.01333, theta=0.0
% INFO    : Bus 179	: V=1.061803, theta=0.70194 -> V=1.012015, theta=0.0
% INFO    : Bus 180	: V=1.040788, theta=61.564881 -> V=1.0, theta=0.0
% INFO    : Bus 181	: V=1.057864, theta=-46.539464 -> V=1.003852, theta=0.0
% INFO    : Bus 182	: V=1.007606, theta=-0.256966 -> V=1.0, theta=0.0
% INFO    : Bus 183	: V=1.042712, theta=-19.254167 -> V=1.006815, theta=0.0
% INFO    : Bus 184	: V=1.063849, theta=3.781789 -> V=1.0172185, theta=0.0
% INFO    : Bus 185	: V=1.062433, theta=-16.925274 -> V=1.0188235, theta=0.0
% INFO    : Bus 186	: V=1.03615, theta=-13.393889 -> V=1.0046785, theta=0.0
% INFO    : Bus 187	: V=1.013491, theta=-26.974477 -> V=1.0, theta=0.0
% INFO    : Bus 188	: V=0.972727, theta=-31.899847 -> V=1.0, theta=0.0
% INFO    : Bus 189	: V=0.979203, theta=-20.113238 -> V=1.0, theta=0.0
% INFO    : Bus 190	: V=1.034151, theta=9.011174 -> V=1.007582, theta=0.0
% INFO    : Bus 191	: V=1.040354, theta=-4.000858 -> V=1.0063445, theta=0.0
% INFO    : Bus 192	: V=1.006456, theta=-30.429716 -> V=1.0, theta=0.0
% INFO    : Bus 193	: V=1.056395, theta=14.274392 -> V=1.0130855, theta=0.0
% INFO    : Bus 194	: V=1.001811, theta=-23.390712 -> V=1.0, theta=0.0
% INFO    : Bus 195	: V=1.071309, theta=-23.375004 -> V=1.0182635, theta=0.0
% INFO    : Bus 196	: V=1.081865, theta=-3.59454 -> V=1.017657, theta=0.0
% INFO    : Bus 197	: V=1.049023, theta=-12.546491 -> V=1.003214, theta=0.0
% INFO    : Bus 198	: V=1.079341, theta=-14.723245 -> V=1.010075, theta=0.0
% INFO    : Bus 199	: V=1.0985, theta=-16.80129 -> V=1.0323765, theta=0.0
% INFO    : Bus 200	: V=1.076684, theta=-16.997007 -> V=1.019158, theta=0.0
% INFO    : Bus 201	: V=0.944667, theta=65.220886 -> V=1.0, theta=0.0
% INFO    : Bus 202	: V=1.022563, theta=-16.762063 -> V=1.0, theta=0.0
% INFO    : Bus 203	: V=1.005716, theta=-15.671355 -> V=1.0, theta=0.0
% INFO    : Bus 204	: V=1.078195, theta=-19.440094 -> V=1.040804, theta=0.0
% INFO    : Bus 205	: V=1.003882, theta=-29.788001 -> V=1.0, theta=0.0
% INFO    : Bus 206	: V=1.075366, theta=-20.605091 -> V=1.011029, theta=0.0
% INFO    : Bus 207	: V=1.086245, theta=-9.25803 -> V=1.0244295, theta=0.0
% INFO    : Bus 208	: V=1.086886, theta=-25.343887 -> V=1.022374, theta=0.0
% INFO    : Bus 209	: V=1.011746, theta=-42.601473 -> V=1.0, theta=0.0
% INFO    : Bus 210	: V=1.04248, theta=17.34212 -> V=1.0060075, theta=0.0
% INFO    : Bus 211	: V=1.031525, theta=-17.322132 -> V=1.0, theta=0.0
% INFO    : Bus 212	: V=0.947371, theta=-27.095908 -> V=1.0, theta=0.0
% INFO    : Bus 213	: V=1.001166, theta=-37.186914 -> V=1.0, theta=0.0
% INFO    : Bus 214	: V=1.0523, theta=-49.135864 -> V=1.005468, theta=0.0
% INFO    : Bus 215	: V=1.063929, theta=40.992984 -> V=1.0122955, theta=0.0
% INFO    : Bus 216	: V=1.073552, theta=-45.318439 -> V=1.015292, theta=0.0
% INFO    : Bus 217	: V=1.036909, theta=-22.83738 -> V=1.0159305, theta=0.0
% INFO    : Bus 218	: V=0.986553, theta=-23.775778 -> V=1.0, theta=0.0
% INFO    : Bus 219	: V=1.007596, theta=60.472961 -> V=1.0, theta=0.0
% INFO    : Bus 220	: V=1.073607, theta=-1.57326 -> V=1.0173285, theta=0.0
% INFO    : Bus 221	: V=1.048173, theta=15.421454 -> V=1.0, theta=0.0
% INFO    : Bus 222	: V=1.056078, theta=5.510922 -> V=1.004873, theta=0.0
% INFO    : Bus 223	: V=0.975182, theta=-26.101782 -> V=1.0, theta=0.0
% INFO    : Bus 224	: V=1.057909, theta=-18.438186 -> V=1.0, theta=0.0
% INFO    : Bus 225	: V=0.990718, theta=-19.403743 -> V=1.0, theta=0.0
% INFO    : Bus 226	: V=1.0115, theta=12.538368 -> V=1.0038215, theta=0.0
% INFO    : Bus 227	: V=1.020417, theta=-38.452691 -> V=1.0, theta=0.0
% INFO    : Bus 228	: V=1.046646, theta=10.107236 -> V=1.0037965, theta=0.0
% INFO    : Bus 229	: V=1.058167, theta=54.278935 -> V=1.003087, theta=0.0
% INFO    : Bus 230	: V=1.058609, theta=-19.146934 -> V=1.005649, theta=0.0
% INFO    : Bus 231	: V=1.064814, theta=-24.013785 -> V=1.017578, theta=0.0
% INFO    : Bus 232	: V=1.102343, theta=-13.747738 -> V=1.023758, theta=0.0
% INFO    : Bus 233	: V=1.078397, theta=-35.325664 -> V=1.028666, theta=0.0
% INFO    : Bus 234	: V=1.017906, theta=-41.855053 -> V=1.0, theta=0.0
% INFO    : Bus 235	: V=1.033422, theta=-25.170853 -> V=1.0, theta=0.0
% INFO    : Bus 236	: V=1.062213, theta=-10.346926 -> V=1.0105505, theta=0.0
% INFO    : Bus 237	: V=1.086366, theta=-41.190921 -> V=1.0230785, theta=0.0
% INFO    : Bus 238	: V=1.028136, theta=10.353076 -> V=1.010168, theta=0.0
% INFO    : Bus 239	: V=1.03375, theta=-42.667185 -> V=1.0, theta=0.0
% INFO    : Bus 240	: V=1.087699, theta=-26.505474 -> V=1.0251005, theta=0.0
% INFO    : Bus 241	: V=1.077426, theta=-38.117944 -> V=1.0275345, theta=0.0
% INFO    : Bus 242	: V=1.019651, theta=-46.889667 -> V=1.0, theta=0.0
% INFO    : Bus 243	: V=1.079235, theta=20.51598 -> V=1.031725, theta=0.0
% INFO    : Bus 244	: V=1.017773, theta=-36.447882 -> V=1.0, theta=0.0
% INFO    : Bus 245	: V=1.08165, theta=67.139659 -> V=1.0, theta=0.0
% INFO    : Bus 246	: V=1.079745, theta=-9.793118 -> V=1.0236355, theta=0.0
% INFO    : Bus 247	: V=1.013233, theta=-22.996644 -> V=1.0219765, theta=0.0
% INFO    : Bus 248	: V=1.012234, theta=-22.01638 -> V=1.0, theta=0.0
% INFO    : Bus 249	: V=0.979697, theta=-23.10462 -> V=1.0, theta=0.0
% INFO    : Bus 250	: V=1.051763, theta=1.603872 -> V=1.005682, theta=0.0
% INFO    : Bus 251	: V=1.026253, theta=65.096126 -> V=1.0, theta=0.0
% INFO    : Bus 252	: V=0.999672, theta=-21.935927 -> V=1.0, theta=0.0
% INFO    : Bus 253	: V=0.979909, theta=-25.596375 -> V=1.0, theta=0.0
% INFO    : Bus 254	: V=1.022513, theta=-22.223609 -> V=1.0062905, theta=0.0
% INFO    : Bus 255	: V=1.099521, theta=-10.827073 -> V=1.028177, theta=0.0
% INFO    : Bus 256	: V=1.065974, theta=11.928881 -> V=1.008544, theta=0.0
% INFO    : Bus 257	: V=1.104, theta=-8.299411 -> V=1.025056, theta=0.0
% INFO    : Bus 258	: V=1.043782, theta=-12.042962 -> V=1.008342, theta=0.0
% INFO    : Bus 259	: V=1.065007, theta=-44.08172 -> V=1.0069225, theta=0.0
% INFO    : Bus 260	: V=1.000093, theta=66.738694 -> V=1.0, theta=0.0
% INFO    : Bus 261	: V=1.099334, theta=-14.390411 -> V=1.023936, theta=0.0
% INFO    : Bus 262	: V=1.070669, theta=-14.380307 -> V=1.0110615, theta=0.0
% INFO    : Bus 263	: V=1.090773, theta=-29.430538 -> V=1.0206865, theta=0.0
% INFO    : Bus 264	: V=1.06625, theta=-19.319712 -> V=1.0, theta=0.0
% INFO    : Bus 265	: V=1.01999, theta=4.423568 -> V=1.0, theta=0.0
% INFO    : Bus 266	: V=1.071346, theta=-13.822146 -> V=1.01764, theta=0.0
% INFO    : Bus 267	: V=1.06169, theta=-15.378716 -> V=1.0101755, theta=0.0
% INFO    : Bus 268	: V=1.05581, theta=-27.142614 -> V=1.0089865, theta=0.0
% INFO    : Bus 269	: V=1.030364, theta=28.27478 -> V=1.0, theta=0.0
% INFO    : Bus 270	: V=1.074839, theta=3.235018 -> V=1.0221495, theta=0.0
% INFO    : Bus 271	: V=1.050548, theta=-33.131623 -> V=1.017091, theta=0.0
% INFO    : Bus 272	: V=1.078658, theta=-41.66976 -> V=1.0100475, theta=0.0
% INFO    : Bus 273	: V=1.042556, theta=-15.707649 -> V=1.0, theta=0.0
% INFO    : Bus 274	: V=0.97336, theta=-19.305206 -> V=1.0, theta=0.0
% INFO    : Bus 275	: V=0.974351, theta=-24.576868 -> V=1.0, theta=0.0
% INFO    : Bus 276	: V=1.030897, theta=-49.304332 -> V=1.0, theta=0.0
% INFO    : Bus 277	: V=1.057362, theta=-31.516276 -> V=1.042126, theta=0.0
% INFO    : Bus 278	: V=1.085277, theta=-17.81646 -> V=1.0329475, theta=0.0
% INFO    : Bus 279	: V=1.091806, theta=-20.656481 -> V=1.0277785, theta=0.0
% INFO    : Bus 280	: V=0.944457, theta=-32.813558 -> V=0.965507, theta=0.0
% INFO    : Bus 281	: V=1.014045, theta=13.924736 -> V=1.0, theta=0.0
% INFO    : Bus 282	: V=1.092632, theta=-13.322266 -> V=1.037655, theta=0.0
% INFO    : Bus 283	: V=1.068698, theta=-0.717571 -> V=1.017875, theta=0.0
% INFO    : Bus 284	: V=1.075726, theta=8.619709 -> V=1.022185, theta=0.0
% INFO    : Bus 285	: V=1.054129, theta=-15.632559 -> V=1.0118325, theta=0.0
% INFO    : Bus 286	: V=1.046946, theta=-32.258169 -> V=1.0027045, theta=0.0
% INFO    : Bus 287	: V=1.075715, theta=-3.694537 -> V=1.017795, theta=0.0
% INFO    : Bus 288	: V=1.086367, theta=1.518637 -> V=1.0174495, theta=0.0
% INFO    : Bus 289	: V=1.031226, theta=-24.032509 -> V=1.0, theta=0.0
% INFO    : Bus 290	: V=1.027328, theta=64.861694 -> V=1.0, theta=0.0
% INFO    : Bus 291	: V=0.979764, theta=-40.335625 -> V=1.0, theta=0.0
% INFO    : Bus 292	: V=1.087711, theta=53.455386 -> V=1.007087, theta=0.0
% INFO    : Bus 293	: V=1.079163, theta=20.557431 -> V=1.0317745, theta=0.0
% INFO    : Bus 294	: V=1.056394, theta=-11.319676 -> V=1.012071, theta=0.0
% INFO    : Bus 295	: V=0.948091, theta=25.15516 -> V=1.0, theta=0.0
% INFO    : Bus 296	: V=0.981243, theta=-24.794944 -> V=1.0, theta=0.0
% INFO    : Bus 297	: V=1.046773, theta=10.828043 -> V=1.0041725, theta=0.0
% INFO    : Bus 298	: V=0.991813, theta=-25.115659 -> V=1.0, theta=0.0
% INFO    : Bus 299	: V=1.023813, theta=-21.256669 -> V=1.0, theta=0.0
% INFO    : Bus 300	: V=1.016255, theta=-41.301074 -> V=1.012752, theta=0.0
% INFO    : Bus 301	: V=0.943888, theta=-27.508957 -> V=1.0, theta=0.0
% INFO    : Bus 302	: V=1.021895, theta=-15.877938 -> V=1.0, theta=0.0
% INFO    : Bus 303	: V=1.030147, theta=-16.413037 -> V=1.016444, theta=0.0
% INFO    : Bus 304	: V=1.076818, theta=-5.802663 -> V=1.018164, theta=0.0
% INFO    : Bus 305	: V=1.074351, theta=-33.95989 -> V=1.0272645, theta=0.0
% INFO    : Bus 306	: V=1.098289, theta=-19.922406 -> V=1.0258075, theta=0.0
% INFO    : Bus 307	: V=0.976967, theta=-24.995005 -> V=1.0, theta=0.0
% INFO    : Bus 308	: V=1.060331, theta=-32.224317 -> V=1.0178225, theta=0.0
% INFO    : Bus 309	: V=1.038716, theta=-18.255563 -> V=1.011795, theta=0.0
% INFO    : Bus 310	: V=1.064048, theta=-2.428148 -> V=1.020977, theta=0.0
% INFO    : Bus 311	: V=1.011521, theta=-24.28785 -> V=1.0126915, theta=0.0
% INFO    : Bus 312	: V=1.070747, theta=-20.262446 -> V=1.017849, theta=0.0
% INFO    : Bus 313	: V=1.102211, theta=-23.66592 -> V=1.02752, theta=0.0
% INFO    : Bus 314	: V=1.082248, theta=7.031108 -> V=1.024724, theta=0.0
% INFO    : Bus 315	: V=1.076544, theta=-23.052428 -> V=1.030729, theta=0.0
% INFO    : Bus 316	: V=1.029313, theta=13.665017 -> V=1.003374, theta=0.0
% INFO    : Bus 317	: V=1.092132, theta=-0.233458 -> V=1.0269445, theta=0.0
% INFO    : Bus 318	: V=1.036616, theta=-25.081018 -> V=1.0, theta=0.0
% INFO    : Bus 319	: V=1.070807, theta=-15.141283 -> V=1.011077, theta=0.0
% INFO    : Bus 320	: V=0.975854, theta=-20.255082 -> V=1.0, theta=0.0
% INFO    : Bus 321	: V=1.080003, theta=-15.933285 -> V=1.0117965, theta=0.0
% INFO    : Bus 322	: V=1.032825, theta=-25.473856 -> V=1.0, theta=0.0
% INFO    : Bus 323	: V=1.075258, theta=-12.558053 -> V=1.0152375, theta=0.0
% INFO    : Bus 324	: V=1.068521, theta=8.388578 -> V=1.0191045, theta=0.0
% INFO    : Bus 325	: V=1.095395, theta=17.445456 -> V=1.0317185, theta=0.0
% INFO    : Bus 326	: V=0.97953, theta=61.92687 -> V=1.0, theta=0.0
% INFO    : Bus 327	: V=1.006927, theta=-27.662808 -> V=1.0471995, theta=0.0
% INFO    : Bus 328	: V=1.055392, theta=-35.677307 -> V=1.018579, theta=0.0
% INFO    : Bus 329	: V=1.035646, theta=-15.919004 -> V=1.0, theta=0.0
% INFO    : Bus 330	: V=1.073567, theta=-22.7269 -> V=1.030183, theta=0.0
% INFO    : Bus 331	: V=1.048695, theta=-31.028999 -> V=1.0049385, theta=0.0
% INFO    : Bus 332	: V=1.010246, theta=9.382501 -> V=1.0, theta=0.0
% INFO    : Bus 333	: V=1.066165, theta=-0.886317 -> V=1.0166805, theta=0.0
% INFO    : Bus 334	: V=1.092053, theta=9.444908 -> V=1.013107, theta=0.0
% INFO    : Bus 335	: V=1.04291, theta=-23.435765 -> V=1.0, theta=0.0
% INFO    : Bus 336	: V=0.955804, theta=54.65206 -> V=1.0, theta=0.0
% INFO    : Bus 337	: V=1.057572, theta=-30.223531 -> V=1.0116595, theta=0.0
% INFO    : Bus 338	: V=1.064448, theta=9.242033 -> V=1.0, theta=0.0
% INFO    : Bus 339	: V=0.999614, theta=-6.673699 -> V=1.0, theta=0.0
% INFO    : Bus 340	: V=0.965191, theta=-27.482574 -> V=1.0, theta=0.0
% INFO    : Bus 341	: V=1.01476, theta=-29.052805 -> V=1.0, theta=0.0
% INFO    : Bus 342	: V=1.028942, theta=-30.323699 -> V=1.0, theta=0.0
% INFO    : Bus 343	: V=1.090682, theta=-21.668732 -> V=1.020417, theta=0.0
% INFO    : Bus 344	: V=1.026573, theta=-23.594182 -> V=1.0, theta=0.0
% INFO    : Bus 345	: V=1.004959, theta=-22.886213 -> V=1.0, theta=0.0
% INFO    : Bus 346	: V=1.081256, theta=-44.957472 -> V=1.0188965, theta=0.0
% INFO    : Bus 347	: V=1.088634, theta=21.61296 -> V=1.016511, theta=0.0
% INFO    : Bus 348	: V=1.086247, theta=4.965551 -> V=1.0264385, theta=0.0
% INFO    : Bus 349	: V=0.991411, theta=8.387595 -> V=1.0, theta=0.0
% INFO    : Bus 350	: V=1.0236, theta=-36.548388 -> V=1.0, theta=0.0
% INFO    : Bus 351	: V=1.021416, theta=-15.357982 -> V=1.0110595, theta=0.0
% INFO    : Bus 352	: V=1.050774, theta=-20.66845 -> V=1.0, theta=0.0
% INFO    : Bus 353	: V=1.05597, theta=-0.689213 -> V=1.0094555, theta=0.0
% INFO    : Bus 354	: V=0.996871, theta=-21.657581 -> V=1.0, theta=0.0
% INFO    : Bus 355	: V=1.082, theta=42.561895 -> V=1.0, theta=0.0
% INFO    : Bus 356	: V=1.065657, theta=13.092137 -> V=1.0078755, theta=0.0
% INFO    : Bus 357	: V=0.961936, theta=-29.660674 -> V=0.988194, theta=0.0
% INFO    : Bus 358	: V=1.049744, theta=-12.44878 -> V=1.007295, theta=0.0
% INFO    : Bus 359	: V=0.99307, theta=-16.90292 -> V=1.0, theta=0.0
% INFO    : Bus 360	: V=1.060595, theta=-35.381005 -> V=1.0208935, theta=0.0
% INFO    : Bus 361	: V=0.997732, theta=-25.836673 -> V=1.0, theta=0.0
% INFO    : Bus 362	: V=1.021904, theta=-13.644157 -> V=1.006759, theta=0.0
% INFO    : Bus 363	: V=1.040595, theta=-33.842534 -> V=1.0, theta=0.0
% INFO    : Bus 364	: V=1.058148, theta=-24.550667 -> V=1.0138815, theta=0.0
% INFO    : Bus 365	: V=1.012912, theta=-22.206507 -> V=1.0, theta=0.0
% INFO    : Bus 366	: V=1.056855, theta=-44.244899 -> V=1.012556, theta=0.0
% INFO    : Bus 367	: V=0.949182, theta=-31.519731 -> V=1.0, theta=0.0
% INFO    : Bus 368	: V=1.044489, theta=-11.534227 -> V=1.0083865, theta=0.0
% INFO    : Bus 369	: V=1.034669, theta=-25.712266 -> V=1.016162, theta=0.0
% INFO    : Bus 370	: V=1.024636, theta=-34.195277 -> V=1.0, theta=0.0
% INFO    : Bus 371	: V=1.014864, theta=-6.165324 -> V=1.008084, theta=0.0
% INFO    : Bus 372	: V=1.034874, theta=-24.829211 -> V=1.0, theta=0.0
% INFO    : Bus 373	: V=1.070185, theta=-47.227929 -> V=1.013184, theta=0.0
% INFO    : Bus 374	: V=1.069833, theta=-6.520725 -> V=1.012546, theta=0.0
% INFO    : Bus 375	: V=1.051469, theta=-10.320102 -> V=1.010656, theta=0.0
% INFO    : Bus 376	: V=0.974426, theta=-21.82411 -> V=1.0, theta=0.0
% INFO    : Bus 377	: V=0.970255, theta=-18.625797 -> V=1.0, theta=0.0
% INFO    : Bus 378	: V=1.082652, theta=16.184558 -> V=1.0139235, theta=0.0
% INFO    : Bus 379	: V=0.960682, theta=-25.230096 -> V=1.0, theta=0.0
% INFO    : Bus 380	: V=1.020192, theta=-23.61097 -> V=1.0090415, theta=0.0
% INFO    : Bus 381	: V=1.070579, theta=33.824652 -> V=1.0, theta=0.0
% INFO    : Bus 382	: V=1.040789, theta=6.718977 -> V=1.0, theta=0.0
% INFO    : Bus 383	: V=1.082612, theta=-17.660855 -> V=1.0255095, theta=0.0
% INFO    : Bus 384	: V=1.093485, theta=-31.813916 -> V=1.032284, theta=0.0
% INFO    : Bus 385	: V=0.986531, theta=-17.527618 -> V=1.0, theta=0.0
% INFO    : Bus 386	: V=1.047042, theta=-44.072735 -> V=1.0, theta=0.0
% INFO    : Bus 387	: V=1.013882, theta=-21.68604 -> V=1.0, theta=0.0
% INFO    : Bus 388	: V=1.059877, theta=7.883555 -> V=1.0211015, theta=0.0
% INFO    : Bus 389	: V=1.065452, theta=2.455898 -> V=1.022282, theta=0.0
% INFO    : Bus 390	: V=1.047842, theta=20.80638 -> V=1.003901, theta=0.0
% INFO    : Bus 391	: V=1.039563, theta=-22.920885 -> V=1.0215895, theta=0.0
% INFO    : Bus 392	: V=1.093118, theta=-14.837767 -> V=1.027952, theta=0.0
% INFO    : Bus 393	: V=1.062436, theta=-35.129169 -> V=1.0219915, theta=0.0
% INFO    : Bus 394	: V=1.021182, theta=61.01308 -> V=1.0, theta=0.0
% INFO    : Bus 395	: V=1.098682, theta=62.268815 -> V=1.003104, theta=0.0
% INFO    : Bus 396	: V=1.085545, theta=-32.943003 -> V=1.017388, theta=0.0
% INFO    : Bus 397	: V=1.075203, theta=-47.422751 -> V=1.0160125, theta=0.0
% INFO    : Bus 398	: V=1.0075, theta=-42.326698 -> V=1.0, theta=0.0
% INFO    : Bus 399	: V=1.015555, theta=-23.274057 -> V=1.0, theta=0.0
% INFO    : Bus 400	: V=1.045135, theta=-12.171396 -> V=1.0087885, theta=0.0
% INFO    : Bus 401	: V=1.058974, theta=-40.304851 -> V=1.00388, theta=0.0
% INFO    : Bus 402	: V=1.045887, theta=-23.426034 -> V=1.0148335, theta=0.0
% INFO    : Bus 403	: V=1.001545, theta=-4.717098 -> V=1.0, theta=0.0
% INFO    : Bus 404	: V=0.983818, theta=-25.515252 -> V=1.0, theta=0.0
% INFO    : Bus 405	: V=1.043068, theta=-8.209284 -> V=1.0148615, theta=0.0
% INFO    : Bus 406	: V=1.035254, theta=-20.111554 -> V=1.0065145, theta=0.0
% INFO    : Bus 407	: V=1.062953, theta=23.327858 -> V=1.0, theta=0.0
% INFO    : Bus 408	: V=1.012818, theta=-36.91865 -> V=1.0, theta=0.0
% INFO    : Bus 409	: V=1.077842, theta=-7.453377 -> V=1.017485, theta=0.0
% INFO    : Bus 410	: V=1.057826, theta=-29.432357 -> V=1.0283495, theta=0.0
% INFO    : Bus 411	: V=0.996818, theta=-23.598987 -> V=1.0, theta=0.0
% INFO    : Bus 412	: V=0.994994, theta=-13.474962 -> V=1.0, theta=0.0
% INFO    : Bus 413	: V=1.057916, theta=-21.135615 -> V=1.0, theta=0.0
% INFO    : Bus 414	: V=1.030089, theta=-5.556067 -> V=1.004792, theta=0.0
% INFO    : Bus 415	: V=0.980117, theta=-21.9188 -> V=1.0, theta=0.0
% INFO    : Bus 416	: V=1.017721, theta=-26.785907 -> V=1.0, theta=0.0
% INFO    : Bus 417	: V=0.975061, theta=-24.159228 -> V=1.0, theta=0.0
% INFO    : Bus 418	: V=1.001541, theta=-15.95114 -> V=1.0, theta=0.0
% INFO    : Bus 419	: V=1.086771, theta=-13.164256 -> V=1.016092, theta=0.0
% INFO    : Bus 420	: V=0.990433, theta=-23.016834 -> V=1.0, theta=0.0
% INFO    : Bus 421	: V=0.999928, theta=-23.123736 -> V=1.0, theta=0.0
% INFO    : Bus 422	: V=0.948895, theta=-24.265169 -> V=1.0, theta=0.0
% INFO    : Bus 423	: V=1.005412, theta=-23.167447 -> V=1.0, theta=0.0
% INFO    : Bus 424	: V=1.012315, theta=-21.821988 -> V=1.0, theta=0.0
% INFO    : Bus 425	: V=1.060701, theta=-20.695437 -> V=1.012077, theta=0.0
% INFO    : Bus 426	: V=1.081014, theta=5.91166 -> V=1.0250115, theta=0.0
% INFO    : Bus 427	: V=1.045996, theta=-41.849136 -> V=1.0050625, theta=0.0
% INFO    : Bus 428	: V=0.993561, theta=-34.672866 -> V=1.0, theta=0.0
% INFO    : Bus 429	: V=1.088461, theta=54.25258 -> V=1.009736, theta=0.0
% INFO    : Bus 430	: V=0.996111, theta=7.446131 -> V=1.0, theta=0.0
% INFO    : Bus 431	: V=1.097108, theta=-37.992251 -> V=1.0291235, theta=0.0
% INFO    : Bus 432	: V=1.092705, theta=45.840566 -> V=1.0, theta=0.0
% INFO    : Bus 433	: V=1.024265, theta=-14.345058 -> V=1.0, theta=0.0
% INFO    : Bus 434	: V=1.063304, theta=-5.672326 -> V=1.0193575, theta=0.0
% INFO    : Bus 435	: V=1.064909, theta=-43.610049 -> V=1.0072495, theta=0.0
% INFO    : Bus 436	: V=0.968794, theta=-21.067697 -> V=1.0, theta=0.0
% INFO    : Bus 437	: V=1.046287, theta=-45.347647 -> V=1.0026715, theta=0.0
% INFO    : Bus 438	: V=0.989364, theta=56.583338 -> V=1.0, theta=0.0
% INFO    : Bus 439	: V=1.077182, theta=-30.675461 -> V=1.025257, theta=0.0
% INFO    : Bus 440	: V=1.053109, theta=3.801329 -> V=1.004595, theta=0.0
% INFO    : Bus 441	: V=1.011891, theta=3.678516 -> V=1.0, theta=0.0
% INFO    : Bus 442	: V=1.031, theta=-43.432127 -> V=1.0, theta=0.0
% INFO    : Bus 443	: V=1.060755, theta=-21.985393 -> V=1.019141, theta=0.0
% INFO    : Bus 444	: V=1.099, theta=35.801068 -> V=1.0115345, theta=0.0
% INFO    : Bus 445	: V=0.952381, theta=-38.943375 -> V=1.0, theta=0.0
% INFO    : Bus 446	: V=0.950541, theta=-28.78371 -> V=1.0, theta=0.0
% INFO    : Bus 447	: V=1.029368, theta=-23.366632 -> V=1.0, theta=0.0
% INFO    : Bus 448	: V=1.072133, theta=47.570741 -> V=1.0, theta=0.0
% INFO    : Bus 449	: V=1.06281, theta=9.349979 -> V=1.0, theta=0.0
% INFO    : Bus 450	: V=1.031577, theta=-23.207466 -> V=1.0, theta=0.0
% INFO    : Bus 451	: V=1.032798, theta=-3.638804 -> V=1.008711, theta=0.0
% INFO    : Bus 452	: V=1.045347, theta=-14.231817 -> V=1.0, theta=0.0
% INFO    : Bus 453	: V=1.012854, theta=-27.407185 -> V=1.0, theta=0.0
% INFO    : Bus 454	: V=1.04021, theta=-6.27181 -> V=1.014781, theta=0.0
% INFO    : Bus 455	: V=1.092736, theta=23.67849 -> V=1.016074, theta=0.0
% INFO    : Bus 456	: V=0.970219, theta=-27.534951 -> V=1.0, theta=0.0
% INFO    : Bus 457	: V=1.100091, theta=-8.858699 -> V=1.033912, theta=0.0
% INFO    : Bus 458	: V=1.056915, theta=-20.934087 -> V=1.007419, theta=0.0
% INFO    : Bus 459	: V=0.960088, theta=-20.167411 -> V=1.0, theta=0.0
% INFO    : Bus 460	: V=1.05739, theta=-54.985593 -> V=1.0, theta=0.0
% INFO    : Bus 461	: V=1.061946, theta=-20.329748 -> V=1.0126165, theta=0.0
% INFO    : Bus 462	: V=1.078553, theta=57.975376 -> V=1.0, theta=0.0
% INFO    : Bus 463	: V=0.985078, theta=-24.175429 -> V=1.0, theta=0.0
% INFO    : Bus 464	: V=1.036071, theta=-7.033356 -> V=1.012734, theta=0.0
% INFO    : Bus 465	: V=0.950378, theta=-34.336303 -> V=1.0, theta=0.0
% INFO    : Bus 466	: V=1.075364, theta=-18.939255 -> V=1.013476, theta=0.0
% INFO    : Bus 467	: V=1.075818, theta=-32.766717 -> V=1.038842, theta=0.0
% INFO    : Bus 468	: V=0.986269, theta=-27.842525 -> V=1.0, theta=0.0
% INFO    : Bus 469	: V=1.031395, theta=-1.819847 -> V=1.0, theta=0.0
% INFO    : Bus 470	: V=1.048016, theta=-46.06973 -> V=1.005058, theta=0.0
% INFO    : Bus 471	: V=1.045585, theta=-26.971909 -> V=1.0116155, theta=0.0
% INFO    : Bus 472	: V=1.011979, theta=-22.426698 -> V=1.005462, theta=0.0
% INFO    : Bus 473	: V=1.033781, theta=-25.505581 -> V=1.0, theta=0.0
% INFO    : Bus 474	: V=1.076315, theta=5.25489 -> V=1.0230575, theta=0.0
% INFO    : Bus 475	: V=1.006839, theta=14.481993 -> V=1.0, theta=0.0
% INFO    : Bus 476	: V=1.042456, theta=-44.891763 -> V=1.0, theta=0.0
% INFO    : Bus 477	: V=1.033882, theta=-42.508442 -> V=1.0, theta=0.0
% INFO    : Bus 478	: V=1.013266, theta=-47.679933 -> V=1.0, theta=0.0
% INFO    : Bus 479	: V=1.058796, theta=-15.004281 -> V=1.007803, theta=0.0
% INFO    : Bus 480	: V=1.07775, theta=-15.093516 -> V=1.0105485, theta=0.0
% INFO    : Bus 481	: V=1.019064, theta=11.085555 -> V=1.0, theta=0.0
% INFO    : Bus 482	: V=0.940317, theta=-25.253513 -> V=1.0, theta=0.0
% INFO    : Bus 483	: V=0.956985, theta=-32.157302 -> V=1.0, theta=0.0
% INFO    : Bus 484	: V=1.095133, theta=-43.920539 -> V=1.0260675, theta=0.0
% INFO    : Bus 485	: V=1.000264, theta=-22.280101 -> V=1.0, theta=0.0
% INFO    : Bus 486	: V=0.968559, theta=-29.923957 -> V=1.0, theta=0.0
% INFO    : Bus 487	: V=1.05206, theta=2.750607 -> V=1.004762, theta=0.0
% INFO    : Bus 488	: V=1.005852, theta=11.422371 -> V=1.0, theta=0.0
% INFO    : Bus 489	: V=1.025532, theta=-16.821682 -> V=1.0137295, theta=0.0
% INFO    : Bus 490	: V=1.077184, theta=-47.177539 -> V=1.0168705, theta=0.0
% INFO    : Bus 491	: V=1.058459, theta=-17.763846 -> V=1.0127975, theta=0.0
% INFO    : Bus 492	: V=1.016452, theta=-26.858608 -> V=1.041964, theta=0.0
% INFO    : Bus 493	: V=1.059733, theta=-35.465613 -> V=1.020494, theta=0.0
% INFO    : Bus 494	: V=1.067795, theta=11.013566 -> V=1.0230455, theta=0.0
% INFO    : Bus 495	: V=1.070269, theta=-10.116176 -> V=1.0265135, theta=0.0
% INFO    : Bus 496	: V=1.058763, theta=-41.33226 -> V=1.0072985, theta=0.0
% INFO    : Bus 497	: V=0.904142, theta=-32.155554 -> V=1.0, theta=0.0
% INFO    : Bus 498	: V=0.991133, theta=-39.099122 -> V=1.0, theta=0.0
% INFO    : Bus 499	: V=1.071157, theta=-19.658311 -> V=1.0184115, theta=0.0
% INFO    : Bus 500	: V=1.06005, theta=-25.172393 -> V=1.0120745, theta=0.0
% INFO    : Bus 501	: V=1.061003, theta=-21.745314 -> V=1.019202, theta=0.0
% INFO    : Bus 502	: V=1.030144, theta=-9.265439 -> V=1.005943, theta=0.0
% INFO    : Bus 503	: V=1.04818, theta=15.421511 -> V=1.0, theta=0.0
% INFO    : Bus 504	: V=1.081374, theta=3.930379 -> V=1.024723, theta=0.0
% INFO    : Bus 505	: V=1.018785, theta=-11.955025 -> V=1.0, theta=0.0
% INFO    : Bus 506	: V=1.052531, theta=-10.711361 -> V=1.0166675, theta=0.0
% INFO    : Bus 507	: V=1.015579, theta=-3.731791 -> V=1.0, theta=0.0
% INFO    : Bus 508	: V=1.03851, theta=-24.498833 -> V=1.0, theta=0.0
% INFO    : Bus 509	: V=1.040728, theta=-46.512792 -> V=1.035849, theta=0.0
% INFO    : Bus 510	: V=1.018483, theta=-22.201732 -> V=1.0, theta=0.0
% INFO    : Bus 511	: V=0.951679, theta=-27.11965 -> V=1.0, theta=0.0
% INFO    : Bus 512	: V=1.088721, theta=-32.900237 -> V=1.018659, theta=0.0
% INFO    : Bus 513	: V=1.036617, theta=-22.89367 -> V=1.0163105, theta=0.0
% INFO    : Bus 514	: V=1.092128, theta=-20.100979 -> V=1.030488, theta=0.0
% INFO    : Bus 515	: V=0.954046, theta=-25.902941 -> V=1.0, theta=0.0
% INFO    : Bus 516	: V=1.006567, theta=12.647319 -> V=1.0, theta=0.0
% INFO    : Bus 517	: V=1.051536, theta=-11.788539 -> V=1.015113, theta=0.0
% INFO    : Bus 518	: V=0.961477, theta=-35.326019 -> V=1.0, theta=0.0
% INFO    : Bus 519	: V=1.018149, theta=-23.182896 -> V=1.0, theta=0.0
% INFO    : Bus 520	: V=1.046577, theta=-11.266074 -> V=1.008898, theta=0.0
% INFO    : Bus 521	: V=1.014391, theta=-14.608178 -> V=1.0, theta=0.0
% INFO    : Bus 522	: V=1.078858, theta=20.442128 -> V=1.0306385, theta=0.0
% INFO    : Bus 523	: V=0.997091, theta=20.068849 -> V=1.0, theta=0.0
% INFO    : Bus 524	: V=1.077814, theta=-47.108294 -> V=1.007028, theta=0.0
% INFO    : Bus 525	: V=1.043444, theta=-38.335942 -> V=1.0056745, theta=0.0
% INFO    : Bus 526	: V=1.073726, theta=-18.965303 -> V=1.0065155, theta=0.0
% INFO    : Bus 527	: V=1.057636, theta=-14.590902 -> V=1.0056455, theta=0.0
% INFO    : Bus 528	: V=1.02113, theta=5.007866 -> V=1.0, theta=0.0
% INFO    : Bus 529	: V=1.075899, theta=2.86124 -> V=1.022571, theta=0.0
% INFO    : Bus 530	: V=1.017403, theta=-22.354383 -> V=1.0, theta=0.0
% INFO    : Bus 531	: V=1.0595, theta=1.211549 -> V=1.013101, theta=0.0
% INFO    : Bus 532	: V=0.984147, theta=-25.3661 -> V=1.0, theta=0.0
% INFO    : Bus 533	: V=1.04692, theta=-21.588347 -> V=1.003973, theta=0.0
% INFO    : Bus 534	: V=1.094921, theta=56.239847 -> V=1.007353, theta=0.0
% INFO    : Bus 535	: V=0.977568, theta=-27.132905 -> V=1.0, theta=0.0
% INFO    : Bus 536	: V=1.03131, theta=4.041293 -> V=1.0, theta=0.0
% INFO    : Bus 537	: V=1.072705, theta=10.807187 -> V=1.011997, theta=0.0
% INFO    : Bus 538	: V=1.013163, theta=-8.636851 -> V=1.006348, theta=0.0
% INFO    : Bus 539	: V=1.048075, theta=-46.061821 -> V=1.0057795, theta=0.0
% INFO    : Bus 540	: V=0.936642, theta=-24.930101 -> V=1.0, theta=0.0
% INFO    : Bus 541	: V=1.090217, theta=-43.441063 -> V=1.027876, theta=0.0
% INFO    : Bus 542	: V=0.991741, theta=-20.692445 -> V=1.0, theta=0.0
% INFO    : Bus 543	: V=1.010913, theta=-19.593834 -> V=1.0, theta=0.0
% INFO    : Bus 544	: V=1.040607, theta=3.750387 -> V=1.005391, theta=0.0
% INFO    : Bus 545	: V=1.069518, theta=-13.520167 -> V=1.0164115, theta=0.0
% INFO    : Bus 546	: V=1.070342, theta=-42.699287 -> V=1.0094365, theta=0.0
% INFO    : Bus 547	: V=1.077907, theta=-15.344549 -> V=1.0232885, theta=0.0
% INFO    : Bus 548	: V=1.046028, theta=-12.56487 -> V=1.0060835, theta=0.0
% INFO    : Bus 549	: V=1.069062, theta=31.546178 -> V=1.0, theta=0.0
% INFO    : Bus 550	: V=1.05654, theta=-11.287673 -> V=1.0244775, theta=0.0
% INFO    : Bus 551	: V=1.036054, theta=-32.584651 -> V=1.0156445, theta=0.0
% INFO    : Bus 552	: V=1.026875, theta=-14.094244 -> V=1.0, theta=0.0
% INFO    : Bus 553	: V=1.02753, theta=-50.882772 -> V=1.0, theta=0.0
% INFO    : Bus 554	: V=1.075706, theta=-10.638282 -> V=1.016642, theta=0.0
% INFO    : Bus 555	: V=1.016872, theta=-25.693887 -> V=1.0, theta=0.0
% INFO    : Bus 556	: V=0.964544, theta=-30.567292 -> V=1.0, theta=0.0
% INFO    : Bus 557	: V=1.096591, theta=-10.595994 -> V=1.035825, theta=0.0
% INFO    : Bus 558	: V=1.079273, theta=-12.189346 -> V=1.0207975, theta=0.0
% INFO    : Bus 559	: V=0.973935, theta=-24.453497 -> V=1.0, theta=0.0
% INFO    : Bus 560	: V=1.082367, theta=-44.35254 -> V=1.009449, theta=0.0
% INFO    : Bus 561	: V=1.057314, theta=-24.09848 -> V=1.016003, theta=0.0
% INFO    : Bus 562	: V=1.012667, theta=-14.766434 -> V=1.0, theta=0.0
% INFO    : Bus 563	: V=1.03714, theta=-47.366002 -> V=1.0, theta=0.0
% INFO    : Bus 564	: V=1.099017, theta=60.575265 -> V=1.0084705, theta=0.0
% INFO    : Bus 565	: V=1.080951, theta=-9.661245 -> V=1.0228125, theta=0.0
% INFO    : Bus 566	: V=1.025239, theta=-23.241188 -> V=1.0, theta=0.0
% INFO    : Bus 567	: V=1.002386, theta=-26.000495 -> V=1.0, theta=0.0
% INFO    : Bus 568	: V=1.002737, theta=-27.984949 -> V=1.0, theta=0.0
% INFO    : Bus 569	: V=0.992455, theta=-30.836531 -> V=1.0, theta=0.0
% INFO    : Bus 570	: V=1.043347, theta=-16.985065 -> V=1.0, theta=0.0
% INFO    : Bus 571	: V=1.063857, theta=8.160507 -> V=1.0127325, theta=0.0
% INFO    : Bus 572	: V=1.003202, theta=-23.569718 -> V=1.0, theta=0.0
% INFO    : Bus 573	: V=1.035331, theta=-21.602683 -> V=1.0059705, theta=0.0
% INFO    : Bus 574	: V=0.939513, theta=-25.220281 -> V=1.0, theta=0.0
% INFO    : Bus 575	: V=1.009138, theta=10.749861 -> V=1.0, theta=0.0
% INFO    : Bus 576	: V=1.056636, theta=-18.681614 -> V=1.009033, theta=0.0
% INFO    : Bus 577	: V=1.020676, theta=15.654738 -> V=1.0, theta=0.0
% INFO    : Bus 578	: V=1.050773, theta=-29.649309 -> V=1.0223425, theta=0.0
% INFO    : Bus 579	: V=1.023843, theta=37.784045 -> V=1.0, theta=0.0
% INFO    : Bus 580	: V=1.081123, theta=-12.616963 -> V=1.0176895, theta=0.0
% INFO    : Bus 581	: V=1.085368, theta=-45.64343 -> V=1.013295, theta=0.0
% INFO    : Bus 582	: V=1.072329, theta=-0.479283 -> V=1.0195845, theta=0.0
% INFO    : Bus 583	: V=1.017177, theta=-20.84962 -> V=1.004656, theta=0.0
% INFO    : Bus 584	: V=1.05456, theta=-15.677227 -> V=1.0032305, theta=0.0
% INFO    : Bus 585	: V=1.06482, theta=63.864513 -> V=1.0, theta=0.0
% INFO    : Bus 586	: V=1.054773, theta=61.445595 -> V=1.004198, theta=0.0
% INFO    : Bus 587	: V=1.064975, theta=-43.910399 -> V=1.0069175, theta=0.0
% INFO    : Bus 588	: V=1.051264, theta=7.851991 -> V=1.0135945, theta=0.0
% INFO    : Bus 589	: V=0.950047, theta=64.765831 -> V=1.0, theta=0.0
% INFO    : Bus 590	: V=1.056145, theta=-9.787783 -> V=1.01383, theta=0.0
% INFO    : Bus 591	: V=0.962021, theta=-13.410075 -> V=1.0, theta=0.0
% INFO    : Bus 592	: V=1.039073, theta=-22.588184 -> V=1.0, theta=0.0
% INFO    : Bus 593	: V=1.029293, theta=13.66667 -> V=1.003363, theta=0.0
% INFO    : Bus 594	: V=1.010518, theta=10.828212 -> V=1.0, theta=0.0
% INFO    : Bus 595	: V=1.060491, theta=-16.808833 -> V=1.019987, theta=0.0
% INFO    : Bus 596	: V=1.085071, theta=1.446342 -> V=1.017156, theta=0.0
% INFO    : Bus 597	: V=1.082237, theta=-40.354654 -> V=1.0259335, theta=0.0
% INFO    : Bus 598	: V=1.081054, theta=0.960033 -> V=1.016068, theta=0.0
% INFO    : Bus 599	: V=1.050487, theta=9.632286 -> V=1.0050575, theta=0.0
% INFO    : Bus 600	: V=0.973603, theta=-24.18199 -> V=1.0, theta=0.0
% INFO    : Bus 601	: V=1.013055, theta=-28.447765 -> V=1.0, theta=0.0
% INFO    : Bus 602	: V=1.05194, theta=-17.59937 -> V=1.003905, theta=0.0
% INFO    : Bus 603	: V=1.07087, theta=-5.228918 -> V=1.012115, theta=0.0
% INFO    : Bus 604	: V=1.052359, theta=-27.841534 -> V=1.0, theta=0.0
% INFO    : Bus 605	: V=1.024517, theta=-23.233757 -> V=1.0, theta=0.0
% INFO    : Bus 606	: V=0.995949, theta=-22.378624 -> V=1.0, theta=0.0
% INFO    : Bus 607	: V=1.048697, theta=-20.010721 -> V=1.0, theta=0.0
% INFO    : Bus 608	: V=1.063973, theta=-41.996651 -> V=1.0147055, theta=0.0
% INFO    : Bus 609	: V=1.027265, theta=12.552226 -> V=1.0, theta=0.0
% INFO    : Bus 610	: V=1.110436, theta=-10.188562 -> V=1.035356, theta=0.0
% INFO    : Bus 611	: V=0.981868, theta=-21.643463 -> V=1.0, theta=0.0
% INFO    : Bus 612	: V=1.069406, theta=4.526731 -> V=1.0197215, theta=0.0
% INFO    : Bus 613	: V=0.996149, theta=-25.902399 -> V=1.0, theta=0.0
% INFO    : Bus 614	: V=1.052765, theta=-20.45451 -> V=1.0060305, theta=0.0
% INFO    : Bus 615	: V=1.080299, theta=-15.43131 -> V=1.0186725, theta=0.0
% INFO    : Bus 616	: V=1.043128, theta=8.683305 -> V=1.0, theta=0.0
% INFO    : Bus 617	: V=1.088737, theta=-32.903548 -> V=1.0186855, theta=0.0
% INFO    : Bus 618	: V=1.084227, theta=-9.495118 -> V=1.027438, theta=0.0
% INFO    : Bus 619	: V=1.000498, theta=11.419469 -> V=1.0, theta=0.0
% INFO    : Bus 620	: V=1.015238, theta=-47.069623 -> V=1.0, theta=0.0
% INFO    : Bus 621	: V=1.100635, theta=-16.433157 -> V=1.0322735, theta=0.0
% INFO    : Bus 622	: V=1.053044, theta=-42.094203 -> V=1.004489, theta=0.0
% INFO    : Bus 623	: V=1.070885, theta=-4.95474 -> V=1.018323, theta=0.0
% INFO    : Bus 624	: V=1.048712, theta=-22.206669 -> V=1.0, theta=0.0
% INFO    : Bus 625	: V=0.981202, theta=-18.295145 -> V=1.0, theta=0.0
% INFO    : Bus 626	: V=1.022882, theta=-29.78219 -> V=1.0, theta=0.0
% INFO    : Bus 627	: V=1.09875, theta=-36.043391 -> V=1.038684, theta=0.0
% INFO    : Bus 628	: V=1.094993, theta=-36.282578 -> V=1.023744, theta=0.0
% INFO    : Bus 629	: V=1.010466, theta=-19.896256 -> V=1.0, theta=0.0
% INFO    : Bus 630	: V=1.021471, theta=-34.04119 -> V=1.0, theta=0.0
% INFO    : Bus 631	: V=1.073545, theta=-15.08163 -> V=1.01009, theta=0.0
% INFO    : Bus 632	: V=1.096316, theta=-36.938434 -> V=1.0309475, theta=0.0
% INFO    : Bus 633	: V=1.016727, theta=-25.873368 -> V=1.0, theta=0.0
% INFO    : Bus 634	: V=1.050616, theta=-47.882481 -> V=1.0, theta=0.0
% INFO    : Bus 635	: V=0.936202, theta=-25.332066 -> V=1.0, theta=0.0
% INFO    : Bus 636	: V=1.005987, theta=-32.586588 -> V=1.0, theta=0.0
% INFO    : Bus 637	: V=1.007914, theta=-31.413473 -> V=1.0, theta=0.0
% INFO    : Bus 638	: V=1.094656, theta=-14.544391 -> V=1.0262605, theta=0.0
% INFO    : Bus 639	: V=1.05586, theta=-27.16557 -> V=1.0092005, theta=0.0
% INFO    : Bus 640	: V=1.056118, theta=-39.867239 -> V=1.0028475, theta=0.0
% INFO    : Bus 641	: V=1.057489, theta=-25.087192 -> V=1.02222, theta=0.0
% INFO    : Bus 642	: V=1.016196, theta=-47.303864 -> V=1.0, theta=0.0
% INFO    : Bus 643	: V=1.085395, theta=-38.006581 -> V=1.0320775, theta=0.0
% INFO    : Bus 644	: V=1.05869, theta=-41.127056 -> V=1.0103465, theta=0.0
% INFO    : Bus 645	: V=1.055184, theta=-0.174084 -> V=1.017619, theta=0.0
% INFO    : Bus 646	: V=1.049086, theta=-0.355982 -> V=1.011988, theta=0.0
% INFO    : Bus 647	: V=0.991455, theta=-4.755008 -> V=1.0, theta=0.0
% INFO    : Bus 648	: V=1.092237, theta=-8.089901 -> V=1.0141485, theta=0.0
% INFO    : Bus 649	: V=1.036944, theta=-19.884576 -> V=1.0, theta=0.0
% INFO    : Bus 650	: V=1.010496, theta=-19.629822 -> V=1.0, theta=0.0
% INFO    : Bus 651	: V=1.039331, theta=-24.598821 -> V=1.0118555, theta=0.0
% INFO    : Bus 652	: V=1.043796, theta=-18.556075 -> V=1.008854, theta=0.0
% INFO    : Bus 653	: V=0.984414, theta=-26.529834 -> V=1.0, theta=0.0
% INFO    : Bus 654	: V=1.06525, theta=-23.139584 -> V=1.0114255, theta=0.0
% INFO    : Bus 655	: V=1.087705, theta=1.081026 -> V=1.0283065, theta=0.0
% INFO    : Bus 656	: V=1.006528, theta=-36.876182 -> V=1.0, theta=0.0
% INFO    : Bus 657	: V=1.103275, theta=-16.201189 -> V=1.031095, theta=0.0
% INFO    : Bus 658	: V=1.061657, theta=-5.79777 -> V=1.013968, theta=0.0
% INFO    : Bus 659	: V=1.097447, theta=-7.91391 -> V=1.016099, theta=0.0
% INFO    : Bus 660	: V=1.040387, theta=-20.642275 -> V=1.0, theta=0.0
% INFO    : Bus 661	: V=0.998773, theta=-37.10915 -> V=1.0, theta=0.0
% INFO    : Bus 662	: V=1.082696, theta=-45.346098 -> V=1.0206345, theta=0.0
% INFO    : Bus 663	: V=1.063546, theta=19.952996 -> V=1.0135845, theta=0.0
% INFO    : Bus 664	: V=1.02225, theta=2.801027 -> V=1.0, theta=0.0
% INFO    : Bus 665	: V=1.04125, theta=-0.687841 -> V=1.005723, theta=0.0
% INFO    : Bus 666	: V=1.033004, theta=61.84178 -> V=1.0, theta=0.0
% INFO    : Bus 667	: V=0.95955, theta=-24.453893 -> V=1.0, theta=0.0
% INFO    : Bus 668	: V=1.016545, theta=-34.347516 -> V=1.0, theta=0.0
% INFO    : Bus 669	: V=1.079789, theta=-38.547778 -> V=1.0207415, theta=0.0
% INFO    : Bus 670	: V=1.010953, theta=-22.101037 -> V=1.0, theta=0.0
% INFO    : Bus 671	: V=0.979566, theta=-17.226484 -> V=1.0, theta=0.0
% INFO    : Bus 672	: V=1.071057, theta=-4.956251 -> V=1.0184135, theta=0.0
% INFO    : Bus 673	: V=1.030998, theta=-22.748654 -> V=1.005186, theta=0.0
% INFO    : Bus 674	: V=1.053309, theta=-15.190851 -> V=1.0, theta=0.0
% INFO    : Bus 675	: V=1.014668, theta=-20.259451 -> V=1.0, theta=0.0
% INFO    : Bus 676	: V=0.941454, theta=-27.824941 -> V=1.0, theta=0.0
% INFO    : Bus 677	: V=0.989364, theta=-24.886173 -> V=1.0, theta=0.0
% INFO    : Bus 678	: V=1.077267, theta=-38.424914 -> V=1.018867, theta=0.0
% INFO    : Bus 679	: V=0.995136, theta=-36.974928 -> V=1.00913, theta=0.0
% INFO    : Bus 680	: V=1.073044, theta=-23.237951 -> V=1.019094, theta=0.0
% INFO    : Bus 681	: V=1.023544, theta=-39.765126 -> V=1.0, theta=0.0
% INFO    : Bus 682	: V=1.08267, theta=-24.837295 -> V=1.011187, theta=0.0
% INFO    : Bus 683	: V=0.995543, theta=-22.609869 -> V=1.0, theta=0.0
% INFO    : Bus 684	: V=1.093563, theta=-40.631783 -> V=1.0170015, theta=0.0
% INFO    : Bus 685	: V=1.010469, theta=-12.668448 -> V=1.0, theta=0.0
% INFO    : Bus 686	: V=1.066816, theta=-13.252332 -> V=1.0162235, theta=0.0
% INFO    : Bus 687	: V=0.968559, theta=-29.923957 -> V=1.0, theta=0.0
% INFO    : Bus 688	: V=1.082469, theta=-24.635807 -> V=1.0260495, theta=0.0
% INFO    : Bus 689	: V=1.054, theta=-12.322977 -> V=1.008167, theta=0.0
% INFO    : Bus 690	: V=1.014676, theta=-16.703663 -> V=1.0064425, theta=0.0
% INFO    : Bus 691	: V=1.019974, theta=-23.37169 -> V=1.0, theta=0.0
% INFO    : Bus 692	: V=1.081455, theta=-28.862538 -> V=1.0167885, theta=0.0
% INFO    : Bus 693	: V=1.000409, theta=-1.210827 -> V=1.0, theta=0.0
% INFO    : Bus 694	: V=1.062591, theta=-35.079996 -> V=1.0220795, theta=0.0
% INFO    : Bus 695	: V=1.05028, theta=-20.49844 -> V=1.01949, theta=0.0
% INFO    : Bus 696	: V=0.939995, theta=-29.215258 -> V=0.9956795, theta=0.0
% INFO    : Bus 697	: V=0.995714, theta=-16.713646 -> V=1.0, theta=0.0
% INFO    : Bus 698	: V=1.065508, theta=-10.9882 -> V=1.0179985, theta=0.0
% INFO    : Bus 699	: V=1.085545, theta=0.805565 -> V=1.0424245, theta=0.0
% INFO    : Bus 700	: V=1.03043, theta=-35.060062 -> V=1.0, theta=0.0
% INFO    : Bus 701	: V=1.036593, theta=-13.466759 -> V=1.0, theta=0.0
% INFO    : Bus 702	: V=0.988124, theta=-16.638085 -> V=1.0, theta=0.0
% INFO    : Bus 703	: V=1.081084, theta=5.919215 -> V=1.025248, theta=0.0
% INFO    : Bus 704	: V=1.063773, theta=-12.379783 -> V=1.0176375, theta=0.0
% INFO    : Bus 705	: V=1.078, theta=-6.313339 -> V=1.018369, theta=0.0
% INFO    : Bus 706	: V=1.068842, theta=18.5322 -> V=1.017879, theta=0.0
% INFO    : Bus 707	: V=1.024136, theta=-40.423528 -> V=1.0, theta=0.0
% INFO    : Bus 708	: V=0.998449, theta=-40.215058 -> V=1.0, theta=0.0
% INFO    : Bus 709	: V=1.070257, theta=-18.149929 -> V=1.0, theta=0.0
% INFO    : Bus 710	: V=1.032508, theta=-22.742899 -> V=1.0, theta=0.0
% INFO    : Bus 711	: V=1.076152, theta=3.335431 -> V=1.0229325, theta=0.0
% INFO    : Bus 712	: V=1.057221, theta=-29.951981 -> V=1.005832, theta=0.0
% INFO    : Bus 713	: V=1.041123, theta=-18.611205 -> V=1.0, theta=0.0
% INFO    : Bus 714	: V=0.935692, theta=-25.509866 -> V=1.0, theta=0.0
% INFO    : Bus 715	: V=1.073369, theta=-5.732901 -> V=1.0139885, theta=0.0
% INFO    : Bus 716	: V=1.077179, theta=9.472781 -> V=1.023059, theta=0.0
% INFO    : Bus 717	: V=1.103342, theta=-5.260136 -> V=1.0243415, theta=0.0
% INFO    : Bus 718	: V=1.083378, theta=-6.042288 -> V=1.019499, theta=0.0
% INFO    : Bus 719	: V=1.014657, theta=-14.948117 -> V=1.0, theta=0.0
% INFO    : Bus 720	: V=1.073864, theta=-13.952376 -> V=1.014879, theta=0.0
% INFO    : Bus 721	: V=1.014545, theta=-39.036205 -> V=1.0, theta=0.0
% INFO    : Bus 722	: V=1.065212, theta=-35.856476 -> V=1.0129305, theta=0.0
% INFO    : Bus 723	: V=1.018784, theta=14.701661 -> V=1.0, theta=0.0
% INFO    : Bus 724	: V=0.990239, theta=-26.326965 -> V=1.0, theta=0.0
% INFO    : Bus 725	: V=1.04336, theta=-12.076378 -> V=1.0081435, theta=0.0
% INFO    : Bus 726	: V=0.94674, theta=-29.320349 -> V=1.0, theta=0.0
% INFO    : Bus 727	: V=1.082658, theta=-40.003793 -> V=1.0261825, theta=0.0
% INFO    : Bus 728	: V=1.038955, theta=-24.396361 -> V=1.010971, theta=0.0
% INFO    : Bus 729	: V=1.096935, theta=-7.047745 -> V=1.0329155, theta=0.0
% INFO    : Bus 730	: V=1.05892, theta=-10.601115 -> V=1.007971, theta=0.0
% INFO    : Bus 731	: V=1.031214, theta=6.71888 -> V=1.0, theta=0.0
% INFO    : Bus 732	: V=1.085841, theta=-34.273374 -> V=1.014022, theta=0.0
% INFO    : Bus 733	: V=1.043736, theta=-45.794562 -> V=1.0, theta=0.0
% INFO    : Bus 734	: V=1.076669, theta=-0.969106 -> V=1.019296, theta=0.0
% INFO    : Bus 735	: V=1.06309, theta=-20.119799 -> V=1.0, theta=0.0
% INFO    : Bus 736	: V=1.059217, theta=-20.297167 -> V=1.0, theta=0.0
% INFO    : Bus 737	: V=0.971733, theta=-24.413773 -> V=1.0, theta=0.0
% INFO    : Bus 738	: V=1.072584, theta=-45.683359 -> V=1.0056335, theta=0.0
% INFO    : Bus 739	: V=1.03953, theta=-20.176584 -> V=1.023319, theta=0.0
% INFO    : Bus 740	: V=1.092618, theta=-30.870659 -> V=1.0173595, theta=0.0
% INFO    : Bus 741	: V=1.03835, theta=-42.812321 -> V=1.0031615, theta=0.0
% INFO    : Bus 742	: V=1.039768, theta=54.342291 -> V=1.0, theta=0.0
% INFO    : Bus 743	: V=1.090656, theta=-0.669868 -> V=1.027388, theta=0.0
% INFO    : Bus 744	: V=1.016356, theta=-26.875174 -> V=1.04367, theta=0.0
% INFO    : Bus 745	: V=1.025139, theta=-6.006674 -> V=1.0, theta=0.0
% INFO    : Bus 746	: V=1.084658, theta=-2.629753 -> V=1.0242385, theta=0.0
% INFO    : Bus 747	: V=1.012539, theta=-31.933832 -> V=1.0, theta=0.0
% INFO    : Bus 748	: V=1.053193, theta=-28.380077 -> V=1.0, theta=0.0
% INFO    : Bus 749	: V=1.059471, theta=-11.775101 -> V=1.014293, theta=0.0
% INFO    : Bus 750	: V=1.026817, theta=16.096788 -> V=1.0, theta=0.0
% INFO    : Bus 751	: V=1.051214, theta=-38.437215 -> V=1.008023, theta=0.0
% INFO    : Bus 752	: V=0.999909, theta=-22.239846 -> V=1.0, theta=0.0
% INFO    : Bus 753	: V=1.013227, theta=-47.46786 -> V=1.0, theta=0.0
% INFO    : Bus 754	: V=1.028939, theta=-20.791212 -> V=1.0, theta=0.0
% INFO    : Bus 755	: V=1.054022, theta=-36.296311 -> V=1.018128, theta=0.0
% INFO    : Bus 756	: V=1.077362, theta=-18.302932 -> V=1.0102125, theta=0.0
% INFO    : Bus 757	: V=1.066136, theta=-38.885019 -> V=1.0220535, theta=0.0
% INFO    : Bus 758	: V=1.068649, theta=2.419407 -> V=1.0200755, theta=0.0
% INFO    : Bus 759	: V=1.072841, theta=-2.173491 -> V=1.0176985, theta=0.0
% INFO    : Bus 760	: V=1.042197, theta=-16.65121 -> V=1.0, theta=0.0
% INFO    : Bus 761	: V=1.081358, theta=-17.198493 -> V=1.0255615, theta=0.0
% INFO    : Bus 762	: V=1.03341, theta=-4.165138 -> V=1.0, theta=0.0
% INFO    : Bus 763	: V=1.005459, theta=-35.742258 -> V=1.0, theta=0.0
% INFO    : Bus 764	: V=1.091289, theta=-8.207248 -> V=1.0141355, theta=0.0
% INFO    : Bus 765	: V=0.968077, theta=-24.776211 -> V=1.0, theta=0.0
% INFO    : Bus 766	: V=1.095555, theta=-13.408463 -> V=1.0198745, theta=0.0
% INFO    : Bus 767	: V=1.045867, theta=61.77888 -> V=1.0, theta=0.0
% INFO    : Bus 768	: V=1.087553, theta=-37.636356 -> V=1.0140505, theta=0.0
% INFO    : Bus 769	: V=0.952473, theta=-26.817877 -> V=1.0, theta=0.0
% INFO    : Bus 770	: V=1.065727, theta=-19.378858 -> V=1.01218, theta=0.0
% INFO    : Bus 771	: V=1.028902, theta=-10.954463 -> V=1.0, theta=0.0
% INFO    : Bus 772	: V=1.056166, theta=-49.275668 -> V=1.0069155, theta=0.0
% INFO    : Bus 773	: V=1.003235, theta=-29.621822 -> V=1.0, theta=0.0
% INFO    : Bus 774	: V=0.990393, theta=-16.810805 -> V=1.0, theta=0.0
% INFO    : Bus 775	: V=0.967182, theta=-26.708669 -> V=1.0, theta=0.0
% INFO    : Bus 776	: V=1.081211, theta=0.098725 -> V=1.021375, theta=0.0
% INFO    : Bus 777	: V=1.040712, theta=-21.289009 -> V=1.008542, theta=0.0
% INFO    : Bus 778	: V=1.054546, theta=-25.486784 -> V=1.008086, theta=0.0
% INFO    : Bus 779	: V=0.962557, theta=-25.771318 -> V=1.0, theta=0.0
% INFO    : Bus 780	: V=0.942577, theta=-27.496595 -> V=1.0, theta=0.0
% INFO    : Bus 781	: V=1.030691, theta=-21.834225 -> V=1.003876, theta=0.0
% INFO    : Bus 782	: V=0.978946, theta=46.587878 -> V=1.0, theta=0.0
% INFO    : Bus 783	: V=1.028193, theta=-4.425097 -> V=1.0, theta=0.0
% INFO    : Bus 784	: V=1.044959, theta=-17.314953 -> V=1.014368, theta=0.0
% INFO    : Bus 785	: V=1.07354, theta=-42.317747 -> V=1.01105, theta=0.0
% INFO    : Bus 786	: V=1.0727, theta=-23.386228 -> V=1.0189535, theta=0.0
% INFO    : Bus 787	: V=1.057058, theta=-11.613944 -> V=1.018226, theta=0.0
% INFO    : Bus 788	: V=1.023641, theta=5.267888 -> V=1.0, theta=0.0
% INFO    : Bus 789	: V=1.038653, theta=-24.43639 -> V=1.0, theta=0.0
% INFO    : Bus 790	: V=1.081263, theta=-34.709792 -> V=1.0299745, theta=0.0
% INFO    : Bus 791	: V=0.984869, theta=-22.171686 -> V=1.0, theta=0.0
% INFO    : Bus 792	: V=0.979864, theta=-25.175252 -> V=1.0, theta=0.0
% INFO    : Bus 793	: V=1.085208, theta=8.56556 -> V=1.0168205, theta=0.0
% INFO    : Bus 794	: V=1.001774, theta=-39.954836 -> V=1.0, theta=0.0
% INFO    : Bus 795	: V=1.091067, theta=-15.940967 -> V=1.039967, theta=0.0
% INFO    : Bus 796	: V=1.039167, theta=-15.877499 -> V=1.0, theta=0.0
% INFO    : Bus 797	: V=1.054342, theta=-43.772308 -> V=1.0114245, theta=0.0
% INFO    : Bus 798	: V=1.063145, theta=-9.400205 -> V=1.0152375, theta=0.0
% INFO    : Bus 799	: V=1.037779, theta=-22.836501 -> V=1.0174815, theta=0.0
% INFO    : Bus 800	: V=1.01978, theta=-23.607485 -> V=1.0, theta=0.0
% INFO    : Bus 801	: V=1.032767, theta=12.765979 -> V=1.0, theta=0.0
% INFO    : Bus 802	: V=1.081228, theta=-17.801039 -> V=1.021914, theta=0.0
% INFO    : Bus 803	: V=1.061636, theta=-16.969741 -> V=1.0093735, theta=0.0
% INFO    : Bus 804	: V=1.028501, theta=-23.148996 -> V=1.003916, theta=0.0
% INFO    : Bus 805	: V=1.068788, theta=-1.068902 -> V=1.0191085, theta=0.0
% INFO    : Bus 806	: V=1.068474, theta=-18.145672 -> V=1.0317995, theta=0.0
% INFO    : Bus 807	: V=1.044273, theta=-27.200919 -> V=1.0104865, theta=0.0
% INFO    : Bus 808	: V=1.077735, theta=-35.161598 -> V=1.0283205, theta=0.0
% INFO    : Bus 809	: V=1.016409, theta=-19.78518 -> V=1.0, theta=0.0
% INFO    : Bus 810	: V=1.073504, theta=-23.02874 -> V=1.0212495, theta=0.0
% INFO    : Bus 811	: V=1.037784, theta=9.111298 -> V=1.008819, theta=0.0
% INFO    : Bus 812	: V=1.092821, theta=-20.270457 -> V=1.030609, theta=0.0
% INFO    : Bus 813	: V=1.043609, theta=-15.093189 -> V=1.0152495, theta=0.0
% INFO    : Bus 814	: V=1.010896, theta=-21.971618 -> V=1.0, theta=0.0
% INFO    : Bus 815	: V=0.996099, theta=-18.388802 -> V=1.0, theta=0.0
% INFO    : Bus 816	: V=1.075891, theta=-25.523591 -> V=1.032538, theta=0.0
% INFO    : Bus 817	: V=1.052998, theta=-36.179675 -> V=1.0176935, theta=0.0
% INFO    : Bus 818	: V=1.063944, theta=-14.034728 -> V=1.0077915, theta=0.0
% INFO    : Bus 819	: V=1.00395, theta=-22.862459 -> V=1.0, theta=0.0
% INFO    : Bus 820	: V=1.075332, theta=-9.043212 -> V=1.021021, theta=0.0
% INFO    : Bus 821	: V=1.072965, theta=-7.67217 -> V=1.0216195, theta=0.0
% INFO    : Bus 822	: V=1.000469, theta=-18.781015 -> V=1.0, theta=0.0
% INFO    : Bus 823	: V=1.010475, theta=-36.627746 -> V=1.0, theta=0.0
% INFO    : Bus 824	: V=1.038626, theta=-21.38617 -> V=1.0075665, theta=0.0
% INFO    : Bus 825	: V=1.047395, theta=-2.297436 -> V=1.005998, theta=0.0
% INFO    : Bus 826	: V=1.067976, theta=-17.521788 -> V=1.0095515, theta=0.0
% INFO    : Bus 827	: V=1.046077, theta=-21.123218 -> V=1.0, theta=0.0
% INFO    : Bus 828	: V=1.079591, theta=-34.192611 -> V=1.0140575, theta=0.0
% INFO    : Bus 829	: V=1.014182, theta=-14.237512 -> V=1.0, theta=0.0
% INFO    : Bus 830	: V=0.965654, theta=-25.969307 -> V=1.0, theta=0.0
% INFO    : Bus 831	: V=1.042167, theta=9.63592 -> V=1.0, theta=0.0
% INFO    : Bus 832	: V=1.075441, theta=-19.762939 -> V=1.0199515, theta=0.0
% INFO    : Bus 833	: V=1.015807, theta=-17.563473 -> V=1.0, theta=0.0
% INFO    : Bus 834	: V=0.967804, theta=-13.115979 -> V=1.0, theta=0.0
% INFO    : Bus 835	: V=1.05995, theta=-22.058247 -> V=1.018778, theta=0.0
% INFO    : Bus 836	: V=1.019985, theta=-46.415581 -> V=1.0, theta=0.0
% INFO    : Bus 837	: V=0.968579, theta=-11.939655 -> V=1.0, theta=0.0
% INFO    : Bus 838	: V=1.067318, theta=-39.809461 -> V=1.0119515, theta=0.0
% INFO    : Bus 839	: V=1.056505, theta=0.38933 -> V=1.009112, theta=0.0
% INFO    : Bus 840	: V=1.071998, theta=-41.398698 -> V=1.010904, theta=0.0
% INFO    : Bus 841	: V=1.099553, theta=-33.813071 -> V=1.0228995, theta=0.0
% INFO    : Bus 842	: V=1.009885, theta=-26.520065 -> V=1.0, theta=0.0
% INFO    : Bus 843	: V=1.055383, theta=-48.841081 -> V=1.006513, theta=0.0
% INFO    : Bus 844	: V=1.033372, theta=-20.215155 -> V=1.0, theta=0.0
% INFO    : Bus 845	: V=0.972717, theta=-25.723178 -> V=1.0, theta=0.0
% INFO    : Bus 846	: V=1.059586, theta=-23.331244 -> V=1.016833, theta=0.0
% INFO    : Bus 847	: V=1.002489, theta=-20.013347 -> V=1.0, theta=0.0
% INFO    : Bus 848	: V=1.006199, theta=-24.97228 -> V=1.0, theta=0.0
% INFO    : Bus 849	: V=1.054407, theta=37.877043 -> V=1.0, theta=0.0
% INFO    : Bus 850	: V=1.077517, theta=-15.867506 -> V=1.020288, theta=0.0
% INFO    : Bus 851	: V=1.009917, theta=-24.553819 -> V=1.0, theta=0.0
% INFO    : Bus 852	: V=0.97531, theta=-20.273197 -> V=1.0, theta=0.0
% INFO    : Bus 853	: V=1.102702, theta=-10.257462 -> V=1.01645, theta=0.0
% INFO    : Bus 854	: V=1.051281, theta=-20.579653 -> V=1.0, theta=0.0
% INFO    : Bus 855	: V=1.046009, theta=-15.84881 -> V=1.0035845, theta=0.0
% INFO    : Bus 856	: V=1.021532, theta=-28.047066 -> V=1.0, theta=0.0
% INFO    : Bus 857	: V=1.036496, theta=-45.673731 -> V=1.0, theta=0.0
% INFO    : Bus 858	: V=1.045509, theta=-44.666819 -> V=1.0, theta=0.0
% INFO    : Bus 859	: V=1.02798, theta=-50.516313 -> V=1.0, theta=0.0
% INFO    : Bus 860	: V=0.937072, theta=-25.43818 -> V=1.0, theta=0.0
% INFO    : Bus 861	: V=1.06758, theta=0.040681 -> V=1.015594, theta=0.0
% INFO    : Bus 862	: V=1.074461, theta=-14.959924 -> V=1.0127905, theta=0.0
% INFO    : Bus 863	: V=1.069559, theta=-15.015629 -> V=1.0137035, theta=0.0
% INFO    : Bus 864	: V=1.066541, theta=-12.341042 -> V=1.0315255, theta=0.0
% INFO    : Bus 865	: V=1.050622, theta=-20.596583 -> V=1.0100275, theta=0.0
% INFO    : Bus 866	: V=1.064388, theta=-11.012839 -> V=1.0181845, theta=0.0
% INFO    : Bus 867	: V=1.04499, theta=-9.958324 -> V=1.0092785, theta=0.0
% INFO    : Bus 868	: V=1.042261, theta=-42.076334 -> V=1.0, theta=0.0
% INFO    : Bus 869	: V=1.091142, theta=-27.579975 -> V=1.0186095, theta=0.0
% INFO    : Bus 870	: V=1.052, theta=-12.817203 -> V=1.0103025, theta=0.0
% INFO    : Bus 871	: V=1.10009, theta=-8.858707 -> V=1.033907, theta=0.0
% INFO    : Bus 872	: V=0.950004, theta=-31.621675 -> V=0.97349, theta=0.0
% INFO    : Bus 873	: V=1.03618, theta=-41.755384 -> V=1.0, theta=0.0
% INFO    : Bus 874	: V=1.037247, theta=-27.442276 -> V=1.0, theta=0.0
% INFO    : Bus 875	: V=1.073586, theta=-11.340651 -> V=1.0166265, theta=0.0
% INFO    : Bus 876	: V=1.012119, theta=-36.962919 -> V=1.0, theta=0.0
% INFO    : Bus 877	: V=0.992788, theta=14.756517 -> V=1.0, theta=0.0
% INFO    : Bus 878	: V=0.987596, theta=-17.491918 -> V=1.0, theta=0.0
% INFO    : Bus 879	: V=1.086594, theta=32.711972 -> V=1.0096185, theta=0.0
% INFO    : Bus 880	: V=1.057447, theta=-38.32951 -> V=1.003022, theta=0.0
% INFO    : Bus 881	: V=1.093542, theta=-14.627919 -> V=1.0275045, theta=0.0
% INFO    : Bus 882	: V=1.101711, theta=4.874542 -> V=1.0207215, theta=0.0
% INFO    : Bus 883	: V=1.030031, theta=-22.502842 -> V=1.0, theta=0.0
% INFO    : Bus 884	: V=0.989091, theta=-29.316426 -> V=1.0, theta=0.0
% INFO    : Bus 885	: V=0.916942, theta=-31.270092 -> V=1.0, theta=0.0
% INFO    : Bus 886	: V=1.084026, theta=-44.998356 -> V=1.01051, theta=0.0
% INFO    : Bus 887	: V=1.091167, theta=-9.896786 -> V=1.0202905, theta=0.0
% INFO    : Bus 888	: V=1.016636, theta=-21.968124 -> V=1.0, theta=0.0
% INFO    : Bus 889	: V=0.954907, theta=-18.641198 -> V=1.0, theta=0.0
% INFO    : Bus 890	: V=1.057724, theta=-23.986777 -> V=1.0161705, theta=0.0
% INFO    : Bus 891	: V=1.018022, theta=-40.097196 -> V=1.0, theta=0.0
% INFO    : Bus 892	: V=1.101921, theta=44.71579 -> V=1.0058905, theta=0.0
% INFO    : Bus 893	: V=1.097158, theta=-36.856675 -> V=1.031224, theta=0.0
% INFO    : Bus 894	: V=1.073119, theta=-36.277558 -> V=1.017408, theta=0.0
% INFO    : Bus 895	: V=1.072235, theta=-47.702846 -> V=1.012266, theta=0.0
% INFO    : Bus 896	: V=1.019784, theta=-34.821772 -> V=1.0, theta=0.0
% INFO    : Bus 897	: V=1.053768, theta=-47.923512 -> V=1.0056485, theta=0.0
% INFO    : Bus 898	: V=0.960005, theta=-28.524817 -> V=1.0, theta=0.0
% INFO    : Bus 899	: V=1.027793, theta=-27.457202 -> V=1.0, theta=0.0
% INFO    : Bus 900	: V=0.980456, theta=-19.001786 -> V=1.0, theta=0.0
% INFO    : Bus 901	: V=1.062909, theta=-23.309107 -> V=1.0082485, theta=0.0
% INFO    : Bus 902	: V=0.996763, theta=3.707005 -> V=1.0, theta=0.0
% INFO    : Bus 903	: V=1.083461, theta=0.052671 -> V=1.0264585, theta=0.0
% INFO    : Bus 904	: V=1.073835, theta=-26.993777 -> V=1.0133285, theta=0.0
% INFO    : Bus 905	: V=0.979078, theta=-11.994215 -> V=1.0, theta=0.0
% INFO    : Bus 906	: V=0.989308, theta=-23.760215 -> V=1.0, theta=0.0
% INFO    : Bus 907	: V=1.018707, theta=-22.368862 -> V=1.0, theta=0.0
% INFO    : Bus 908	: V=1.046305, theta=15.044132 -> V=1.0109635, theta=0.0
% INFO    : Bus 909	: V=1.038378, theta=-29.382605 -> V=1.0, theta=0.0
% INFO    : Bus 910	: V=1.074682, theta=-32.936649 -> V=1.038571, theta=0.0
% INFO    : Bus 911	: V=1.080409, theta=-19.127652 -> V=1.021907, theta=0.0
% INFO    : Bus 912	: V=0.952218, theta=-29.159422 -> V=1.0, theta=0.0
% INFO    : Bus 913	: V=0.994409, theta=11.216246 -> V=1.0, theta=0.0
% INFO    : Bus 914	: V=1.073994, theta=-12.03159 -> V=1.027009, theta=0.0
% INFO    : Bus 915	: V=1.08826, theta=-14.675473 -> V=1.015375, theta=0.0
% INFO    : Bus 916	: V=1.012214, theta=-19.903974 -> V=1.0, theta=0.0
% INFO    : Bus 917	: V=0.973526, theta=-27.912982 -> V=1.0, theta=0.0
% INFO    : Bus 918	: V=1.055835, theta=-9.16684 -> V=1.014105, theta=0.0
% INFO    : Bus 919	: V=1.048795, theta=17.547105 -> V=1.010694, theta=0.0
% INFO    : Bus 920	: V=1.064428, theta=-2.424373 -> V=1.0211545, theta=0.0
% INFO    : Bus 921	: V=1.00251, theta=-26.107918 -> V=1.0, theta=0.0
% INFO    : Bus 922	: V=1.014597, theta=-42.442545 -> V=1.0, theta=0.0
% INFO    : Bus 923	: V=0.981285, theta=-23.776845 -> V=1.0, theta=0.0
% INFO    : Bus 924	: V=1.077545, theta=-5.217637 -> V=1.0162915, theta=0.0
% INFO    : Bus 925	: V=1.085382, theta=-34.962146 -> V=1.0163175, theta=0.0
% INFO    : Bus 926	: V=1.077988, theta=-21.627611 -> V=1.012001, theta=0.0
% INFO    : Bus 927	: V=0.943413, theta=-28.027334 -> V=1.0, theta=0.0
% INFO    : Bus 928	: V=0.967616, theta=-32.907594 -> V=1.0, theta=0.0
% INFO    : Bus 929	: V=1.086238, theta=4.965539 -> V=1.0264005, theta=0.0
% INFO    : Bus 930	: V=1.010682, theta=-42.454261 -> V=1.0, theta=0.0
% INFO    : Bus 931	: V=0.963374, theta=-13.287601 -> V=1.0, theta=0.0
% INFO    : Bus 932	: V=1.03406, theta=-47.034641 -> V=1.0, theta=0.0
% INFO    : Bus 933	: V=1.06672, theta=-47.431082 -> V=1.0108195, theta=0.0
% INFO    : Bus 934	: V=1.020422, theta=-30.519274 -> V=1.0, theta=0.0
% INFO    : Bus 935	: V=1.036036, theta=-17.284298 -> V=1.0075455, theta=0.0
% INFO    : Bus 936	: V=1.011853, theta=-22.278151 -> V=1.005285, theta=0.0
% INFO    : Bus 937	: V=1.047364, theta=66.194779 -> V=1.0, theta=0.0
% INFO    : Bus 938	: V=1.028955, theta=-32.167854 -> V=1.0, theta=0.0
% INFO    : Bus 939	: V=1.086728, theta=-37.673057 -> V=1.0298005, theta=0.0
% INFO    : Bus 940	: V=1.060117, theta=-27.359002 -> V=1.0110475, theta=0.0
% INFO    : Bus 941	: V=1.072859, theta=-23.310894 -> V=1.0190215, theta=0.0
% INFO    : Bus 942	: V=1.05581, theta=-27.142614 -> V=1.008986, theta=0.0
% INFO    : Bus 943	: V=1.057995, theta=-31.402002 -> V=1.042408, theta=0.0
% INFO    : Bus 944	: V=1.065182, theta=-27.607913 -> V=1.0072015, theta=0.0
% INFO    : Bus 945	: V=1.087637, theta=0.76719 -> V=1.018472, theta=0.0
% INFO    : Bus 946	: V=1.022036, theta=-16.045017 -> V=1.0, theta=0.0
% INFO    : Bus 947	: V=1.049305, theta=-18.303684 -> V=1.0, theta=0.0
% INFO    : Bus 948	: V=1.078787, theta=-8.375009 -> V=1.0226835, theta=0.0
% INFO    : Bus 949	: V=0.998391, theta=-39.64231 -> V=1.0, theta=0.0
% INFO    : Bus 950	: V=1.069509, theta=2.38695 -> V=1.004488, theta=0.0
% INFO    : Bus 951	: V=1.079053, theta=-3.539546 -> V=1.020831, theta=0.0
% INFO    : Bus 952	: V=0.935334, theta=-27.894813 -> V=1.0, theta=0.0
% INFO    : Bus 953	: V=1.065795, theta=-3.059679 -> V=1.017928, theta=0.0
% INFO    : Bus 954	: V=0.990766, theta=-23.758622 -> V=1.0, theta=0.0
% INFO    : Bus 955	: V=0.970967, theta=-24.764244 -> V=1.0, theta=0.0
% INFO    : Bus 956	: V=1.085256, theta=-15.871687 -> V=1.0285405, theta=0.0
% INFO    : Bus 957	: V=1.076682, theta=8.708948 -> V=1.029576, theta=0.0
% INFO    : Bus 958	: V=1.038957, theta=-12.244221 -> V=1.0145255, theta=0.0
% INFO    : Bus 959	: V=1.056958, theta=17.042819 -> V=1.01869, theta=0.0
% INFO    : Bus 960	: V=0.95516, theta=-23.841365 -> V=1.0, theta=0.0
% INFO    : Bus 961	: V=1.030034, theta=-24.47861 -> V=1.0, theta=0.0
% INFO    : Bus 962	: V=1.023768, theta=-23.061171 -> V=1.0, theta=0.0
% INFO    : Bus 963	: V=1.078993, theta=20.514548 -> V=1.031612, theta=0.0
% INFO    : Bus 964	: V=1.068363, theta=-3.734237 -> V=1.0135685, theta=0.0
% INFO    : Bus 965	: V=1.067545, theta=-17.586073 -> V=1.009328, theta=0.0
% INFO    : Bus 966	: V=1.092306, theta=-37.413602 -> V=1.0214565, theta=0.0
% INFO    : Bus 967	: V=1.026574, theta=-23.57534 -> V=1.0, theta=0.0
% INFO    : Bus 968	: V=1.0635, theta=-19.707728 -> V=1.0, theta=0.0
% INFO    : Bus 969	: V=0.986976, theta=-21.96064 -> V=1.0, theta=0.0
% INFO    : Bus 970	: V=1.07013, theta=-42.614333 -> V=1.0083, theta=0.0
% INFO    : Bus 971	: V=1.052458, theta=-49.271226 -> V=1.0049895, theta=0.0
% INFO    : Bus 972	: V=1.066949, theta=24.173625 -> V=1.0077005, theta=0.0
% INFO    : Bus 973	: V=1.067128, theta=-8.293514 -> V=1.014641, theta=0.0
% INFO    : Bus 974	: V=1.002652, theta=-29.856388 -> V=1.0, theta=0.0
% INFO    : Bus 975	: V=1.048366, theta=-17.730474 -> V=1.0041135, theta=0.0
% INFO    : Bus 976	: V=1.022442, theta=-15.661336 -> V=1.0, theta=0.0
% INFO    : Bus 977	: V=1.040513, theta=-29.176141 -> V=1.0, theta=0.0
% INFO    : Bus 978	: V=1.06815, theta=-20.375662 -> V=1.0205005, theta=0.0
% INFO    : Bus 979	: V=1.047135, theta=-22.169959 -> V=1.0250245, theta=0.0
% INFO    : Bus 980	: V=1.076496, theta=-39.155008 -> V=1.014552, theta=0.0
% INFO    : Bus 981	: V=1.097121, theta=-9.870688 -> V=1.036572, theta=0.0
% INFO    : Bus 982	: V=0.964642, theta=-30.559805 -> V=1.0, theta=0.0
% INFO    : Bus 983	: V=1.043784, theta=-12.042992 -> V=1.0083425, theta=0.0
% INFO    : Bus 984	: V=1.087927, theta=-3.436245 -> V=1.020787, theta=0.0
% INFO    : Bus 985	: V=1.036659, theta=4.307241 -> V=1.005466, theta=0.0
% INFO    : Bus 986	: V=1.090124, theta=-10.25809 -> V=1.02599, theta=0.0
% INFO    : Bus 987	: V=1.074737, theta=-33.364893 -> V=1.0267295, theta=0.0
% INFO    : Bus 988	: V=1.059409, theta=-8.192606 -> V=1.008384, theta=0.0
% INFO    : Bus 989	: V=1.044611, theta=-21.804078 -> V=1.0223905, theta=0.0
% INFO    : Bus 990	: V=1.009901, theta=-7.309111 -> V=1.0, theta=0.0
% INFO    : Bus 991	: V=1.062541, theta=-43.003321 -> V=1.0119515, theta=0.0
% INFO    : Bus 992	: V=0.96078, theta=-28.337438 -> V=1.0, theta=0.0
% INFO    : Bus 993	: V=1.054438, theta=-15.986693 -> V=1.004945, theta=0.0
% INFO    : Bus 994	: V=1.0669, theta=-20.396646 -> V=1.024696, theta=0.0
% INFO    : Bus 995	: V=1.03649, theta=-10.38925 -> V=1.0, theta=0.0
% INFO    : Bus 996	: V=1.064631, theta=-35.273636 -> V=1.01249, theta=0.0
% INFO    : Bus 997	: V=1.088579, theta=-8.530321 -> V=1.021567, theta=0.0
% INFO    : Bus 998	: V=1.082452, theta=4.482732 -> V=1.024848, theta=0.0
% INFO    : Bus 999	: V=1.074706, theta=-11.557029 -> V=1.0, theta=0.0
% INFO    : Bus 1000	: V=1.087016, theta=-1.017499 -> V=1.026031, theta=0.0
% INFO    : Bus 1001	: V=1.073, theta=-12.478025 -> V=1.03049, theta=0.0
% INFO    : Bus 1002	: V=1.005346, theta=-23.226226 -> V=1.0, theta=0.0
% INFO    : Bus 1003	: V=1.079182, theta=-4.01661 -> V=1.022154, theta=0.0
% INFO    : Bus 1004	: V=1.034565, theta=-13.521388 -> V=1.0, theta=0.0
% INFO    : Bus 1005	: V=1.014591, theta=-6.203112 -> V=1.0079465, theta=0.0
% INFO    : Bus 1006	: V=1.105132, theta=29.309268 -> V=1.0470295, theta=0.0
% INFO    : Bus 1007	: V=0.945903, theta=-24.62856 -> V=1.0, theta=0.0
% INFO    : Bus 1008	: V=1.076765, theta=-25.444108 -> V=1.0332925, theta=0.0
% INFO    : Bus 1009	: V=1.080354, theta=3.737959 -> V=1.024109, theta=0.0
% INFO    : Bus 1010	: V=0.958198, theta=-18.793219 -> V=1.0, theta=0.0
% INFO    : Bus 1011	: V=1.043534, theta=-22.391761 -> V=1.0, theta=0.0
% INFO    : Bus 1012	: V=1.047591, theta=-30.997674 -> V=1.0030875, theta=0.0
% INFO    : Bus 1013	: V=1.008854, theta=12.959511 -> V=1.002918, theta=0.0
% INFO    : Bus 1014	: V=1.0133, theta=-8.638766 -> V=1.006423, theta=0.0
% INFO    : Bus 1015	: V=0.994221, theta=-28.903513 -> V=1.0, theta=0.0
% INFO    : Bus 1016	: V=1.090969, theta=-34.906109 -> V=1.020117, theta=0.0
% INFO    : Bus 1017	: V=1.081648, theta=-34.935619 -> V=1.0138955, theta=0.0
% INFO    : Bus 1018	: V=1.025259, theta=15.603569 -> V=1.0, theta=0.0
% INFO    : Bus 1019	: V=1.082229, theta=-16.465736 -> V=1.0254595, theta=0.0
% INFO    : Bus 1020	: V=1.078545, theta=-13.274296 -> V=1.0166145, theta=0.0
% INFO    : Bus 1021	: V=1.025885, theta=-12.865223 -> V=1.0, theta=0.0
% INFO    : Bus 1022	: V=1.075, theta=-34.988125 -> V=1.00809, theta=0.0
% INFO    : Bus 1023	: V=1.090727, theta=-21.053155 -> V=1.0139865, theta=0.0
% INFO    : Bus 1024	: V=1.054154, theta=15.193815 -> V=1.0, theta=0.0
% INFO    : Bus 1025	: V=1.019624, theta=11.436964 -> V=1.0, theta=0.0
% INFO    : Bus 1026	: V=1.045455, theta=-26.165766 -> V=1.0027295, theta=0.0
% INFO    : Bus 1027	: V=1.093184, theta=-8.302072 -> V=1.023668, theta=0.0
% INFO    : Bus 1028	: V=1.084035, theta=-6.977282 -> V=1.0237185, theta=0.0
% INFO    : Bus 1029	: V=1.06054, theta=-21.149573 -> V=1.021765, theta=0.0
% INFO    : Bus 1030	: V=1.085658, theta=-21.02362 -> V=1.03966, theta=0.0
% INFO    : Bus 1031	: V=1.077447, theta=-13.719185 -> V=1.0061255, theta=0.0
% INFO    : Bus 1032	: V=1.09077, theta=-39.494213 -> V=1.029581, theta=0.0
% INFO    : Bus 1033	: V=0.964219, theta=-21.451959 -> V=1.0, theta=0.0
% INFO    : Bus 1034	: V=1.081119, theta=-17.594285 -> V=1.0229555, theta=0.0
% INFO    : Bus 1035	: V=1.059155, theta=-23.290164 -> V=1.0166615, theta=0.0
% INFO    : Bus 1036	: V=1.081658, theta=8.036763 -> V=1.00387, theta=0.0
% INFO    : Bus 1037	: V=1.0165, theta=-19.808915 -> V=1.0, theta=0.0
% INFO    : Bus 1038	: V=1.040935, theta=-45.757775 -> V=1.0, theta=0.0
% INFO    : Bus 1039	: V=1.083097, theta=-8.229026 -> V=1.019076, theta=0.0
% INFO    : Bus 1040	: V=1.068354, theta=-17.308 -> V=1.009316, theta=0.0
% INFO    : Bus 1041	: V=1.05066, theta=-17.738341 -> V=1.0042925, theta=0.0
% INFO    : Bus 1042	: V=0.992303, theta=37.804141 -> V=1.0, theta=0.0
% INFO    : Bus 1043	: V=1.082591, theta=-19.227352 -> V=1.0091405, theta=0.0
% INFO    : Bus 1044	: V=1.068784, theta=-5.655699 -> V=1.0120635, theta=0.0
% INFO    : Bus 1045	: V=0.995273, theta=10.382623 -> V=1.0, theta=0.0
% INFO    : Bus 1046	: V=1.034886, theta=3.934959 -> V=1.0044995, theta=0.0
% INFO    : Bus 1047	: V=1.020017, theta=-24.344159 -> V=1.0, theta=0.0
% INFO    : Bus 1048	: V=1.067164, theta=27.419435 -> V=1.0156945, theta=0.0
% INFO    : Bus 1049	: V=1.077968, theta=-19.60349 -> V=1.021161, theta=0.0
% INFO    : Bus 1050	: V=1.074009, theta=-6.621724 -> V=1.0200495, theta=0.0
% INFO    : Bus 1051	: V=1.07952, theta=-47.003678 -> V=1.0181955, theta=0.0
% INFO    : Bus 1052	: V=1.064415, theta=-21.505816 -> V=1.020858, theta=0.0
% INFO    : Bus 1053	: V=0.987383, theta=-26.675135 -> V=1.0, theta=0.0
% INFO    : Bus 1054	: V=1.046067, theta=-35.675451 -> V=1.026302, theta=0.0
% INFO    : Bus 1055	: V=1.031286, theta=4.040219 -> V=1.0, theta=0.0
% INFO    : Bus 1056	: V=1.040711, theta=8.914671 -> V=1.0081245, theta=0.0
% INFO    : Bus 1057	: V=1.062886, theta=-19.033089 -> V=1.0, theta=0.0
% INFO    : Bus 1058	: V=1.047306, theta=-3.612777 -> V=1.0, theta=0.0
% INFO    : Bus 1059	: V=0.998013, theta=-23.701566 -> V=1.0, theta=0.0
% INFO    : Bus 1060	: V=1.068762, theta=18.520171 -> V=1.0178745, theta=0.0
% INFO    : Bus 1061	: V=1.02288, theta=-22.098043 -> V=1.0, theta=0.0
% INFO    : Bus 1062	: V=1.031959, theta=-25.555762 -> V=1.0, theta=0.0
% INFO    : Bus 1063	: V=1.090377, theta=-38.215081 -> V=1.015719, theta=0.0
% INFO    : Bus 1064	: V=1.013588, theta=-46.627483 -> V=1.0, theta=0.0
% INFO    : Bus 1065	: V=1.04222, theta=-20.780378 -> V=1.0, theta=0.0
% INFO    : Bus 1066	: V=1.076452, theta=-24.678106 -> V=1.032791, theta=0.0
% INFO    : Bus 1067	: V=1.027727, theta=-37.676069 -> V=1.0, theta=0.0
% INFO    : Bus 1068	: V=1.022467, theta=-34.199348 -> V=1.0, theta=0.0
% INFO    : Bus 1069	: V=1.078727, theta=-34.967579 -> V=1.015134, theta=0.0
% INFO    : Bus 1070	: V=1.015, theta=-18.846841 -> V=1.0, theta=0.0
% INFO    : Bus 1071	: V=1.000338, theta=57.089623 -> V=1.0, theta=0.0
% INFO    : Bus 1072	: V=0.945259, theta=-30.065159 -> V=1.0, theta=0.0
% INFO    : Bus 1073	: V=1.080069, theta=-3.779352 -> V=1.0167985, theta=0.0
% INFO    : Bus 1074	: V=1.038148, theta=-29.874337 -> V=1.0, theta=0.0
% INFO    : Bus 1075	: V=1.067295, theta=-18.37886 -> V=1.0, theta=0.0
% INFO    : Bus 1076	: V=0.998031, theta=-19.530608 -> V=1.0, theta=0.0
% INFO    : Bus 1077	: V=1.046395, theta=-32.617282 -> V=1.0265075, theta=0.0
% INFO    : Bus 1078	: V=1.068421, theta=-7.600622 -> V=1.015281, theta=0.0
% INFO    : Bus 1079	: V=1.056397, theta=-39.907951 -> V=1.00295, theta=0.0
% INFO    : Bus 1080	: V=1.074583, theta=-5.000372 -> V=1.0146895, theta=0.0
% INFO    : Bus 1081	: V=1.079051, theta=-13.763662 -> V=1.0287705, theta=0.0
% INFO    : Bus 1082	: V=1.042574, theta=39.422858 -> V=1.0, theta=0.0
% INFO    : Bus 1083	: V=1.006243, theta=-16.153225 -> V=1.0, theta=0.0
% INFO    : Bus 1084	: V=0.946667, theta=-20.739671 -> V=1.0, theta=0.0
% INFO    : Bus 1085	: V=1.099864, theta=-17.488937 -> V=1.0329655, theta=0.0
% INFO    : Bus 1086	: V=1.07462, theta=-14.521122 -> V=1.025229, theta=0.0
% INFO    : Bus 1087	: V=1.002436, theta=-15.395547 -> V=1.0, theta=0.0
% INFO    : Bus 1088	: V=1.031505, theta=-23.76333 -> V=1.0, theta=0.0
% INFO    : Bus 1089	: V=0.975627, theta=-24.912686 -> V=1.0, theta=0.0
% INFO    : Bus 1090	: V=1.063887, theta=-13.368797 -> V=1.0096515, theta=0.0
% INFO    : Bus 1091	: V=1.065146, theta=-15.381302 -> V=1.0056795, theta=0.0
% INFO    : Bus 1092	: V=1.06889, theta=-37.979089 -> V=1.0174665, theta=0.0
% INFO    : Bus 1093	: V=1.025006, theta=-19.164407 -> V=1.0175485, theta=0.0
% INFO    : Bus 1094	: V=1.103384, theta=-16.144236 -> V=1.0318515, theta=0.0
% INFO    : Bus 1095	: V=1.020377, theta=-21.036257 -> V=1.0, theta=0.0
% INFO    : Bus 1096	: V=1.063104, theta=1.011281 -> V=1.018509, theta=0.0
% INFO    : Bus 1097	: V=1.001476, theta=-22.902653 -> V=1.0, theta=0.0
% INFO    : Bus 1098	: V=1.079101, theta=0.353621 -> V=1.0242495, theta=0.0
% INFO    : Bus 1099	: V=1.039895, theta=-45.803964 -> V=1.0, theta=0.0
% INFO    : Bus 1100	: V=1.050466, theta=-19.808717 -> V=1.0, theta=0.0
% INFO    : Bus 1101	: V=1.09671, theta=-8.146926 -> V=1.0261335, theta=0.0
% INFO    : Bus 1102	: V=1.100879, theta=-16.831907 -> V=1.041305, theta=0.0
% INFO    : Bus 1103	: V=1.038823, theta=19.435403 -> V=1.0, theta=0.0
% INFO    : Bus 1104	: V=1.050233, theta=-15.796787 -> V=1.0025875, theta=0.0
% INFO    : Bus 1105	: V=1.082554, theta=-10.992986 -> V=1.027086, theta=0.0
% INFO    : Bus 1106	: V=1.026278, theta=-17.977972 -> V=1.0, theta=0.0
% INFO    : Bus 1107	: V=0.979093, theta=-36.422876 -> V=1.0, theta=0.0
% INFO    : Bus 1108	: V=1.00416, theta=-33.044166 -> V=1.0, theta=0.0
% INFO    : Bus 1109	: V=1.023727, theta=-41.519434 -> V=1.0, theta=0.0
% INFO    : Bus 1110	: V=1.066853, theta=-2.470678 -> V=1.0221075, theta=0.0
% INFO    : Bus 1111	: V=1.041394, theta=-25.089083 -> V=1.0, theta=0.0
% INFO    : Bus 1112	: V=1.07399, theta=-35.19395 -> V=1.0259665, theta=0.0
% INFO    : Bus 1113	: V=1.091909, theta=-15.904391 -> V=1.014355, theta=0.0
% INFO    : Bus 1114	: V=1.037156, theta=-21.490804 -> V=1.006979, theta=0.0
% INFO    : Bus 1115	: V=1.064464, theta=9.242222 -> V=1.0, theta=0.0
% INFO    : Bus 1116	: V=0.94541, theta=-27.423788 -> V=1.0, theta=0.0
% INFO    : Bus 1117	: V=1.03726, theta=-21.668884 -> V=1.0168195, theta=0.0
% INFO    : Bus 1118	: V=1.038399, theta=-22.439623 -> V=1.0, theta=0.0
% INFO    : Bus 1119	: V=1.087869, theta=-45.322628 -> V=1.0247455, theta=0.0
% INFO    : Bus 1120	: V=1.064317, theta=-21.529421 -> V=1.0206815, theta=0.0
% INFO    : Bus 1121	: V=1.079936, theta=-15.533349 -> V=1.0211995, theta=0.0
% INFO    : Bus 1122	: V=1.045474, theta=-34.286609 -> V=1.004058, theta=0.0
% INFO    : Bus 1123	: V=1.100237, theta=-5.518412 -> V=1.0434935, theta=0.0
% INFO    : Bus 1124	: V=0.963367, theta=58.645088 -> V=1.0, theta=0.0
% INFO    : Bus 1125	: V=1.041038, theta=-50.369746 -> V=1.0, theta=0.0
% INFO    : Bus 1126	: V=1.065603, theta=-37.542169 -> V=1.007603, theta=0.0
% INFO    : Bus 1127	: V=1.079727, theta=-34.55186 -> V=1.016416, theta=0.0
% INFO    : Bus 1128	: V=1.029132, theta=-2.43524 -> V=1.0035015, theta=0.0
% INFO    : Bus 1129	: V=1.086316, theta=57.474165 -> V=1.0, theta=0.0
% INFO    : Bus 1130	: V=1.014258, theta=-22.123443 -> V=1.0, theta=0.0
% INFO    : Bus 1131	: V=0.976978, theta=-24.72408 -> V=1.0, theta=0.0
% INFO    : Bus 1132	: V=1.032832, theta=-20.701302 -> V=1.0, theta=0.0
% INFO    : Bus 1133	: V=1.074157, theta=-10.279961 -> V=1.01786, theta=0.0
% INFO    : Bus 1134	: V=1.07597, theta=-10.43724 -> V=1.016692, theta=0.0
% INFO    : Bus 1135	: V=1.015905, theta=-31.528241 -> V=1.0, theta=0.0
% INFO    : Bus 1136	: V=1.088632, theta=-8.539114 -> V=1.0217285, theta=0.0
% INFO    : Bus 1137	: V=1.004772, theta=-29.436706 -> V=1.0, theta=0.0
% INFO    : Bus 1138	: V=1.056233, theta=23.158546 -> V=1.0035735, theta=0.0
% INFO    : Bus 1139	: V=0.988497, theta=-24.860737 -> V=1.0, theta=0.0
% INFO    : Bus 1140	: V=1.067289, theta=3.229482 -> V=1.01901, theta=0.0
% INFO    : Bus 1141	: V=1.025806, theta=-15.210579 -> V=1.0, theta=0.0
% INFO    : Bus 1142	: V=1.063121, theta=-35.439749 -> V=1.011909, theta=0.0
% INFO    : Bus 1143	: V=1.014591, theta=40.034083 -> V=1.0, theta=0.0
% INFO    : Bus 1144	: V=1.106746, theta=-16.605214 -> V=1.0313405, theta=0.0
% INFO    : Bus 1145	: V=1.03711, theta=14.041362 -> V=1.0, theta=0.0
% INFO    : Bus 1146	: V=1.057394, theta=-40.2934 -> V=1.0133065, theta=0.0
% INFO    : Bus 1147	: V=1.061892, theta=-21.049539 -> V=1.019442, theta=0.0
% INFO    : Bus 1148	: V=1.015064, theta=-6.393574 -> V=1.0, theta=0.0
% INFO    : Bus 1149	: V=1.079701, theta=-31.966953 -> V=1.027323, theta=0.0
% INFO    : Bus 1150	: V=1.037443, theta=-49.683096 -> V=1.031436, theta=0.0
% INFO    : Bus 1151	: V=0.999946, theta=-37.116054 -> V=1.0, theta=0.0
% INFO    : Bus 1152	: V=1.008409, theta=21.543852 -> V=1.0, theta=0.0
% INFO    : Bus 1153	: V=1.072422, theta=-2.452171 -> V=1.0, theta=0.0
% INFO    : Bus 1154	: V=1.044499, theta=-34.376189 -> V=1.003621, theta=0.0
% INFO    : Bus 1155	: V=1.038896, theta=-20.019694 -> V=1.0, theta=0.0
% INFO    : Bus 1156	: V=1.003864, theta=-42.392439 -> V=1.0, theta=0.0
% INFO    : Bus 1157	: V=0.979121, theta=-23.955722 -> V=1.0, theta=0.0
% INFO    : Bus 1158	: V=0.94596, theta=-31.279299 -> V=1.0, theta=0.0
% INFO    : Bus 1159	: V=0.959356, theta=-18.460955 -> V=1.0, theta=0.0
% INFO    : Bus 1160	: V=1.07171, theta=-17.916683 -> V=1.0175925, theta=0.0
% INFO    : Bus 1161	: V=1.030245, theta=-21.622707 -> V=1.0, theta=0.0
% INFO    : Bus 1162	: V=1.064562, theta=-2.422936 -> V=1.021217, theta=0.0
% INFO    : Bus 1163	: V=1.068476, theta=-15.067859 -> V=1.009837, theta=0.0
% INFO    : Bus 1164	: V=1.020095, theta=-46.407006 -> V=1.0, theta=0.0
% INFO    : Bus 1165	: V=1.086307, theta=-32.848111 -> V=1.032876, theta=0.0
% INFO    : Bus 1166	: V=0.986843, theta=-17.234553 -> V=1.0, theta=0.0
% INFO    : Bus 1167	: V=1.071149, theta=-42.592452 -> V=1.009865, theta=0.0
% INFO    : Bus 1168	: V=0.997766, theta=-20.153583 -> V=1.0, theta=0.0
% INFO    : Bus 1169	: V=0.990866, theta=-22.855841 -> V=1.0, theta=0.0
% INFO    : Bus 1170	: V=1.063504, theta=-11.344968 -> V=1.0127245, theta=0.0
% INFO    : Bus 1171	: V=0.944756, theta=-24.708919 -> V=1.0, theta=0.0
% INFO    : Bus 1172	: V=1.080647, theta=15.971884 -> V=1.017619, theta=0.0
% INFO    : Bus 1173	: V=0.968237, theta=-26.066436 -> V=1.0, theta=0.0
% INFO    : Bus 1174	: V=0.926972, theta=-31.411792 -> V=1.0, theta=0.0
% INFO    : Bus 1175	: V=1.018693, theta=-31.954636 -> V=1.0, theta=0.0
% INFO    : Bus 1176	: V=1.01697, theta=9.190559 -> V=1.0, theta=0.0
% INFO    : Bus 1177	: V=1.038977, theta=-44.338563 -> V=1.003673, theta=0.0
% INFO    : Bus 1178	: V=1.055364, theta=-8.090508 -> V=1.008302, theta=0.0
% INFO    : Bus 1179	: V=1.006175, theta=-23.119258 -> V=1.0, theta=0.0
% INFO    : Bus 1180	: V=0.979708, theta=-22.096714 -> V=1.0, theta=0.0
% INFO    : Bus 1181	: V=1.017564, theta=-29.802073 -> V=1.0, theta=0.0
% INFO    : Bus 1182	: V=0.950476, theta=-29.35272 -> V=1.0, theta=0.0
% INFO    : Bus 1183	: V=0.9393, theta=-29.246523 -> V=0.995313, theta=0.0
% INFO    : Bus 1184	: V=1.033456, theta=-28.141178 -> V=1.0191365, theta=0.0
% INFO    : Bus 1185	: V=0.968529, theta=-19.494757 -> V=1.0, theta=0.0
% INFO    : Bus 1186	: V=1.082902, theta=-16.316951 -> V=1.033205, theta=0.0
% INFO    : Bus 1187	: V=1.046483, theta=-30.78661 -> V=1.0061035, theta=0.0
% INFO    : Bus 1188	: V=1.048099, theta=-21.810708 -> V=1.018226, theta=0.0
% INFO    : Bus 1189	: V=0.939249, theta=-25.634299 -> V=1.0, theta=0.0
% INFO    : Bus 1190	: V=1.080632, theta=-9.108559 -> V=1.011041, theta=0.0
% INFO    : Bus 1191	: V=1.036179, theta=-31.643376 -> V=1.0, theta=0.0
% INFO    : Bus 1192	: V=0.944419, theta=-23.372227 -> V=1.0, theta=0.0
% INFO    : Bus 1193	: V=0.958282, theta=-28.037861 -> V=1.0, theta=0.0
% INFO    : Bus 1194	: V=1.039341, theta=-20.861329 -> V=1.021091, theta=0.0
% INFO    : Bus 1195	: V=1.022455, theta=-34.384361 -> V=1.0, theta=0.0
% INFO    : Bus 1196	: V=1.04056, theta=-17.08067 -> V=1.006736, theta=0.0
% INFO    : Bus 1197	: V=1.085868, theta=12.653441 -> V=1.0305255, theta=0.0
% INFO    : Bus 1198	: V=0.945112, theta=-25.465665 -> V=1.0, theta=0.0
% INFO    : Bus 1199	: V=1.074861, theta=-0.506567 -> V=1.014053, theta=0.0
% INFO    : Bus 1200	: V=1.024497, theta=15.617788 -> V=1.0, theta=0.0
% INFO    : Bus 1201	: V=1.022692, theta=-23.153062 -> V=1.0, theta=0.0
% INFO    : Bus 1202	: V=1.023136, theta=-45.934477 -> V=1.0, theta=0.0
% INFO    : Bus 1203	: V=1.024086, theta=-16.266549 -> V=1.0, theta=0.0
% INFO    : Bus 1204	: V=1.024147, theta=-27.828053 -> V=1.0, theta=0.0
% INFO    : Bus 1205	: V=1.026565, theta=3.62329 -> V=1.0, theta=0.0
% INFO    : Bus 1206	: V=1.047224, theta=-20.501954 -> V=1.0039655, theta=0.0
% INFO    : Bus 1207	: V=1.049571, theta=-21.485862 -> V=1.0051525, theta=0.0
% INFO    : Bus 1208	: V=1.068088, theta=-34.304332 -> V=1.0364725, theta=0.0
% INFO    : Bus 1209	: V=1.046484, theta=-34.268858 -> V=1.004527, theta=0.0
% INFO    : Bus 1210	: V=1.095567, theta=-37.221237 -> V=1.0306535, theta=0.0
% INFO    : Bus 1211	: V=1.04421, theta=-1.72669 -> V=1.0039375, theta=0.0
% INFO    : Bus 1212	: V=1.082965, theta=16.353739 -> V=1.013933, theta=0.0
% INFO    : Bus 1213	: V=1.077041, theta=-17.727646 -> V=1.0, theta=0.0
% INFO    : Bus 1214	: V=1.033846, theta=-25.813239 -> V=1.0, theta=0.0
% INFO    : Bus 1215	: V=1.081787, theta=-15.342426 -> V=1.0223035, theta=0.0
% INFO    : Bus 1216	: V=1.101181, theta=-19.095646 -> V=1.0223295, theta=0.0
% INFO    : Bus 1217	: V=1.100789, theta=-15.497949 -> V=1.0226565, theta=0.0
% INFO    : Bus 1218	: V=1.067513, theta=8.315346 -> V=1.0186365, theta=0.0
% INFO    : Bus 1219	: V=1.085886, theta=-42.051893 -> V=1.02236, theta=0.0
% INFO    : Bus 1220	: V=0.952398, theta=-37.898379 -> V=1.0, theta=0.0
% INFO    : Bus 1221	: V=1.033955, theta=-13.517214 -> V=1.0, theta=0.0
% INFO    : Bus 1222	: V=1.06053, theta=0.390122 -> V=1.0160685, theta=0.0
% INFO    : Bus 1223	: V=1.069655, theta=-13.034805 -> V=1.012964, theta=0.0
% INFO    : Bus 1224	: V=1.07294, theta=-41.879555 -> V=1.0110715, theta=0.0
% INFO    : Bus 1225	: V=1.013458, theta=61.700688 -> V=1.0, theta=0.0
% INFO    : Bus 1226	: V=1.066738, theta=-18.371595 -> V=1.0, theta=0.0
% INFO    : Bus 1227	: V=1.055801, theta=-48.626867 -> V=1.005149, theta=0.0
% INFO    : Bus 1228	: V=1.06725, theta=-1.808695 -> V=1.0217945, theta=0.0
% INFO    : Bus 1229	: V=0.952892, theta=-12.866249 -> V=1.0, theta=0.0
% INFO    : Bus 1230	: V=1.081184, theta=0.090725 -> V=1.023746, theta=0.0
% INFO    : Bus 1231	: V=1.015607, theta=-17.748981 -> V=1.0, theta=0.0
% INFO    : Bus 1232	: V=1.035273, theta=-6.948872 -> V=1.0124565, theta=0.0
% INFO    : Bus 1233	: V=1.085148, theta=-8.348088 -> V=1.023425, theta=0.0
% INFO    : Bus 1234	: V=1.082004, theta=-40.333516 -> V=1.025469, theta=0.0
% INFO    : Bus 1235	: V=0.933329, theta=-30.696806 -> V=1.0, theta=0.0
% INFO    : Bus 1236	: V=1.027929, theta=-4.445692 -> V=1.0, theta=0.0
% INFO    : Bus 1237	: V=1.089319, theta=-19.619044 -> V=1.026935, theta=0.0
% INFO    : Bus 1238	: V=0.951545, theta=-20.521921 -> V=1.0, theta=0.0
% INFO    : Bus 1239	: V=1.078709, theta=20.441211 -> V=1.030569, theta=0.0
% INFO    : Bus 1240	: V=1.068575, theta=-19.462303 -> V=1.0079125, theta=0.0
% INFO    : Bus 1241	: V=1.070711, theta=-11.617571 -> V=1.0163635, theta=0.0
% INFO    : Bus 1242	: V=1.068712, theta=-37.038293 -> V=1.016016, theta=0.0
% INFO    : Bus 1243	: V=1.030688, theta=-36.27661 -> V=1.0, theta=0.0
% INFO    : Bus 1244	: V=1.061118, theta=-2.51717 -> V=1.0093735, theta=0.0
% INFO    : Bus 1245	: V=0.99822, theta=-23.421572 -> V=1.0, theta=0.0
% INFO    : Bus 1246	: V=1.058004, theta=-24.678366 -> V=1.0145115, theta=0.0
% INFO    : Bus 1247	: V=0.985991, theta=-23.580828 -> V=1.0, theta=0.0
% INFO    : Bus 1248	: V=0.945825, theta=-30.274629 -> V=1.0, theta=0.0
% INFO    : Bus 1249	: V=0.954263, theta=-25.880669 -> V=1.0, theta=0.0
% INFO    : Bus 1250	: V=1.038391, theta=-22.424596 -> V=1.0, theta=0.0
% INFO    : Bus 1251	: V=0.941456, theta=-27.822407 -> V=1.0, theta=0.0
% INFO    : Bus 1252	: V=1.030497, theta=-26.504927 -> V=1.0, theta=0.0
% INFO    : Bus 1253	: V=0.950026, theta=-27.230988 -> V=1.0, theta=0.0
% INFO    : Bus 1254	: V=0.987636, theta=-23.245004 -> V=1.0, theta=0.0
% INFO    : Bus 1255	: V=1.009375, theta=-22.219997 -> V=1.0104855, theta=0.0
% INFO    : Bus 1256	: V=1.037952, theta=-31.307444 -> V=1.0, theta=0.0
% INFO    : Bus 1257	: V=1.04268, theta=-18.757465 -> V=1.0, theta=0.0
% INFO    : Bus 1258	: V=1.088169, theta=-16.449167 -> V=1.0249735, theta=0.0
% INFO    : Bus 1259	: V=1.014707, theta=61.833986 -> V=1.0, theta=0.0
% INFO    : Bus 1260	: V=1.01978, theta=-23.607485 -> V=1.0, theta=0.0
% INFO    : Bus 1261	: V=0.980591, theta=-0.010459 -> V=1.0, theta=0.0
% INFO    : Bus 1262	: V=1.000059, theta=-29.871323 -> V=1.0, theta=0.0
% INFO    : Bus 1263	: V=1.040555, theta=-29.172708 -> V=1.0, theta=0.0
% INFO    : Bus 1264	: V=1.054273, theta=-14.53172 -> V=1.011488, theta=0.0
% INFO    : Bus 1265	: V=1.076227, theta=-33.847335 -> V=1.0145785, theta=0.0
% INFO    : Bus 1266	: V=1.028774, theta=13.664863 -> V=1.003121, theta=0.0
% INFO    : Bus 1267	: V=1.046415, theta=-41.551082 -> V=1.003115, theta=0.0
% INFO    : Bus 1268	: V=1.076664, theta=-25.432458 -> V=1.0333195, theta=0.0
% INFO    : Bus 1269	: V=1.02138, theta=-31.456754 -> V=1.0, theta=0.0
% INFO    : Bus 1270	: V=0.988479, theta=-23.641661 -> V=1.0, theta=0.0
% INFO    : Bus 1271	: V=1.054816, theta=-12.454437 -> V=1.0192415, theta=0.0
% INFO    : Bus 1272	: V=1.052397, theta=-17.819329 -> V=1.0086495, theta=0.0
% INFO    : Bus 1273	: V=1.080763, theta=-44.499809 -> V=1.024579, theta=0.0
% INFO    : Bus 1274	: V=1.029056, theta=3.094471 -> V=1.0, theta=0.0
% INFO    : Bus 1275	: V=1.078078, theta=-14.02878 -> V=1.0193955, theta=0.0
% INFO    : Bus 1276	: V=1.037682, theta=-17.619303 -> V=1.0, theta=0.0
% INFO    : Bus 1277	: V=1.037614, theta=57.89664 -> V=1.0, theta=0.0
% INFO    : Bus 1278	: V=0.969449, theta=-20.539803 -> V=1.0, theta=0.0
% INFO    : Bus 1279	: V=1.039598, theta=-22.355349 -> V=1.0, theta=0.0
% INFO    : Bus 1280	: V=1.028537, theta=-45.064836 -> V=1.0, theta=0.0
% INFO    : Bus 1281	: V=0.936472, theta=-28.090673 -> V=1.0, theta=0.0
% INFO    : Bus 1282	: V=1.065091, theta=-43.903137 -> V=1.00678, theta=0.0
% INFO    : Bus 1283	: V=0.928893, theta=-28.004198 -> V=1.0, theta=0.0
% INFO    : Bus 1284	: V=1.031297, theta=-43.531848 -> V=1.0, theta=0.0
% INFO    : Bus 1285	: V=0.980998, theta=-21.937132 -> V=1.0, theta=0.0
% INFO    : Bus 1286	: V=0.995695, theta=-20.48945 -> V=1.0, theta=0.0
% INFO    : Bus 1287	: V=1.052979, theta=-26.449926 -> V=1.020592, theta=0.0
% INFO    : Bus 1288	: V=1.096041, theta=-11.176882 -> V=1.0260115, theta=0.0
% INFO    : Bus 1289	: V=1.010679, theta=-18.994193 -> V=1.0, theta=0.0
% INFO    : Bus 1290	: V=0.983273, theta=-8.757619 -> V=1.0, theta=0.0
% INFO    : Bus 1291	: V=1.057563, theta=-49.653534 -> V=1.0, theta=0.0
% INFO    : Bus 1292	: V=1.008232, theta=-39.56415 -> V=1.0, theta=0.0
% INFO    : Bus 1293	: V=1.054231, theta=-47.45836 -> V=1.0, theta=0.0
% INFO    : Bus 1294	: V=1.036182, theta=-20.539581 -> V=1.01208, theta=0.0
% INFO    : Bus 1295	: V=1.064999, theta=-35.026988 -> V=1.0231115, theta=0.0
% INFO    : Bus 1296	: V=0.994613, theta=-18.581575 -> V=1.0, theta=0.0
% INFO    : Bus 1297	: V=1.074108, theta=-7.025917 -> V=1.0210245, theta=0.0
% INFO    : Bus 1298	: V=1.073684, theta=27.284838 -> V=1.0, theta=0.0
% INFO    : Bus 1299	: V=0.981616, theta=-27.983677 -> V=1.0, theta=0.0
% INFO    : Bus 1300	: V=0.949529, theta=-32.34433 -> V=1.0, theta=0.0
% INFO    : Bus 1301	: V=1.084368, theta=-31.60295 -> V=1.0184625, theta=0.0
% INFO    : Bus 1302	: V=1.050447, theta=-46.281085 -> V=1.0, theta=0.0
% INFO    : Bus 1303	: V=0.992609, theta=-25.259383 -> V=1.0, theta=0.0
% INFO    : Bus 1304	: V=1.028232, theta=-7.911823 -> V=1.0, theta=0.0
% INFO    : Bus 1305	: V=1.054853, theta=-17.286978 -> V=1.0084665, theta=0.0
% INFO    : Bus 1306	: V=1.064996, theta=-23.362896 -> V=1.032424, theta=0.0
% INFO    : Bus 1307	: V=1.060455, theta=-12.507277 -> V=1.0221145, theta=0.0
% INFO    : Bus 1308	: V=1.008487, theta=-34.190115 -> V=1.0, theta=0.0
% INFO    : Bus 1309	: V=1.05459, theta=-17.28688 -> V=1.0061635, theta=0.0
% INFO    : Bus 1310	: V=1.065115, theta=-43.884482 -> V=1.006995, theta=0.0
% INFO    : Bus 1311	: V=0.938841, theta=-27.705658 -> V=1.0, theta=0.0
% INFO    : Bus 1312	: V=1.07671, theta=-6.193256 -> V=1.0177955, theta=0.0
% INFO    : Bus 1313	: V=1.06943, theta=-4.141656 -> V=1.014167, theta=0.0
% INFO    : Bus 1314	: V=0.917123, theta=-31.142264 -> V=1.0, theta=0.0
% INFO    : Bus 1315	: V=1.046725, theta=-15.766244 -> V=1.003832, theta=0.0
% INFO    : Bus 1316	: V=1.09917, theta=-14.776255 -> V=1.0472775, theta=0.0
% INFO    : Bus 1317	: V=1.041509, theta=-25.081813 -> V=1.0, theta=0.0
% INFO    : Bus 1318	: V=1.042688, theta=-18.795553 -> V=1.0141345, theta=0.0
% INFO    : Bus 1319	: V=0.95807, theta=-29.405476 -> V=1.0, theta=0.0
% INFO    : Bus 1320	: V=1.06901, theta=4.686012 -> V=1.013278, theta=0.0
% INFO    : Bus 1321	: V=0.958955, theta=-31.63482 -> V=1.0, theta=0.0
% INFO    : Bus 1322	: V=1.07742, theta=-17.685245 -> V=1.0, theta=0.0
% INFO    : Bus 1323	: V=0.963329, theta=-27.248259 -> V=1.0, theta=0.0
% INFO    : Bus 1324	: V=0.931793, theta=-33.314429 -> V=1.0, theta=0.0
% INFO    : Bus 1325	: V=1.088018, theta=-36.017311 -> V=1.0203945, theta=0.0
% INFO    : Bus 1326	: V=1.098447, theta=-34.636571 -> V=1.0272355, theta=0.0
% INFO    : Bus 1327	: V=1.049262, theta=-20.885126 -> V=1.0094805, theta=0.0
% INFO    : Bus 1328	: V=1.039584, theta=-31.524685 -> V=1.0101825, theta=0.0
% INFO    : Bus 1329	: V=1.036204, theta=-20.54008 -> V=1.0120915, theta=0.0
% INFO    : Bus 1330	: V=1.072122, theta=4.435848 -> V=1.021417, theta=0.0
% INFO    : Bus 1331	: V=1.05778, theta=6.387704 -> V=1.0050185, theta=0.0
% INFO    : Bus 1332	: V=1.044907, theta=-14.6501 -> V=1.0079635, theta=0.0
% INFO    : Bus 1333	: V=1.031512, theta=-21.814447 -> V=1.0042555, theta=0.0
% INFO    : Bus 1334	: V=1.032594, theta=-25.572664 -> V=1.0, theta=0.0
% INFO    : Bus 1335	: V=1.017001, theta=-19.73758 -> V=1.0, theta=0.0
% INFO    : Bus 1336	: V=1.091232, theta=-30.618589 -> V=1.021668, theta=0.0
% INFO    : Bus 1337	: V=1.023141, theta=-46.244898 -> V=1.0, theta=0.0
% INFO    : Bus 1338	: V=1.028966, theta=-44.511405 -> V=1.0, theta=0.0
% INFO    : Bus 1339	: V=0.952937, theta=-20.543815 -> V=1.0, theta=0.0
% INFO    : Bus 1340	: V=0.97039, theta=-25.91911 -> V=1.0, theta=0.0
% INFO    : Bus 1341	: V=1.073316, theta=-39.449718 -> V=1.015452, theta=0.0
% INFO    : Bus 1342	: V=0.944372, theta=-32.81358 -> V=0.965507, theta=0.0
% INFO    : Bus 1343	: V=1.08481, theta=7.908254 -> V=1.019597, theta=0.0
% INFO    : Bus 1344	: V=1.060909, theta=-14.76996 -> V=1.006745, theta=0.0
% INFO    : Bus 1345	: V=1.082097, theta=-39.366017 -> V=1.020359, theta=0.0
% INFO    : Bus 1346	: V=1.027925, theta=-43.965179 -> V=1.0, theta=0.0
% INFO    : Bus 1347	: V=1.041864, theta=3.033043 -> V=1.0106705, theta=0.0
% INFO    : Bus 1348	: V=1.01711, theta=-19.65202 -> V=1.0, theta=0.0
% INFO    : Bus 1349	: V=1.047912, theta=-27.225683 -> V=1.036348, theta=0.0
% INFO    : Bus 1350	: V=1.055227, theta=61.640938 -> V=1.0044095, theta=0.0
% INFO    : Bus 1351	: V=1.061571, theta=-13.819717 -> V=1.0141545, theta=0.0
% INFO    : Bus 1352	: V=1.060521, theta=-22.305182 -> V=1.019147, theta=0.0
% INFO    : Bus 1353	: V=1.094409, theta=-11.055518 -> V=1.022065, theta=0.0
% INFO    : Bus 1354	: V=1.094704, theta=-38.343457 -> V=1.030146, theta=0.0
% INFO    : Bus 1355	: V=1.046886, theta=-32.272663 -> V=1.002679, theta=0.0
% INFO    : Bus 1356	: V=1.057574, theta=-15.320487 -> V=1.0, theta=0.0
% INFO    : Bus 1357	: V=1.059675, theta=-43.033765 -> V=1.0056705, theta=0.0
% INFO    : Bus 1358	: V=1.072636, theta=-4.659792 -> V=1.014462, theta=0.0
% INFO    : Bus 1359	: V=1.067287, theta=-4.112417 -> V=1.013221, theta=0.0
% INFO    : Bus 1360	: V=1.061162, theta=-10.68696 -> V=1.006504, theta=0.0
% INFO    : Bus 1361	: V=0.986505, theta=-23.401632 -> V=1.0, theta=0.0
% INFO    : Bus 1362	: V=0.990135, theta=-29.552812 -> V=1.0, theta=0.0
% INFO    : Bus 1363	: V=1.040311, theta=32.042834 -> V=1.0, theta=0.0
% INFO    : Bus 1364	: V=1.097789, theta=-35.914605 -> V=1.034663, theta=0.0
% INFO    : Bus 1365	: V=1.007552, theta=-18.137118 -> V=1.0, theta=0.0
% INFO    : Bus 1366	: V=1.018829, theta=-16.415551 -> V=1.005851, theta=0.0
% INFO    : Bus 1367	: V=1.056878, theta=-49.178223 -> V=1.0076065, theta=0.0
% INFO    : Bus 1368	: V=1.035352, theta=-25.853636 -> V=1.0192545, theta=0.0
% INFO    : Bus 1369	: V=1.029562, theta=-40.04276 -> V=1.0, theta=0.0
% INFO    : Bus 1370	: V=1.041434, theta=-14.319125 -> V=1.006772, theta=0.0
% INFO    : Bus 1371	: V=1.002694, theta=-23.611137 -> V=1.0, theta=0.0
% INFO    : Bus 1372	: V=1.082919, theta=-14.840709 -> V=1.015362, theta=0.0
% INFO    : Bus 1373	: V=1.064546, theta=-0.372288 -> V=1.03122, theta=0.0
% INFO    : Bus 1374	: V=1.065364, theta=-16.411253 -> V=1.0, theta=0.0
% INFO    : Bus 1375	: V=1.047214, theta=-21.192944 -> V=1.0040065, theta=0.0
% INFO    : Bus 1376	: V=1.01897, theta=-19.024602 -> V=1.0, theta=0.0
% INFO    : Bus 1377	: V=1.002266, theta=-22.324974 -> V=1.0, theta=0.0
% INFO    : Bus 1378	: V=1.060931, theta=-42.00302 -> V=1.012392, theta=0.0
% INFO    : Bus 1379	: V=1.055232, theta=-35.94238 -> V=1.0039415, theta=0.0
% INFO    : Bus 1380	: V=1.027116, theta=-16.57007 -> V=1.0, theta=0.0
% INFO    : Bus 1381	: V=1.086457, theta=0.692814 -> V=1.02667, theta=0.0
% INFO    : Bus 1382	: V=1.024999, theta=-21.09291 -> V=1.0, theta=0.0
% INFO    : Bus 1383	: V=0.958436, theta=-25.540311 -> V=1.0, theta=0.0
% INFO    : Bus 1384	: V=1.048672, theta=-20.010759 -> V=1.0, theta=0.0
% INFO    : Bus 1385	: V=1.016971, theta=-42.41885 -> V=1.0, theta=0.0
% INFO    : Bus 1386	: V=1.02645, theta=-23.775588 -> V=1.0, theta=0.0
% INFO    : Bus 1387	: V=1.064435, theta=22.880718 -> V=1.008783, theta=0.0
% INFO    : Bus 1388	: V=0.990484, theta=-50.248133 -> V=1.0, theta=0.0
% INFO    : Bus 1389	: V=1.039454, theta=15.72315 -> V=1.002595, theta=0.0
% INFO    : Bus 1390	: V=1.07981, theta=18.773105 -> V=1.0192905, theta=0.0
% INFO    : Bus 1391	: V=1.052282, theta=-11.911518 -> V=1.0121295, theta=0.0
% INFO    : Bus 1392	: V=1.015967, theta=-36.617099 -> V=1.0, theta=0.0
% INFO    : Bus 1393	: V=0.962911, theta=-26.12829 -> V=1.0, theta=0.0
% INFO    : Bus 1394	: V=1.038261, theta=-21.049991 -> V=1.0, theta=0.0
% INFO    : Bus 1395	: V=1.060919, theta=-11.306723 -> V=1.0067275, theta=0.0
% INFO    : Bus 1396	: V=1.011424, theta=-14.947239 -> V=1.0, theta=0.0
% INFO    : Bus 1397	: V=1.06716, theta=-17.594597 -> V=1.0092735, theta=0.0
% INFO    : Bus 1398	: V=1.062352, theta=-20.892642 -> V=1.020478, theta=0.0
% INFO    : Bus 1399	: V=0.955922, theta=-25.511825 -> V=1.0, theta=0.0
% INFO    : Bus 1400	: V=1.020044, theta=-14.187352 -> V=1.0, theta=0.0
% INFO    : Bus 1401	: V=0.971835, theta=-27.334067 -> V=1.0, theta=0.0
% INFO    : Bus 1402	: V=1.042862, theta=-8.265546 -> V=1.0090535, theta=0.0
% INFO    : Bus 1403	: V=1.088761, theta=-14.726452 -> V=1.0327405, theta=0.0
% INFO    : Bus 1404	: V=1.090288, theta=-11.972403 -> V=1.027585, theta=0.0
% INFO    : Bus 1405	: V=1.087262, theta=-18.579179 -> V=1.0255325, theta=0.0
% INFO    : Bus 1406	: V=1.091811, theta=-31.006362 -> V=1.0174745, theta=0.0
% INFO    : Bus 1407	: V=1.02101, theta=-45.060116 -> V=1.0, theta=0.0
% INFO    : Bus 1408	: V=1.090345, theta=-20.137685 -> V=1.0359385, theta=0.0
% INFO    : Bus 1409	: V=1.078337, theta=-22.236749 -> V=1.03162, theta=0.0
% INFO    : Bus 1410	: V=1.066526, theta=-38.203373 -> V=1.017345, theta=0.0
% INFO    : Bus 1411	: V=1.045405, theta=-14.232365 -> V=1.0, theta=0.0
% INFO    : Bus 1412	: V=0.954516, theta=-13.104112 -> V=1.0, theta=0.0
% INFO    : Bus 1413	: V=1.080085, theta=-48.18551 -> V=1.007744, theta=0.0
% INFO    : Bus 1414	: V=1.103737, theta=-9.485996 -> V=1.0294395, theta=0.0
% INFO    : Bus 1415	: V=1.080434, theta=-19.414614 -> V=1.029511, theta=0.0
% INFO    : Bus 1416	: V=1.071489, theta=-15.934231 -> V=1.026466, theta=0.0
% INFO    : Bus 1417	: V=1.086074, theta=-16.198131 -> V=1.0155665, theta=0.0
% INFO    : Bus 1418	: V=1.056748, theta=-15.753986 -> V=1.014654, theta=0.0
% INFO    : Bus 1419	: V=1.092237, theta=-8.087624 -> V=1.014148, theta=0.0
% INFO    : Bus 1420	: V=1.095288, theta=-11.339243 -> V=1.0350275, theta=0.0
% INFO    : Bus 1421	: V=1.064211, theta=-16.157657 -> V=1.0064345, theta=0.0
% INFO    : Bus 1422	: V=1.040733, theta=-17.080269 -> V=1.0068215, theta=0.0
% INFO    : Bus 1423	: V=1.065295, theta=-38.962096 -> V=1.0215485, theta=0.0
% INFO    : Bus 1424	: V=1.052814, theta=-24.688593 -> V=1.0139775, theta=0.0
% INFO    : Bus 1425	: V=1.053968, theta=-13.412752 -> V=1.0072865, theta=0.0
% INFO    : Bus 1426	: V=1.068942, theta=6.077462 -> V=1.01211, theta=0.0
% INFO    : Bus 1427	: V=1.06843, theta=-23.445591 -> V=1.026662, theta=0.0
% INFO    : Bus 1428	: V=1.024718, theta=-20.485976 -> V=1.0, theta=0.0
% INFO    : Bus 1429	: V=1.057421, theta=-24.002728 -> V=1.016029, theta=0.0
% INFO    : Bus 1430	: V=1.0415, theta=-24.684348 -> V=1.0, theta=0.0
% INFO    : Bus 1431	: V=1.095842, theta=-31.415193 -> V=1.0326685, theta=0.0
% INFO    : Bus 1432	: V=1.085113, theta=-28.859468 -> V=1.02165, theta=0.0
% INFO    : Bus 1433	: V=1.024563, theta=-23.569742 -> V=1.0, theta=0.0
% INFO    : Bus 1434	: V=1.006465, theta=-36.913937 -> V=1.0, theta=0.0
% INFO    : Bus 1435	: V=1.040874, theta=-29.526323 -> V=1.0, theta=0.0
% INFO    : Bus 1436	: V=1.045656, theta=12.118274 -> V=1.003491, theta=0.0
% INFO    : Bus 1437	: V=1.048467, theta=-15.818185 -> V=1.0028825, theta=0.0
% INFO    : Bus 1438	: V=1.042542, theta=-12.136696 -> V=1.007027, theta=0.0
% INFO    : Bus 1439	: V=1.033087, theta=-1.927681 -> V=1.0, theta=0.0
% INFO    : Bus 1440	: V=1.039866, theta=-15.691519 -> V=1.0, theta=0.0
% INFO    : Bus 1441	: V=1.054052, theta=-13.269986 -> V=1.007581, theta=0.0
% INFO    : Bus 1442	: V=1.084737, theta=67.225872 -> V=1.0, theta=0.0
% INFO    : Bus 1443	: V=0.98905, theta=-19.178121 -> V=1.0, theta=0.0
% INFO    : Bus 1444	: V=1.022383, theta=-13.62466 -> V=1.0080765, theta=0.0
% INFO    : Bus 1445	: V=1.058817, theta=-4.74426 -> V=1.017174, theta=0.0
% INFO    : Bus 1446	: V=1.052549, theta=-30.587652 -> V=1.0101565, theta=0.0
% INFO    : Bus 1447	: V=0.951133, theta=57.250853 -> V=1.0, theta=0.0
% INFO    : Bus 1448	: V=1.071506, theta=-7.296736 -> V=1.0199065, theta=0.0
% INFO    : Bus 1449	: V=1.025303, theta=-16.833271 -> V=1.013647, theta=0.0
% INFO    : Bus 1450	: V=1.04174, theta=13.591568 -> V=1.005022, theta=0.0
% INFO    : Bus 1451	: V=1.083188, theta=-3.299275 -> V=1.022295, theta=0.0
% INFO    : Bus 1452	: V=1.099824, theta=61.294434 -> V=1.0085965, theta=0.0
% INFO    : Bus 1453	: V=1.046454, theta=-27.759196 -> V=1.017732, theta=0.0
% INFO    : Bus 1454	: V=1.077793, theta=41.797847 -> V=1.007966, theta=0.0
% INFO    : Bus 1455	: V=1.059031, theta=9.321907 -> V=1.019278, theta=0.0
% INFO    : Bus 1456	: V=0.976904, theta=-22.764718 -> V=1.0, theta=0.0
% INFO    : Bus 1457	: V=1.039398, theta=-44.330879 -> V=1.0, theta=0.0
% INFO    : Bus 1458	: V=1.053401, theta=-49.158103 -> V=1.0053575, theta=0.0
% INFO    : Bus 1459	: V=1.070906, theta=26.7089 -> V=1.0, theta=0.0
% INFO    : Bus 1460	: V=1.059454, theta=-54.618359 -> V=1.0, theta=0.0
% INFO    : Bus 1461	: V=1.041271, theta=-23.126896 -> V=1.0, theta=0.0
% INFO    : Bus 1462	: V=1.0405, theta=-6.236207 -> V=1.014904, theta=0.0
% INFO    : Bus 1463	: V=1.070451, theta=-23.607654 -> V=1.0358355, theta=0.0
% INFO    : Bus 1464	: V=1.097816, theta=8.748499 -> V=1.014776, theta=0.0
% INFO    : Bus 1465	: V=1.07079, theta=-5.321793 -> V=1.0120795, theta=0.0
% INFO    : Bus 1466	: V=1.047683, theta=-25.536543 -> V=1.0, theta=0.0
% INFO    : Bus 1467	: V=1.056415, theta=-19.75713 -> V=1.0127185, theta=0.0
% INFO    : Bus 1468	: V=1.051855, theta=-41.961478 -> V=1.0045715, theta=0.0
% INFO    : Bus 1469	: V=1.080835, theta=-9.018311 -> V=1.0238345, theta=0.0
% INFO    : Bus 1470	: V=1.075639, theta=-16.662785 -> V=1.021182, theta=0.0
% INFO    : Bus 1471	: V=1.035773, theta=11.357558 -> V=1.0, theta=0.0
% INFO    : Bus 1472	: V=1.036105, theta=-32.110208 -> V=1.0, theta=0.0
% INFO    : Bus 1473	: V=1.031779, theta=-4.630219 -> V=1.0, theta=0.0
% INFO    : Bus 1474	: V=1.070759, theta=-0.379171 -> V=1.019102, theta=0.0
% INFO    : Bus 1475	: V=1.071632, theta=-39.403361 -> V=1.0175085, theta=0.0
% INFO    : Bus 1476	: V=0.916618, theta=-26.435399 -> V=1.0, theta=0.0
% INFO    : Bus 1477	: V=1.057436, theta=-30.223855 -> V=1.011667, theta=0.0
% INFO    : Bus 1478	: V=1.030136, theta=-5.556483 -> V=1.004817, theta=0.0
% INFO    : Bus 1479	: V=1.009528, theta=39.734393 -> V=1.0, theta=0.0
% INFO    : Bus 1480	: V=1.058801, theta=-15.674027 -> V=1.0064815, theta=0.0
% INFO    : Bus 1481	: V=1.050155, theta=-20.496786 -> V=1.0194225, theta=0.0
% INFO    : Bus 1482	: V=1.069166, theta=-10.025969 -> V=1.017885, theta=0.0
% INFO    : Bus 1483	: V=0.996214, theta=-35.237396 -> V=1.0, theta=0.0
% INFO    : Bus 1484	: V=1.050283, theta=-11.276916 -> V=1.0100325, theta=0.0
% INFO    : Bus 1485	: V=1.055835, theta=33.894772 -> V=1.006544, theta=0.0
% INFO    : Bus 1486	: V=1.000632, theta=-23.971326 -> V=1.0, theta=0.0
% INFO    : Bus 1487	: V=1.055758, theta=-47.792241 -> V=1.003906, theta=0.0
% INFO    : Bus 1488	: V=1.04345, theta=14.702286 -> V=1.0, theta=0.0
% INFO    : Bus 1489	: V=0.96198, theta=-11.311463 -> V=1.0, theta=0.0
% INFO    : Bus 1490	: V=1.059861, theta=9.042542 -> V=1.0, theta=0.0
% INFO    : Bus 1491	: V=0.978776, theta=67.068683 -> V=1.0, theta=0.0
% INFO    : Bus 1492	: V=1.030457, theta=-19.149786 -> V=1.004954, theta=0.0
% INFO    : Bus 1493	: V=1.054329, theta=-49.289182 -> V=1.006143, theta=0.0
% INFO    : Bus 1494	: V=1.057312, theta=-48.491756 -> V=1.007619, theta=0.0
% INFO    : Bus 1495	: V=1.066717, theta=-17.234306 -> V=1.009082, theta=0.0
% INFO    : Bus 1496	: V=1.078, theta=-0.521835 -> V=1.019974, theta=0.0
% INFO    : Bus 1497	: V=1.052856, theta=-24.721443 -> V=1.013907, theta=0.0
% INFO    : Bus 1498	: V=1.085557, theta=3.011276 -> V=1.015436, theta=0.0
% INFO    : Bus 1499	: V=1.049998, theta=-49.48291 -> V=1.006057, theta=0.0
% INFO    : Bus 1500	: V=1.041667, theta=62.768437 -> V=1.0, theta=0.0
% INFO    : Bus 1501	: V=1.06303, theta=-16.871544 -> V=1.019103, theta=0.0
% INFO    : Bus 1502	: V=1.057643, theta=-21.348618 -> V=1.0, theta=0.0
% INFO    : Bus 1503	: V=1.006906, theta=-21.87433 -> V=1.0, theta=0.0
% INFO    : Bus 1504	: V=1.082591, theta=-15.408247 -> V=1.013374, theta=0.0
% INFO    : Bus 1505	: V=1.084971, theta=-2.272792 -> V=1.022679, theta=0.0
% INFO    : Bus 1506	: V=0.950378, theta=-26.51067 -> V=1.0, theta=0.0
% INFO    : Bus 1507	: V=1.047104, theta=-26.6495 -> V=1.0029285, theta=0.0
% INFO    : Bus 1508	: V=1.09094, theta=-22.493426 -> V=1.0329715, theta=0.0
% INFO    : Bus 1509	: V=0.965826, theta=-9.442007 -> V=1.0, theta=0.0
% INFO    : Bus 1510	: V=1.075218, theta=-14.342638 -> V=1.0067945, theta=0.0
% INFO    : Bus 1511	: V=1.04277, theta=-1.098104 -> V=1.0072645, theta=0.0
% INFO    : Bus 1512	: V=1.000786, theta=-22.42929 -> V=1.0, theta=0.0
% INFO    : Bus 1513	: V=1.03101, theta=-24.242247 -> V=1.0, theta=0.0
% INFO    : Bus 1514	: V=0.974973, theta=-24.168823 -> V=1.0, theta=0.0
% INFO    : Bus 1515	: V=1.076143, theta=-19.793582 -> V=1.020421, theta=0.0
% INFO    : Bus 1516	: V=1.075832, theta=-8.262329 -> V=1.019285, theta=0.0
% INFO    : Bus 1517	: V=0.951673, theta=-29.260635 -> V=1.0, theta=0.0
% INFO    : Bus 1518	: V=1.028872, theta=-43.898627 -> V=1.0, theta=0.0
% INFO    : Bus 1519	: V=1.094364, theta=45.053162 -> V=1.008388, theta=0.0
% INFO    : Bus 1520	: V=1.075566, theta=-15.12992 -> V=1.0113395, theta=0.0
% INFO    : Bus 1521	: V=1.099367, theta=-6.506666 -> V=1.029003, theta=0.0
% INFO    : Bus 1522	: V=1.087176, theta=0.750438 -> V=1.0270085, theta=0.0
% INFO    : Bus 1523	: V=1.025533, theta=-35.153359 -> V=1.0, theta=0.0
% INFO    : Bus 1524	: V=1.095247, theta=-11.351247 -> V=1.0350195, theta=0.0
% INFO    : Bus 1525	: V=1.047019, theta=61.886246 -> V=1.0, theta=0.0
% INFO    : Bus 1526	: V=0.930913, theta=-35.380515 -> V=1.0, theta=0.0
% INFO    : Bus 1527	: V=1.055982, theta=-10.080928 -> V=1.013738, theta=0.0
% INFO    : Bus 1528	: V=1.046773, theta=-3.662338 -> V=1.0, theta=0.0
% INFO    : Bus 1529	: V=1.053187, theta=-15.319766 -> V=1.006272, theta=0.0
% INFO    : Bus 1530	: V=1.01622, theta=-26.8587 -> V=1.041972, theta=0.0
% INFO    : Bus 1531	: V=1.056804, theta=-32.477662 -> V=1.0100155, theta=0.0
% INFO    : Bus 1532	: V=1.084579, theta=-2.626137 -> V=1.0241945, theta=0.0
% INFO    : Bus 1533	: V=0.965198, theta=-18.447 -> V=1.0, theta=0.0
% INFO    : Bus 1534	: V=1.047354, theta=-17.140158 -> V=1.0154505, theta=0.0
% INFO    : Bus 1535	: V=1.023401, theta=-17.848929 -> V=1.0, theta=0.0
% INFO    : Bus 1536	: V=1.062921, theta=-34.261268 -> V=1.011709, theta=0.0
% INFO    : Bus 1537	: V=1.0234, theta=-33.988231 -> V=1.0, theta=0.0
% INFO    : Bus 1538	: V=1.046561, theta=-20.33932 -> V=1.0162705, theta=0.0
% INFO    : Bus 1539	: V=0.967916, theta=-28.328391 -> V=1.0, theta=0.0
% INFO    : Bus 1540	: V=1.066092, theta=-38.895352 -> V=1.0219215, theta=0.0
% INFO    : Bus 1541	: V=1.057499, theta=9.97086 -> V=1.0056585, theta=0.0
% INFO    : Bus 1542	: V=1.029081, theta=-19.315872 -> V=1.0, theta=0.0
% INFO    : Bus 1543	: V=1.04874, theta=-10.64346 -> V=1.0095115, theta=0.0
% INFO    : Bus 1544	: V=0.941739, theta=-27.202264 -> V=1.0, theta=0.0
% INFO    : Bus 1545	: V=1.028288, theta=-18.659623 -> V=1.004359, theta=0.0
% INFO    : Bus 1546	: V=0.970679, theta=-20.185607 -> V=1.0, theta=0.0
% INFO    : Bus 1547	: V=1.087842, theta=-45.684724 -> V=1.014847, theta=0.0
% INFO    : Bus 1548	: V=1.084086, theta=1.543403 -> V=1.0241295, theta=0.0
% INFO    : Bus 1549	: V=0.996669, theta=-22.820275 -> V=1.0, theta=0.0
% INFO    : Bus 1550	: V=0.98418, theta=-24.283648 -> V=1.0, theta=0.0
% INFO    : Bus 1551	: V=0.956503, theta=-29.30269 -> V=0.9953445, theta=0.0
% INFO    : Bus 1552	: V=1.079603, theta=3.219078 -> V=1.024428, theta=0.0
% INFO    : Bus 1553	: V=1.085753, theta=-39.641906 -> V=1.0235755, theta=0.0
% INFO    : Bus 1554	: V=1.048673, theta=-13.159743 -> V=1.009202, theta=0.0
% INFO    : Bus 1555	: V=0.923823, theta=-28.733328 -> V=1.0, theta=0.0
% INFO    : Bus 1556	: V=1.042957, theta=19.982571 -> V=1.0, theta=0.0
% INFO    : Bus 1557	: V=1.003933, theta=11.690271 -> V=1.0, theta=0.0
% INFO    : Bus 1558	: V=1.079342, theta=-12.712394 -> V=1.0253615, theta=0.0
% INFO    : Bus 1559	: V=1.064406, theta=-13.906042 -> V=1.012925, theta=0.0
% INFO    : Bus 1560	: V=1.007272, theta=-19.733683 -> V=1.0, theta=0.0
% INFO    : Bus 1561	: V=1.053044, theta=-29.433914 -> V=1.0234095, theta=0.0
% INFO    : Bus 1562	: V=0.992644, theta=-23.294223 -> V=1.0, theta=0.0
% INFO    : Bus 1563	: V=0.971022, theta=-27.787759 -> V=1.0, theta=0.0
% INFO    : Bus 1564	: V=0.96728, theta=-25.712909 -> V=1.0, theta=0.0
% INFO    : Bus 1565	: V=1.019636, theta=-29.537982 -> V=1.0, theta=0.0
% INFO    : Bus 1566	: V=1.067258, theta=-37.453485 -> V=1.017852, theta=0.0
% INFO    : Bus 1567	: V=0.981001, theta=-18.754176 -> V=1.0, theta=0.0
% INFO    : Bus 1568	: V=0.985174, theta=-24.312737 -> V=1.0, theta=0.0
% INFO    : Bus 1569	: V=1.065273, theta=24.821342 -> V=1.007421, theta=0.0
% INFO    : Bus 1570	: V=1.052079, theta=13.039106 -> V=1.0061375, theta=0.0
% INFO    : Bus 1571	: V=1.096591, theta=2.319811 -> V=1.0316265, theta=0.0
% INFO    : Bus 1572	: V=1.066343, theta=7.733385 -> V=1.007681, theta=0.0
% INFO    : Bus 1573	: V=1.08371, theta=-16.510568 -> V=1.0263115, theta=0.0
% INFO    : Bus 1574	: V=0.997561, theta=-24.755577 -> V=1.0, theta=0.0
% INFO    : Bus 1575	: V=1.032502, theta=-25.294349 -> V=1.0, theta=0.0
% INFO    : Bus 1576	: V=1.0735, theta=-21.712517 -> V=1.009457, theta=0.0
% INFO    : Bus 1577	: V=0.992061, theta=-20.283226 -> V=1.0, theta=0.0
% INFO    : Bus 1578	: V=1.092603, theta=-44.228184 -> V=1.0172645, theta=0.0
% INFO    : Bus 1579	: V=1.005417, theta=-20.211066 -> V=1.0, theta=0.0
% INFO    : Bus 1580	: V=1.038717, theta=-13.917056 -> V=1.016194, theta=0.0
% INFO    : Bus 1581	: V=0.960676, theta=-27.131501 -> V=1.0, theta=0.0
% INFO    : Bus 1582	: V=1.077155, theta=-19.737808 -> V=1.023807, theta=0.0
% INFO    : Bus 1583	: V=0.966738, theta=-32.096715 -> V=1.0, theta=0.0
% INFO    : Bus 1584	: V=1.029058, theta=-49.638507 -> V=1.0, theta=0.0
% INFO    : Bus 1585	: V=1.064498, theta=-15.151712 -> V=1.008879, theta=0.0
% INFO    : Bus 1586	: V=1.011364, theta=-19.407991 -> V=1.0, theta=0.0
% INFO    : Bus 1587	: V=1.056451, theta=-17.590331 -> V=1.0179625, theta=0.0
% INFO    : Bus 1588	: V=1.06681, theta=-8.556398 -> V=1.014505, theta=0.0
% INFO    : Bus 1589	: V=0.976099, theta=-22.811038 -> V=1.0, theta=0.0
% INFO    : Bus 1590	: V=1.005024, theta=-41.221466 -> V=1.0, theta=0.0
% INFO    : Bus 1591	: V=1.034308, theta=-32.485081 -> V=1.0172785, theta=0.0
% INFO    : Bus 1592	: V=1.085591, theta=-13.416257 -> V=1.0350815, theta=0.0
% INFO    : Bus 1593	: V=0.990662, theta=-27.32064 -> V=1.0, theta=0.0
% INFO    : Bus 1594	: V=1.04331, theta=-21.001063 -> V=1.0, theta=0.0
% INFO    : Bus 1595	: V=1.05981, theta=-22.957794 -> V=1.016886, theta=0.0
% INFO    : Bus 1596	: V=1.073026, theta=10.864149 -> V=1.012599, theta=0.0
% INFO    : Bus 1597	: V=1.068105, theta=-34.666452 -> V=1.0153875, theta=0.0
% INFO    : Bus 1598	: V=1.031855, theta=-25.496848 -> V=1.0, theta=0.0
% INFO    : Bus 1599	: V=1.071578, theta=-18.271598 -> V=1.019659, theta=0.0
% INFO    : Bus 1600	: V=1.017485, theta=-14.54073 -> V=1.0, theta=0.0
% INFO    : Bus 1601	: V=1.050788, theta=-48.326364 -> V=1.0053755, theta=0.0
% INFO    : Bus 1602	: V=0.987557, theta=-22.443821 -> V=1.0, theta=0.0
% INFO    : Bus 1603	: V=1.063, theta=-16.376579 -> V=1.021911, theta=0.0
% INFO    : Bus 1604	: V=1.021069, theta=-21.58337 -> V=1.0, theta=0.0
% INFO    : Bus 1605	: V=1.024682, theta=-20.77908 -> V=1.0, theta=0.0
% INFO    : Bus 1606	: V=1.044027, theta=16.269152 -> V=1.0, theta=0.0
% INFO    : Bus 1607	: V=1.073339, theta=-4.602966 -> V=1.020231, theta=0.0
% INFO    : Bus 1608	: V=1.092533, theta=-30.405019 -> V=1.0221155, theta=0.0
% INFO    : Bus 1609	: V=1.063069, theta=-41.416065 -> V=1.016696, theta=0.0
% INFO    : Bus 1610	: V=0.990985, theta=-23.000704 -> V=1.0, theta=0.0
% INFO    : Bus 1611	: V=1.016454, theta=-16.843255 -> V=1.0, theta=0.0
% INFO    : Bus 1612	: V=1.0264, theta=-30.060736 -> V=1.017113, theta=0.0
% INFO    : Bus 1613	: V=1.043533, theta=-18.556644 -> V=1.008722, theta=0.0
% INFO    : Bus 1614	: V=1.093721, theta=-7.959084 -> V=1.0286115, theta=0.0
% INFO    : Bus 1615	: V=0.996829, theta=-22.713864 -> V=1.0, theta=0.0
% INFO    : Bus 1616	: V=1.034685, theta=-45.002232 -> V=1.0260395, theta=0.0
% INFO    : Bus 1617	: V=1.069988, theta=-10.720539 -> V=1.015882, theta=0.0
% INFO    : Bus 1618	: V=1.068313, theta=-42.4901 -> V=1.009961, theta=0.0
% INFO    : Bus 1619	: V=1.033813, theta=-37.331954 -> V=1.0, theta=0.0
% INFO    : Bus 1620	: V=0.973529, theta=-25.885712 -> V=1.0, theta=0.0
% INFO    : Bus 1621	: V=1.03126, theta=29.815778 -> V=1.0, theta=0.0
% INFO    : Bus 1622	: V=1.08635, theta=-41.190867 -> V=1.0230705, theta=0.0
% INFO    : Bus 1623	: V=1.046017, theta=-28.731866 -> V=1.0066895, theta=0.0
% INFO    : Bus 1624	: V=1.084526, theta=68.851453 -> V=1.0, theta=0.0
% INFO    : Bus 1625	: V=1.06828, theta=11.312509 -> V=1.023197, theta=0.0
% INFO    : Bus 1626	: V=1.043385, theta=14.686877 -> V=1.0, theta=0.0
% INFO    : Bus 1627	: V=1.019217, theta=-20.833485 -> V=1.0, theta=0.0
% INFO    : Bus 1628	: V=1.077063, theta=-17.717886 -> V=1.0, theta=0.0
% INFO    : Bus 1629	: V=1.040079, theta=-29.568847 -> V=1.0, theta=0.0
% INFO    : Bus 1630	: V=1.038312, theta=-15.1678 -> V=1.0136385, theta=0.0
% INFO    : Bus 1631	: V=1.051053, theta=5.125141 -> V=1.0197695, theta=0.0
% INFO    : Bus 1632	: V=1.000793, theta=-24.4208 -> V=1.0, theta=0.0
% INFO    : Bus 1633	: V=0.967727, theta=-12.726152 -> V=1.0, theta=0.0
% INFO    : Bus 1634	: V=1.098053, theta=-12.085788 -> V=1.0170465, theta=0.0
% INFO    : Bus 1635	: V=1.025129, theta=8.06856 -> V=1.0033315, theta=0.0
% INFO    : Bus 1636	: V=1.043079, theta=12.550941 -> V=1.0052895, theta=0.0
% INFO    : Bus 1637	: V=1.078536, theta=-16.544345 -> V=1.009379, theta=0.0
% INFO    : Bus 1638	: V=1.030573, theta=-2.352541 -> V=1.004244, theta=0.0
% INFO    : Bus 1639	: V=1.053766, theta=-16.104425 -> V=1.0045565, theta=0.0
% INFO    : Bus 1640	: V=1.032172, theta=17.072875 -> V=1.0, theta=0.0
% INFO    : Bus 1641	: V=1.017091, theta=-40.134796 -> V=1.0, theta=0.0
% INFO    : Bus 1642	: V=1.092, theta=-0.717685 -> V=1.026482, theta=0.0
% INFO    : Bus 1643	: V=0.975064, theta=-25.139677 -> V=1.0, theta=0.0
% INFO    : Bus 1644	: V=0.985744, theta=-23.427539 -> V=1.0, theta=0.0
% INFO    : Bus 1645	: V=0.979909, theta=-22.070432 -> V=1.0, theta=0.0
% INFO    : Bus 1646	: V=1.037611, theta=-7.797658 -> V=1.0, theta=0.0
% INFO    : Bus 1647	: V=1.026137, theta=-17.992618 -> V=1.0, theta=0.0
% INFO    : Bus 1648	: V=1.021233, theta=-42.245154 -> V=1.0, theta=0.0
% INFO    : Bus 1649	: V=1.062173, theta=-21.051612 -> V=1.0195925, theta=0.0
% INFO    : Bus 1650	: V=1.061057, theta=-35.346347 -> V=1.0211075, theta=0.0
% INFO    : Bus 1651	: V=0.915108, theta=-29.723929 -> V=1.0, theta=0.0
% INFO    : Bus 1652	: V=1.093858, theta=35.188922 -> V=1.0138635, theta=0.0
% INFO    : Bus 1653	: V=1.075182, theta=-0.680521 -> V=1.022108, theta=0.0
% INFO    : Bus 1654	: V=0.976383, theta=-17.441685 -> V=1.0, theta=0.0
% INFO    : Bus 1655	: V=1.070179, theta=12.147287 -> V=1.0237715, theta=0.0
% INFO    : Bus 1656	: V=1.083448, theta=34.161267 -> V=1.014681, theta=0.0
% INFO    : Bus 1657	: V=1.036709, theta=-7.100736 -> V=1.012713, theta=0.0
% INFO    : Bus 1658	: V=1.088474, theta=-26.226652 -> V=1.033437, theta=0.0
% INFO    : Bus 1659	: V=1.081173, theta=-2.392743 -> V=1.019272, theta=0.0
% INFO    : Bus 1660	: V=1.086222, theta=-21.30892 -> V=1.0188175, theta=0.0
% INFO    : Bus 1661	: V=1.069693, theta=-11.898239 -> V=1.0330235, theta=0.0
% INFO    : Bus 1662	: V=1.045113, theta=-19.908863 -> V=1.0, theta=0.0
% INFO    : Bus 1663	: V=1.093262, theta=-20.244147 -> V=1.0319955, theta=0.0
% INFO    : Bus 1664	: V=1.030585, theta=-12.523381 -> V=1.0115485, theta=0.0
% INFO    : Bus 1665	: V=1.099942, theta=-7.615854 -> V=1.0283895, theta=0.0
% INFO    : Bus 1666	: V=1.065737, theta=-40.613091 -> V=1.0189315, theta=0.0
% INFO    : Bus 1667	: V=1.030737, theta=17.054978 -> V=1.0, theta=0.0
% INFO    : Bus 1668	: V=1.041029, theta=-19.93418 -> V=1.0102935, theta=0.0
% INFO    : Bus 1669	: V=1.054603, theta=-0.478483 -> V=1.006246, theta=0.0
% INFO    : Bus 1670	: V=1.083988, theta=-41.42952 -> V=1.027891, theta=0.0
% INFO    : Bus 1671	: V=1.022935, theta=-15.279912 -> V=1.0, theta=0.0
% INFO    : Bus 1672	: V=1.072283, theta=-23.045491 -> V=1.0, theta=0.0
% INFO    : Bus 1673	: V=1.002143, theta=-18.066246 -> V=1.0, theta=0.0
% INFO    : Bus 1674	: V=1.034858, theta=-24.796436 -> V=1.0, theta=0.0
% INFO    : Bus 1675	: V=1.029966, theta=-24.478599 -> V=1.0, theta=0.0
% INFO    : Bus 1676	: V=1.072555, theta=-21.340499 -> V=1.027716, theta=0.0
% INFO    : Bus 1677	: V=0.992675, theta=-18.790669 -> V=1.0, theta=0.0
% INFO    : Bus 1678	: V=1.021406, theta=1.478548 -> V=1.010738, theta=0.0
% INFO    : Bus 1679	: V=1.077577, theta=-0.413992 -> V=1.0222465, theta=0.0
% INFO    : Bus 1680	: V=1.041069, theta=-0.488226 -> V=1.0072745, theta=0.0
% INFO    : Bus 1681	: V=1.07381, theta=-21.043675 -> V=1.028, theta=0.0
% INFO    : Bus 1682	: V=1.074727, theta=-15.229126 -> V=1.013069, theta=0.0
% INFO    : Bus 1683	: V=1.030631, theta=-24.292102 -> V=1.0, theta=0.0
% INFO    : Bus 1684	: V=1.056515, theta=-48.621876 -> V=1.007129, theta=0.0
% INFO    : Bus 1685	: V=1.086185, theta=-2.726652 -> V=1.0230915, theta=0.0
% INFO    : Bus 1686	: V=1.029, theta=-15.337851 -> V=1.0161325, theta=0.0
% INFO    : Bus 1687	: V=1.095264, theta=-11.350693 -> V=1.0350275, theta=0.0
% INFO    : Bus 1688	: V=0.977909, theta=-22.784621 -> V=1.0, theta=0.0
% INFO    : Bus 1689	: V=1.056931, theta=-29.698285 -> V=1.005535, theta=0.0
% INFO    : Bus 1690	: V=0.996166, theta=-4.990037 -> V=1.0, theta=0.0
% INFO    : Bus 1691	: V=1.081318, theta=-46.663151 -> V=1.013951, theta=0.0
% INFO    : Bus 1692	: V=1.060364, theta=-12.51623 -> V=1.0220895, theta=0.0
% INFO    : Bus 1693	: V=1.047409, theta=-25.385501 -> V=1.0135405, theta=0.0
% INFO    : Bus 1694	: V=0.997595, theta=-16.488296 -> V=1.0, theta=0.0
% INFO    : Bus 1695	: V=1.003749, theta=60.303766 -> V=1.0, theta=0.0
% INFO    : Bus 1696	: V=0.9871, theta=8.466334 -> V=1.0, theta=0.0
% INFO    : Bus 1697	: V=1.092155, theta=2.610009 -> V=1.0271895, theta=0.0
% INFO    : Bus 1698	: V=1.054553, theta=-10.118408 -> V=1.010471, theta=0.0
% INFO    : Bus 1699	: V=0.989806, theta=-17.16555 -> V=1.0, theta=0.0
% INFO    : Bus 1700	: V=1.004281, theta=-27.221113 -> V=1.0, theta=0.0
% INFO    : Bus 1701	: V=1.050543, theta=-25.509827 -> V=1.0142135, theta=0.0
% INFO    : Bus 1702	: V=1.064995, theta=20.495402 -> V=1.013148, theta=0.0
% INFO    : Bus 1703	: V=1.00778, theta=-36.543341 -> V=1.0, theta=0.0
% INFO    : Bus 1704	: V=1.087569, theta=28.190954 -> V=1.024213, theta=0.0
% INFO    : Bus 1705	: V=1.023823, theta=-20.053123 -> V=1.010374, theta=0.0
% INFO    : Bus 1706	: V=1.018627, theta=-22.368885 -> V=1.0, theta=0.0
% INFO    : Bus 1707	: V=1.050561, theta=-27.820616 -> V=1.0217095, theta=0.0
% INFO    : Bus 1708	: V=1.077723, theta=-35.157515 -> V=1.028288, theta=0.0
% INFO    : Bus 1709	: V=1.072233, theta=-14.31271 -> V=1.014131, theta=0.0
% INFO    : Bus 1710	: V=1.053042, theta=-40.359058 -> V=1.009105, theta=0.0
% INFO    : Bus 1711	: V=1.067321, theta=1.062909 -> V=1.0148725, theta=0.0
% INFO    : Bus 1712	: V=1.013818, theta=-47.209009 -> V=1.0, theta=0.0
% INFO    : Bus 1713	: V=1.051014, theta=-49.386974 -> V=1.006578, theta=0.0
% INFO    : Bus 1714	: V=1.043117, theta=-13.99344 -> V=1.0290345, theta=0.0
% INFO    : Bus 1715	: V=1.040291, theta=-27.194634 -> V=1.0, theta=0.0
% INFO    : Bus 1716	: V=0.999869, theta=-23.487073 -> V=1.0, theta=0.0
% INFO    : Bus 1717	: V=1.075466, theta=-13.686052 -> V=1.0230085, theta=0.0
% INFO    : Bus 1718	: V=1.073867, theta=-14.805858 -> V=1.0093345, theta=0.0
% INFO    : Bus 1719	: V=0.994977, theta=-22.771881 -> V=1.0, theta=0.0
% INFO    : Bus 1720	: V=1.034783, theta=-24.416259 -> V=1.0, theta=0.0
% INFO    : Bus 1721	: V=1.061422, theta=0.471738 -> V=1.011956, theta=0.0
% INFO    : Bus 1722	: V=1.052519, theta=-36.57683 -> V=1.0171215, theta=0.0
% INFO    : Bus 1723	: V=1.079582, theta=-15.435364 -> V=1.0213095, theta=0.0
% INFO    : Bus 1724	: V=1.082211, theta=-9.673947 -> V=1.013083, theta=0.0
% INFO    : Bus 1725	: V=1.089113, theta=-23.923314 -> V=1.0221665, theta=0.0
% INFO    : Bus 1726	: V=1.006857, theta=-36.046673 -> V=1.0, theta=0.0
% INFO    : Bus 1727	: V=1.084227, theta=-3.40484 -> V=1.0221445, theta=0.0
% INFO    : Bus 1728	: V=1.047176, theta=6.149572 -> V=1.009605, theta=0.0
% INFO    : Bus 1729	: V=1.042605, theta=48.838336 -> V=1.007468, theta=0.0
% INFO    : Bus 1730	: V=0.97218, theta=-24.849475 -> V=1.0, theta=0.0
% INFO    : Bus 1731	: V=1.068348, theta=-3.731118 -> V=1.013554, theta=0.0
% INFO    : Bus 1732	: V=1.065912, theta=-43.35851 -> V=1.0073835, theta=0.0
% INFO    : Bus 1733	: V=1.044736, theta=7.888855 -> V=1.0090515, theta=0.0
% INFO    : Bus 1734	: V=1.049808, theta=-5.537084 -> V=1.017398, theta=0.0
% INFO    : Bus 1735	: V=1.058082, theta=-54.860986 -> V=1.0, theta=0.0
% INFO    : Bus 1736	: V=1.096079, theta=-31.987342 -> V=1.0319565, theta=0.0
% INFO    : Bus 1737	: V=1.104359, theta=-42.674769 -> V=1.0312555, theta=0.0
% INFO    : Bus 1738	: V=1.078947, theta=59.161968 -> V=1.0, theta=0.0
% INFO    : Bus 1739	: V=1.011728, theta=10.817881 -> V=1.0, theta=0.0
% INFO    : Bus 1740	: V=1.026726, theta=-34.128746 -> V=1.0, theta=0.0
% INFO    : Bus 1741	: V=1.033179, theta=-25.317358 -> V=1.0, theta=0.0
% INFO    : Bus 1742	: V=0.978014, theta=-33.950446 -> V=1.0, theta=0.0
% INFO    : Bus 1743	: V=1.064237, theta=-8.852507 -> V=1.0, theta=0.0
% INFO    : Bus 1744	: V=1.021227, theta=61.023584 -> V=1.0, theta=0.0
% INFO    : Bus 1745	: V=0.983988, theta=-18.556808 -> V=1.0, theta=0.0
% INFO    : Bus 1746	: V=1.068591, theta=-35.937395 -> V=1.0083605, theta=0.0
% INFO    : Bus 1747	: V=1.077948, theta=-6.328511 -> V=1.018284, theta=0.0
% INFO    : Bus 1748	: V=1.048902, theta=-19.345834 -> V=1.002627, theta=0.0
% INFO    : Bus 1749	: V=1.00367, theta=-41.00055 -> V=1.0, theta=0.0
% INFO    : Bus 1750	: V=1.087999, theta=8.208077 -> V=1.0215095, theta=0.0
% INFO    : Bus 1751	: V=1.054545, theta=-20.312039 -> V=1.019546, theta=0.0
% INFO    : Bus 1752	: V=1.088236, theta=-24.217319 -> V=1.0138435, theta=0.0
% INFO    : Bus 1753	: V=0.947132, theta=-34.996936 -> V=1.0, theta=0.0
% INFO    : Bus 1754	: V=1.060906, theta=-23.981122 -> V=1.01755, theta=0.0
% INFO    : Bus 1755	: V=1.070959, theta=0.755863 -> V=1.0197555, theta=0.0
% INFO    : Bus 1756	: V=1.099158, theta=-15.352801 -> V=1.043811, theta=0.0
% INFO    : Bus 1757	: V=1.072554, theta=-35.594915 -> V=1.011373, theta=0.0
% INFO    : Bus 1758	: V=1.023678, theta=-12.804055 -> V=1.0, theta=0.0
% INFO    : Bus 1759	: V=1.060627, theta=-18.109041 -> V=1.0321315, theta=0.0
% INFO    : Bus 1760	: V=1.049394, theta=-11.299289 -> V=1.0103775, theta=0.0
% INFO    : Bus 1761	: V=1.049997, theta=-22.038572 -> V=1.0, theta=0.0
% INFO    : Bus 1762	: V=1.054318, theta=-30.124888 -> V=1.0097835, theta=0.0
% INFO    : Bus 1763	: V=1.044864, theta=-3.944317 -> V=1.0, theta=0.0
% INFO    : Bus 1764	: V=1.028079, theta=-35.257724 -> V=1.0, theta=0.0
% INFO    : Bus 1765	: V=1.097471, theta=-15.695981 -> V=1.0281455, theta=0.0
% INFO    : Bus 1766	: V=1.032508, theta=-22.742899 -> V=1.0, theta=0.0
% INFO    : Bus 1767	: V=0.983314, theta=-31.375817 -> V=1.0, theta=0.0
% INFO    : Bus 1768	: V=1.0898, theta=-22.257603 -> V=1.019848, theta=0.0
% INFO    : Bus 1769	: V=1.035467, theta=-24.80166 -> V=1.0, theta=0.0
% INFO    : Bus 1770	: V=1.072732, theta=3.688233 -> V=1.0220085, theta=0.0
% INFO    : Bus 1771	: V=1.022946, theta=31.435394 -> V=1.0, theta=0.0
% INFO    : Bus 1772	: V=1.060729, theta=-20.692146 -> V=1.0120905, theta=0.0
% INFO    : Bus 1773	: V=1.092304, theta=-17.09038 -> V=1.0329185, theta=0.0
% INFO    : Bus 1774	: V=1.059866, theta=-53.686415 -> V=1.0, theta=0.0
% INFO    : Bus 1775	: V=1.046441, theta=6.357376 -> V=1.003199, theta=0.0
% INFO    : Bus 1776	: V=0.958607, theta=58.546113 -> V=1.0, theta=0.0
% INFO    : Bus 1777	: V=0.967426, theta=-30.526625 -> V=1.0, theta=0.0
% INFO    : Bus 1778	: V=1.049537, theta=40.078758 -> V=1.0, theta=0.0
% INFO    : Bus 1779	: V=1.08729, theta=-36.112519 -> V=1.019048, theta=0.0
% INFO    : Bus 1780	: V=1.022603, theta=-8.031697 -> V=1.0, theta=0.0
% INFO    : Bus 1781	: V=1.076097, theta=0.508008 -> V=1.0142965, theta=0.0
% INFO    : Bus 1782	: V=1.041048, theta=-18.611914 -> V=1.0, theta=0.0
% INFO    : Bus 1783	: V=1.077915, theta=-27.451114 -> V=1.01836, theta=0.0
% INFO    : Bus 1784	: V=1.007112, theta=65.354664 -> V=1.0, theta=0.0
% INFO    : Bus 1785	: V=1.063065, theta=-20.119821 -> V=1.0, theta=0.0
% INFO    : Bus 1786	: V=1.03372, theta=17.09215 -> V=1.0, theta=0.0
% INFO    : Bus 1787	: V=1.050215, theta=23.932183 -> V=1.013913, theta=0.0
% INFO    : Bus 1788	: V=1.055667, theta=-43.869008 -> V=1.005109, theta=0.0
% INFO    : Bus 1789	: V=1.097227, theta=-10.50203 -> V=1.03612, theta=0.0
% INFO    : Bus 1790	: V=0.988245, theta=-24.023199 -> V=1.0, theta=0.0
% INFO    : Bus 1791	: V=0.959522, theta=-13.514562 -> V=1.0, theta=0.0
% INFO    : Bus 1792	: V=0.958276, theta=58.546671 -> V=1.0, theta=0.0
% INFO    : Bus 1793	: V=1.015303, theta=-16.661348 -> V=1.0038755, theta=0.0
% INFO    : Bus 1794	: V=1.015728, theta=-19.908581 -> V=1.0, theta=0.0
% INFO    : Bus 1795	: V=1.035931, theta=-49.301023 -> V=1.0312805, theta=0.0
% INFO    : Bus 1796	: V=1.04013, theta=-24.325246 -> V=1.0, theta=0.0
% INFO    : Bus 1797	: V=1.023967, theta=-15.687738 -> V=1.0135205, theta=0.0
% INFO    : Bus 1798	: V=1.074494, theta=-11.191814 -> V=1.022766, theta=0.0
% INFO    : Bus 1799	: V=1.055113, theta=-48.876893 -> V=1.006365, theta=0.0
% INFO    : Bus 1800	: V=0.993364, theta=-16.623204 -> V=1.0, theta=0.0
% INFO    : Bus 1801	: V=1.05383, theta=-19.248567 -> V=1.003476, theta=0.0
% INFO    : Bus 1802	: V=1.104363, theta=-17.10477 -> V=1.0278375, theta=0.0
% INFO    : Bus 1803	: V=1.076746, theta=-25.418477 -> V=1.033354, theta=0.0
% INFO    : Bus 1804	: V=0.982554, theta=-40.074438 -> V=1.0, theta=0.0
% INFO    : Bus 1805	: V=1.042932, theta=7.902757 -> V=1.0, theta=0.0
% INFO    : Bus 1806	: V=1.098202, theta=-15.862108 -> V=1.043171, theta=0.0
% INFO    : Bus 1807	: V=1.073844, theta=-19.031574 -> V=1.022419, theta=0.0
% INFO    : Bus 1808	: V=1.074683, theta=-32.93662 -> V=1.0385715, theta=0.0
% INFO    : Bus 1809	: V=1.071021, theta=-20.378888 -> V=1.0179715, theta=0.0
% INFO    : Bus 1810	: V=1.037876, theta=-16.608064 -> V=1.0, theta=0.0
% INFO    : Bus 1811	: V=1.073834, theta=3.181348 -> V=1.021836, theta=0.0
% INFO    : Bus 1812	: V=1.033851, theta=-47.129047 -> V=1.0, theta=0.0
% INFO    : Bus 1813	: V=1.002476, theta=-23.210688 -> V=1.0, theta=0.0
% INFO    : Bus 1814	: V=1.014166, theta=-23.33878 -> V=1.0, theta=0.0
% INFO    : Bus 1815	: V=0.999473, theta=-22.34578 -> V=1.0, theta=0.0
% INFO    : Bus 1816	: V=1.065779, theta=10.012692 -> V=1.022394, theta=0.0
% INFO    : Bus 1817	: V=1.044198, theta=-30.551886 -> V=1.003349, theta=0.0
% INFO    : Bus 1818	: V=1.066136, theta=-38.885212 -> V=1.0220545, theta=0.0
% INFO    : Bus 1819	: V=1.043305, theta=-1.107537 -> V=1.0075535, theta=0.0
% INFO    : Bus 1820	: V=0.991041, theta=10.981826 -> V=1.0, theta=0.0
% INFO    : Bus 1821	: V=1.079797, theta=-6.955997 -> V=1.023299, theta=0.0
% INFO    : Bus 1822	: V=0.97808, theta=-20.227752 -> V=1.0, theta=0.0
% INFO    : Bus 1823	: V=1.029212, theta=-27.128934 -> V=1.0, theta=0.0
% INFO    : Bus 1824	: V=1.06863, theta=-19.162605 -> V=1.0184675, theta=0.0
% INFO    : Bus 1825	: V=1.101763, theta=-35.742904 -> V=1.033356, theta=0.0
% INFO    : Bus 1826	: V=1.067083, theta=-17.657536 -> V=1.00905, theta=0.0
% INFO    : Bus 1827	: V=1.040366, theta=25.791028 -> V=1.015022, theta=0.0
% INFO    : Bus 1828	: V=1.008904, theta=10.807994 -> V=1.0, theta=0.0
% INFO    : Bus 1829	: V=1.07179, theta=-28.844243 -> V=1.0161205, theta=0.0
% INFO    : Bus 1830	: V=1.048243, theta=-22.080269 -> V=1.0, theta=0.0
% INFO    : Bus 1831	: V=1.041765, theta=-34.406196 -> V=1.0, theta=0.0
% INFO    : Bus 1832	: V=0.98767, theta=-26.644879 -> V=1.0, theta=0.0
% INFO    : Bus 1833	: V=1.049431, theta=-46.817678 -> V=1.005423, theta=0.0
% INFO    : Bus 1834	: V=0.977314, theta=-27.162759 -> V=1.0, theta=0.0
% INFO    : Bus 1835	: V=1.016526, theta=-22.074766 -> V=1.0, theta=0.0
% INFO    : Bus 1836	: V=1.073315, theta=-17.787637 -> V=1.0203685, theta=0.0
% INFO    : Bus 1837	: V=1.088437, theta=-3.846111 -> V=1.024642, theta=0.0
% INFO    : Bus 1838	: V=1.099225, theta=-10.212346 -> V=1.0293155, theta=0.0
% INFO    : Bus 1839	: V=0.991652, theta=-21.546592 -> V=1.0, theta=0.0
% INFO    : Bus 1840	: V=1.052005, theta=8.518162 -> V=1.013629, theta=0.0
% INFO    : Bus 1841	: V=1.08841, theta=-24.158387 -> V=1.013791, theta=0.0
% INFO    : Bus 1842	: V=1.014636, theta=-7.733836 -> V=1.0, theta=0.0
% INFO    : Bus 1843	: V=1.074542, theta=-20.055567 -> V=1.019712, theta=0.0
% INFO    : Bus 1844	: V=1.061547, theta=-22.965204 -> V=1.0178105, theta=0.0
% INFO    : Bus 1845	: V=1.060512, theta=-23.817039 -> V=1.017335, theta=0.0
% INFO    : Bus 1846	: V=1.005657, theta=-19.218335 -> V=1.0, theta=0.0
% INFO    : Bus 1847	: V=1.019251, theta=-17.069368 -> V=1.0, theta=0.0
% INFO    : Bus 1848	: V=0.990699, theta=-24.268463 -> V=1.0, theta=0.0
% INFO    : Bus 1849	: V=1.01875, theta=-46.460937 -> V=1.0, theta=0.0
% INFO    : Bus 1850	: V=1.05905, theta=-20.850531 -> V=1.013759, theta=0.0
% INFO    : Bus 1851	: V=1.024392, theta=-15.561308 -> V=1.0, theta=0.0
% INFO    : Bus 1852	: V=1.016081, theta=10.893786 -> V=1.0, theta=0.0
% INFO    : Bus 1853	: V=1.096267, theta=14.431763 -> V=1.0225345, theta=0.0
% INFO    : Bus 1854	: V=1.10175, theta=-35.756914 -> V=1.033366, theta=0.0
% INFO    : Bus 1855	: V=0.98802, theta=-24.241778 -> V=1.0, theta=0.0
% INFO    : Bus 1856	: V=1.042065, theta=-3.617474 -> V=1.0, theta=0.0
% INFO    : Bus 1857	: V=1.054974, theta=-27.092065 -> V=1.008764, theta=0.0
% INFO    : Bus 1858	: V=1.079974, theta=-0.278582 -> V=1.020842, theta=0.0
% INFO    : Bus 1859	: V=1.013608, theta=-22.455538 -> V=1.0, theta=0.0
% INFO    : Bus 1860	: V=0.945655, theta=-28.41367 -> V=1.0, theta=0.0
% INFO    : Bus 1861	: V=1.069177, theta=18.467062 -> V=1.017985, theta=0.0
% INFO    : Bus 1862	: V=1.098522, theta=-16.865013 -> V=1.0332335, theta=0.0
% INFO    : Bus 1863	: V=1.042885, theta=-42.910435 -> V=1.0, theta=0.0
% INFO    : Bus 1864	: V=1.093576, theta=-11.856906 -> V=1.013118, theta=0.0
% INFO    : Bus 1865	: V=1.065397, theta=-6.852361 -> V=1.016513, theta=0.0
% INFO    : Bus 1866	: V=1.036168, theta=-20.540571 -> V=1.0120735, theta=0.0
% INFO    : Bus 1867	: V=1.081534, theta=-11.890374 -> V=1.0236755, theta=0.0
% INFO    : Bus 1868	: V=0.9814, theta=-25.637355 -> V=1.0, theta=0.0
% INFO    : Bus 1869	: V=1.084289, theta=67.103658 -> V=1.0, theta=0.0
% INFO    : Bus 1870	: V=1.000074, theta=-23.122851 -> V=1.0, theta=0.0
% INFO    : Bus 1871	: V=1.032763, theta=-15.342031 -> V=1.0029675, theta=0.0
% INFO    : Bus 1872	: V=1.090211, theta=-1.285702 -> V=1.0208035, theta=0.0
% INFO    : Bus 1873	: V=1.083842, theta=-16.472114 -> V=1.0263365, theta=0.0
% INFO    : Bus 1874	: V=1.037689, theta=-25.230679 -> V=1.0, theta=0.0
% INFO    : Bus 1875	: V=1.083208, theta=-25.839315 -> V=1.011493, theta=0.0
% INFO    : Bus 1876	: V=1.085182, theta=-21.647196 -> V=1.0167505, theta=0.0
% INFO    : Bus 1877	: V=1.066918, theta=-3.07571 -> V=1.018583, theta=0.0
% INFO    : Bus 1878	: V=1.034434, theta=-8.797656 -> V=1.0076525, theta=0.0
% INFO    : Bus 1879	: V=1.050123, theta=-30.412107 -> V=1.0216875, theta=0.0
% INFO    : Bus 1880	: V=1.086366, theta=-41.190921 -> V=1.0230785, theta=0.0
% INFO    : Bus 1881	: V=1.097878, theta=-13.908707 -> V=1.0227815, theta=0.0
% INFO    : Bus 1882	: V=1.04939, theta=-52.897575 -> V=1.0, theta=0.0
% INFO    : Bus 1883	: V=0.967869, theta=-13.111072 -> V=1.0, theta=0.0
% INFO    : Bus 1884	: V=1.007601, theta=-17.4955 -> V=1.0, theta=0.0
% INFO    : Bus 1885	: V=1.089181, theta=-11.033622 -> V=1.0102665, theta=0.0
% INFO    : Bus 1886	: V=1.066789, theta=-8.545704 -> V=1.0144995, theta=0.0
% INFO    : Bus 1887	: V=1.017212, theta=-23.760297 -> V=1.0, theta=0.0
% INFO    : Bus 1888	: V=1.073278, theta=-17.257855 -> V=1.0117825, theta=0.0
% INFO    : Bus 1889	: V=0.939711, theta=65.740428 -> V=1.0, theta=0.0
% INFO    : Bus 1890	: V=1.058933, theta=53.897537 -> V=1.0, theta=0.0
% INFO    : Bus 1891	: V=1.075445, theta=-16.830962 -> V=1.0279335, theta=0.0
% INFO    : Bus 1892	: V=0.993079, theta=-19.805792 -> V=1.0, theta=0.0
% INFO    : Bus 1893	: V=1.071557, theta=3.091619 -> V=1.0137945, theta=0.0
% INFO    : Bus 1894	: V=1.074334, theta=-0.914673 -> V=1.014663, theta=0.0
% INFO    : Bus 1895	: V=1.077614, theta=10.043754 -> V=1.0154965, theta=0.0
% INFO    : Bus 1896	: V=1.070572, theta=-13.939346 -> V=1.0190075, theta=0.0
% INFO    : Bus 1897	: V=1.051476, theta=-11.476172 -> V=1.0035065, theta=0.0
% INFO    : Bus 1898	: V=1.051695, theta=-7.495835 -> V=1.0103545, theta=0.0
% INFO    : Bus 1899	: V=1.027874, theta=-44.240637 -> V=1.0, theta=0.0
% INFO    : Bus 1900	: V=1.081319, theta=-17.542843 -> V=1.0230475, theta=0.0
% INFO    : Bus 1901	: V=1.057337, theta=19.943176 -> V=1.0, theta=0.0
% INFO    : Bus 1902	: V=1.081368, theta=1.008666 -> V=1.0162065, theta=0.0
% INFO    : Bus 1903	: V=1.053682, theta=-16.123186 -> V=1.008587, theta=0.0
% INFO    : Bus 1904	: V=1.055253, theta=-11.490549 -> V=1.0061385, theta=0.0
% INFO    : Bus 1905	: V=1.053687, theta=-24.606301 -> V=1.0142815, theta=0.0
% INFO    : Bus 1906	: V=1.083955, theta=-33.227563 -> V=1.0169525, theta=0.0
% INFO    : Bus 1907	: V=0.975669, theta=-17.901954 -> V=1.0, theta=0.0
% INFO    : Bus 1908	: V=1.058741, theta=-7.624336 -> V=1.006324, theta=0.0
% INFO    : Bus 1909	: V=0.967386, theta=43.102065 -> V=1.0, theta=0.0
% INFO    : Bus 1910	: V=1.041508, theta=-24.696325 -> V=1.0, theta=0.0
% INFO    : Bus 1911	: V=1.092184, theta=-41.851672 -> V=1.0155935, theta=0.0
% INFO    : Bus 1912	: V=1.051172, theta=-20.589914 -> V=1.0, theta=0.0
% INFO    : Bus 1913	: V=1.049526, theta=2.132312 -> V=1.0035805, theta=0.0
% INFO    : Bus 1914	: V=1.05982, theta=-24.885754 -> V=1.010844, theta=0.0
% INFO    : Bus 1915	: V=1.082446, theta=-39.609662 -> V=1.0263895, theta=0.0
% INFO    : Bus 1916	: V=1.078344, theta=-5.042039 -> V=1.018455, theta=0.0
% INFO    : Bus 1917	: V=1.015842, theta=29.767499 -> V=1.0, theta=0.0
% INFO    : Bus 1918	: V=1.054829, theta=-27.078703 -> V=1.008621, theta=0.0
% INFO    : Bus 1919	: V=1.081874, theta=67.200911 -> V=1.0, theta=0.0
% INFO    : Bus 1920	: V=0.965669, theta=-26.14323 -> V=1.0, theta=0.0
% INFO    : Bus 1921	: V=1.054316, theta=-0.111079 -> V=1.0099185, theta=0.0
% INFO    : Bus 1922	: V=1.055381, theta=-19.264026 -> V=1.0123355, theta=0.0
% INFO    : Bus 1923	: V=1.059489, theta=-40.863954 -> V=1.013374, theta=0.0
% INFO    : Bus 1924	: V=1.026031, theta=-11.849162 -> V=1.011837, theta=0.0
% INFO    : Bus 1925	: V=1.021709, theta=-15.170832 -> V=1.0, theta=0.0
% INFO    : Bus 1926	: V=1.011014, theta=7.733915 -> V=1.0, theta=0.0
% INFO    : Bus 1927	: V=1.095395, theta=-13.212546 -> V=1.035265, theta=0.0
% INFO    : Bus 1928	: V=0.955445, theta=-18.925975 -> V=1.0, theta=0.0
% INFO    : Bus 1929	: V=0.964327, theta=-19.364282 -> V=1.0, theta=0.0
% INFO    : Bus 1930	: V=1.019666, theta=-42.352732 -> V=1.0, theta=0.0
% INFO    : Bus 1931	: V=1.064571, theta=-2.422808 -> V=1.0212215, theta=0.0
% INFO    : Bus 1932	: V=0.978584, theta=-33.230311 -> V=1.0, theta=0.0
% INFO    : Bus 1933	: V=1.088007, theta=8.208129 -> V=1.0215425, theta=0.0
% INFO    : Bus 1934	: V=1.091714, theta=-24.951288 -> V=1.031829, theta=0.0
% INFO    : Bus 1935	: V=0.949197, theta=-28.666154 -> V=1.0, theta=0.0
% INFO    : Bus 1936	: V=1.02989, theta=63.604604 -> V=1.0, theta=0.0
% INFO    : Bus 1937	: V=1.026461, theta=-23.792213 -> V=1.0, theta=0.0
% INFO    : Bus 1938	: V=1.053932, theta=-47.973212 -> V=1.0028845, theta=0.0
% INFO    : Bus 1939	: V=1.024925, theta=-22.694434 -> V=1.0139135, theta=0.0
% INFO    : Bus 1940	: V=1.060279, theta=-22.031555 -> V=1.018924, theta=0.0
% INFO    : Bus 1941	: V=1.075123, theta=-7.795322 -> V=1.0160195, theta=0.0
% INFO    : Bus 1942	: V=1.028507, theta=-23.232421 -> V=1.0, theta=0.0
% INFO    : Bus 1943	: V=1.036962, theta=-21.794217 -> V=1.0067715, theta=0.0
% INFO    : Bus 1944	: V=1.077153, theta=-14.825353 -> V=1.0200265, theta=0.0
% INFO    : Bus 1945	: V=1.087274, theta=53.394472 -> V=1.0069765, theta=0.0
% INFO    : Bus 1946	: V=1.086926, theta=-2.729912 -> V=1.023347, theta=0.0
% INFO    : Bus 1947	: V=1.054626, theta=-27.011402 -> V=1.0086495, theta=0.0
% INFO    : Bus 1948	: V=1.049938, theta=-10.596635 -> V=1.00911, theta=0.0
% INFO    : Bus 1949	: V=1.042967, theta=-43.075987 -> V=1.0, theta=0.0
% INFO    : Bus 1950	: V=1.027755, theta=-48.342081 -> V=1.0, theta=0.0
% INFO    : Bus 1951	: V=1.091649, theta=-7.357152 -> V=1.030015, theta=0.0
% INFO    : Bus 1952	: V=1.008764, theta=-39.230306 -> V=1.0, theta=0.0
% INFO    : Bus 1953	: V=1.073646, theta=-19.168167 -> V=1.0051675, theta=0.0
% INFO    : Bus 1954	: V=1.025149, theta=-12.980709 -> V=1.0, theta=0.0
% INFO    : Bus 1955	: V=0.977577, theta=-28.892772 -> V=1.0, theta=0.0
% INFO    : Bus 1956	: V=1.03055, theta=-43.683953 -> V=1.0, theta=0.0
% INFO    : Bus 1957	: V=1.019284, theta=-23.467665 -> V=1.0, theta=0.0
% INFO    : Bus 1958	: V=0.90687, theta=-31.7183 -> V=1.0, theta=0.0
% INFO    : Bus 1959	: V=1.099815, theta=20.562167 -> V=1.0185205, theta=0.0
% INFO    : Bus 1960	: V=1.026756, theta=-18.838366 -> V=1.0038315, theta=0.0
% INFO    : Bus 1961	: V=1.043842, theta=2.775577 -> V=1.0, theta=0.0
% INFO    : Bus 1962	: V=1.062351, theta=9.000362 -> V=1.009069, theta=0.0
% INFO    : Bus 1963	: V=1.065503, theta=-6.84301 -> V=1.016563, theta=0.0
% INFO    : Bus 1964	: V=0.979887, theta=-8.445763 -> V=1.0, theta=0.0
% INFO    : Bus 1965	: V=1.065796, theta=4.098938 -> V=1.005898, theta=0.0
% INFO    : Bus 1966	: V=1.000644, theta=-20.374672 -> V=1.0, theta=0.0
% INFO    : Bus 1967	: V=0.914372, theta=-34.680605 -> V=0.9475, theta=0.0
% INFO    : Bus 1968	: V=1.056021, theta=-42.8691 -> V=1.011089, theta=0.0
% INFO    : Bus 1969	: V=1.041988, theta=-28.387202 -> V=1.0150665, theta=0.0
% INFO    : Bus 1970	: V=1.01964, theta=-16.293028 -> V=1.0, theta=0.0
% INFO    : Bus 1971	: V=1.034909, theta=-17.044746 -> V=1.0054185, theta=0.0
% INFO    : Bus 1972	: V=1.020632, theta=-23.361959 -> V=1.0, theta=0.0
% INFO    : Bus 1973	: V=1.066551, theta=-13.744298 -> V=1.0094015, theta=0.0
% INFO    : Bus 1974	: V=1.046818, theta=-20.97316 -> V=1.004236, theta=0.0
% INFO    : Bus 1975	: V=1.071915, theta=-12.868628 -> V=1.0229855, theta=0.0
% INFO    : Bus 1976	: V=1.073006, theta=-21.8543 -> V=1.0106705, theta=0.0
% INFO    : Bus 1977	: V=1.013955, theta=-23.461466 -> V=1.0, theta=0.0
% INFO    : Bus 1978	: V=1.051015, theta=-45.445346 -> V=1.0077555, theta=0.0
% INFO    : Bus 1979	: V=1.092258, theta=-25.682858 -> V=1.0214245, theta=0.0
% INFO    : Bus 1980	: V=1.069589, theta=-12.689404 -> V=1.0148195, theta=0.0
% INFO    : Bus 1981	: V=1.040114, theta=-18.636043 -> V=1.0, theta=0.0
% INFO    : Bus 1982	: V=1.066132, theta=29.576315 -> V=1.0124205, theta=0.0
% INFO    : Bus 1983	: V=1.038045, theta=-30.374923 -> V=1.0080375, theta=0.0
% INFO    : Bus 1984	: V=1.056201, theta=-26.969857 -> V=1.00994, theta=0.0
% INFO    : Bus 1985	: V=1.071295, theta=-18.022579 -> V=1.0, theta=0.0
% INFO    : Bus 1986	: V=1.063118, theta=-1.730318 -> V=1.0195115, theta=0.0
% INFO    : Bus 1987	: V=1.044827, theta=-15.453298 -> V=1.005255, theta=0.0
% INFO    : Bus 1988	: V=0.959599, theta=-25.439559 -> V=1.0, theta=0.0
% INFO    : Bus 1989	: V=1.076727, theta=-11.542915 -> V=1.0163985, theta=0.0
% INFO    : Bus 1990	: V=1.096947, theta=-14.681699 -> V=1.0259785, theta=0.0
% INFO    : Bus 1991	: V=1.084426, theta=-45.12964 -> V=1.024909, theta=0.0
% INFO    : Bus 1992	: V=1.076102, theta=-5.913744 -> V=1.017823, theta=0.0
% INFO    : Bus 1993	: V=1.088696, theta=21.614515 -> V=1.016542, theta=0.0
% INFO    : Bus 1994	: V=1.064925, theta=-23.116167 -> V=1.011172, theta=0.0
% INFO    : Bus 1995	: V=1.086015, theta=34.180815 -> V=1.0, theta=0.0
% INFO    : Bus 1996	: V=1.034636, theta=-43.122784 -> V=1.0, theta=0.0
% INFO    : Bus 1997	: V=1.02572, theta=-24.774376 -> V=1.0, theta=0.0
% INFO    : Bus 1998	: V=0.934652, theta=-28.440844 -> V=1.0, theta=0.0
% INFO    : Bus 1999	: V=1.04983, theta=40.168868 -> V=1.0, theta=0.0
% INFO    : Bus 2000	: V=1.080421, theta=-5.808673 -> V=1.0220855, theta=0.0
% INFO    : Bus 2001	: V=0.957152, theta=-26.880891 -> V=1.0, theta=0.0
% INFO    : Bus 2002	: V=1.0268, theta=-47.663661 -> V=1.0, theta=0.0
% INFO    : Bus 2003	: V=1.056425, theta=-25.124087 -> V=1.0066515, theta=0.0
% INFO    : Bus 2004	: V=0.940714, theta=-28.150605 -> V=1.0, theta=0.0
% INFO    : Bus 2005	: V=1.085579, theta=-45.023251 -> V=1.014502, theta=0.0
% INFO    : Bus 2006	: V=1.067753, theta=-19.463791 -> V=1.0074745, theta=0.0
% INFO    : Bus 2007	: V=1.058277, theta=-43.759067 -> V=1.013085, theta=0.0
% INFO    : Bus 2008	: V=1.000461, theta=-32.232981 -> V=1.0, theta=0.0
% INFO    : Bus 2009	: V=1.0354, theta=-30.485151 -> V=1.0, theta=0.0
% INFO    : Bus 2010	: V=0.996182, theta=-25.89864 -> V=1.0, theta=0.0
% INFO    : Bus 2011	: V=1.046244, theta=-13.088552 -> V=1.0159195, theta=0.0
% INFO    : Bus 2012	: V=0.949007, theta=-24.357908 -> V=1.0, theta=0.0
% INFO    : Bus 2013	: V=1.03844, theta=-29.258672 -> V=1.0, theta=0.0
% INFO    : Bus 2014	: V=0.938078, theta=-18.334591 -> V=1.0, theta=0.0
% INFO    : Bus 2015	: V=1.006136, theta=12.990225 -> V=1.0, theta=0.0
% INFO    : Bus 2016	: V=0.957679, theta=-25.680604 -> V=1.0, theta=0.0
% INFO    : Bus 2017	: V=0.979656, theta=61.937948 -> V=1.0, theta=0.0
% INFO    : Bus 2018	: V=1.080437, theta=8.707094 -> V=1.028871, theta=0.0
% INFO    : Bus 2019	: V=0.977956, theta=-26.817106 -> V=1.0, theta=0.0
% INFO    : Bus 2020	: V=0.986561, theta=-22.383793 -> V=1.0, theta=0.0
% INFO    : Bus 2021	: V=0.953886, theta=-32.191617 -> V=1.0, theta=0.0
% INFO    : Bus 2022	: V=1.053638, theta=-20.980592 -> V=1.007107, theta=0.0
% INFO    : Bus 2023	: V=0.971857, theta=-22.945461 -> V=1.0, theta=0.0
% INFO    : Bus 2024	: V=1.097593, theta=57.978487 -> V=1.028392, theta=0.0
% INFO    : Bus 2025	: V=1.046385, theta=1.114025 -> V=1.00638, theta=0.0
% INFO    : Bus 2026	: V=1.011746, theta=-47.239744 -> V=1.0, theta=0.0
% INFO    : Bus 2027	: V=1.077, theta=-40.082337 -> V=1.0114185, theta=0.0
% INFO    : Bus 2028	: V=1.083228, theta=-12.278916 -> V=1.0187795, theta=0.0
% INFO    : Bus 2029	: V=1.040584, theta=-29.176159 -> V=1.0, theta=0.0
% INFO    : Bus 2030	: V=1.040171, theta=17.504257 -> V=1.0029375, theta=0.0
% INFO    : Bus 2031	: V=1.01055, theta=-21.646935 -> V=1.0, theta=0.0
% INFO    : Bus 2032	: V=1.072702, theta=-21.341674 -> V=1.0277945, theta=0.0
% INFO    : Bus 2033	: V=1.080026, theta=1.169577 -> V=1.026387, theta=0.0
% INFO    : Bus 2034	: V=1.063378, theta=-31.383815 -> V=1.0132865, theta=0.0
% INFO    : Bus 2035	: V=1.027489, theta=-51.103445 -> V=1.0, theta=0.0
% INFO    : Bus 2036	: V=1.002881, theta=-23.202064 -> V=1.0, theta=0.0
% INFO    : Bus 2037	: V=1.061707, theta=-40.976934 -> V=1.0117905, theta=0.0
% INFO    : Bus 2038	: V=1.046182, theta=-37.986176 -> V=1.0, theta=0.0
% INFO    : Bus 2039	: V=1.067455, theta=60.879306 -> V=1.0065465, theta=0.0
% INFO    : Bus 2040	: V=0.976346, theta=-12.024133 -> V=1.0, theta=0.0
% INFO    : Bus 2041	: V=0.991489, theta=-18.913899 -> V=1.0, theta=0.0
% INFO    : Bus 2042	: V=1.051625, theta=2.689291 -> V=1.004566, theta=0.0
% INFO    : Bus 2043	: V=1.093887, theta=-17.969958 -> V=1.033474, theta=0.0
% INFO    : Bus 2044	: V=1.054298, theta=-15.936125 -> V=1.004893, theta=0.0
% INFO    : Bus 2045	: V=1.031969, theta=-10.73282 -> V=1.0, theta=0.0
% INFO    : Bus 2046	: V=0.979297, theta=63.077688 -> V=1.0, theta=0.0
% INFO    : Bus 2047	: V=1.034561, theta=-42.462607 -> V=1.0, theta=0.0
% INFO    : Bus 2048	: V=1.058269, theta=-20.827296 -> V=1.0311005, theta=0.0
% INFO    : Bus 2049	: V=0.994045, theta=-5.741575 -> V=1.0, theta=0.0
% INFO    : Bus 2050	: V=1.024626, theta=-20.379787 -> V=1.0, theta=0.0
% INFO    : Bus 2051	: V=1.03886, theta=-47.399903 -> V=1.035059, theta=0.0
% INFO    : Bus 2052	: V=1.079368, theta=-17.752186 -> V=1.033725, theta=0.0
% INFO    : Bus 2053	: V=0.998778, theta=-26.993978 -> V=1.0, theta=0.0
% INFO    : Bus 2054	: V=0.970382, theta=-17.400565 -> V=1.0, theta=0.0
% INFO    : Bus 2055	: V=1.044298, theta=-22.510885 -> V=1.0, theta=0.0
% INFO    : Bus 2056	: V=1.041035, theta=-11.394598 -> V=1.0, theta=0.0
% INFO    : Bus 2057	: V=0.959068, theta=-24.830209 -> V=1.0, theta=0.0
% INFO    : Bus 2058	: V=1.02696, theta=6.048213 -> V=1.0, theta=0.0
% INFO    : Bus 2059	: V=1.089597, theta=-36.552623 -> V=1.0173115, theta=0.0
% INFO    : Bus 2060	: V=0.992698, theta=-25.319579 -> V=1.0, theta=0.0
% INFO    : Bus 2061	: V=1.005897, theta=-18.266768 -> V=1.0, theta=0.0
% INFO    : Bus 2062	: V=1.073816, theta=1.973752 -> V=1.012217, theta=0.0
% INFO    : Bus 2063	: V=1.02407, theta=-5.509624 -> V=1.0, theta=0.0
% INFO    : Bus 2064	: V=1.044971, theta=-18.038581 -> V=1.0, theta=0.0
% INFO    : Bus 2065	: V=1.069085, theta=-14.55019 -> V=1.0105075, theta=0.0
% INFO    : Bus 2066	: V=1.062472, theta=9.523157 -> V=1.0, theta=0.0
% INFO    : Bus 2067	: V=1.087314, theta=-11.084706 -> V=1.015965, theta=0.0
% INFO    : Bus 2068	: V=1.076366, theta=-25.457525 -> V=1.033181, theta=0.0
% INFO    : Bus 2069	: V=0.968259, theta=-9.027976 -> V=1.0, theta=0.0
% INFO    : Bus 2070	: V=1.003708, theta=-19.881503 -> V=1.0, theta=0.0
% INFO    : Bus 2071	: V=1.078364, theta=-24.035135 -> V=1.0193865, theta=0.0
% INFO    : Bus 2072	: V=1.078029, theta=51.759076 -> V=1.009604, theta=0.0
% INFO    : Bus 2073	: V=0.98352, theta=-18.280498 -> V=1.0, theta=0.0
% INFO    : Bus 2074	: V=0.983143, theta=-21.252542 -> V=1.0, theta=0.0
% INFO    : Bus 2075	: V=0.989364, theta=-34.33832 -> V=1.0, theta=0.0
% INFO    : Bus 2076	: V=1.046997, theta=-19.231915 -> V=1.005595, theta=0.0
% INFO    : Bus 2077	: V=1.083909, theta=-9.304882 -> V=1.0141835, theta=0.0
% INFO    : Bus 2078	: V=1.071398, theta=63.309558 -> V=1.0, theta=0.0
% INFO    : Bus 2079	: V=1.063189, theta=-9.056401 -> V=1.015681, theta=0.0
% INFO    : Bus 2080	: V=1.077787, theta=-7.974825 -> V=1.021961, theta=0.0
% INFO    : Bus 2081	: V=1.080257, theta=-12.6298 -> V=1.015743, theta=0.0
% INFO    : Bus 2082	: V=1.078591, theta=-9.946636 -> V=1.0272455, theta=0.0
% INFO    : Bus 2083	: V=0.986518, theta=-23.775783 -> V=1.0, theta=0.0
% INFO    : Bus 2084	: V=1.010168, theta=-23.823969 -> V=1.0, theta=0.0
% INFO    : Bus 2085	: V=1.090114, theta=-12.470077 -> V=1.0174115, theta=0.0
% INFO    : Bus 2086	: V=0.980303, theta=-23.06167 -> V=1.0, theta=0.0
% INFO    : Bus 2087	: V=1.000053, theta=-40.154204 -> V=1.0, theta=0.0
% INFO    : Bus 2088	: V=1.050724, theta=-49.392903 -> V=1.0064155, theta=0.0
% INFO    : Bus 2089	: V=1.074377, theta=-11.652678 -> V=1.017081, theta=0.0
% INFO    : Bus 2090	: V=1.053657, theta=-20.14237 -> V=1.0050585, theta=0.0
% INFO    : Bus 2091	: V=1.05301, theta=-49.246877 -> V=1.005723, theta=0.0
% INFO    : Bus 2092	: V=1.025641, theta=-47.975712 -> V=1.0, theta=0.0
% INFO    : Bus 2093	: V=1.076191, theta=-14.977423 -> V=1.019097, theta=0.0
% INFO    : Bus 2094	: V=1.072575, theta=-25.115941 -> V=1.0318485, theta=0.0
% INFO    : Bus 2095	: V=1.069023, theta=-0.86792 -> V=1.0219745, theta=0.0
% INFO    : Bus 2096	: V=1.087726, theta=44.129511 -> V=1.0080075, theta=0.0
% INFO    : Bus 2097	: V=1.01152, theta=-29.161469 -> V=1.0, theta=0.0
% INFO    : Bus 2098	: V=1.07072, theta=-22.807456 -> V=1.0276915, theta=0.0
% INFO    : Bus 2099	: V=1.092555, theta=23.624753 -> V=1.015027, theta=0.0
% INFO    : Bus 2100	: V=1.040318, theta=-19.032253 -> V=1.0, theta=0.0
% INFO    : Bus 2101	: V=0.989029, theta=-25.087295 -> V=1.0, theta=0.0
% INFO    : Bus 2102	: V=1.017705, theta=-23.44175 -> V=1.0, theta=0.0
% INFO    : Bus 2103	: V=1.052938, theta=-20.339422 -> V=1.0111185, theta=0.0
% INFO    : Bus 2104	: V=1.044027, theta=-34.32269 -> V=1.003382, theta=0.0
% INFO    : Bus 2105	: V=1.056943, theta=-33.422296 -> V=1.009594, theta=0.0
% INFO    : Bus 2106	: V=1.048267, theta=-33.866552 -> V=1.0053265, theta=0.0
% INFO    : Bus 2107	: V=0.974048, theta=-27.37002 -> V=1.0, theta=0.0
% INFO    : Bus 2108	: V=1.062292, theta=-8.66485 -> V=1.0187745, theta=0.0
% INFO    : Bus 2109	: V=1.057636, theta=-42.134291 -> V=1.0055775, theta=0.0
% INFO    : Bus 2110	: V=0.9536, theta=-34.078413 -> V=1.0, theta=0.0
% INFO    : Bus 2111	: V=0.951192, theta=63.781 -> V=1.0, theta=0.0
% INFO    : Bus 2112	: V=1.015454, theta=-19.579353 -> V=1.0, theta=0.0
% INFO    : Bus 2113	: V=1.018623, theta=-35.267457 -> V=1.0, theta=0.0
% INFO    : Bus 2114	: V=1.057752, theta=-23.982239 -> V=1.016177, theta=0.0
% INFO    : Bus 2115	: V=1.062899, theta=-13.937862 -> V=1.01516, theta=0.0
% INFO    : Bus 2116	: V=1.052785, theta=10.506157 -> V=1.005782, theta=0.0
% INFO    : Bus 2117	: V=1.04909, theta=-0.355926 -> V=1.012, theta=0.0
% INFO    : Bus 2118	: V=1.045999, theta=14.03449 -> V=1.0112145, theta=0.0
% INFO    : Bus 2119	: V=1.057704, theta=-30.200666 -> V=1.0119505, theta=0.0
% INFO    : Bus 2120	: V=0.955566, theta=-25.634344 -> V=1.0, theta=0.0
% INFO    : Bus 2121	: V=1.065328, theta=-15.210557 -> V=1.011713, theta=0.0
% INFO    : Bus 2122	: V=1.086467, theta=5.012024 -> V=1.026795, theta=0.0
% INFO    : Bus 2123	: V=1.026124, theta=-29.245979 -> V=1.016174, theta=0.0
% INFO    : Bus 2124	: V=0.939317, theta=-28.219577 -> V=1.0, theta=0.0
% INFO    : Bus 2125	: V=1.028044, theta=-17.562426 -> V=1.0, theta=0.0
% INFO    : Bus 2126	: V=1.041598, theta=-12.350501 -> V=1.006564, theta=0.0
% INFO    : Bus 2127	: V=1.089761, theta=-25.250235 -> V=1.0411175, theta=0.0
% INFO    : Bus 2128	: V=1.095501, theta=56.949995 -> V=1.0076345, theta=0.0
% INFO    : Bus 2129	: V=1.054334, theta=-37.933355 -> V=1.0031195, theta=0.0
% INFO    : Bus 2130	: V=1.10272, theta=-17.259279 -> V=1.0380155, theta=0.0
% INFO    : Bus 2131	: V=0.993392, theta=-22.071097 -> V=1.0, theta=0.0
% INFO    : Bus 2132	: V=1.009679, theta=-22.254751 -> V=1.0, theta=0.0
% INFO    : Bus 2133	: V=0.899791, theta=-32.618439 -> V=0.9974545, theta=0.0
% INFO    : Bus 2134	: V=0.993519, theta=-21.944974 -> V=1.0, theta=0.0
% INFO    : Bus 2135	: V=1.039169, theta=14.18306 -> V=1.0, theta=0.0
% INFO    : Bus 2136	: V=1.008533, theta=62.437332 -> V=1.0, theta=0.0
% INFO    : Bus 2137	: V=0.938577, theta=-25.369756 -> V=1.0, theta=0.0
% INFO    : Bus 2138	: V=1.031963, theta=-24.998566 -> V=1.0, theta=0.0
% INFO    : Bus 2139	: V=1.055231, theta=-46.495758 -> V=1.0, theta=0.0
% INFO    : Bus 2140	: V=1.042876, theta=-23.441963 -> V=1.0, theta=0.0
% INFO    : Bus 2141	: V=1.053447, theta=-2.781342 -> V=1.0130875, theta=0.0
% INFO    : Bus 2142	: V=1.054552, theta=-49.268703 -> V=1.0062485, theta=0.0
% INFO    : Bus 2143	: V=1.076342, theta=-9.586923 -> V=1.019785, theta=0.0
% INFO    : Bus 2144	: V=1.02057, theta=-20.659148 -> V=1.015491, theta=0.0
% INFO    : Bus 2145	: V=1.054551, theta=-28.77905 -> V=1.0258915, theta=0.0
% INFO    : Bus 2146	: V=1.100553, theta=-13.119044 -> V=1.0269505, theta=0.0
% INFO    : Bus 2147	: V=1.018153, theta=-19.904768 -> V=1.0, theta=0.0
% INFO    : Bus 2148	: V=1.015472, theta=10.409059 -> V=1.0, theta=0.0
% INFO    : Bus 2149	: V=1.035189, theta=-21.383815 -> V=1.0215725, theta=0.0
% INFO    : Bus 2150	: V=1.026987, theta=-46.297924 -> V=1.0, theta=0.0
% INFO    : Bus 2151	: V=1.041498, theta=-21.661425 -> V=1.0, theta=0.0
% INFO    : Bus 2152	: V=1.096733, theta=-24.680638 -> V=1.0236425, theta=0.0
% INFO    : Bus 2153	: V=1.092955, theta=-13.002888 -> V=1.01734, theta=0.0
% INFO    : Bus 2154	: V=1.054499, theta=-40.556652 -> V=1.0066555, theta=0.0
% INFO    : Bus 2155	: V=1.038889, theta=-16.634555 -> V=1.0085855, theta=0.0
% INFO    : Bus 2156	: V=0.968059, theta=-24.775992 -> V=1.0, theta=0.0
% INFO    : Bus 2157	: V=0.972378, theta=-23.069382 -> V=1.0, theta=0.0
% INFO    : Bus 2158	: V=1.060449, theta=-14.254126 -> V=1.010469, theta=0.0
% INFO    : Bus 2159	: V=1.036006, theta=-18.6289 -> V=1.0, theta=0.0
% INFO    : Bus 2160	: V=1.042905, theta=-19.845059 -> V=1.0, theta=0.0
% INFO    : Bus 2161	: V=1.078039, theta=-26.418161 -> V=1.0163825, theta=0.0
% INFO    : Bus 2162	: V=1.080446, theta=3.749758 -> V=1.024573, theta=0.0
% INFO    : Bus 2163	: V=1.016684, theta=-26.907965 -> V=1.0, theta=0.0
% INFO    : Bus 2164	: V=1.073295, theta=-12.653118 -> V=1.014903, theta=0.0
% INFO    : Bus 2165	: V=1.073759, theta=-34.560246 -> V=1.0157615, theta=0.0
% INFO    : Bus 2166	: V=1.06667, theta=-7.830651 -> V=1.0153465, theta=0.0
% INFO    : Bus 2167	: V=1.060681, theta=-16.705205 -> V=1.0064635, theta=0.0
% INFO    : Bus 2168	: V=0.995346, theta=10.385073 -> V=1.0, theta=0.0
% INFO    : Bus 2169	: V=1.054119, theta=-36.431516 -> V=1.017761, theta=0.0
% INFO    : Bus 2170	: V=1.067505, theta=-26.004209 -> V=1.004454, theta=0.0
% INFO    : Bus 2171	: V=0.99091, theta=10.896018 -> V=1.0, theta=0.0
% INFO    : Bus 2172	: V=1.044929, theta=-22.909941 -> V=1.0, theta=0.0
% INFO    : Bus 2173	: V=1.046294, theta=-23.139248 -> V=1.0, theta=0.0
% INFO    : Bus 2174	: V=1.044754, theta=8.006832 -> V=1.0090615, theta=0.0
% INFO    : Bus 2175	: V=1.094947, theta=56.244595 -> V=1.0074715, theta=0.0
% INFO    : Bus 2176	: V=1.008125, theta=-46.806456 -> V=1.0, theta=0.0
% INFO    : Bus 2177	: V=1.03077, theta=-24.170177 -> V=1.0, theta=0.0
% INFO    : Bus 2178	: V=1.079237, theta=-17.780998 -> V=1.032994, theta=0.0
% INFO    : Bus 2179	: V=0.970908, theta=-27.421821 -> V=1.0, theta=0.0
% INFO    : Bus 2180	: V=0.981817, theta=-25.683243 -> V=1.0, theta=0.0
% INFO    : Bus 2181	: V=1.054682, theta=-14.495161 -> V=1.011072, theta=0.0
% INFO    : Bus 2182	: V=1.065728, theta=-43.361953 -> V=1.007941, theta=0.0
% INFO    : Bus 2183	: V=0.915008, theta=-31.362086 -> V=1.0, theta=0.0
% INFO    : Bus 2184	: V=1.059155, theta=-23.290164 -> V=1.0166615, theta=0.0
% INFO    : Bus 2185	: V=1.015477, theta=-35.606541 -> V=1.0, theta=0.0
% INFO    : Bus 2186	: V=1.043402, theta=11.109021 -> V=1.0, theta=0.0
% INFO    : Bus 2187	: V=1.046707, theta=-32.895073 -> V=1.002539, theta=0.0
% INFO    : Bus 2188	: V=0.985667, theta=62.461818 -> V=1.0, theta=0.0
% INFO    : Bus 2189	: V=1.060091, theta=-38.456982 -> V=1.0, theta=0.0
% INFO    : Bus 2190	: V=0.992136, theta=10.925026 -> V=1.0, theta=0.0
% INFO    : Bus 2191	: V=1.026886, theta=-21.611337 -> V=1.010135, theta=0.0
% INFO    : Bus 2192	: V=1.091958, theta=-44.836341 -> V=1.022115, theta=0.0
% INFO    : Bus 2193	: V=1.006357, theta=-14.652376 -> V=1.0, theta=0.0
% INFO    : Bus 2194	: V=1.070919, theta=29.222478 -> V=1.004154, theta=0.0
% INFO    : Bus 2195	: V=1.001136, theta=-9.854836 -> V=1.0, theta=0.0
% INFO    : Bus 2196	: V=1.061332, theta=-16.6139 -> V=1.012784, theta=0.0
% INFO    : Bus 2197	: V=1.076909, theta=-22.485013 -> V=1.031145, theta=0.0
% INFO    : Bus 2198	: V=0.976226, theta=-23.965635 -> V=1.0, theta=0.0
% INFO    : Bus 2199	: V=1.057714, theta=-44.216629 -> V=1.012853, theta=0.0
% INFO    : Bus 2200	: V=1.058363, theta=-21.414583 -> V=1.017819, theta=0.0
% INFO    : Bus 2201	: V=1.073773, theta=-9.652838 -> V=1.022266, theta=0.0
% INFO    : Bus 2202	: V=1.083545, theta=-12.439283 -> V=1.0188445, theta=0.0
% INFO    : Bus 2203	: V=1.08198, theta=-17.22128 -> V=1.026031, theta=0.0
% INFO    : Bus 2204	: V=1.071211, theta=0.340339 -> V=1.0177715, theta=0.0
% INFO    : Bus 2205	: V=1.047289, theta=13.686595 -> V=1.0043325, theta=0.0
% INFO    : Bus 2206	: V=1.072182, theta=-11.456445 -> V=1.017059, theta=0.0
% INFO    : Bus 2207	: V=1.026409, theta=-24.557145 -> V=1.0, theta=0.0
% INFO    : Bus 2208	: V=1.035083, theta=-32.148732 -> V=1.01717, theta=0.0
% INFO    : Bus 2209	: V=1.016587, theta=8.208956 -> V=1.0, theta=0.0
% INFO    : Bus 2210	: V=1.022213, theta=-21.234259 -> V=1.0, theta=0.0
% INFO    : Bus 2211	: V=1.080554, theta=-17.689079 -> V=1.0321595, theta=0.0
% INFO    : Bus 2212	: V=1.088162, theta=-37.799003 -> V=1.024408, theta=0.0
% INFO    : Bus 2213	: V=1.05291, theta=-20.339111 -> V=1.0111035, theta=0.0
% INFO    : Bus 2214	: V=1.042459, theta=24.753832 -> V=1.0, theta=0.0
% INFO    : Bus 2215	: V=1.031298, theta=4.49255 -> V=1.0, theta=0.0
% INFO    : Bus 2216	: V=1.020348, theta=-5.108166 -> V=1.0, theta=0.0
% INFO    : Bus 2217	: V=1.00834, theta=9.675065 -> V=1.0, theta=0.0
% INFO    : Bus 2218	: V=1.066908, theta=8.106528 -> V=1.013464, theta=0.0
% INFO    : Bus 2219	: V=1.028176, theta=-24.446012 -> V=1.0, theta=0.0
% INFO    : Bus 2220	: V=1.104211, theta=5.705528 -> V=1.0235775, theta=0.0
% INFO    : Bus 2221	: V=1.079137, theta=20.553752 -> V=1.031841, theta=0.0
% INFO    : Bus 2222	: V=1.088357, theta=-8.448565 -> V=1.021761, theta=0.0
% INFO    : Bus 2223	: V=1.06079, theta=-14.538737 -> V=1.0054725, theta=0.0
% INFO    : Bus 2224	: V=1.049729, theta=-1.189361 -> V=1.0106705, theta=0.0
% INFO    : Bus 2225	: V=0.988074, theta=-23.675673 -> V=1.0, theta=0.0
% INFO    : Bus 2226	: V=1.096173, theta=-17.274095 -> V=1.041034, theta=0.0
% INFO    : Bus 2227	: V=1.072019, theta=-23.402566 -> V=1.018291, theta=0.0
% INFO    : Bus 2228	: V=1.040296, theta=-12.941236 -> V=1.0113075, theta=0.0
% INFO    : Bus 2229	: V=1.091262, theta=-38.562846 -> V=1.0268355, theta=0.0
% INFO    : Bus 2230	: V=0.992364, theta=-35.832036 -> V=1.0, theta=0.0
% INFO    : Bus 2231	: V=1.061356, theta=-4.386181 -> V=1.018269, theta=0.0
% INFO    : Bus 2232	: V=1.013914, theta=-22.616618 -> V=1.0, theta=0.0
% INFO    : Bus 2233	: V=1.09269, theta=45.83635 -> V=1.0, theta=0.0
% INFO    : Bus 2234	: V=0.972971, theta=-28.821802 -> V=1.0, theta=0.0
% INFO    : Bus 2235	: V=1.048703, theta=1.983533 -> V=1.003184, theta=0.0
% INFO    : Bus 2236	: V=0.924151, theta=-28.491213 -> V=1.0, theta=0.0
% INFO    : Bus 2237	: V=1.067557, theta=-13.866047 -> V=1.0177775, theta=0.0
% INFO    : Bus 2238	: V=1.076591, theta=-5.851285 -> V=1.018037, theta=0.0
% INFO    : Bus 2239	: V=1.008359, theta=-23.241991 -> V=1.0, theta=0.0
% INFO    : Bus 2240	: V=1.056047, theta=-18.952426 -> V=1.0, theta=0.0
% INFO    : Bus 2241	: V=1.049813, theta=-43.07985 -> V=1.002626, theta=0.0
% INFO    : Bus 2242	: V=0.983459, theta=6.557129 -> V=1.0, theta=0.0
% INFO    : Bus 2243	: V=0.906226, theta=-31.809081 -> V=1.0, theta=0.0
% INFO    : Bus 2244	: V=1.017724, theta=-21.402252 -> V=1.0, theta=0.0
% INFO    : Bus 2245	: V=1.073321, theta=-7.553008 -> V=1.0217875, theta=0.0
% INFO    : Bus 2246	: V=0.987583, theta=-17.285401 -> V=1.0, theta=0.0
% INFO    : Bus 2247	: V=1.06807, theta=10.768466 -> V=1.023768, theta=0.0
% INFO    : Bus 2248	: V=1.081245, theta=-2.535791 -> V=1.01797, theta=0.0
% INFO    : Bus 2249	: V=1.006764, theta=-32.247252 -> V=1.0, theta=0.0
% INFO    : Bus 2250	: V=1.057, theta=-16.980392 -> V=1.0049, theta=0.0
% INFO    : Bus 2251	: V=1.060382, theta=7.031571 -> V=1.0060385, theta=0.0
% INFO    : Bus 2252	: V=1.054018, theta=-41.348618 -> V=1.006616, theta=0.0
% INFO    : Bus 2253	: V=1.027776, theta=12.426607 -> V=1.0, theta=0.0
% INFO    : Bus 2254	: V=1.07702, theta=-18.39735 -> V=1.0081205, theta=0.0
% INFO    : Bus 2255	: V=0.981983, theta=-21.613426 -> V=1.0, theta=0.0
% INFO    : Bus 2256	: V=1.08, theta=1.16987 -> V=1.026373, theta=0.0
% INFO    : Bus 2257	: V=0.971801, theta=-18.027773 -> V=1.0, theta=0.0
% INFO    : Bus 2258	: V=1.074673, theta=-9.407892 -> V=1.022064, theta=0.0
% INFO    : Bus 2259	: V=1.058132, theta=0.522482 -> V=1.0098615, theta=0.0
% INFO    : Bus 2260	: V=1.056936, theta=-21.92114 -> V=1.0, theta=0.0
% INFO    : Bus 2261	: V=1.056622, theta=-54.885101 -> V=1.0, theta=0.0
% INFO    : Bus 2262	: V=1.023141, theta=-51.331437 -> V=1.0, theta=0.0
% INFO    : Bus 2263	: V=1.074546, theta=-14.841909 -> V=1.010345, theta=0.0
% INFO    : Bus 2264	: V=1.090587, theta=-20.138786 -> V=1.036068, theta=0.0
% INFO    : Bus 2265	: V=1.091591, theta=-20.935857 -> V=1.0143565, theta=0.0
% INFO    : Bus 2266	: V=1.093457, theta=-33.851876 -> V=1.020514, theta=0.0
% INFO    : Bus 2267	: V=1.069577, theta=-20.208957 -> V=1.0259925, theta=0.0
% INFO    : Bus 2268	: V=1.045017, theta=-41.320233 -> V=1.0, theta=0.0
% INFO    : Bus 2269	: V=0.930409, theta=-30.781398 -> V=1.0, theta=0.0
% INFO    : Bus 2270	: V=0.969104, theta=-17.853133 -> V=1.0, theta=0.0
% INFO    : Bus 2271	: V=1.103085, theta=-37.690579 -> V=1.02518, theta=0.0
% INFO    : Bus 2272	: V=1.081045, theta=-12.556413 -> V=1.009634, theta=0.0
% INFO    : Bus 2273	: V=1.092711, theta=-11.685387 -> V=1.024494, theta=0.0
% INFO    : Bus 2274	: V=1.071675, theta=17.273174 -> V=1.020572, theta=0.0
% INFO    : Bus 2275	: V=1.091875, theta=-30.038378 -> V=1.0317805, theta=0.0
% INFO    : Bus 2276	: V=1.088424, theta=36.303029 -> V=1.014847, theta=0.0
% INFO    : Bus 2277	: V=0.981636, theta=-21.690715 -> V=1.0, theta=0.0
% INFO    : Bus 2278	: V=1.062392, theta=-11.155914 -> V=1.0122, theta=0.0
% INFO    : Bus 2279	: V=1.022273, theta=-38.662487 -> V=1.0, theta=0.0
% INFO    : Bus 2280	: V=1.062122, theta=-10.748993 -> V=1.011648, theta=0.0
% INFO    : Bus 2281	: V=0.997533, theta=66.207202 -> V=1.0, theta=0.0
% INFO    : Bus 2282	: V=1.02642, theta=-5.405739 -> V=1.0, theta=0.0
% INFO    : Bus 2283	: V=1.07116, theta=-16.894665 -> V=1.0081895, theta=0.0
% INFO    : Bus 2284	: V=1.078703, theta=20.439743 -> V=1.030573, theta=0.0
% INFO    : Bus 2285	: V=1.051659, theta=-21.501573 -> V=1.0, theta=0.0
% INFO    : Bus 2286	: V=1.040521, theta=-19.190396 -> V=1.0250505, theta=0.0
% INFO    : Bus 2287	: V=1.074655, theta=-4.617535 -> V=1.014143, theta=0.0
% INFO    : Bus 2288	: V=1.054099, theta=-15.821508 -> V=1.004802, theta=0.0
% INFO    : Bus 2289	: V=0.985991, theta=-23.580828 -> V=1.0, theta=0.0
% INFO    : Bus 2290	: V=1.014477, theta=-28.194121 -> V=1.0, theta=0.0
% INFO    : Bus 2291	: V=0.991598, theta=-18.795605 -> V=1.0, theta=0.0
% INFO    : Bus 2292	: V=1.07955, theta=46.363175 -> V=1.0, theta=0.0
% INFO    : Bus 2293	: V=1.060318, theta=-17.527667 -> V=1.0135395, theta=0.0
% INFO    : Bus 2294	: V=1.081562, theta=-3.877074 -> V=1.0212955, theta=0.0
% INFO    : Bus 2295	: V=0.966203, theta=-24.767487 -> V=1.0, theta=0.0
% INFO    : Bus 2296	: V=1.011593, theta=-22.564707 -> V=1.0, theta=0.0
% INFO    : Bus 2297	: V=1.021201, theta=-39.923649 -> V=1.0, theta=0.0
% INFO    : Bus 2298	: V=0.994318, theta=-5.766864 -> V=1.0, theta=0.0
% INFO    : Bus 2299	: V=1.035779, theta=-30.835079 -> V=1.0, theta=0.0
% INFO    : Bus 2300	: V=1.050067, theta=-14.969538 -> V=1.0, theta=0.0
% INFO    : Bus 2301	: V=1.020342, theta=-23.553817 -> V=1.0, theta=0.0
% INFO    : Bus 2302	: V=1.006474, theta=-33.97354 -> V=1.0, theta=0.0
% INFO    : Bus 2303	: V=1.06761, theta=62.066032 -> V=1.0, theta=0.0
% INFO    : Bus 2304	: V=1.063756, theta=19.876535 -> V=1.013439, theta=0.0
% INFO    : Bus 2305	: V=1.020065, theta=-19.450214 -> V=1.0, theta=0.0
% INFO    : Bus 2306	: V=1.040517, theta=-29.17268 -> V=1.0, theta=0.0
% INFO    : Bus 2307	: V=1.086074, theta=-4.406955 -> V=1.0199705, theta=0.0
% INFO    : Bus 2308	: V=1.078227, theta=-6.3027 -> V=1.0183865, theta=0.0
% INFO    : Bus 2309	: V=1.056093, theta=-55.236043 -> V=1.0, theta=0.0
% INFO    : Bus 2310	: V=1.078237, theta=3.509968 -> V=1.0231825, theta=0.0
% INFO    : Bus 2311	: V=1.09233, theta=14.73935 -> V=1.03578, theta=0.0
% INFO    : Bus 2312	: V=0.901131, theta=-33.225217 -> V=1.0, theta=0.0
% INFO    : Bus 2313	: V=1.077179, theta=9.472667 -> V=1.023059, theta=0.0
% INFO    : Bus 2314	: V=1.090785, theta=-17.620574 -> V=1.01404, theta=0.0
% INFO    : Bus 2315	: V=1.036883, theta=-11.870091 -> V=1.0, theta=0.0
% INFO    : Bus 2316	: V=1.059808, theta=-16.263455 -> V=1.0166905, theta=0.0
% INFO    : Bus 2317	: V=1.031301, theta=-20.04868 -> V=1.0, theta=0.0
% INFO    : Bus 2318	: V=0.958173, theta=-20.304896 -> V=1.0, theta=0.0
% INFO    : Bus 2319	: V=1.02276, theta=-23.603719 -> V=1.0114675, theta=0.0
% INFO    : Bus 2320	: V=1.038682, theta=-47.107197 -> V=1.0, theta=0.0
% INFO    : Bus 2321	: V=1.081181, theta=-4.685517 -> V=1.0176135, theta=0.0
% INFO    : Bus 2322	: V=1.056555, theta=-48.655971 -> V=1.007252, theta=0.0
% INFO    : Bus 2323	: V=0.971763, theta=-10.064971 -> V=1.0, theta=0.0
% INFO    : Bus 2324	: V=1.074045, theta=-40.819919 -> V=1.0212095, theta=0.0
% INFO    : Bus 2325	: V=0.999011, theta=-23.600239 -> V=1.0, theta=0.0
% INFO    : Bus 2326	: V=0.968364, theta=-25.426775 -> V=1.0, theta=0.0
% INFO    : Bus 2327	: V=1.055933, theta=62.747132 -> V=1.0, theta=0.0
% INFO    : Bus 2328	: V=1.069898, theta=-39.485725 -> V=1.014444, theta=0.0
% INFO    : Bus 2329	: V=1.014355, theta=-21.995068 -> V=1.0, theta=0.0
% INFO    : Bus 2330	: V=1.098133, theta=15.030212 -> V=1.018689, theta=0.0
% INFO    : Bus 2331	: V=1.015822, theta=-2.555921 -> V=1.003067, theta=0.0
% INFO    : Bus 2332	: V=1.012744, theta=-47.53743 -> V=1.0, theta=0.0
% INFO    : Bus 2333	: V=1.080736, theta=-3.707203 -> V=1.017118, theta=0.0
% INFO    : Bus 2334	: V=1.044648, theta=-22.312796 -> V=1.0, theta=0.0
% INFO    : Bus 2335	: V=1.068228, theta=-32.197744 -> V=1.014499, theta=0.0
% INFO    : Bus 2336	: V=1.013944, theta=-47.414081 -> V=1.0, theta=0.0
% INFO    : Bus 2337	: V=1.074097, theta=-27.071588 -> V=1.019807, theta=0.0
% INFO    : Bus 2338	: V=0.957306, theta=-29.199935 -> V=0.996347, theta=0.0
% INFO    : Bus 2339	: V=0.977884, theta=-25.293762 -> V=1.0, theta=0.0
% INFO    : Bus 2340	: V=1.050851, theta=-18.185736 -> V=1.0164805, theta=0.0
% INFO    : Bus 2341	: V=1.04901, theta=-13.111468 -> V=1.008783, theta=0.0
% INFO    : Bus 2342	: V=1.082732, theta=-22.618066 -> V=1.02574, theta=0.0
% INFO    : Bus 2343	: V=1.067206, theta=-14.596449 -> V=1.009601, theta=0.0
% INFO    : Bus 2344	: V=1.032594, theta=-25.572664 -> V=1.0, theta=0.0
% INFO    : Bus 2345	: V=1.027061, theta=-13.176669 -> V=1.0, theta=0.0
% INFO    : Bus 2346	: V=1.055579, theta=-14.053673 -> V=1.0119805, theta=0.0
% INFO    : Bus 2347	: V=1.018458, theta=4.127009 -> V=1.0, theta=0.0
% INFO    : Bus 2348	: V=1.063811, theta=-15.015251 -> V=1.018247, theta=0.0
% INFO    : Bus 2349	: V=0.976584, theta=-20.308463 -> V=1.0, theta=0.0
% INFO    : Bus 2350	: V=1.042248, theta=-20.373521 -> V=1.0, theta=0.0
% INFO    : Bus 2351	: V=1.096818, theta=-26.364211 -> V=1.027857, theta=0.0
% INFO    : Bus 2352	: V=1.048921, theta=14.430459 -> V=1.006622, theta=0.0
% INFO    : Bus 2353	: V=1.044172, theta=-20.625952 -> V=1.0, theta=0.0
% INFO    : Bus 2354	: V=1.073925, theta=-10.106196 -> V=1.022187, theta=0.0
% INFO    : Bus 2355	: V=1.072909, theta=-14.34941 -> V=1.0181075, theta=0.0
% INFO    : Bus 2356	: V=1.084818, theta=-12.332319 -> V=1.019412, theta=0.0
% INFO    : Bus 2357	: V=0.970522, theta=-33.469219 -> V=1.0, theta=0.0
% INFO    : Bus 2358	: V=1.051537, theta=-21.258241 -> V=1.0061515, theta=0.0
% INFO    : Bus 2359	: V=1.027092, theta=-27.308585 -> V=1.0, theta=0.0
% INFO    : Bus 2360	: V=0.978909, theta=14.712342 -> V=1.0, theta=0.0
% INFO    : Bus 2361	: V=1.081696, theta=-9.262047 -> V=1.01703, theta=0.0
% INFO    : Bus 2362	: V=1.035727, theta=13.320365 -> V=1.0, theta=0.0
% INFO    : Bus 2363	: V=1.098549, theta=-17.869836 -> V=1.022384, theta=0.0
% INFO    : Bus 2364	: V=0.961377, theta=20.810354 -> V=1.0, theta=0.0
% INFO    : Bus 2365	: V=0.955456, theta=-24.186037 -> V=1.0, theta=0.0
% INFO    : Bus 2366	: V=1.015288, theta=10.043328 -> V=1.0, theta=0.0
% INFO    : Bus 2367	: V=1.066435, theta=-14.560224 -> V=1.008929, theta=0.0
% INFO    : Bus 2368	: V=1.030682, theta=-25.99429 -> V=1.0298555, theta=0.0
% INFO    : Bus 2369	: V=0.973725, theta=-33.01629 -> V=1.0, theta=0.0
% INFO    : Bus 2370	: V=1.028285, theta=-6.864028 -> V=1.0, theta=0.0
% INFO    : Bus 2371	: V=1.049288, theta=-42.336723 -> V=1.0041535, theta=0.0
% INFO    : Bus 2372	: V=1.081445, theta=3.955879 -> V=1.0247405, theta=0.0
% INFO    : Bus 2373	: V=1.023768, theta=-23.061171 -> V=1.0, theta=0.0
% INFO    : Bus 2374	: V=1.054723, theta=4.976814 -> V=1.004592, theta=0.0
% INFO    : Bus 2375	: V=1.031455, theta=-26.976837 -> V=1.0, theta=0.0
% INFO    : Bus 2376	: V=1.086761, theta=-45.147293 -> V=1.021427, theta=0.0
% INFO    : Bus 2377	: V=1.084136, theta=-22.4956 -> V=1.0113485, theta=0.0
% INFO    : Bus 2378	: V=1.007946, theta=-29.499638 -> V=1.0, theta=0.0
% INFO    : Bus 2379	: V=1.024131, theta=-16.146729 -> V=1.010971, theta=0.0
% INFO    : Bus 2380	: V=1.103421, theta=5.677433 -> V=1.0235025, theta=0.0
% INFO    : Bus 2381	: V=0.992518, theta=-25.013232 -> V=1.0, theta=0.0
% INFO    : Bus 2382	: V=1.055989, theta=-23.352663 -> V=1.0150825, theta=0.0
% INFO    : Bus 2383	: V=1.059152, theta=-11.813021 -> V=1.0130055, theta=0.0
% INFO    : Bus 2384	: V=0.991371, theta=37.899365 -> V=1.0, theta=0.0
% INFO    : Bus 2385	: V=1.071091, theta=-8.839585 -> V=1.0166735, theta=0.0
% INFO    : Bus 2386	: V=0.99888, theta=-19.443847 -> V=1.0, theta=0.0
% INFO    : Bus 2387	: V=1.051905, theta=-35.442194 -> V=1.0088205, theta=0.0
% INFO    : Bus 2388	: V=0.937534, theta=-33.294541 -> V=0.9608305, theta=0.0
% INFO    : Bus 2389	: V=1.01153, theta=-45.80468 -> V=1.0, theta=0.0
% INFO    : Bus 2390	: V=1.005288, theta=-35.676965 -> V=1.0, theta=0.0
% INFO    : Bus 2391	: V=0.934116, theta=-27.941655 -> V=1.0, theta=0.0
% INFO    : Bus 2392	: V=1.026373, theta=-22.118533 -> V=1.0, theta=0.0
% INFO    : Bus 2393	: V=1.04862, theta=-11.454829 -> V=1.0092795, theta=0.0
% INFO    : Bus 2394	: V=1.079184, theta=-33.296642 -> V=1.0156195, theta=0.0
% INFO    : Bus 2395	: V=0.995621, theta=-26.339422 -> V=1.0, theta=0.0
% INFO    : Bus 2396	: V=1.075653, theta=-23.932013 -> V=1.031949, theta=0.0
% INFO    : Bus 2397	: V=1.005622, theta=-21.842862 -> V=1.0, theta=0.0
% INFO    : Bus 2398	: V=1.097822, theta=-10.109143 -> V=1.021716, theta=0.0
% INFO    : Bus 2399	: V=1.03006, theta=3.943332 -> V=1.0, theta=0.0
% INFO    : Bus 2400	: V=1.069955, theta=8.085073 -> V=1.0197025, theta=0.0
% INFO    : Bus 2401	: V=1.099211, theta=-31.349972 -> V=1.022912, theta=0.0
% INFO    : Bus 2402	: V=1.078591, theta=-35.269155 -> V=1.0287755, theta=0.0
% INFO    : Bus 2403	: V=0.986958, theta=-23.357532 -> V=1.0, theta=0.0
% INFO    : Bus 2404	: V=1.032502, theta=-25.294349 -> V=1.0, theta=0.0
% INFO    : Bus 2405	: V=1.060818, theta=-21.979124 -> V=1.019169, theta=0.0
% INFO    : Bus 2406	: V=1.054649, theta=-17.597823 -> V=1.0096605, theta=0.0
% INFO    : Bus 2407	: V=0.995482, theta=10.384398 -> V=1.0, theta=0.0
% INFO    : Bus 2408	: V=1.051348, theta=-23.740727 -> V=1.0110145, theta=0.0
% INFO    : Bus 2409	: V=0.999561, theta=54.111164 -> V=1.0, theta=0.0
% INFO    : Bus 2410	: V=1.048773, theta=-44.801132 -> V=1.0042245, theta=0.0
% INFO    : Bus 2411	: V=1.032533, theta=-28.038967 -> V=1.0, theta=0.0
% INFO    : Bus 2412	: V=1.024125, theta=-25.664124 -> V=1.0, theta=0.0
% INFO    : Bus 2413	: V=1.041933, theta=60.744998 -> V=1.0, theta=0.0
% INFO    : Bus 2414	: V=1.044496, theta=-21.184983 -> V=1.0, theta=0.0
% INFO    : Bus 2415	: V=1.0764, theta=-17.693338 -> V=1.0, theta=0.0
% INFO    : Bus 2416	: V=1.000498, theta=11.102933 -> V=1.0, theta=0.0
% INFO    : Bus 2417	: V=1.057501, theta=-48.543217 -> V=1.0074735, theta=0.0
% INFO    : Bus 2418	: V=1.017585, theta=-40.196255 -> V=1.0, theta=0.0
% INFO    : Bus 2419	: V=1.030445, theta=-46.540949 -> V=1.0, theta=0.0
% INFO    : Bus 2420	: V=1.010346, theta=-38.793036 -> V=1.0, theta=0.0
% INFO    : Bus 2421	: V=1.005682, theta=-29.681714 -> V=1.0, theta=0.0
% INFO    : Bus 2422	: V=1.028639, theta=-20.274014 -> V=1.0, theta=0.0
% INFO    : Bus 2423	: V=0.932986, theta=-35.426189 -> V=1.0, theta=0.0
% INFO    : Bus 2424	: V=1.030726, theta=-24.276189 -> V=1.0, theta=0.0
% INFO    : Bus 2425	: V=1.062587, theta=-39.952465 -> V=1.0157195, theta=0.0
% INFO    : Bus 2426	: V=1.077784, theta=-14.304801 -> V=1.0233405, theta=0.0
% INFO    : Bus 2427	: V=1.019993, theta=-15.020372 -> V=1.004153, theta=0.0
% INFO    : Bus 2428	: V=1.061033, theta=-20.537394 -> V=1.0105845, theta=0.0
% INFO    : Bus 2429	: V=1.04124, theta=-17.703726 -> V=1.012706, theta=0.0
% INFO    : Bus 2430	: V=1.079494, theta=-35.172571 -> V=1.027348, theta=0.0
% INFO    : Bus 2431	: V=1.084389, theta=39.260819 -> V=1.0, theta=0.0
% INFO    : Bus 2432	: V=1.030342, theta=-27.363915 -> V=1.0, theta=0.0
% INFO    : Bus 2433	: V=1.049205, theta=-35.250303 -> V=1.0067445, theta=0.0
% INFO    : Bus 2434	: V=1.022955, theta=-42.119894 -> V=1.0, theta=0.0
% INFO    : Bus 2435	: V=1.060818, theta=-38.492625 -> V=1.0, theta=0.0
% INFO    : Bus 2436	: V=0.973835, theta=-27.369538 -> V=1.0, theta=0.0
% INFO    : Bus 2437	: V=0.9393, theta=-29.246523 -> V=0.995313, theta=0.0
% INFO    : Bus 2438	: V=1.078199, theta=-4.168971 -> V=1.019717, theta=0.0
% INFO    : Bus 2439	: V=1.070077, theta=-18.776249 -> V=1.0, theta=0.0
% INFO    : Bus 2440	: V=1.002973, theta=-23.335056 -> V=1.0, theta=0.0
% INFO    : Bus 2441	: V=1.028894, theta=-49.623367 -> V=1.0, theta=0.0
% INFO    : Bus 2442	: V=1.057948, theta=-43.217344 -> V=1.0137315, theta=0.0
% INFO    : Bus 2443	: V=1.07857, theta=-19.996963 -> V=1.020731, theta=0.0
% INFO    : Bus 2444	: V=0.998154, theta=-23.43324 -> V=1.0, theta=0.0
% INFO    : Bus 2445	: V=0.958441, theta=-25.538445 -> V=1.0, theta=0.0
% INFO    : Bus 2446	: V=1.054888, theta=20.017056 -> V=1.0055675, theta=0.0
% INFO    : Bus 2447	: V=1.03943, theta=-29.43462 -> V=1.0, theta=0.0
% INFO    : Bus 2448	: V=1.070988, theta=-35.466171 -> V=1.0108635, theta=0.0
% INFO    : Bus 2449	: V=1.036914, theta=-29.382505 -> V=1.0, theta=0.0
% INFO    : Bus 2450	: V=1.053711, theta=-24.448086 -> V=1.0141595, theta=0.0
% INFO    : Bus 2451	: V=1.083674, theta=7.639697 -> V=1.019118, theta=0.0
% INFO    : Bus 2452	: V=0.934839, theta=-34.45066 -> V=1.0, theta=0.0
% INFO    : Bus 2453	: V=1.012363, theta=10.759849 -> V=1.0, theta=0.0
% INFO    : Bus 2454	: V=1.014396, theta=-14.609682 -> V=1.0, theta=0.0
% INFO    : Bus 2455	: V=1.080538, theta=-14.284529 -> V=1.021008, theta=0.0
% INFO    : Bus 2456	: V=1.062791, theta=-1.720063 -> V=1.0193525, theta=0.0
% INFO    : Bus 2457	: V=1.056412, theta=-44.268937 -> V=1.012513, theta=0.0
% INFO    : Bus 2458	: V=1.064579, theta=-31.085511 -> V=1.012516, theta=0.0
% INFO    : Bus 2459	: V=1.014512, theta=7.65489 -> V=1.0, theta=0.0
% INFO    : Bus 2460	: V=0.983202, theta=-15.359246 -> V=1.0, theta=0.0
% INFO    : Bus 2461	: V=1.03829, theta=-21.045165 -> V=1.0, theta=0.0
% INFO    : Bus 2462	: V=1.074796, theta=-15.265311 -> V=1.009648, theta=0.0
% INFO    : Bus 2463	: V=1.061363, theta=-21.532162 -> V=1.007384, theta=0.0
% INFO    : Bus 2464	: V=0.999225, theta=-18.929738 -> V=1.0, theta=0.0
% INFO    : Bus 2465	: V=1.073773, theta=-13.96315 -> V=1.014836, theta=0.0
% INFO    : Bus 2466	: V=1.048128, theta=15.41589 -> V=1.0, theta=0.0
% INFO    : Bus 2467	: V=0.988355, theta=-22.293577 -> V=1.0, theta=0.0
% INFO    : Bus 2468	: V=1.044563, theta=7.422561 -> V=1.0, theta=0.0
% INFO    : Bus 2469	: V=0.973274, theta=-9.656202 -> V=1.0, theta=0.0
% INFO    : Bus 2470	: V=1.063721, theta=9.7985 -> V=1.011635, theta=0.0
% INFO    : Bus 2471	: V=1.0334, theta=-25.161622 -> V=1.0, theta=0.0
% INFO    : Bus 2472	: V=1.038064, theta=17.870194 -> V=1.0, theta=0.0
% INFO    : Bus 2473	: V=0.984835, theta=-17.034133 -> V=1.0, theta=0.0
% INFO    : Bus 2474	: V=1.07923, theta=20.516073 -> V=1.0317795, theta=0.0
% INFO    : Bus 2475	: V=1.030636, theta=-25.767285 -> V=1.0, theta=0.0
% INFO    : Bus 2476	: V=1.085634, theta=-39.733214 -> V=1.02446, theta=0.0
% INFO    : Bus 2477	: V=0.922727, theta=-31.153799 -> V=1.0, theta=0.0
% INFO    : Bus 2478	: V=1.073441, theta=-9.88268 -> V=1.0142425, theta=0.0
% INFO    : Bus 2479	: V=0.991722, theta=-13.904976 -> V=1.0, theta=0.0
% INFO    : Bus 2480	: V=1.028122, theta=-43.707214 -> V=1.0, theta=0.0
% INFO    : Bus 2481	: V=1.017318, theta=49.59778 -> V=1.0, theta=0.0
% INFO    : Bus 2482	: V=1.07018, theta=-18.694932 -> V=1.0294585, theta=0.0
% INFO    : Bus 2483	: V=1.004579, theta=-29.362917 -> V=1.0, theta=0.0
% INFO    : Bus 2484	: V=0.98674, theta=-25.519193 -> V=1.0, theta=0.0
% INFO    : Bus 2485	: V=1.050786, theta=-49.373617 -> V=1.0064445, theta=0.0
% INFO    : Bus 2486	: V=1.047017, theta=-21.576427 -> V=1.003464, theta=0.0
% INFO    : Bus 2487	: V=1.054136, theta=55.115493 -> V=1.0, theta=0.0
% INFO    : Bus 2488	: V=0.996493, theta=-18.314691 -> V=1.0, theta=0.0
% INFO    : Bus 2489	: V=1.075843, theta=-1.946106 -> V=1.022638, theta=0.0
% INFO    : Bus 2490	: V=1.019444, theta=-21.678873 -> V=1.0, theta=0.0
% INFO    : Bus 2491	: V=1.072296, theta=-2.374486 -> V=1.0211205, theta=0.0
% INFO    : Bus 2492	: V=1.04932, theta=-29.774715 -> V=1.0216775, theta=0.0
% INFO    : Bus 2493	: V=1.048493, theta=-20.963168 -> V=1.0091145, theta=0.0
% INFO    : Bus 2494	: V=0.952126, theta=-24.333039 -> V=1.0, theta=0.0
% INFO    : Bus 2495	: V=1.006417, theta=-25.965277 -> V=1.0, theta=0.0
% INFO    : Bus 2496	: V=1.058723, theta=-12.614185 -> V=1.0066635, theta=0.0
% INFO    : Bus 2497	: V=1.036077, theta=-0.498321 -> V=1.0026125, theta=0.0
% INFO    : Bus 2498	: V=1.053704, theta=-17.305692 -> V=1.0126465, theta=0.0
% INFO    : Bus 2499	: V=1.042863, theta=-23.437738 -> V=1.0, theta=0.0
% INFO    : Bus 2500	: V=1.081947, theta=14.796398 -> V=1.0270475, theta=0.0
% INFO    : Bus 2501	: V=1.084921, theta=-3.18017 -> V=1.022308, theta=0.0
% INFO    : Bus 2502	: V=1.070369, theta=3.43959 -> V=1.020357, theta=0.0
% INFO    : Bus 2503	: V=1.018031, theta=-28.467367 -> V=1.0, theta=0.0
% INFO    : Bus 2504	: V=1.015778, theta=-22.991165 -> V=1.007743, theta=0.0
% INFO    : Bus 2505	: V=1.088579, theta=-44.700546 -> V=1.022131, theta=0.0
% INFO    : Bus 2506	: V=1.064189, theta=-35.188938 -> V=1.0129005, theta=0.0
% INFO    : Bus 2507	: V=0.985628, theta=-25.185929 -> V=1.0, theta=0.0
% INFO    : Bus 2508	: V=1.078971, theta=20.270825 -> V=1.028636, theta=0.0
% INFO    : Bus 2509	: V=1.050609, theta=-9.704287 -> V=1.010859, theta=0.0
% INFO    : Bus 2510	: V=1.056239, theta=6.801808 -> V=1.0135365, theta=0.0
% INFO    : Bus 2511	: V=1.090409, theta=-27.837881 -> V=1.0184165, theta=0.0
% INFO    : Bus 2512	: V=0.976393, theta=-12.024571 -> V=1.0, theta=0.0
% INFO    : Bus 2513	: V=0.996092, theta=-22.684788 -> V=1.0, theta=0.0
% INFO    : Bus 2514	: V=1.03873, theta=-20.402988 -> V=1.0, theta=0.0
% INFO    : Bus 2515	: V=1.066954, theta=-13.302516 -> V=1.0158125, theta=0.0
% INFO    : Bus 2516	: V=0.97218, theta=-24.849475 -> V=1.0, theta=0.0
% INFO    : Bus 2517	: V=1.006595, theta=-25.950033 -> V=1.0, theta=0.0
% INFO    : Bus 2518	: V=0.95906, theta=-23.453285 -> V=1.0, theta=0.0
% INFO    : Bus 2519	: V=1.051746, theta=-21.251126 -> V=1.0, theta=0.0
% INFO    : Bus 2520	: V=1.095266, theta=-11.350467 -> V=1.035028, theta=0.0
% INFO    : Bus 2521	: V=1.029944, theta=-24.359302 -> V=1.0, theta=0.0
% INFO    : Bus 2522	: V=0.994193, theta=11.442067 -> V=1.0, theta=0.0
% INFO    : Bus 2523	: V=1.03695, theta=-45.25056 -> V=1.0, theta=0.0
% INFO    : Bus 2524	: V=1.102737, theta=5.853766 -> V=1.020322, theta=0.0
% INFO    : Bus 2525	: V=1.005479, theta=10.823786 -> V=1.0, theta=0.0
% INFO    : Bus 2526	: V=0.964005, theta=21.394699 -> V=1.0, theta=0.0
% INFO    : Bus 2527	: V=0.998351, theta=-27.112844 -> V=1.0, theta=0.0
% INFO    : Bus 2528	: V=1.029141, theta=-16.062744 -> V=1.017415, theta=0.0
% INFO    : Bus 2529	: V=0.948498, theta=-24.196018 -> V=1.0, theta=0.0
% INFO    : Bus 2530	: V=1.081324, theta=-17.542881 -> V=1.0230505, theta=0.0
% INFO    : Bus 2531	: V=1.047876, theta=-31.946451 -> V=1.0272215, theta=0.0
% INFO    : Bus 2532	: V=1.083134, theta=7.604784 -> V=1.0188245, theta=0.0
% INFO    : Bus 2533	: V=1.078545, theta=-4.14217 -> V=1.0218645, theta=0.0
% INFO    : Bus 2534	: V=0.996764, theta=-23.821388 -> V=1.0, theta=0.0
% INFO    : Bus 2535	: V=1.074091, theta=-12.009763 -> V=1.027028, theta=0.0
% INFO    : Bus 2536	: V=1.083868, theta=-44.127421 -> V=1.010182, theta=0.0
% INFO    : Bus 2537	: V=1.072943, theta=-23.292872 -> V=1.019058, theta=0.0
% INFO    : Bus 2538	: V=0.965744, theta=-26.191022 -> V=1.0, theta=0.0
% INFO    : Bus 2539	: V=1.042877, theta=-34.343944 -> V=1.0027955, theta=0.0
% INFO    : Bus 2540	: V=1.028928, theta=8.403044 -> V=1.005189, theta=0.0
% INFO    : Bus 2541	: V=1.062335, theta=-40.064695 -> V=1.0155435, theta=0.0
% INFO    : Bus 2542	: V=1.075858, theta=0.279328 -> V=1.025561, theta=0.0
% INFO    : Bus 2543	: V=1.084842, theta=-14.215372 -> V=1.0196665, theta=0.0
% INFO    : Bus 2544	: V=0.952492, theta=-38.906525 -> V=1.0, theta=0.0
% INFO    : Bus 2545	: V=0.964307, theta=-31.504183 -> V=1.0, theta=0.0
% INFO    : Bus 2546	: V=1.043376, theta=14.686882 -> V=1.0, theta=0.0
% INFO    : Bus 2547	: V=1.043646, theta=-16.106382 -> V=1.002588, theta=0.0
% INFO    : Bus 2548	: V=1.089301, theta=-14.512865 -> V=1.0156965, theta=0.0
% INFO    : Bus 2549	: V=1.060871, theta=-21.957111 -> V=1.0191955, theta=0.0
% INFO    : Bus 2550	: V=1.0915, theta=-0.846843 -> V=1.0264085, theta=0.0
% INFO    : Bus 2551	: V=1.024868, theta=-42.149931 -> V=1.0, theta=0.0
% INFO    : Bus 2552	: V=1.040858, theta=-36.505145 -> V=1.0, theta=0.0
% INFO    : Bus 2553	: V=1.03278, theta=-21.824671 -> V=1.0, theta=0.0
% INFO    : Bus 2554	: V=1.00331, theta=-47.836763 -> V=1.0, theta=0.0
% INFO    : Bus 2555	: V=1.053318, theta=-44.251365 -> V=1.003059, theta=0.0
% INFO    : Bus 2556	: V=1.058492, theta=-29.577247 -> V=1.0115905, theta=0.0
% INFO    : Bus 2557	: V=1.025323, theta=13.046319 -> V=1.0, theta=0.0
% INFO    : Bus 2558	: V=1.026882, theta=-24.48424 -> V=1.0, theta=0.0
% INFO    : Bus 2559	: V=1.03903, theta=0.250242 -> V=1.006644, theta=0.0
% INFO    : Bus 2560	: V=1.026462, theta=-18.064619 -> V=1.0, theta=0.0
% INFO    : Bus 2561	: V=0.975926, theta=-34.624345 -> V=1.0, theta=0.0
% INFO    : Bus 2562	: V=0.945136, theta=-24.513567 -> V=1.0, theta=0.0
% INFO    : Bus 2563	: V=1.048109, theta=-21.465139 -> V=1.024966, theta=0.0
% INFO    : Bus 2564	: V=1.02367, theta=7.929674 -> V=1.0027365, theta=0.0
% INFO    : Bus 2565	: V=0.962896, theta=-13.323297 -> V=1.0, theta=0.0
% INFO    : Bus 2566	: V=1.084184, theta=-3.438488 -> V=1.0225015, theta=0.0
% INFO    : Bus 2567	: V=0.969603, theta=62.599067 -> V=1.0, theta=0.0
% INFO    : Bus 2568	: V=0.975873, theta=-30.338776 -> V=1.0, theta=0.0
% INFO    : Bus 2569	: V=1.032479, theta=-23.299073 -> V=1.0, theta=0.0
% INFO    : Bus 2570	: V=1.005, theta=66.562332 -> V=1.0, theta=0.0
% INFO    : Bus 2571	: V=1.098019, theta=-21.245866 -> V=1.0241895, theta=0.0
% INFO    : Bus 2572	: V=1.059773, theta=-28.201077 -> V=1.0135855, theta=0.0
% INFO    : Bus 2573	: V=1.040364, theta=-6.246332 -> V=1.0148445, theta=0.0
% INFO    : Bus 2574	: V=1.042845, theta=-23.441941 -> V=1.0, theta=0.0
% INFO    : Bus 2575	: V=1.020534, theta=-42.204037 -> V=1.0, theta=0.0
% INFO    : Bus 2576	: V=0.985096, theta=-23.404839 -> V=1.0, theta=0.0
% INFO    : Bus 2577	: V=0.962094, theta=-19.013018 -> V=1.0, theta=0.0
% INFO    : Bus 2578	: V=1.085139, theta=-3.965624 -> V=1.0190645, theta=0.0
% INFO    : Bus 2579	: V=1.044584, theta=-7.943453 -> V=1.005666, theta=0.0
% INFO    : Bus 2580	: V=1.074589, theta=-38.891749 -> V=1.0195625, theta=0.0
% INFO    : Bus 2581	: V=1.072116, theta=-17.809949 -> V=1.017784, theta=0.0
% INFO    : Bus 2582	: V=1.010941, theta=-22.445338 -> V=1.0, theta=0.0
% INFO    : Bus 2583	: V=1.096817, theta=59.130678 -> V=1.0041215, theta=0.0
% INFO    : Bus 2584	: V=1.024, theta=-32.230453 -> V=1.0, theta=0.0
% INFO    : Bus 2585	: V=1.085298, theta=-10.471932 -> V=1.0269155, theta=0.0
% INFO    : Bus 2586	: V=1.084605, theta=-14.759209 -> V=1.0257005, theta=0.0
% INFO    : Bus 2587	: V=1.046549, theta=-20.83721 -> V=1.0, theta=0.0
% INFO    : Bus 2588	: V=0.986082, theta=-17.403914 -> V=1.0, theta=0.0
% INFO    : Bus 2589	: V=1.039048, theta=-19.30151 -> V=1.0, theta=0.0
% INFO    : Bus 2590	: V=0.976695, theta=-26.902591 -> V=1.0, theta=0.0
% INFO    : Bus 2591	: V=0.966203, theta=-24.767487 -> V=1.0, theta=0.0
% INFO    : Bus 2592	: V=0.945102, theta=-27.145607 -> V=1.0, theta=0.0
% INFO    : Bus 2593	: V=1.061909, theta=-7.161958 -> V=1.010032, theta=0.0
% INFO    : Bus 2594	: V=1.054352, theta=-10.13625 -> V=1.0103765, theta=0.0
% INFO    : Bus 2595	: V=0.947734, theta=-27.413084 -> V=1.0, theta=0.0
% INFO    : Bus 2596	: V=1.058733, theta=-17.312153 -> V=1.0072555, theta=0.0
% INFO    : Bus 2597	: V=1.038853, theta=-6.87386 -> V=1.013921, theta=0.0
% INFO    : Bus 2598	: V=1.072592, theta=-22.107209 -> V=1.014737, theta=0.0
% INFO    : Bus 2599	: V=0.986659, theta=-5.381227 -> V=1.0, theta=0.0
% INFO    : Bus 2600	: V=1.096855, theta=-14.901823 -> V=1.0303385, theta=0.0
% INFO    : Bus 2601	: V=1.087637, theta=0.76719 -> V=1.018473, theta=0.0
% INFO    : Bus 2602	: V=1.043873, theta=-45.520158 -> V=1.0, theta=0.0
% INFO    : Bus 2603	: V=1.065683, theta=-10.23004 -> V=1.02079, theta=0.0
% INFO    : Bus 2604	: V=1.010387, theta=-27.444724 -> V=1.0468825, theta=0.0
% INFO    : Bus 2605	: V=1.033634, theta=-35.120743 -> V=1.0, theta=0.0
% INFO    : Bus 2606	: V=1.033124, theta=-22.980448 -> V=1.0, theta=0.0
% INFO    : Bus 2607	: V=1.071544, theta=-13.995808 -> V=1.0174465, theta=0.0
% INFO    : Bus 2608	: V=1.058773, theta=-10.628368 -> V=1.018365, theta=0.0
% INFO    : Bus 2609	: V=1.059039, theta=-4.925584 -> V=1.0172925, theta=0.0
% INFO    : Bus 2610	: V=1.022186, theta=-46.418083 -> V=1.0, theta=0.0
% INFO    : Bus 2611	: V=0.959599, theta=-24.248667 -> V=1.0, theta=0.0
% INFO    : Bus 2612	: V=1.058045, theta=-11.45014 -> V=1.0122385, theta=0.0
% INFO    : Bus 2613	: V=1.047706, theta=-36.557601 -> V=1.0073385, theta=0.0
% INFO    : Bus 2614	: V=1.083282, theta=-23.736003 -> V=1.0236435, theta=0.0
% INFO    : Bus 2615	: V=1.068864, theta=-13.258918 -> V=1.0102055, theta=0.0
% INFO    : Bus 2616	: V=1.036982, theta=-38.471532 -> V=1.0, theta=0.0
% INFO    : Bus 2617	: V=1.070275, theta=-20.006583 -> V=1.0262325, theta=0.0
% INFO    : Bus 2618	: V=1.087013, theta=-1.01745 -> V=1.026029, theta=0.0
% INFO    : Bus 2619	: V=1.078821, theta=-7.112744 -> V=1.0228505, theta=0.0
% INFO    : Bus 2620	: V=1.060946, theta=1.629209 -> V=1.009029, theta=0.0
% INFO    : Bus 2621	: V=1.045905, theta=-13.879132 -> V=1.028599, theta=0.0
% INFO    : Bus 2622	: V=1.018581, theta=-29.434591 -> V=1.0, theta=0.0
% INFO    : Bus 2623	: V=1.019871, theta=-34.869863 -> V=1.0, theta=0.0
% INFO    : Bus 2624	: V=1.049092, theta=-12.921404 -> V=1.0066, theta=0.0
% INFO    : Bus 2625	: V=1.044318, theta=-40.294865 -> V=1.0, theta=0.0
% INFO    : Bus 2626	: V=1.094545, theta=-16.607931 -> V=1.0179885, theta=0.0
% INFO    : Bus 2627	: V=1.060166, theta=-22.038997 -> V=1.0185985, theta=0.0
% INFO    : Bus 2628	: V=1.08682, theta=-40.55165 -> V=1.021857, theta=0.0
% INFO    : Bus 2629	: V=1.079603, theta=3.219078 -> V=1.024428, theta=0.0
% INFO    : Bus 2630	: V=1.061894, theta=-14.517943 -> V=1.014986, theta=0.0
% INFO    : Bus 2631	: V=1.085, theta=-23.59459 -> V=1.021552, theta=0.0
% INFO    : Bus 2632	: V=0.989901, theta=8.953609 -> V=1.0, theta=0.0
% INFO    : Bus 2633	: V=1.095437, theta=-10.964339 -> V=1.028054, theta=0.0
% INFO    : Bus 2634	: V=1.060654, theta=-35.376624 -> V=1.0209205, theta=0.0
% INFO    : Bus 2635	: V=1.054045, theta=-9.435987 -> V=1.0109445, theta=0.0
% INFO    : Bus 2636	: V=1.06531, theta=-43.859277 -> V=1.0071435, theta=0.0
% INFO    : Bus 2637	: V=1.074095, theta=-10.56835 -> V=1.022715, theta=0.0
% INFO    : Bus 2638	: V=1.047044, theta=-34.065276 -> V=1.004753, theta=0.0
% INFO    : Bus 2639	: V=1.086112, theta=-3.23242 -> V=1.023691, theta=0.0
% INFO    : Bus 2640	: V=1.003638, theta=-29.701567 -> V=1.0, theta=0.0
% INFO    : Bus 2641	: V=1.047531, theta=40.020553 -> V=1.0, theta=0.0
% INFO    : Bus 2642	: V=1.08437, theta=-37.522987 -> V=1.0143785, theta=0.0
% INFO    : Bus 2643	: V=1.023446, theta=-23.350939 -> V=1.0106005, theta=0.0
% INFO    : Bus 2644	: V=0.997344, theta=-23.712148 -> V=1.0, theta=0.0
% INFO    : Bus 2645	: V=1.094969, theta=-34.411761 -> V=1.020024, theta=0.0
% INFO    : Bus 2646	: V=1.070861, theta=-42.37947 -> V=1.0086125, theta=0.0
% INFO    : Bus 2647	: V=1.02914, theta=-27.383698 -> V=1.0132635, theta=0.0
% INFO    : Bus 2648	: V=1.036348, theta=-17.406243 -> V=1.006926, theta=0.0
% INFO    : Bus 2649	: V=1.066553, theta=-35.500883 -> V=1.0141075, theta=0.0
% INFO    : Bus 2650	: V=1.041199, theta=-36.286309 -> V=1.0, theta=0.0
% INFO    : Bus 2651	: V=1.07426, theta=-19.582152 -> V=1.016327, theta=0.0
% INFO    : Bus 2652	: V=1.062342, theta=-39.446995 -> V=1.014726, theta=0.0
% INFO    : Bus 2653	: V=1.069672, theta=-31.342825 -> V=1.0283185, theta=0.0
% INFO    : Bus 2654	: V=1.01711, theta=-19.65202 -> V=1.0, theta=0.0
% INFO    : Bus 2655	: V=1.075384, theta=-17.534465 -> V=1.0079645, theta=0.0
% INFO    : Bus 2656	: V=1.082444, theta=16.019049 -> V=1.0138525, theta=0.0
% INFO    : Bus 2657	: V=1.076574, theta=-25.454026 -> V=1.0332765, theta=0.0
% INFO    : Bus 2658	: V=0.997221, theta=-23.481773 -> V=1.0, theta=0.0
% INFO    : Bus 2659	: V=1.060455, theta=-12.501967 -> V=1.022121, theta=0.0
% INFO    : Bus 2660	: V=1.050685, theta=-31.363096 -> V=1.031261, theta=0.0
% INFO    : Bus 2661	: V=1.079946, theta=17.859832 -> V=1.0161455, theta=0.0
% INFO    : Bus 2662	: V=1.093009, theta=-29.011561 -> V=1.017491, theta=0.0
% INFO    : Bus 2663	: V=1.080136, theta=-6.175668 -> V=1.0193195, theta=0.0
% INFO    : Bus 2664	: V=1.082118, theta=-9.810925 -> V=1.0136425, theta=0.0
% INFO    : Bus 2665	: V=1.050362, theta=-18.434224 -> V=1.0055655, theta=0.0
% INFO    : Bus 2666	: V=0.938353, theta=-17.973868 -> V=1.0, theta=0.0
% INFO    : Bus 2667	: V=1.051329, theta=-7.568721 -> V=1.0089175, theta=0.0
% INFO    : Bus 2668	: V=1.004448, theta=-21.42796 -> V=1.0, theta=0.0
% INFO    : Bus 2669	: V=1.0593, theta=-13.982117 -> V=1.0131285, theta=0.0
% INFO    : Bus 2670	: V=1.092016, theta=-31.19555 -> V=1.019021, theta=0.0
% INFO    : Bus 2671	: V=1.064316, theta=-8.855721 -> V=1.0, theta=0.0
% INFO    : Bus 2672	: V=1.016321, theta=-24.394135 -> V=1.0, theta=0.0
% INFO    : Bus 2673	: V=1.014059, theta=-34.666398 -> V=1.0, theta=0.0
% INFO    : Bus 2674	: V=1.016558, theta=8.202589 -> V=1.0, theta=0.0
% INFO    : Bus 2675	: V=1.03201, theta=-25.666017 -> V=1.0, theta=0.0
% INFO    : Bus 2676	: V=1.014409, theta=-42.051018 -> V=1.0, theta=0.0
% INFO    : Bus 2677	: V=1.031212, theta=-20.893656 -> V=1.0, theta=0.0
% INFO    : Bus 2678	: V=1.037439, theta=0.906331 -> V=1.013255, theta=0.0
% INFO    : Bus 2679	: V=1.055346, theta=-4.537223 -> V=1.0221755, theta=0.0
% INFO    : Bus 2680	: V=1.025859, theta=-16.598019 -> V=1.0, theta=0.0
% INFO    : Bus 2681	: V=1.050279, theta=-48.968345 -> V=1.0, theta=0.0
% INFO    : Bus 2682	: V=1.031907, theta=-25.496827 -> V=1.0, theta=0.0
% INFO    : Bus 2683	: V=1.027298, theta=-51.122233 -> V=1.0, theta=0.0
% INFO    : Bus 2684	: V=1.042041, theta=-18.126406 -> V=1.0, theta=0.0
% INFO    : Bus 2685	: V=1.088658, theta=-13.971565 -> V=1.0405945, theta=0.0
% INFO    : Bus 2686	: V=1.029672, theta=-35.306555 -> V=1.0, theta=0.0
% INFO    : Bus 2687	: V=0.946514, theta=-34.954698 -> V=1.0, theta=0.0
% INFO    : Bus 2688	: V=1.010038, theta=-17.487074 -> V=1.0, theta=0.0
% INFO    : Bus 2689	: V=0.998342, theta=-16.784976 -> V=1.0, theta=0.0
% INFO    : Bus 2690	: V=1.073099, theta=-23.184092 -> V=1.0191065, theta=0.0
% INFO    : Bus 2691	: V=1.095428, theta=-38.669676 -> V=1.026267, theta=0.0
% INFO    : Bus 2692	: V=1.074968, theta=-23.273952 -> V=1.0201665, theta=0.0
% INFO    : Bus 2693	: V=1.007507, theta=-23.430479 -> V=1.0, theta=0.0
% INFO    : Bus 2694	: V=1.061073, theta=15.8976 -> V=1.0, theta=0.0
% INFO    : Bus 2695	: V=0.9632, theta=-21.518806 -> V=1.0, theta=0.0
% INFO    : Bus 2696	: V=1.061365, theta=-15.912754 -> V=1.00665, theta=0.0
% INFO    : Bus 2697	: V=1.081031, theta=-8.81714 -> V=1.025625, theta=0.0
% INFO    : Bus 2698	: V=0.957086, theta=-29.325733 -> V=1.0, theta=0.0
% INFO    : Bus 2699	: V=1.026598, theta=-17.952346 -> V=1.0, theta=0.0
% INFO    : Bus 2700	: V=1.032009, theta=-6.372907 -> V=1.0, theta=0.0
% INFO    : Bus 2701	: V=1.045299, theta=-14.335082 -> V=1.0, theta=0.0
% INFO    : Bus 2702	: V=1.081632, theta=8.027599 -> V=1.0038725, theta=0.0
% INFO    : Bus 2703	: V=1.075578, theta=-1.097104 -> V=1.0220845, theta=0.0
% INFO    : Bus 2704	: V=1.063636, theta=-29.452452 -> V=1.0120855, theta=0.0
% INFO    : Bus 2705	: V=0.957181, theta=-27.388703 -> V=1.0, theta=0.0
% INFO    : Bus 2706	: V=0.944665, theta=-27.32933 -> V=1.0, theta=0.0
% INFO    : Bus 2707	: V=1.064938, theta=-43.926837 -> V=1.0068295, theta=0.0
% INFO    : Bus 2708	: V=1.100091, theta=-8.858751 -> V=1.033912, theta=0.0
% INFO    : Bus 2709	: V=1.099531, theta=-14.779109 -> V=1.047473, theta=0.0
% INFO    : Bus 2710	: V=0.992818, theta=-21.421752 -> V=1.0, theta=0.0
% INFO    : Bus 2711	: V=1.000697, theta=-19.851554 -> V=1.0, theta=0.0
% INFO    : Bus 2712	: V=0.966927, theta=-24.57451 -> V=1.0, theta=0.0
% INFO    : Bus 2713	: V=1.092182, theta=-8.170966 -> V=1.0259665, theta=0.0
% INFO    : Bus 2714	: V=1.084874, theta=-28.643421 -> V=1.0212005, theta=0.0
% INFO    : Bus 2715	: V=1.098455, theta=-11.580514 -> V=1.0230605, theta=0.0
% INFO    : Bus 2716	: V=0.953862, theta=-29.467479 -> V=1.0, theta=0.0
% INFO    : Bus 2717	: V=1.052026, theta=-8.038678 -> V=1.0067495, theta=0.0
% INFO    : Bus 2718	: V=1.046368, theta=9.07934 -> V=1.0110035, theta=0.0
% INFO    : Bus 2719	: V=0.937633, theta=-33.294515 -> V=0.9608305, theta=0.0
% INFO    : Bus 2720	: V=1.102526, theta=-24.20092 -> V=1.029777, theta=0.0
% INFO    : Bus 2721	: V=0.948563, theta=-26.26888 -> V=1.0, theta=0.0
% INFO    : Bus 2722	: V=0.995302, theta=-30.131562 -> V=1.0, theta=0.0
% INFO    : Bus 2723	: V=1.083369, theta=-3.783616 -> V=1.0182185, theta=0.0
% INFO    : Bus 2724	: V=0.963271, theta=-13.280004 -> V=1.0, theta=0.0
% INFO    : Bus 2725	: V=1.083553, theta=12.393441 -> V=1.031728, theta=0.0
% INFO    : Bus 2726	: V=1.044528, theta=-13.687294 -> V=1.0034515, theta=0.0
% INFO    : Bus 2727	: V=1.049277, theta=12.845433 -> V=1.0, theta=0.0
% INFO    : Bus 2728	: V=1.037701, theta=2.208062 -> V=1.0148205, theta=0.0
% INFO    : Bus 2729	: V=1.054955, theta=5.750006 -> V=1.0145565, theta=0.0
% INFO    : Bus 2730	: V=1.056551, theta=-15.353344 -> V=1.00443, theta=0.0
% INFO    : Bus 2731	: V=1.0667, theta=-7.830804 -> V=1.0153625, theta=0.0
% INFO    : Bus 2732	: V=1.043094, theta=-5.889712 -> V=1.0092865, theta=0.0
% INFO    : Bus 2733	: V=1.070437, theta=-47.421461 -> V=1.012562, theta=0.0
% INFO    : Bus 2734	: V=1.059381, theta=-41.812151 -> V=1.0130515, theta=0.0
% INFO    : Bus 2735	: V=1.057067, theta=61.130764 -> V=1.0, theta=0.0
% INFO    : Bus 2736	: V=1.035945, theta=-29.496065 -> V=1.0, theta=0.0
% INFO    : Bus 2737	: V=0.899865, theta=-33.250859 -> V=1.0, theta=0.0
% INFO    : Bus 2738	: V=1.093523, theta=-5.172233 -> V=1.0266705, theta=0.0
% INFO    : Bus 2739	: V=1.052224, theta=-4.912474 -> V=1.0205835, theta=0.0
% INFO    : Bus 2740	: V=1.010502, theta=-16.763633 -> V=1.0, theta=0.0
% INFO    : Bus 2741	: V=0.99831, theta=-4.853194 -> V=1.0, theta=0.0
% INFO    : Bus 2742	: V=0.99212, theta=-21.950828 -> V=1.0, theta=0.0
% INFO    : Bus 2743	: V=1.073029, theta=-21.858929 -> V=1.0214425, theta=0.0
% INFO    : Bus 2744	: V=1.039091, theta=-12.214521 -> V=1.014928, theta=0.0
% INFO    : Bus 2745	: V=1.060889, theta=-21.74615 -> V=1.019144, theta=0.0
% INFO    : Bus 2746	: V=1.085399, theta=-39.425705 -> V=1.028071, theta=0.0
% INFO    : Bus 2747	: V=1.044973, theta=-11.54051 -> V=1.0082575, theta=0.0
% INFO    : Bus 2748	: V=1.072247, theta=-14.320456 -> V=1.0243015, theta=0.0
% INFO    : Bus 2749	: V=1.029194, theta=7.551285 -> V=1.0, theta=0.0
% INFO    : Bus 2750	: V=1.057205, theta=-34.498318 -> V=1.0178415, theta=0.0
% INFO    : Bus 2751	: V=1.090745, theta=-18.260083 -> V=1.0249335, theta=0.0
% INFO    : Bus 2752	: V=0.960377, theta=-27.224344 -> V=1.0, theta=0.0
% INFO    : Bus 2753	: V=1.056576, theta=-48.669733 -> V=1.007255, theta=0.0
% INFO    : Bus 2754	: V=1.079816, theta=-0.359435 -> V=1.020741, theta=0.0
% INFO    : Bus 2755	: V=1.005545, theta=-19.708393 -> V=1.0, theta=0.0
% INFO    : Bus 2756	: V=0.941623, theta=-27.818482 -> V=1.0, theta=0.0
% INFO    : Bus 2757	: V=0.994537, theta=-26.28118 -> V=1.0, theta=0.0
% INFO    : Bus 2758	: V=0.969281, theta=-23.072183 -> V=1.0, theta=0.0
% INFO    : Bus 2759	: V=0.987078, theta=-17.17728 -> V=1.0, theta=0.0
% INFO    : Bus 2760	: V=1.055658, theta=-41.847447 -> V=1.0059235, theta=0.0
% INFO    : Bus 2761	: V=1.05737, theta=-24.023488 -> V=1.0159995, theta=0.0
% INFO    : Bus 2762	: V=1.015939, theta=-6.171251 -> V=1.0083525, theta=0.0
% INFO    : Bus 2763	: V=1.035045, theta=13.09578 -> V=1.0, theta=0.0
% INFO    : Bus 2764	: V=1.085773, theta=-11.471439 -> V=1.0107265, theta=0.0
% INFO    : Bus 2765	: V=1.030002, theta=-24.352705 -> V=1.0, theta=0.0
% INFO    : Bus 2766	: V=1.092042, theta=-15.905297 -> V=1.0144235, theta=0.0
% INFO    : Bus 2767	: V=1.065028, theta=-22.310743 -> V=1.010724, theta=0.0
% INFO    : Bus 2768	: V=0.999762, theta=-22.427486 -> V=1.0, theta=0.0
% INFO    : Bus 2769	: V=1.020876, theta=-20.587136 -> V=1.015657, theta=0.0
% INFO    : Bus 2770	: V=1.03981, theta=-29.288278 -> V=1.0, theta=0.0
% INFO    : Bus 2771	: V=1.058082, theta=2.045053 -> V=1.0088925, theta=0.0
% INFO    : Bus 2772	: V=1.082534, theta=-26.75273 -> V=1.0111795, theta=0.0
% INFO    : Bus 2773	: V=1.046458, theta=-22.327997 -> V=1.0, theta=0.0
% INFO    : Bus 2774	: V=1.08369, theta=-12.513783 -> V=1.022185, theta=0.0
% INFO    : Bus 2775	: V=1.039331, theta=-24.598821 -> V=1.0118555, theta=0.0
% INFO    : Bus 2776	: V=1.034455, theta=-15.397715 -> V=1.016007, theta=0.0
% INFO    : Bus 2777	: V=1.065839, theta=3.620543 -> V=1.015959, theta=0.0
% INFO    : Bus 2778	: V=0.978671, theta=-21.474884 -> V=1.0, theta=0.0
% INFO    : Bus 2779	: V=1.032045, theta=-46.969915 -> V=1.0, theta=0.0
% INFO    : Bus 2780	: V=1.103373, theta=-16.268351 -> V=1.030978, theta=0.0
% INFO    : Bus 2781	: V=1.105203, theta=44.315547 -> V=1.009867, theta=0.0
% INFO    : Bus 2782	: V=0.967787, theta=-19.52933 -> V=1.0, theta=0.0
% INFO    : Bus 2783	: V=1.041415, theta=-20.285092 -> V=1.0, theta=0.0
% INFO    : Bus 2784	: V=1.076332, theta=-43.49106 -> V=1.008438, theta=0.0
% INFO    : Bus 2785	: V=1.050547, theta=-7.283379 -> V=1.014183, theta=0.0
% INFO    : Bus 2786	: V=1.037593, theta=-46.236655 -> V=1.0, theta=0.0
% INFO    : Bus 2787	: V=1.05238, theta=-49.729887 -> V=1.0063595, theta=0.0
% INFO    : Bus 2788	: V=1.04994, theta=-49.502471 -> V=1.0060295, theta=0.0
% INFO    : Bus 2789	: V=1.068861, theta=-38.560337 -> V=1.0173115, theta=0.0
% INFO    : Bus 2790	: V=1.035525, theta=-45.305993 -> V=1.0, theta=0.0
% INFO    : Bus 2791	: V=1.04307, theta=-8.249229 -> V=1.0091505, theta=0.0
% INFO    : Bus 2792	: V=1.070268, theta=-20.006492 -> V=1.026229, theta=0.0
% INFO    : Bus 2793	: V=1.07104, theta=-6.852238 -> V=1.0154215, theta=0.0
% INFO    : Bus 2794	: V=1.050072, theta=-29.747047 -> V=1.0220285, theta=0.0
% INFO    : Bus 2795	: V=1.066659, theta=-21.508622 -> V=1.0, theta=0.0
% INFO    : Bus 2796	: V=1.034547, theta=-24.434307 -> V=1.0, theta=0.0
% INFO    : Bus 2797	: V=1.044151, theta=-43.560599 -> V=1.0, theta=0.0
% INFO    : Bus 2798	: V=1.019837, theta=-15.300959 -> V=1.0, theta=0.0
% INFO    : Bus 2799	: V=1.059636, theta=-26.448279 -> V=1.0109875, theta=0.0
% INFO    : Bus 2800	: V=0.97411, theta=-18.433926 -> V=1.0, theta=0.0
% INFO    : Bus 2801	: V=1.10113, theta=-43.269272 -> V=1.0284235, theta=0.0
% INFO    : Bus 2802	: V=1.069248, theta=-15.072586 -> V=1.0137545, theta=0.0
% INFO    : Bus 2803	: V=1.054851, theta=-14.422775 -> V=1.0081895, theta=0.0
% INFO    : Bus 2804	: V=1.075195, theta=-26.800459 -> V=1.041801, theta=0.0
% INFO    : Bus 2805	: V=1.050273, theta=1.81267 -> V=1.012612, theta=0.0
% INFO    : Bus 2806	: V=1.074034, theta=-26.856325 -> V=1.0412925, theta=0.0
% INFO    : Bus 2807	: V=0.972538, theta=-24.834318 -> V=1.0, theta=0.0
% INFO    : Bus 2808	: V=1.040877, theta=-34.646783 -> V=1.0, theta=0.0
% INFO    : Bus 2809	: V=1.073227, theta=-11.87513 -> V=1.0132825, theta=0.0
% INFO    : Bus 2810	: V=1.009293, theta=-29.857443 -> V=1.0, theta=0.0
% INFO    : Bus 2811	: V=1.030455, theta=-5.519567 -> V=1.004838, theta=0.0
% INFO    : Bus 2812	: V=1.00646, theta=-35.547763 -> V=1.0, theta=0.0
% INFO    : Bus 2813	: V=1.070037, theta=-27.372165 -> V=1.0188425, theta=0.0
% INFO    : Bus 2814	: V=1.036238, theta=-15.421489 -> V=1.0128015, theta=0.0
% INFO    : Bus 2815	: V=1.04813, theta=-49.199981 -> V=1.0, theta=0.0
% INFO    : Bus 2816	: V=1.081518, theta=0.98606 -> V=1.015857, theta=0.0
% INFO    : Bus 2817	: V=1.024472, theta=-27.86673 -> V=1.0, theta=0.0
% INFO    : Bus 2818	: V=1.079144, theta=-24.956358 -> V=1.0197385, theta=0.0
% INFO    : Bus 2819	: V=0.982255, theta=-23.806162 -> V=1.0, theta=0.0
% INFO    : Bus 2820	: V=1.040264, theta=-20.896707 -> V=1.0, theta=0.0
% INFO    : Bus 2821	: V=1.053046, theta=12.027943 -> V=1.013246, theta=0.0
% INFO    : Bus 2822	: V=1.037644, theta=-18.423267 -> V=1.0, theta=0.0
% INFO    : Bus 2823	: V=1.006279, theta=-21.440196 -> V=1.0, theta=0.0
% INFO    : Bus 2824	: V=0.961079, theta=-32.322499 -> V=1.0, theta=0.0
% INFO    : Bus 2825	: V=1.095921, theta=-41.060743 -> V=1.017808, theta=0.0
% INFO    : Bus 2826	: V=1.067392, theta=-0.76 -> V=1.019234, theta=0.0
% INFO    : Bus 2827	: V=0.975647, theta=-23.94277 -> V=1.0, theta=0.0
% INFO    : Bus 2828	: V=1.061796, theta=-38.628046 -> V=1.0, theta=0.0
% INFO    : Bus 2829	: V=1.080657, theta=15.971905 -> V=1.0176235, theta=0.0
% INFO    : Bus 2830	: V=1.066847, theta=-37.417919 -> V=1.0122975, theta=0.0
% INFO    : Bus 2831	: V=1.074742, theta=2.456158 -> V=1.027462, theta=0.0
% INFO    : Bus 2832	: V=1.093184, theta=-34.279704 -> V=1.027736, theta=0.0
% INFO    : Bus 2833	: V=1.071636, theta=-10.916577 -> V=1.025382, theta=0.0
% INFO    : Bus 2834	: V=1.097059, theta=-10.968097 -> V=1.0299215, theta=0.0
% INFO    : Bus 2835	: V=1.036011, theta=-0.497965 -> V=1.0025775, theta=0.0
% INFO    : Bus 2836	: V=1.048163, theta=-15.484434 -> V=1.0, theta=0.0
% INFO    : Bus 2837	: V=0.989739, theta=38.018589 -> V=1.0, theta=0.0
% INFO    : Bus 2838	: V=1.066189, theta=7.732993 -> V=1.0076075, theta=0.0
% INFO    : Bus 2839	: V=1.049231, theta=-18.03817 -> V=1.010432, theta=0.0
% INFO    : Bus 2840	: V=1.036673, theta=-6.89217 -> V=1.013882, theta=0.0
% INFO    : Bus 2841	: V=0.933176, theta=-27.925794 -> V=1.0, theta=0.0
% INFO    : Bus 2842	: V=1.088685, theta=-22.237488 -> V=1.028202, theta=0.0
% INFO    : Bus 2843	: V=1.076037, theta=-21.327851 -> V=1.010823, theta=0.0
% INFO    : Bus 2844	: V=1.05504, theta=-36.158993 -> V=1.0043575, theta=0.0
% INFO    : Bus 2845	: V=1.050103, theta=-16.728876 -> V=1.007485, theta=0.0
% INFO    : Bus 2846	: V=1.070526, theta=54.903209 -> V=1.0, theta=0.0
% INFO    : Bus 2847	: V=0.995223, theta=-16.764522 -> V=1.0, theta=0.0
% INFO    : Bus 2848	: V=0.919422, theta=-26.134721 -> V=1.0, theta=0.0
% INFO    : Bus 2849	: V=1.070632, theta=-18.079898 -> V=1.010667, theta=0.0
% INFO    : Bus 2850	: V=0.964357, theta=-29.885459 -> V=1.0, theta=0.0
% INFO    : Bus 2851	: V=0.992533, theta=-16.445176 -> V=1.0, theta=0.0
% INFO    : Bus 2852	: V=1.089773, theta=-8.701437 -> V=1.027775, theta=0.0
% INFO    : Bus 2853	: V=0.983864, theta=-14.904843 -> V=1.0, theta=0.0
% INFO    : Bus 2854	: V=1.09583, theta=-33.926353 -> V=1.019612, theta=0.0
% INFO    : Bus 2855	: V=0.982117, theta=-24.507986 -> V=1.0, theta=0.0
% INFO    : Bus 2856	: V=1.089761, theta=-25.250235 -> V=1.041118, theta=0.0
% INFO    : Bus 2857	: V=1.018979, theta=-19.016221 -> V=1.0, theta=0.0
% INFO    : Bus 2858	: V=1.052452, theta=-20.164167 -> V=1.004097, theta=0.0
% INFO    : Bus 2859	: V=1.081925, theta=-18.869476 -> V=1.022721, theta=0.0
% INFO    : Bus 2860	: V=1.017967, theta=-21.454816 -> V=1.0, theta=0.0
% INFO    : Bus 2861	: V=1.02912, theta=-38.849966 -> V=1.008582, theta=0.0
% INFO    : Bus 2862	: V=1.086511, theta=-17.124378 -> V=1.0287125, theta=0.0
% INFO    : Bus 2863	: V=1.104579, theta=21.853809 -> V=1.038576, theta=0.0
% INFO    : Bus 2864	: V=1.075899, theta=2.86124 -> V=1.022571, theta=0.0
% INFO    : Bus 2865	: V=1.042922, theta=19.863301 -> V=1.0, theta=0.0
% INFO    : Bus 2866	: V=1.041863, theta=-44.098617 -> V=1.004693, theta=0.0
% INFO    : Bus 2867	: V=1.022756, theta=-19.14096 -> V=1.0057405, theta=0.0
% INFO    : Bus 2868	: V=1.073273, theta=-21.618659 -> V=1.008423, theta=0.0
% INFO    : Bus 2869	: V=1.005744, theta=-16.196641 -> V=1.0, theta=0.0
% INFO    : Bus 2870	: V=0.965084, theta=-27.581006 -> V=1.0, theta=0.0
% INFO    : Bus 2871	: V=1.031304, theta=4.041372 -> V=1.0, theta=0.0
% INFO    : Bus 2872	: V=1.079773, theta=-34.243346 -> V=1.014596, theta=0.0
% INFO    : Bus 2873	: V=1.061267, theta=63.934137 -> V=1.0, theta=0.0
% INFO    : Bus 2874	: V=1.090057, theta=-22.031154 -> V=1.0290255, theta=0.0
% INFO    : Bus 2875	: V=1.030073, theta=13.067022 -> V=1.0, theta=0.0
% INFO    : Bus 2876	: V=1.005569, theta=-21.855857 -> V=1.0, theta=0.0
% INFO    : Bus 2877	: V=1.001467, theta=-19.115983 -> V=1.0, theta=0.0
% INFO    : Bus 2878	: V=1.0335, theta=-43.36439 -> V=1.0, theta=0.0
% INFO    : Bus 2879	: V=1.035503, theta=-24.795186 -> V=1.0, theta=0.0
% INFO    : Bus 2880	: V=1.07408, theta=-16.856615 -> V=1.0239235, theta=0.0
% INFO    : Bus 2881	: V=0.998479, theta=-30.140155 -> V=1.0, theta=0.0
% INFO    : Bus 2882	: V=1.070814, theta=2.3646 -> V=1.022178, theta=0.0
% INFO    : Bus 2883	: V=0.987377, theta=-40.63887 -> V=1.0, theta=0.0
% INFO    : Bus 2884	: V=0.983142, theta=-18.289118 -> V=1.0, theta=0.0
% INFO    : Bus 2885	: V=1.040737, theta=-20.316032 -> V=1.0, theta=0.0
% INFO    : Bus 2886	: V=1.038236, theta=-17.596212 -> V=1.0047875, theta=0.0
% INFO    : Bus 2887	: V=1.053124, theta=-42.574248 -> V=1.0110005, theta=0.0
% INFO    : Bus 2888	: V=1.016981, theta=-23.75469 -> V=1.0, theta=0.0
% INFO    : Bus 2889	: V=1.009887, theta=7.38318 -> V=1.0, theta=0.0
% INFO    : Bus 2890	: V=1.055546, theta=6.091122 -> V=1.0040525, theta=0.0
% INFO    : Bus 2891	: V=1.030206, theta=-41.356831 -> V=1.0, theta=0.0
% INFO    : Bus 2892	: V=1.055868, theta=-29.87625 -> V=1.010427, theta=0.0
% INFO    : Bus 2893	: V=1.062192, theta=-36.47934 -> V=1.012836, theta=0.0
% INFO    : Bus 2894	: V=1.026681, theta=-25.760867 -> V=1.0, theta=0.0
% INFO    : Bus 2895	: V=1.073834, theta=3.181348 -> V=1.021836, theta=0.0
% INFO    : Bus 2896	: V=1.076455, theta=-11.515071 -> V=1.0279345, theta=0.0
% INFO    : Bus 2897	: V=1.070373, theta=-20.300599 -> V=1.0176795, theta=0.0
% INFO    : Bus 2898	: V=1.02288, theta=-22.098043 -> V=1.0, theta=0.0
% INFO    : Bus 2899	: V=1.037744, theta=-29.629195 -> V=1.0, theta=0.0
% INFO    : Bus 2900	: V=1.043618, theta=-12.299307 -> V=1.0, theta=0.0
% INFO    : Bus 2901	: V=1.083289, theta=-41.425378 -> V=1.0275495, theta=0.0
% INFO    : Bus 2902	: V=1.007818, theta=48.693314 -> V=1.0, theta=0.0
% INFO    : Bus 2903	: V=1.062981, theta=11.749103 -> V=1.007664, theta=0.0
% INFO    : Bus 2904	: V=1.042791, theta=-12.186136 -> V=1.0071155, theta=0.0
% INFO    : Bus 2905	: V=1.091495, theta=-13.918236 -> V=1.0312395, theta=0.0
% INFO    : Bus 2906	: V=1.092832, theta=-39.219982 -> V=1.031634, theta=0.0
% INFO    : Bus 2907	: V=1.052964, theta=-36.357715 -> V=1.01745, theta=0.0
% INFO    : Bus 2908	: V=1.067691, theta=-32.518832 -> V=1.0142315, theta=0.0
% INFO    : Bus 2909	: V=0.968446, theta=-12.842848 -> V=1.0, theta=0.0
% INFO    : Bus 2910	: V=0.983182, theta=-33.384459 -> V=1.0, theta=0.0
% INFO    : Bus 2911	: V=1.06048, theta=-22.022673 -> V=1.019015, theta=0.0
% INFO    : Bus 2912	: V=1.030401, theta=-24.301847 -> V=1.0, theta=0.0
% INFO    : Bus 2913	: V=1.069406, theta=25.410679 -> V=1.0128475, theta=0.0
% INFO    : Bus 2914	: V=1.024037, theta=-16.561097 -> V=1.0, theta=0.0
% INFO    : Bus 2915	: V=1.063111, theta=-9.524379 -> V=1.0152995, theta=0.0
% INFO    : Bus 2916	: V=1.077342, theta=-1.39469 -> V=1.013932, theta=0.0
% INFO    : Bus 2917	: V=1.096427, theta=8.533967 -> V=1.025127, theta=0.0
% INFO    : Bus 2918	: V=0.928457, theta=-23.185415 -> V=1.0, theta=0.0
% INFO    : Bus 2919	: V=1.081465, theta=-25.064029 -> V=1.019874, theta=0.0
% INFO    : Bus 2920	: V=0.988449, theta=-37.145049 -> V=1.0, theta=0.0
% INFO    : Bus 2921	: V=1.043088, theta=7.259541 -> V=1.0, theta=0.0
% INFO    : Bus 2922	: V=1.031073, theta=-40.297721 -> V=1.0, theta=0.0
% INFO    : Bus 2923	: V=1.017209, theta=-22.29518 -> V=1.0, theta=0.0
% INFO    : Bus 2924	: V=1.040196, theta=-20.652844 -> V=1.0, theta=0.0
% INFO    : Bus 2925	: V=1.071987, theta=-2.443752 -> V=1.021002, theta=0.0
% INFO    : Bus 2926	: V=1.070963, theta=-2.55651 -> V=1.0205415, theta=0.0
% INFO    : Bus 2927	: V=1.054318, theta=-10.304506 -> V=1.0100805, theta=0.0
% INFO    : Bus 2928	: V=1.057045, theta=9.752306 -> V=1.010641, theta=0.0
% INFO    : Bus 2929	: V=1.049979, theta=-11.615394 -> V=1.003766, theta=0.0
% INFO    : Bus 2930	: V=0.989834, theta=-36.205638 -> V=1.0, theta=0.0
% INFO    : Bus 2931	: V=1.012901, theta=-21.912101 -> V=1.0, theta=0.0
% INFO    : Bus 2932	: V=1.069318, theta=22.313237 -> V=1.008117, theta=0.0
% INFO    : Bus 2933	: V=1.024544, theta=12.674949 -> V=1.0, theta=0.0
% INFO    : Bus 2934	: V=1.088158, theta=-26.898486 -> V=1.0220695, theta=0.0
% INFO    : Bus 2935	: V=1.083431, theta=-15.588848 -> V=1.032811, theta=0.0
% INFO    : Bus 2936	: V=1.098211, theta=-15.581378 -> V=1.0439735, theta=0.0
% INFO    : Bus 2937	: V=1.04127, theta=-14.316994 -> V=1.006685, theta=0.0
% INFO    : Bus 2938	: V=0.997635, theta=-26.477314 -> V=1.0, theta=0.0
% INFO    : Bus 2939	: V=1.020864, theta=-42.048303 -> V=1.0, theta=0.0
% INFO    : Bus 2940	: V=1.0705, theta=-22.319689 -> V=1.0105175, theta=0.0
% INFO    : Bus 2941	: V=1.029379, theta=-16.029925 -> V=1.0, theta=0.0
% INFO    : Bus 2942	: V=1.026591, theta=-26.893398 -> V=1.0, theta=0.0
% INFO    : Bus 2943	: V=1.047606, theta=-21.218837 -> V=1.0044145, theta=0.0
% INFO    : Bus 2944	: V=1.078628, theta=-35.26126 -> V=1.0287935, theta=0.0
% INFO    : Bus 2945	: V=1.092885, theta=-11.251163 -> V=1.030968, theta=0.0
% INFO    : Bus 2946	: V=1.087545, theta=-1.032971 -> V=1.026184, theta=0.0
% INFO    : Bus 2947	: V=1.054574, theta=-16.871844 -> V=1.0099085, theta=0.0
% INFO    : Bus 2948	: V=1.08624, theta=-9.134961 -> V=1.025903, theta=0.0
% INFO    : Bus 2949	: V=1.036049, theta=-17.284365 -> V=1.007552, theta=0.0
% INFO    : Bus 2950	: V=1.043739, theta=-20.653319 -> V=1.0, theta=0.0
% INFO    : Bus 2951	: V=1.027394, theta=-21.20604 -> V=1.0, theta=0.0
% INFO    : Bus 2952	: V=1.064365, theta=8.117001 -> V=1.015639, theta=0.0
% INFO    : Bus 2953	: V=0.996651, theta=-27.472636 -> V=1.0, theta=0.0
% INFO    : Bus 2954	: V=1.095794, theta=-11.226288 -> V=1.034219, theta=0.0
% INFO    : Bus 2955	: V=1.034796, theta=0.11921 -> V=1.0, theta=0.0
% INFO    : Bus 2956	: V=1.020164, theta=-15.279162 -> V=1.0, theta=0.0
% INFO    : Bus 2957	: V=1.065364, theta=24.835544 -> V=1.007638, theta=0.0
% INFO    : Bus 2958	: V=0.994519, theta=-16.682469 -> V=1.0, theta=0.0
% INFO    : Bus 2959	: V=1.053981, theta=-14.837508 -> V=1.0059705, theta=0.0
% INFO    : Bus 2960	: V=1.062173, theta=-21.051562 -> V=1.019592, theta=0.0
% INFO    : Bus 2961	: V=1.07952, theta=-47.003678 -> V=1.0181955, theta=0.0
% INFO    : Bus 2962	: V=1.010308, theta=9.405488 -> V=1.0, theta=0.0
% INFO    : Bus 2963	: V=1.003753, theta=-24.689226 -> V=1.0, theta=0.0
% INFO    : Bus 2964	: V=1.082548, theta=-17.322142 -> V=1.031966, theta=0.0
% INFO    : Bus 2965	: V=1.001623, theta=9.757293 -> V=1.0, theta=0.0
% INFO    : Bus 2966	: V=1.104831, theta=-20.196172 -> V=1.0, theta=0.0
% INFO    : Bus 2967	: V=1.056273, theta=-21.158846 -> V=1.0258055, theta=0.0
% INFO    : Bus 2968	: V=1.069263, theta=18.478192 -> V=1.0179935, theta=0.0
% INFO    : Bus 2969	: V=1.072857, theta=-46.821614 -> V=1.0142405, theta=0.0
% INFO    : Bus 2970	: V=1.02902, theta=-49.549768 -> V=1.0, theta=0.0
% INFO    : Bus 2971	: V=1.061676, theta=21.764821 -> V=1.0150235, theta=0.0
% INFO    : Bus 2972	: V=1.080021, theta=-35.918561 -> V=1.0219445, theta=0.0
% INFO    : Bus 2973	: V=1.059599, theta=3.907864 -> V=1.008186, theta=0.0
% INFO    : Bus 2974	: V=0.987583, theta=-17.285401 -> V=1.0, theta=0.0
% INFO    : Bus 2975	: V=0.952053, theta=-24.0663 -> V=1.0, theta=0.0
% INFO    : Bus 2976	: V=1.043903, theta=-30.841539 -> V=1.00287, theta=0.0
% INFO    : Bus 2977	: V=1.070603, theta=-39.006717 -> V=1.0206755, theta=0.0
% INFO    : Bus 2978	: V=1.0913, theta=-7.348617 -> V=1.029874, theta=0.0
% INFO    : Bus 2979	: V=1.07182, theta=-15.293222 -> V=1.0101305, theta=0.0
% INFO    : Bus 2980	: V=1.071091, theta=-24.982263 -> V=1.00582, theta=0.0
% INFO    : Bus 2981	: V=1.083585, theta=-6.006357 -> V=1.020358, theta=0.0
% INFO    : Bus 2982	: V=1.075349, theta=-1.951692 -> V=1.0223905, theta=0.0
% INFO    : Bus 2983	: V=1.008822, theta=-11.819252 -> V=1.0, theta=0.0
% INFO    : Bus 2984	: V=1.066468, theta=-51.893841 -> V=1.0, theta=0.0
% INFO    : Bus 2985	: V=1.058895, theta=-29.704244 -> V=1.012321, theta=0.0
% INFO    : Bus 2986	: V=1.086684, theta=-25.586738 -> V=1.0218095, theta=0.0
% INFO    : Bus 2987	: V=1.003861, theta=-15.722515 -> V=1.0, theta=0.0
% INFO    : Bus 2988	: V=1.015739, theta=-19.90835 -> V=1.0, theta=0.0
% INFO    : Bus 2989	: V=1.003496, theta=-23.891826 -> V=1.0, theta=0.0
% INFO    : Bus 2990	: V=1.097053, theta=8.622068 -> V=1.0146485, theta=0.0
% INFO    : Bus 2991	: V=1.042136, theta=-40.513228 -> V=1.00408, theta=0.0
% INFO    : Bus 2992	: V=1.045123, theta=-11.331823 -> V=1.008991, theta=0.0
% INFO    : Bus 2993	: V=1.064348, theta=-1.36035 -> V=1.0168285, theta=0.0
% INFO    : Bus 2994	: V=1.016345, theta=-26.874598 -> V=1.043626, theta=0.0
% INFO    : Bus 2995	: V=1.012289, theta=-21.9118 -> V=1.0, theta=0.0
% INFO    : Bus 2996	: V=1.003159, theta=-23.571916 -> V=1.0, theta=0.0
% INFO    : Bus 2997	: V=1.036267, theta=-19.773625 -> V=1.008062, theta=0.0
% INFO    : Bus 2998	: V=1.05505, theta=6.406052 -> V=1.003474, theta=0.0
% INFO    : Bus 2999	: V=0.969295, theta=-25.734721 -> V=1.0, theta=0.0
% INFO    : Bus 3000	: V=1.075094, theta=-1.729751 -> V=1.022153, theta=0.0
% INFO    : Bus 3001	: V=1.064543, theta=-9.244203 -> V=1.017842, theta=0.0
% INFO    : Bus 3002	: V=1.046091, theta=8.406196 -> V=1.009549, theta=0.0
% INFO    : Bus 3003	: V=1.026633, theta=-23.601729 -> V=1.0, theta=0.0
% INFO    : Bus 3004	: V=1.080601, theta=-16.830247 -> V=1.0253475, theta=0.0
% INFO    : Bus 3005	: V=1.020547, theta=-22.845816 -> V=1.0103005, theta=0.0
% INFO    : Bus 3006	: V=1.0, theta=-5.043151 -> V=1.0, theta=0.0
% INFO    : Bus 3007	: V=1.003783, theta=-32.916916 -> V=1.0, theta=0.0
% INFO    : Bus 3008	: V=1.058575, theta=-15.251834 -> V=1.0, theta=0.0
% INFO    : Bus 3009	: V=1.085527, theta=-13.73514 -> V=1.026342, theta=0.0
% INFO    : Bus 3010	: V=1.068652, theta=2.4194 -> V=1.02009, theta=0.0
% INFO    : Bus 3011	: V=1.036213, theta=-21.55027 -> V=1.006363, theta=0.0
% INFO    : Bus 3012	: V=1.019148, theta=-32.434261 -> V=1.0, theta=0.0
% INFO    : Bus 3013	: V=0.968237, theta=-26.066436 -> V=1.0, theta=0.0
% INFO    : Bus 3014	: V=1.054959, theta=-14.736713 -> V=1.00918, theta=0.0
% INFO    : Bus 3015	: V=1.021075, theta=-21.33261 -> V=1.0, theta=0.0
% INFO    : Bus 3016	: V=1.009742, theta=13.572274 -> V=1.0, theta=0.0
% INFO    : Bus 3017	: V=0.942133, theta=65.870463 -> V=1.0, theta=0.0
% INFO    : Bus 3018	: V=1.059273, theta=-15.204714 -> V=1.0141045, theta=0.0
% INFO    : Bus 3019	: V=1.069291, theta=-19.082239 -> V=1.018769, theta=0.0
% INFO    : Bus 3020	: V=1.073273, theta=7.751892 -> V=1.0294265, theta=0.0
% INFO    : Bus 3021	: V=1.040299, theta=-11.625128 -> V=1.0, theta=0.0
% INFO    : Bus 3022	: V=0.984444, theta=-19.644972 -> V=1.0, theta=0.0
% INFO    : Bus 3023	: V=0.968236, theta=-17.871157 -> V=1.0, theta=0.0
% INFO    : Bus 3024	: V=1.030364, theta=65.884655 -> V=1.0, theta=0.0
% INFO    : Bus 3025	: V=1.063558, theta=-9.477405 -> V=1.015504, theta=0.0
% INFO    : Bus 3026	: V=1.03285, theta=39.128509 -> V=1.0, theta=0.0
% INFO    : Bus 3027	: V=1.082318, theta=11.673814 -> V=1.0312585, theta=0.0
% INFO    : Bus 3028	: V=1.025909, theta=-34.584864 -> V=1.0, theta=0.0
% INFO    : Bus 3029	: V=1.040526, theta=25.906379 -> V=1.0158735, theta=0.0
% INFO    : Bus 3030	: V=1.030231, theta=-32.668653 -> V=1.0, theta=0.0
% INFO    : Bus 3031	: V=0.957473, theta=-22.872858 -> V=1.0, theta=0.0
% INFO    : Bus 3032	: V=1.026441, theta=-23.760392 -> V=1.0, theta=0.0
% INFO    : Bus 3033	: V=1.003182, theta=-9.399957 -> V=1.0, theta=0.0
% INFO    : Bus 3034	: V=1.006631, theta=-39.037707 -> V=1.0, theta=0.0
% INFO    : Bus 3035	: V=1.02589, theta=-36.295819 -> V=1.0, theta=0.0
% INFO    : Bus 3036	: V=1.049278, theta=-42.33604 -> V=1.0043825, theta=0.0
% INFO    : Bus 3037	: V=1.0521, theta=-15.562147 -> V=1.002847, theta=0.0
% INFO    : Bus 3038	: V=1.074632, theta=-11.35296 -> V=1.017146, theta=0.0
% INFO    : Bus 3039	: V=1.061833, theta=-20.337599 -> V=1.012381, theta=0.0
% INFO    : Bus 3040	: V=1.057573, theta=-30.223551 -> V=1.0116675, theta=0.0
% INFO    : Bus 3041	: V=1.087237, theta=66.661369 -> V=1.0, theta=0.0
% INFO    : Bus 3042	: V=0.972237, theta=-24.777487 -> V=1.0, theta=0.0
% INFO    : Bus 3043	: V=1.088193, theta=-27.374381 -> V=1.033683, theta=0.0
% INFO    : Bus 3044	: V=1.051033, theta=9.65765 -> V=1.00576, theta=0.0
% INFO    : Bus 3045	: V=1.081773, theta=-2.798707 -> V=1.0232475, theta=0.0
% INFO    : Bus 3046	: V=1.041428, theta=-25.089107 -> V=1.0, theta=0.0
% INFO    : Bus 3047	: V=1.028381, theta=-2.994963 -> V=1.0, theta=0.0
% INFO    : Bus 3048	: V=1.085969, theta=-14.458368 -> V=1.0233625, theta=0.0
% INFO    : Bus 3049	: V=1.013357, theta=14.456595 -> V=1.0, theta=0.0
% INFO    : Bus 3050	: V=1.019781, theta=-23.85086 -> V=1.0, theta=0.0
% INFO    : Bus 3051	: V=1.002717, theta=-23.606678 -> V=1.0, theta=0.0
% INFO    : Bus 3052	: V=1.087105, theta=-25.530327 -> V=1.022491, theta=0.0
% INFO    : Bus 3053	: V=1.062052, theta=5.03699 -> V=1.013716, theta=0.0
% INFO    : Bus 3054	: V=1.055591, theta=-15.852267 -> V=1.0093615, theta=0.0
% INFO    : Bus 3055	: V=1.067642, theta=1.578991 -> V=1.0148265, theta=0.0
% INFO    : Bus 3056	: V=1.074, theta=-12.014604 -> V=1.0269975, theta=0.0
% INFO    : Bus 3057	: V=1.048153, theta=-18.119406 -> V=1.009967, theta=0.0
% INFO    : Bus 3058	: V=0.969778, theta=-22.645306 -> V=1.0, theta=0.0
% INFO    : Bus 3059	: V=1.068901, theta=-47.707222 -> V=1.011662, theta=0.0
% INFO    : Bus 3060	: V=1.086521, theta=-6.970111 -> V=1.02371, theta=0.0
% INFO    : Bus 3061	: V=0.949452, theta=-20.611045 -> V=1.0, theta=0.0
% INFO    : Bus 3062	: V=1.082724, theta=16.347499 -> V=1.013807, theta=0.0
% INFO    : Bus 3063	: V=1.036818, theta=-31.317998 -> V=1.0, theta=0.0
% INFO    : Bus 3064	: V=0.993199, theta=-23.856781 -> V=1.0, theta=0.0
% INFO    : Bus 3065	: V=1.024599, theta=-15.800574 -> V=1.0, theta=0.0
% INFO    : Bus 3066	: V=1.063094, theta=8.595146 -> V=1.003076, theta=0.0
% INFO    : Bus 3067	: V=1.004682, theta=3.072873 -> V=1.0, theta=0.0
% INFO    : Bus 3068	: V=1.040333, theta=-15.75639 -> V=1.0, theta=0.0
% INFO    : Bus 3069	: V=1.066992, theta=-9.713682 -> V=1.016932, theta=0.0
% INFO    : Bus 3070	: V=1.032648, theta=-41.169306 -> V=1.0, theta=0.0
% INFO    : Bus 3071	: V=0.998568, theta=-21.430918 -> V=1.0, theta=0.0
% INFO    : Bus 3072	: V=0.961372, theta=-18.873153 -> V=1.0, theta=0.0
% INFO    : Bus 3073	: V=1.072029, theta=-42.461354 -> V=1.009411, theta=0.0
% INFO    : Bus 3074	: V=1.005816, theta=-32.10697 -> V=1.0, theta=0.0
% INFO    : Bus 3075	: V=1.02928, theta=-43.852293 -> V=1.0, theta=0.0
% INFO    : Bus 3076	: V=0.958516, theta=-29.073595 -> V=0.9974325, theta=0.0
% INFO    : Bus 3077	: V=1.017948, theta=-22.940404 -> V=1.0089345, theta=0.0
% INFO    : Bus 3078	: V=1.068652, theta=2.4194 -> V=1.02009, theta=0.0
% INFO    : Bus 3079	: V=1.018318, theta=-3.449897 -> V=1.0, theta=0.0
% INFO    : Bus 3080	: V=1.044682, theta=-11.480405 -> V=1.008477, theta=0.0
% INFO    : Bus 3081	: V=1.073766, theta=-20.184055 -> V=1.0388495, theta=0.0
% INFO    : Bus 3082	: V=0.957716, theta=-25.67641 -> V=1.0, theta=0.0
% INFO    : Bus 3083	: V=1.038648, theta=-10.170538 -> V=1.0, theta=0.0
% INFO    : Bus 3084	: V=0.977859, theta=-25.427294 -> V=1.0, theta=0.0
% INFO    : Bus 3085	: V=1.003788, theta=-24.739094 -> V=1.0, theta=0.0
% INFO    : Bus 3086	: V=1.074053, theta=54.85819 -> V=1.0, theta=0.0
% INFO    : Bus 3087	: V=1.078084, theta=0.269717 -> V=1.0237725, theta=0.0
% INFO    : Bus 3088	: V=0.978189, theta=-28.791355 -> V=1.0, theta=0.0
% INFO    : Bus 3089	: V=0.954497, theta=-26.787892 -> V=1.0, theta=0.0
% INFO    : Bus 3090	: V=1.058125, theta=-23.9344 -> V=1.01635, theta=0.0
% INFO    : Bus 3091	: V=1.080147, theta=-12.764753 -> V=1.0174425, theta=0.0
% INFO    : Bus 3092	: V=1.063538, theta=0.577203 -> V=1.0178395, theta=0.0
% INFO    : Bus 3093	: V=1.038064, theta=-27.443733 -> V=1.0, theta=0.0
% INFO    : Bus 3094	: V=1.006418, theta=-23.483663 -> V=1.0, theta=0.0
% INFO    : Bus 3095	: V=1.053678, theta=-21.066389 -> V=1.0, theta=0.0
% INFO    : Bus 3096	: V=1.023853, theta=-27.475478 -> V=1.0, theta=0.0
% INFO    : Bus 3097	: V=1.062375, theta=-35.579827 -> V=1.018184, theta=0.0
% INFO    : Bus 3098	: V=0.977118, theta=-25.641839 -> V=1.0, theta=0.0
% INFO    : Bus 3099	: V=0.994091, theta=-5.770157 -> V=1.0, theta=0.0
% INFO    : Bus 3100	: V=1.074784, theta=2.456169 -> V=1.027462, theta=0.0
% INFO    : Bus 3101	: V=1.023463, theta=-44.10462 -> V=1.0, theta=0.0
% INFO    : Bus 3102	: V=1.033301, theta=-35.951008 -> V=1.0, theta=0.0
% INFO    : Bus 3103	: V=1.027439, theta=-21.240965 -> V=1.0, theta=0.0
% INFO    : Bus 3104	: V=1.003318, theta=-32.861751 -> V=1.0, theta=0.0
% INFO    : Bus 3105	: V=0.979939, theta=-26.475468 -> V=1.0, theta=0.0
% INFO    : Bus 3106	: V=1.020153, theta=-21.031406 -> V=1.0, theta=0.0
% INFO    : Bus 3107	: V=1.016722, theta=-29.403456 -> V=1.0, theta=0.0
% INFO    : Bus 3108	: V=1.037993, theta=-19.777788 -> V=1.0, theta=0.0
% INFO    : Bus 3109	: V=1.039123, theta=-15.478106 -> V=1.0138035, theta=0.0
% INFO    : Bus 3110	: V=1.096545, theta=-10.66646 -> V=1.035773, theta=0.0
% INFO    : Bus 3111	: V=1.043342, theta=-17.012245 -> V=1.0, theta=0.0
% INFO    : Bus 3112	: V=1.054874, theta=-49.207278 -> V=1.005861, theta=0.0
% INFO    : Bus 3113	: V=1.052562, theta=-49.019879 -> V=1.00565, theta=0.0
% INFO    : Bus 3114	: V=1.076969, theta=-40.463479 -> V=1.0140185, theta=0.0
% INFO    : Bus 3115	: V=1.02256, theta=-51.68238 -> V=1.0, theta=0.0
% INFO    : Bus 3116	: V=0.993546, theta=-15.351667 -> V=1.0, theta=0.0
% INFO    : Bus 3117	: V=1.047318, theta=66.194703 -> V=1.0, theta=0.0
% INFO    : Bus 3118	: V=1.07932, theta=-15.374402 -> V=1.010383, theta=0.0
% INFO    : Bus 3119	: V=1.063758, theta=-20.964184 -> V=1.0084525, theta=0.0
% INFO    : Bus 3120	: V=0.968204, theta=-22.097585 -> V=1.0, theta=0.0
% INFO    : Bus 3121	: V=1.054091, theta=-24.395115 -> V=1.014334, theta=0.0
% INFO    : Bus 3122	: V=1.052864, theta=-12.884699 -> V=1.0191225, theta=0.0
% INFO    : Bus 3123	: V=1.035448, theta=-17.053031 -> V=1.005512, theta=0.0
% INFO    : Bus 3124	: V=1.055182, theta=3.270548 -> V=1.0146415, theta=0.0
% INFO    : Bus 3125	: V=1.087042, theta=-12.466533 -> V=1.0204275, theta=0.0
% INFO    : Bus 3126	: V=1.0775, theta=-13.253798 -> V=1.017068, theta=0.0
% INFO    : Bus 3127	: V=1.055582, theta=-48.671578 -> V=1.006066, theta=0.0
% INFO    : Bus 3128	: V=1.056115, theta=5.504791 -> V=1.0048935, theta=0.0
% INFO    : Bus 3129	: V=0.949447, theta=-24.354367 -> V=1.0, theta=0.0
% INFO    : Bus 3130	: V=1.044212, theta=-6.1826 -> V=1.004852, theta=0.0
% INFO    : Bus 3131	: V=1.074294, theta=-6.041978 -> V=1.009094, theta=0.0
% INFO    : Bus 3132	: V=1.042023, theta=-36.688391 -> V=1.0, theta=0.0
% INFO    : Bus 3133	: V=1.054667, theta=-20.81845 -> V=1.0076515, theta=0.0
% INFO    : Bus 3134	: V=1.076794, theta=-18.889467 -> V=1.0075995, theta=0.0
% INFO    : Bus 3135	: V=1.051404, theta=-20.54431 -> V=1.0104, theta=0.0
% INFO    : Bus 3136	: V=0.964291, theta=-18.600522 -> V=1.0, theta=0.0
% INFO    : Bus 3137	: V=0.934331, theta=-25.674079 -> V=1.0, theta=0.0
% INFO    : Bus 3138	: V=0.996729, theta=-22.815655 -> V=1.0, theta=0.0
% INFO    : Bus 3139	: V=1.069999, theta=-4.424369 -> V=1.011309, theta=0.0
% INFO    : Bus 3140	: V=1.079827, theta=-12.289138 -> V=1.0169425, theta=0.0
% INFO    : Bus 3141	: V=1.075448, theta=-1.939198 -> V=1.022436, theta=0.0
% INFO    : Bus 3142	: V=1.031482, theta=-35.955999 -> V=1.0, theta=0.0
% INFO    : Bus 3143	: V=1.032947, theta=-18.144229 -> V=1.0, theta=0.0
% INFO    : Bus 3144	: V=1.03054, theta=-24.947004 -> V=1.0, theta=0.0
% INFO    : Bus 3145	: V=1.076029, theta=9.805544 -> V=1.014789, theta=0.0
% INFO    : Bus 3146	: V=1.003816, theta=-23.479426 -> V=1.0, theta=0.0
% INFO    : Bus 3147	: V=1.013932, theta=-47.882634 -> V=1.0, theta=0.0
% INFO    : Bus 3148	: V=1.03219, theta=-30.472952 -> V=1.0, theta=0.0
% INFO    : Bus 3149	: V=0.954703, theta=-29.384894 -> V=1.0, theta=0.0
% INFO    : Bus 3150	: V=1.0668, theta=-43.228151 -> V=1.008743, theta=0.0
% INFO    : Bus 3151	: V=1.030966, theta=-27.498677 -> V=1.0, theta=0.0
% INFO    : Bus 3152	: V=0.981248, theta=-22.885849 -> V=1.0, theta=0.0
% INFO    : Bus 3153	: V=1.064122, theta=-29.423453 -> V=1.0124775, theta=0.0
% INFO    : Bus 3154	: V=1.055968, theta=-19.423448 -> V=1.0077, theta=0.0
% INFO    : Bus 3155	: V=1.002663, theta=-26.096258 -> V=1.0, theta=0.0
% INFO    : Bus 3156	: V=1.040234, theta=-22.333869 -> V=1.0, theta=0.0
% INFO    : Bus 3157	: V=1.094347, theta=34.690759 -> V=1.010836, theta=0.0
% INFO    : Bus 3158	: V=1.023272, theta=-15.231689 -> V=1.0060495, theta=0.0
% INFO    : Bus 3159	: V=1.031114, theta=-40.292116 -> V=1.0, theta=0.0
% INFO    : Bus 3160	: V=1.000588, theta=12.069677 -> V=1.0, theta=0.0
% INFO    : Bus 3161	: V=1.075727, theta=-16.544665 -> V=1.0210965, theta=0.0
% INFO    : Bus 3162	: V=1.070664, theta=-19.654371 -> V=1.018152, theta=0.0
% INFO    : Bus 3163	: V=0.961833, theta=-30.882426 -> V=1.0, theta=0.0
% INFO    : Bus 3164	: V=1.083595, theta=1.94371 -> V=1.014813, theta=0.0
% INFO    : Bus 3165	: V=1.06295, theta=11.729464 -> V=1.0076515, theta=0.0
% INFO    : Bus 3166	: V=1.03757, theta=-15.536186 -> V=1.003027, theta=0.0
% INFO    : Bus 3167	: V=1.075149, theta=-19.823175 -> V=1.0195965, theta=0.0
% INFO    : Bus 3168	: V=1.049407, theta=-35.985153 -> V=1.0, theta=0.0
% INFO    : Bus 3169	: V=1.041017, theta=-12.479683 -> V=1.0063125, theta=0.0
% INFO    : Bus 3170	: V=1.055812, theta=-48.631672 -> V=1.005158, theta=0.0
% INFO    : Bus 3171	: V=1.041869, theta=-32.577565 -> V=1.0053505, theta=0.0
% INFO    : Bus 3172	: V=0.955046, theta=-34.785328 -> V=1.0, theta=0.0
% INFO    : Bus 3173	: V=1.058682, theta=-8.152941 -> V=1.008003, theta=0.0
% INFO    : Bus 3174	: V=1.073299, theta=-10.993906 -> V=1.0186, theta=0.0
% INFO    : Bus 3175	: V=1.070895, theta=-18.518174 -> V=1.0109065, theta=0.0
% INFO    : Bus 3176	: V=1.049129, theta=-51.902872 -> V=1.0, theta=0.0
% INFO    : Bus 3177	: V=1.07358, theta=-20.271266 -> V=1.0263365, theta=0.0
% INFO    : Bus 3178	: V=1.073532, theta=2.918109 -> V=1.0218, theta=0.0
% INFO    : Bus 3179	: V=1.069351, theta=-9.820513 -> V=1.01505, theta=0.0
% INFO    : Bus 3180	: V=1.078839, theta=-3.464642 -> V=1.021261, theta=0.0
% INFO    : Bus 3181	: V=1.057646, theta=-47.815172 -> V=1.0060355, theta=0.0
% INFO    : Bus 3182	: V=1.068949, theta=-9.760004 -> V=1.018142, theta=0.0
% INFO    : Bus 3183	: V=1.096026, theta=-11.176767 -> V=1.0260045, theta=0.0
% INFO    : Bus 3184	: V=0.976557, theta=-22.841304 -> V=1.0, theta=0.0
% INFO    : Bus 3185	: V=1.016398, theta=-7.421913 -> V=1.0, theta=0.0
% INFO    : Bus 3186	: V=1.064651, theta=-10.981418 -> V=1.019299, theta=0.0
% INFO    : Bus 3187	: V=1.055728, theta=-35.644444 -> V=1.0187565, theta=0.0
% INFO    : Bus 3188	: V=1.075658, theta=-20.923204 -> V=1.0030675, theta=0.0
% INFO    : Bus 3189	: V=1.067366, theta=9.729743 -> V=1.0, theta=0.0
% INFO    : Bus 3190	: V=1.079692, theta=-18.576331 -> V=1.026881, theta=0.0
% INFO    : Bus 3191	: V=1.099364, theta=1.523774 -> V=1.0446365, theta=0.0
% INFO    : Bus 3192	: V=1.046462, theta=-48.378524 -> V=1.0, theta=0.0
% INFO    : Bus 3193	: V=1.078842, theta=-3.620859 -> V=1.0197975, theta=0.0
% INFO    : Bus 3194	: V=1.094331, theta=45.036874 -> V=1.0084945, theta=0.0
% INFO    : Bus 3195	: V=1.027682, theta=0.999078 -> V=1.012352, theta=0.0
% INFO    : Bus 3196	: V=1.013112, theta=-16.44844 -> V=1.0, theta=0.0
% INFO    : Bus 3197	: V=1.06287, theta=6.595481 -> V=1.020996, theta=0.0
% INFO    : Bus 3198	: V=1.038667, theta=-7.750821 -> V=1.0078035, theta=0.0
% INFO    : Bus 3199	: V=1.051378, theta=-23.727266 -> V=1.0108945, theta=0.0
% INFO    : Bus 3200	: V=1.065831, theta=-6.830068 -> V=1.0167155, theta=0.0
% INFO    : Bus 3201	: V=1.061351, theta=8.11278 -> V=1.01241, theta=0.0
% INFO    : Bus 3202	: V=0.958475, theta=-29.378311 -> V=1.0, theta=0.0
% INFO    : Bus 3203	: V=1.044371, theta=-22.142775 -> V=1.0030155, theta=0.0
% INFO    : Bus 3204	: V=1.057919, theta=65.60903 -> V=1.0, theta=0.0
% INFO    : Bus 3205	: V=1.070342, theta=-5.01357 -> V=1.0180685, theta=0.0
% INFO    : Bus 3206	: V=0.973168, theta=-22.371002 -> V=1.0, theta=0.0
% INFO    : Bus 3207	: V=1.020382, theta=-23.331467 -> V=1.0, theta=0.0
% INFO    : Bus 3208	: V=1.072647, theta=-18.619454 -> V=1.0065655, theta=0.0
% INFO    : Bus 3209	: V=1.062107, theta=0.616986 -> V=1.012268, theta=0.0
% INFO    : Bus 3210	: V=1.030649, theta=-21.731398 -> V=1.012738, theta=0.0
% INFO    : Bus 3211	: V=0.956692, theta=-29.273887 -> V=0.9956255, theta=0.0
% INFO    : Bus 3212	: V=1.079236, theta=-11.418151 -> V=1.0160585, theta=0.0
% INFO    : Bus 3213	: V=1.058499, theta=-20.182301 -> V=1.0080255, theta=0.0
% INFO    : Bus 3214	: V=1.06802, theta=-23.157995 -> V=1.0264805, theta=0.0
% INFO    : Bus 3215	: V=1.024741, theta=-20.37732 -> V=1.0, theta=0.0
% INFO    : Bus 3216	: V=1.076733, theta=-9.582766 -> V=1.0230015, theta=0.0
% INFO    : Bus 3217	: V=1.028778, theta=13.663149 -> V=1.003124, theta=0.0
% INFO    : Bus 3218	: V=1.055127, theta=-10.341895 -> V=1.012766, theta=0.0
% INFO    : Bus 3219	: V=1.060572, theta=-35.38254 -> V=1.020883, theta=0.0
% INFO    : Bus 3220	: V=1.071282, theta=-22.717958 -> V=1.0279505, theta=0.0
% INFO    : Bus 3221	: V=0.992509, theta=10.978088 -> V=1.0, theta=0.0
% INFO    : Bus 3222	: V=1.038476, theta=-16.695508 -> V=1.0077465, theta=0.0
% INFO    : Bus 3223	: V=1.068766, theta=-39.399619 -> V=1.0079115, theta=0.0
% INFO    : Bus 3224	: V=1.090518, theta=-7.456859 -> V=1.0294865, theta=0.0
% INFO    : Bus 3225	: V=1.067243, theta=-18.974382 -> V=1.020017, theta=0.0
% INFO    : Bus 3226	: V=1.091455, theta=2.355425 -> V=1.0275955, theta=0.0
% INFO    : Bus 3227	: V=0.915007, theta=-32.339722 -> V=1.0, theta=0.0
% INFO    : Bus 3228	: V=1.029975, theta=-38.966407 -> V=1.0, theta=0.0
% INFO    : Bus 3229	: V=1.065273, theta=-19.51989 -> V=1.0030765, theta=0.0
% INFO    : Bus 3230	: V=1.018318, theta=4.128085 -> V=1.0, theta=0.0
% INFO    : Bus 3231	: V=1.048932, theta=21.902365 -> V=1.004399, theta=0.0
% INFO    : Bus 3232	: V=0.993385, theta=-16.719773 -> V=1.0, theta=0.0
% INFO    : Bus 3233	: V=1.014888, theta=-20.219618 -> V=1.0, theta=0.0
% INFO    : Bus 3234	: V=1.053504, theta=-19.29452 -> V=1.0, theta=0.0
% INFO    : Bus 3235	: V=1.042276, theta=-43.14176 -> V=1.0, theta=0.0
% INFO    : Bus 3236	: V=1.049154, theta=-30.125574 -> V=1.0222565, theta=0.0
% INFO    : Bus 3237	: V=1.096506, theta=2.311152 -> V=1.031597, theta=0.0
% INFO    : Bus 3238	: V=0.996965, theta=-25.87292 -> V=1.0, theta=0.0
% INFO    : Bus 3239	: V=1.052248, theta=-34.762187 -> V=1.01557, theta=0.0
% INFO    : Bus 3240	: V=0.970726, theta=-24.528316 -> V=1.0, theta=0.0
% INFO    : Bus 3241	: V=0.917824, theta=-29.167224 -> V=1.0, theta=0.0
% INFO    : Bus 3242	: V=1.05965, theta=-34.074774 -> V=1.0104975, theta=0.0
% INFO    : Bus 3243	: V=1.057682, theta=-28.400536 -> V=1.012951, theta=0.0
% INFO    : Bus 3244	: V=0.948251, theta=-27.493913 -> V=1.0, theta=0.0
% INFO    : Bus 3245	: V=1.016549, theta=-30.024046 -> V=1.0, theta=0.0
% INFO    : Bus 3246	: V=1.074999, theta=-19.957051 -> V=1.0058255, theta=0.0
% INFO    : Bus 3247	: V=1.0415, theta=-18.45953 -> V=1.00797, theta=0.0
% INFO    : Bus 3248	: V=1.020227, theta=-46.248334 -> V=1.0, theta=0.0
% INFO    : Bus 3249	: V=1.0033, theta=-12.417895 -> V=1.0, theta=0.0
% INFO    : Bus 3250	: V=1.026574, theta=-23.580712 -> V=1.0, theta=0.0
% INFO    : Bus 3251	: V=1.030959, theta=-27.2231 -> V=1.0, theta=0.0
% INFO    : Bus 3252	: V=0.975812, theta=-21.737974 -> V=1.0, theta=0.0
% INFO    : Bus 3253	: V=1.045635, theta=-14.894211 -> V=1.0182025, theta=0.0
% INFO    : Bus 3254	: V=1.070314, theta=-5.309326 -> V=1.018862, theta=0.0
% INFO    : Bus 3255	: V=1.070098, theta=32.407615 -> V=1.0, theta=0.0
% INFO    : Bus 3256	: V=1.051337, theta=-38.895968 -> V=1.042546, theta=0.0
% INFO    : Bus 3257	: V=1.076136, theta=-32.717456 -> V=1.038938, theta=0.0
% INFO    : Bus 3258	: V=1.024328, theta=-24.649029 -> V=1.0, theta=0.0
% INFO    : Bus 3259	: V=1.087053, theta=-44.75495 -> V=1.0175895, theta=0.0
% INFO    : Bus 3260	: V=1.069474, theta=31.389322 -> V=1.0168475, theta=0.0
% INFO    : Bus 3261	: V=1.0525, theta=-40.473365 -> V=1.0, theta=0.0
% INFO    : Bus 3262	: V=1.024136, theta=-40.425792 -> V=1.0, theta=0.0
% INFO    : Bus 3263	: V=1.039906, theta=-18.727312 -> V=1.0, theta=0.0
% INFO    : Bus 3264	: V=1.094732, theta=-36.201886 -> V=1.027303, theta=0.0
% INFO    : Bus 3265	: V=0.987907, theta=-25.17741 -> V=1.0, theta=0.0
% INFO    : Bus 3266	: V=1.039581, theta=-6.324915 -> V=1.0144905, theta=0.0
% INFO    : Bus 3267	: V=1.008716, theta=-45.404537 -> V=1.0, theta=0.0
% INFO    : Bus 3268	: V=1.032685, theta=-25.351507 -> V=1.0, theta=0.0
% INFO    : Bus 3269	: V=1.072893, theta=-18.81232 -> V=1.018308, theta=0.0
% INFO    : Bus 3270	: V=1.023126, theta=-14.154816 -> V=1.0, theta=0.0
% INFO    : Bus 3271	: V=1.007265, theta=-48.506211 -> V=1.0, theta=0.0
% INFO    : Bus 3272	: V=1.015728, theta=-19.908581 -> V=1.0, theta=0.0
% INFO    : Bus 3273	: V=1.012068, theta=-35.076991 -> V=1.0, theta=0.0
% INFO    : Bus 3274	: V=1.015545, theta=-3.731409 -> V=1.0, theta=0.0
% INFO    : Bus 3275	: V=1.052139, theta=-15.034527 -> V=1.0, theta=0.0
% INFO    : Bus 3276	: V=1.07049, theta=-20.321105 -> V=1.0177465, theta=0.0
% INFO    : Bus 3277	: V=1.078536, theta=-17.955881 -> V=1.021739, theta=0.0
% INFO    : Bus 3278	: V=1.047282, theta=-21.55009 -> V=1.0036075, theta=0.0
% INFO    : Bus 3279	: V=1.062439, theta=-19.517429 -> V=1.0078875, theta=0.0
% INFO    : Bus 3280	: V=1.075, theta=-34.734836 -> V=1.0169675, theta=0.0
% INFO    : Bus 3281	: V=0.967356, theta=43.104772 -> V=1.0, theta=0.0
% INFO    : Bus 3282	: V=1.033934, theta=12.727123 -> V=1.0, theta=0.0
% INFO    : Bus 3283	: V=1.018901, theta=-40.864908 -> V=1.0197255, theta=0.0
% INFO    : Bus 3284	: V=1.09526, theta=-11.351647 -> V=1.0350255, theta=0.0
% INFO    : Bus 3285	: V=1.07219, theta=-21.588298 -> V=1.027679, theta=0.0
% INFO    : Bus 3286	: V=1.051455, theta=-17.711089 -> V=1.0, theta=0.0
% INFO    : Bus 3287	: V=1.024717, theta=-27.274397 -> V=1.0180185, theta=0.0
% INFO    : Bus 3288	: V=1.012295, theta=-17.05189 -> V=1.005065, theta=0.0
% INFO    : Bus 3289	: V=1.061344, theta=-35.422202 -> V=1.018077, theta=0.0
% INFO    : Bus 3290	: V=1.041342, theta=-0.67683 -> V=1.006089, theta=0.0
% INFO    : Bus 3291	: V=1.030759, theta=31.449083 -> V=1.0, theta=0.0
% INFO    : Bus 3292	: V=1.012, theta=-14.173778 -> V=1.0, theta=0.0
% INFO    : Bus 3293	: V=1.030431, theta=-24.498799 -> V=1.0, theta=0.0
% INFO    : Bus 3294	: V=1.07468, theta=1.207178 -> V=1.0238505, theta=0.0
% INFO    : Bus 3295	: V=1.0555, theta=-47.601482 -> V=1.0034995, theta=0.0
% INFO    : Bus 3296	: V=1.096315, theta=-27.144461 -> V=1.0276575, theta=0.0
% INFO    : Bus 3297	: V=1.057169, theta=-29.960743 -> V=1.005808, theta=0.0
% INFO    : Bus 3298	: V=0.958127, theta=-25.581572 -> V=1.0, theta=0.0
% INFO    : Bus 3299	: V=1.022842, theta=-19.179077 -> V=1.0, theta=0.0
% INFO    : Bus 3300	: V=1.02117, theta=-22.117502 -> V=1.0, theta=0.0
% INFO    : Bus 3301	: V=1.017182, theta=-40.228324 -> V=1.0, theta=0.0
% INFO    : Bus 3302	: V=0.948873, theta=-27.043488 -> V=1.0, theta=0.0
% INFO    : Bus 3303	: V=1.097002, theta=56.286031 -> V=1.0082925, theta=0.0
% INFO    : Bus 3304	: V=1.039284, theta=-19.924334 -> V=1.009409, theta=0.0
% INFO    : Bus 3305	: V=1.072863, theta=-50.091603 -> V=1.0, theta=0.0
% INFO    : Bus 3306	: V=1.098046, theta=-26.524751 -> V=1.028129, theta=0.0
% INFO    : Bus 3307	: V=1.028074, theta=16.478914 -> V=1.0, theta=0.0
% INFO    : Bus 3308	: V=1.011915, theta=-21.816908 -> V=1.0, theta=0.0
% INFO    : Bus 3309	: V=0.939333, theta=-25.674459 -> V=1.0, theta=0.0
% INFO    : Bus 3310	: V=1.039533, theta=-22.817752 -> V=1.007821, theta=0.0
% INFO    : Bus 3311	: V=1.074035, theta=-19.563833 -> V=1.0162045, theta=0.0
% INFO    : Bus 3312	: V=0.969248, theta=-20.984706 -> V=1.0, theta=0.0
% INFO    : Bus 3313	: V=1.047248, theta=-18.103372 -> V=1.0, theta=0.0
% INFO    : Bus 3314	: V=1.054091, theta=-38.789163 -> V=1.0, theta=0.0
% INFO    : Bus 3315	: V=1.069365, theta=-31.365263 -> V=1.02819, theta=0.0
% INFO    : Bus 3316	: V=1.048224, theta=-21.337576 -> V=1.004505, theta=0.0
% INFO    : Bus 3317	: V=1.084886, theta=34.296505 -> V=1.0192365, theta=0.0
% INFO    : Bus 3318	: V=1.086337, theta=5.515906 -> V=1.0109715, theta=0.0
% INFO    : Bus 3319	: V=1.018897, theta=-38.460848 -> V=1.028113, theta=0.0
% INFO    : Bus 3320	: V=1.069032, theta=-39.230696 -> V=1.007535, theta=0.0
% INFO    : Bus 3321	: V=1.082974, theta=-22.278497 -> V=1.0243755, theta=0.0
% INFO    : Bus 3322	: V=1.053869, theta=-20.881549 -> V=1.007301, theta=0.0
% INFO    : Bus 3323	: V=1.076162, theta=-25.51135 -> V=1.033093, theta=0.0
% INFO    : Bus 3324	: V=1.026483, theta=3.626935 -> V=1.0, theta=0.0
% INFO    : Bus 3325	: V=1.070591, theta=-11.063933 -> V=1.024976, theta=0.0
% INFO    : Bus 3326	: V=1.077592, theta=-25.2018 -> V=1.0336465, theta=0.0
% INFO    : Bus 3327	: V=1.020131, theta=-21.03116 -> V=1.0, theta=0.0
% INFO    : Bus 3328	: V=1.064474, theta=1.143328 -> V=1.014431, theta=0.0
% INFO    : Bus 3329	: V=1.082816, theta=4.41849 -> V=1.0260625, theta=0.0
% INFO    : Bus 3330	: V=1.072364, theta=-39.650398 -> V=1.0153275, theta=0.0
% INFO    : Bus 3331	: V=1.063021, theta=7.201363 -> V=1.0061455, theta=0.0
% INFO    : Bus 3332	: V=1.014264, theta=-39.380835 -> V=1.0, theta=0.0
% INFO    : Bus 3333	: V=1.021539, theta=-22.194056 -> V=1.0, theta=0.0
% INFO    : Bus 3334	: V=1.050158, theta=-20.692501 -> V=1.0, theta=0.0
% INFO    : Bus 3335	: V=1.043045, theta=9.727364 -> V=1.0, theta=0.0
% INFO    : Bus 3336	: V=1.061744, theta=-20.591143 -> V=1.0330225, theta=0.0
% INFO    : Bus 3337	: V=1.073953, theta=-20.870822 -> V=1.026777, theta=0.0
% INFO    : Bus 3338	: V=0.915012, theta=-26.52649 -> V=1.0, theta=0.0
% INFO    : Bus 3339	: V=1.041334, theta=-12.869304 -> V=1.0067625, theta=0.0
% INFO    : Bus 3340	: V=1.036227, theta=-35.228121 -> V=1.0, theta=0.0
% INFO    : Bus 3341	: V=1.071885, theta=-13.915092 -> V=1.0176065, theta=0.0
% INFO    : Bus 3342	: V=0.985062, theta=62.471679 -> V=1.0, theta=0.0
% INFO    : Bus 3343	: V=1.093923, theta=-7.142414 -> V=1.025681, theta=0.0
% INFO    : Bus 3344	: V=0.999976, theta=-32.104144 -> V=1.0, theta=0.0
% INFO    : Bus 3345	: V=1.056492, theta=-20.818879 -> V=1.0, theta=0.0
% INFO    : Bus 3346	: V=1.009926, theta=-8.447309 -> V=1.0, theta=0.0
% INFO    : Bus 3347	: V=1.073697, theta=-13.973278 -> V=1.014801, theta=0.0
% INFO    : Bus 3348	: V=0.956995, theta=-29.24601 -> V=0.995884, theta=0.0
% INFO    : Bus 3349	: V=0.949194, theta=-24.320657 -> V=1.0, theta=0.0
% INFO    : Bus 3350	: V=1.012908, theta=-21.158847 -> V=1.00332, theta=0.0
% INFO    : Bus 3351	: V=1.090832, theta=-21.256486 -> V=1.0285875, theta=0.0
% INFO    : Bus 3352	: V=0.928433, theta=-23.21615 -> V=1.0, theta=0.0
% INFO    : Bus 3353	: V=1.038395, theta=-22.432084 -> V=1.0, theta=0.0
% INFO    : Bus 3354	: V=1.086411, theta=-45.482002 -> V=1.023433, theta=0.0
% INFO    : Bus 3355	: V=0.97316, theta=-24.417613 -> V=1.0, theta=0.0
% INFO    : Bus 3356	: V=1.071727, theta=-40.704987 -> V=1.012312, theta=0.0
% INFO    : Bus 3357	: V=1.013653, theta=-22.158841 -> V=1.0, theta=0.0
% INFO    : Bus 3358	: V=1.076067, theta=11.390954 -> V=1.003945, theta=0.0
% INFO    : Bus 3359	: V=1.009909, theta=-38.308132 -> V=1.0, theta=0.0
% INFO    : Bus 3360	: V=1.005901, theta=-21.573799 -> V=1.0, theta=0.0
% INFO    : Bus 3361	: V=1.084737, theta=-29.745117 -> V=1.0359435, theta=0.0
% INFO    : Bus 3362	: V=1.058124, theta=-19.746396 -> V=1.0266285, theta=0.0
% INFO    : Bus 3363	: V=1.073636, theta=-23.112933 -> V=1.0193445, theta=0.0
% INFO    : Bus 3364	: V=1.065624, theta=-40.081415 -> V=1.0119325, theta=0.0
% INFO    : Bus 3365	: V=0.982218, theta=-19.819994 -> V=1.0, theta=0.0
% INFO    : Bus 3366	: V=1.058573, theta=-23.87324 -> V=1.0165455, theta=0.0
% INFO    : Bus 3367	: V=1.082158, theta=-19.271456 -> V=1.009032, theta=0.0
% INFO    : Bus 3368	: V=1.042601, theta=-15.698722 -> V=1.0, theta=0.0
% INFO    : Bus 3369	: V=1.020285, theta=-23.565546 -> V=1.0, theta=0.0
% INFO    : Bus 3370	: V=1.046839, theta=-34.274081 -> V=1.0047015, theta=0.0
% INFO    : Bus 3371	: V=1.023485, theta=-15.971256 -> V=1.0, theta=0.0
% INFO    : Bus 3372	: V=1.044146, theta=-15.012966 -> V=1.015494, theta=0.0
% INFO    : Bus 3373	: V=1.028239, theta=-4.422104 -> V=1.0, theta=0.0
% INFO    : Bus 3374	: V=1.084155, theta=-25.937614 -> V=1.020425, theta=0.0
% INFO    : Bus 3375	: V=1.0198, theta=-34.894617 -> V=1.0, theta=0.0
% INFO    : Bus 3376	: V=1.066214, theta=2.276817 -> V=1.0194335, theta=0.0
% INFO    : Bus 3377	: V=1.009112, theta=-18.286031 -> V=1.0, theta=0.0
% INFO    : Bus 3378	: V=1.094135, theta=-7.913485 -> V=1.0296235, theta=0.0
% INFO    : Bus 3379	: V=1.064765, theta=-44.015029 -> V=1.0066505, theta=0.0
% INFO    : Bus 3380	: V=1.053754, theta=-12.574131 -> V=1.0112795, theta=0.0
% INFO    : Bus 3381	: V=1.004304, theta=-21.727199 -> V=1.0, theta=0.0
% INFO    : Bus 3382	: V=1.056327, theta=-24.093965 -> V=1.015493, theta=0.0
% INFO    : Bus 3383	: V=1.021214, theta=-34.194667 -> V=1.0, theta=0.0
% INFO    : Bus 3384	: V=1.002727, theta=-0.385926 -> V=1.002699, theta=0.0
% INFO    : Bus 3385	: V=1.050814, theta=-44.51312 -> V=1.0, theta=0.0
% INFO    : Bus 3386	: V=0.969993, theta=-25.610197 -> V=1.0, theta=0.0
% INFO    : Bus 3387	: V=1.050894, theta=44.187988 -> V=1.010511, theta=0.0
% INFO    : Bus 3388	: V=1.031955, theta=-7.849073 -> V=1.0, theta=0.0
% INFO    : Bus 3389	: V=0.965981, theta=-25.901439 -> V=1.0, theta=0.0
% INFO    : Bus 3390	: V=1.00079, theta=-35.428405 -> V=1.0, theta=0.0
% INFO    : Bus 3391	: V=1.046543, theta=8.029156 -> V=1.010807, theta=0.0
% INFO    : Bus 3392	: V=1.05887, theta=-48.132635 -> V=1.008357, theta=0.0
% INFO    : Bus 3393	: V=1.105204, theta=-8.715155 -> V=1.027185, theta=0.0
% INFO    : Bus 3394	: V=0.974734, theta=-17.792305 -> V=1.0, theta=0.0
% INFO    : Bus 3395	: V=1.057325, theta=-12.180266 -> V=1.0087085, theta=0.0
% INFO    : Bus 3396	: V=1.04408, theta=-9.779599 -> V=1.0, theta=0.0
% INFO    : Bus 3397	: V=0.989052, theta=-19.182315 -> V=1.0, theta=0.0
% INFO    : Bus 3398	: V=1.070654, theta=-42.501841 -> V=1.0084415, theta=0.0
% INFO    : Bus 3399	: V=0.953361, theta=-25.943321 -> V=1.0, theta=0.0
% INFO    : Bus 3400	: V=1.056969, theta=-52.85065 -> V=1.0, theta=0.0
% INFO    : Bus 3401	: V=1.080953, theta=-3.911881 -> V=1.021007, theta=0.0
% INFO    : Bus 3402	: V=0.942133, theta=-29.637286 -> V=1.0, theta=0.0
% INFO    : Bus 3403	: V=1.067545, theta=60.894272 -> V=1.006628, theta=0.0
% INFO    : Bus 3404	: V=1.078472, theta=-20.197481 -> V=1.020671, theta=0.0
% INFO    : Bus 3405	: V=1.080816, theta=-0.257425 -> V=1.0209285, theta=0.0
% INFO    : Bus 3406	: V=1.060307, theta=-20.732583 -> V=1.0, theta=0.0
% INFO    : Bus 3407	: V=1.025067, theta=64.668813 -> V=1.0, theta=0.0
% INFO    : Bus 3408	: V=1.071874, theta=-42.196835 -> V=1.0107955, theta=0.0
% INFO    : Bus 3409	: V=0.971131, theta=-27.359587 -> V=1.0, theta=0.0
% INFO    : Bus 3410	: V=1.037364, theta=-21.159226 -> V=1.0, theta=0.0
% INFO    : Bus 3411	: V=1.052926, theta=-48.502116 -> V=1.00552, theta=0.0
% INFO    : Bus 3412	: V=0.987809, theta=-24.980661 -> V=1.0, theta=0.0
% INFO    : Bus 3413	: V=1.06697, theta=-16.961048 -> V=1.0246015, theta=0.0
% INFO    : Bus 3414	: V=1.000136, theta=-21.299784 -> V=1.0, theta=0.0
% INFO    : Bus 3415	: V=1.017567, theta=-14.51231 -> V=1.0, theta=0.0
% INFO    : Bus 3416	: V=0.968531, theta=-20.7919 -> V=1.0, theta=0.0
% INFO    : Bus 3417	: V=1.048421, theta=10.271012 -> V=1.0039175, theta=0.0
% INFO    : Bus 3418	: V=1.039143, theta=-31.479248 -> V=1.010121, theta=0.0
% INFO    : Bus 3419	: V=0.980764, theta=-25.222208 -> V=1.0, theta=0.0
% INFO    : Bus 3420	: V=0.9541, theta=-32.133171 -> V=1.0, theta=0.0
% INFO    : Bus 3421	: V=1.09286, theta=-17.961845 -> V=1.0329285, theta=0.0
% INFO    : Bus 3422	: V=1.0155, theta=49.268373 -> V=1.0, theta=0.0
% INFO    : Bus 3423	: V=1.072448, theta=-20.178414 -> V=1.038211, theta=0.0
% INFO    : Bus 3424	: V=1.050277, theta=-16.387558 -> V=1.0, theta=0.0
% INFO    : Bus 3425	: V=1.039631, theta=-4.835891 -> V=1.0098085, theta=0.0
% INFO    : Bus 3426	: V=1.043068, theta=-20.691062 -> V=1.0, theta=0.0
% INFO    : Bus 3427	: V=1.00239, theta=-20.015909 -> V=1.0, theta=0.0
% INFO    : Bus 3428	: V=1.048768, theta=-19.06868 -> V=1.0058415, theta=0.0
% INFO    : Bus 3429	: V=1.075142, theta=-45.486564 -> V=1.01624, theta=0.0
% INFO    : Bus 3430	: V=1.048363, theta=-20.971457 -> V=1.0090535, theta=0.0
% INFO    : Bus 3431	: V=1.053636, theta=-42.627113 -> V=1.004228, theta=0.0
% INFO    : Bus 3432	: V=0.953822, theta=-27.617023 -> V=1.0, theta=0.0
% INFO    : Bus 3433	: V=1.062556, theta=-1.777142 -> V=1.019252, theta=0.0
% INFO    : Bus 3434	: V=1.053025, theta=6.314511 -> V=1.00663, theta=0.0
% INFO    : Bus 3435	: V=1.094654, theta=-29.275071 -> V=1.0203875, theta=0.0
% INFO    : Bus 3436	: V=0.967053, theta=-28.063171 -> V=1.0, theta=0.0
% INFO    : Bus 3437	: V=1.015158, theta=-22.144172 -> V=1.0, theta=0.0
% INFO    : Bus 3438	: V=1.066825, theta=9.62827 -> V=1.0, theta=0.0
% INFO    : Bus 3439	: V=0.997258, theta=9.421188 -> V=1.0, theta=0.0
% INFO    : Bus 3440	: V=1.049761, theta=-21.032225 -> V=1.003804, theta=0.0
% INFO    : Bus 3441	: V=1.03857, theta=-21.641596 -> V=1.007553, theta=0.0
% INFO    : Bus 3442	: V=1.009539, theta=39.734249 -> V=1.0, theta=0.0
% INFO    : Bus 3443	: V=1.037787, theta=-21.193353 -> V=1.0, theta=0.0
% INFO    : Bus 3444	: V=1.007545, theta=-3.521072 -> V=1.0, theta=0.0
% INFO    : Bus 3445	: V=1.049961, theta=11.753126 -> V=1.0053005, theta=0.0
% INFO    : Bus 3446	: V=1.055236, theta=-20.072994 -> V=1.0216075, theta=0.0
% INFO    : Bus 3447	: V=0.992894, theta=14.756874 -> V=1.0, theta=0.0
% INFO    : Bus 3448	: V=1.057436, theta=-21.201925 -> V=1.0077285, theta=0.0
% INFO    : Bus 3449	: V=1.036453, theta=17.687708 -> V=1.0, theta=0.0
% INFO    : Bus 3450	: V=1.031647, theta=-23.623828 -> V=1.0, theta=0.0
% INFO    : Bus 3451	: V=1.0126, theta=-35.915539 -> V=1.0, theta=0.0
% INFO    : Bus 3452	: V=1.071955, theta=-40.04127 -> V=1.0167585, theta=0.0
% INFO    : Bus 3453	: V=1.050529, theta=-19.896605 -> V=1.018657, theta=0.0
% INFO    : Bus 3454	: V=1.025117, theta=-27.367363 -> V=1.018171, theta=0.0
% INFO    : Bus 3455	: V=0.989247, theta=-20.660067 -> V=1.0, theta=0.0
% INFO    : Bus 3456	: V=0.999498, theta=-19.366314 -> V=1.0, theta=0.0
% INFO    : Bus 3457	: V=1.019947, theta=19.290059 -> V=1.0, theta=0.0
% INFO    : Bus 3458	: V=1.085555, theta=-37.047725 -> V=1.014703, theta=0.0
% INFO    : Bus 3459	: V=0.960802, theta=-34.44008 -> V=1.0, theta=0.0
% INFO    : Bus 3460	: V=1.061813, theta=-22.032886 -> V=1.0153325, theta=0.0
% INFO    : Bus 3461	: V=0.97089, theta=-24.429547 -> V=1.0, theta=0.0
% INFO    : Bus 3462	: V=0.927191, theta=-29.169688 -> V=1.0, theta=0.0
% INFO    : Bus 3463	: V=0.989702, theta=-22.779086 -> V=1.0, theta=0.0
% INFO    : Bus 3464	: V=0.994237, theta=-17.494445 -> V=1.0, theta=0.0
% INFO    : Bus 3465	: V=1.103974, theta=11.408652 -> V=1.0156765, theta=0.0
% INFO    : Bus 3466	: V=1.081364, theta=-33.273848 -> V=1.038113, theta=0.0
% INFO    : Bus 3467	: V=1.043, theta=-4.699071 -> V=1.0, theta=0.0
% INFO    : Bus 3468	: V=1.080883, theta=-35.505992 -> V=1.027973, theta=0.0
% INFO    : Bus 3469	: V=1.03048, theta=-24.302047 -> V=1.0, theta=0.0
% INFO    : Bus 3470	: V=1.054809, theta=-48.898878 -> V=1.004933, theta=0.0
% INFO    : Bus 3471	: V=1.047489, theta=-21.033898 -> V=1.0085555, theta=0.0
% INFO    : Bus 3472	: V=1.002346, theta=-22.314062 -> V=1.0, theta=0.0
% INFO    : Bus 3473	: V=1.012909, theta=-47.526125 -> V=1.0, theta=0.0
% INFO    : Bus 3474	: V=1.10001, theta=-14.656263 -> V=1.0403145, theta=0.0
% INFO    : Bus 3475	: V=1.053461, theta=-24.620604 -> V=1.014177, theta=0.0
% INFO    : Bus 3476	: V=1.066871, theta=-3.237849 -> V=1.018929, theta=0.0
% INFO    : Bus 3477	: V=0.994, theta=-29.58117 -> V=1.0, theta=0.0
% INFO    : Bus 3478	: V=1.0305, theta=-35.113464 -> V=1.0, theta=0.0
% INFO    : Bus 3479	: V=1.053046, theta=-42.203761 -> V=1.005184, theta=0.0
% INFO    : Bus 3480	: V=0.987295, theta=-24.257215 -> V=1.0, theta=0.0
% INFO    : Bus 3481	: V=1.088395, theta=-8.550356 -> V=1.021631, theta=0.0
% INFO    : Bus 3482	: V=1.054287, theta=-18.000889 -> V=1.0157005, theta=0.0
% INFO    : Bus 3483	: V=0.973805, theta=-18.109586 -> V=1.0, theta=0.0
% INFO    : Bus 3484	: V=1.024855, theta=-25.563044 -> V=1.0, theta=0.0
% INFO    : Bus 3485	: V=1.043436, theta=-13.242384 -> V=1.007836, theta=0.0
% INFO    : Bus 3486	: V=1.038995, theta=-22.498736 -> V=1.0, theta=0.0
% INFO    : Bus 3487	: V=1.004844, theta=-27.483216 -> V=1.0, theta=0.0
% INFO    : Bus 3488	: V=1.000063, theta=-22.438522 -> V=1.0, theta=0.0
% INFO    : Bus 3489	: V=1.059604, theta=-21.254364 -> V=1.0183715, theta=0.0
% INFO    : Bus 3490	: V=1.049698, theta=-9.825999 -> V=1.009274, theta=0.0
% INFO    : Bus 3491	: V=1.00106, theta=-40.003272 -> V=1.0, theta=0.0
% INFO    : Bus 3492	: V=0.958127, theta=-25.581572 -> V=1.0, theta=0.0
% INFO    : Bus 3493	: V=1.002652, theta=-33.538123 -> V=1.0, theta=0.0
% INFO    : Bus 3494	: V=0.943726, theta=-27.354013 -> V=1.0, theta=0.0
% INFO    : Bus 3495	: V=1.079818, theta=-39.927872 -> V=1.012806, theta=0.0
% INFO    : Bus 3496	: V=1.075727, theta=-16.550563 -> V=1.0211565, theta=0.0
% INFO    : Bus 3497	: V=0.988637, theta=-17.843057 -> V=1.0, theta=0.0
% INFO    : Bus 3498	: V=1.046583, theta=-39.196522 -> V=1.0, theta=0.0
% INFO    : Bus 3499	: V=1.075208, theta=-0.570671 -> V=1.021882, theta=0.0
% INFO    : Bus 3500	: V=1.062438, theta=9.534242 -> V=1.0, theta=0.0
% INFO    : Bus 3501	: V=0.983813, theta=-26.129652 -> V=1.0, theta=0.0
% INFO    : Bus 3502	: V=1.066946, theta=4.670151 -> V=1.021552, theta=0.0
% INFO    : Bus 3503	: V=1.010255, theta=-26.498574 -> V=1.0, theta=0.0
% INFO    : Bus 3504	: V=1.075726, theta=-16.542288 -> V=1.0210925, theta=0.0
% INFO    : Bus 3505	: V=1.0124, theta=63.174664 -> V=1.0, theta=0.0
% INFO    : Bus 3506	: V=1.066632, theta=32.563222 -> V=1.0201085, theta=0.0
% INFO    : Bus 3507	: V=1.094182, theta=-8.289104 -> V=1.0240825, theta=0.0
% INFO    : Bus 3508	: V=1.004584, theta=12.444403 -> V=1.0, theta=0.0
% INFO    : Bus 3509	: V=1.077512, theta=-25.28947 -> V=1.033666, theta=0.0
% INFO    : Bus 3510	: V=1.005824, theta=-29.641371 -> V=1.0, theta=0.0
% INFO    : Bus 3511	: V=1.098182, theta=-21.885136 -> V=1.044808, theta=0.0
% INFO    : Bus 3512	: V=1.069582, theta=-18.874338 -> V=1.0, theta=0.0
% INFO    : Bus 3513	: V=1.065889, theta=-0.213565 -> V=1.0192235, theta=0.0
% INFO    : Bus 3514	: V=1.039458, theta=61.163548 -> V=1.0, theta=0.0
% INFO    : Bus 3515	: V=1.038027, theta=-19.760861 -> V=1.0, theta=0.0
% INFO    : Bus 3516	: V=1.067228, theta=3.438002 -> V=1.0054305, theta=0.0
% INFO    : Bus 3517	: V=1.007889, theta=-22.61275 -> V=1.0, theta=0.0
% INFO    : Bus 3518	: V=1.021563, theta=-16.890943 -> V=1.0, theta=0.0
% INFO    : Bus 3519	: V=1.070725, theta=-13.937309 -> V=1.0201765, theta=0.0
% INFO    : Bus 3520	: V=1.041649, theta=-27.4675 -> V=1.0096535, theta=0.0
% INFO    : Bus 3521	: V=1.008251, theta=-22.247869 -> V=1.0, theta=0.0
% INFO    : Bus 3522	: V=1.065098, theta=0.990072 -> V=1.0136245, theta=0.0
% INFO    : Bus 3523	: V=1.081368, theta=0.17522 -> V=1.0214625, theta=0.0
% INFO    : Bus 3524	: V=1.002549, theta=-47.901959 -> V=1.0, theta=0.0
% INFO    : Bus 3525	: V=0.959887, theta=-13.728823 -> V=1.0, theta=0.0
% INFO    : Bus 3526	: V=1.092506, theta=-17.29639 -> V=1.030222, theta=0.0
% INFO    : Bus 3527	: V=1.003066, theta=-19.206954 -> V=1.0, theta=0.0
% INFO    : Bus 3528	: V=1.047227, theta=-9.482902 -> V=1.0097705, theta=0.0
% INFO    : Bus 3529	: V=1.035667, theta=-10.833757 -> V=1.0, theta=0.0
% INFO    : Bus 3530	: V=1.056877, theta=17.014348 -> V=1.018443, theta=0.0
% INFO    : Bus 3531	: V=1.062867, theta=-18.428352 -> V=1.0, theta=0.0
% INFO    : Bus 3532	: V=1.095247, theta=-11.350929 -> V=1.0350195, theta=0.0
% INFO    : Bus 3533	: V=0.958479, theta=-22.978341 -> V=1.0, theta=0.0
% INFO    : Bus 3534	: V=0.963782, theta=-19.199129 -> V=1.0, theta=0.0
% INFO    : Bus 3535	: V=0.985006, theta=-18.109717 -> V=1.0, theta=0.0
% INFO    : Bus 3536	: V=1.083045, theta=-25.861494 -> V=1.0209815, theta=0.0
% INFO    : Bus 3537	: V=1.067114, theta=-9.018516 -> V=1.0, theta=0.0
% INFO    : Bus 3538	: V=1.011927, theta=10.672739 -> V=1.0, theta=0.0
% INFO    : Bus 3539	: V=1.04007, theta=-18.610582 -> V=1.0, theta=0.0
% INFO    : Bus 3540	: V=1.057273, theta=-19.458444 -> V=1.0, theta=0.0
% INFO    : Bus 3541	: V=1.030714, theta=-20.287002 -> V=1.0, theta=0.0
% INFO    : Bus 3542	: V=1.02397, theta=-18.257279 -> V=1.0050225, theta=0.0
% INFO    : Bus 3543	: V=1.02157, theta=12.034734 -> V=1.0, theta=0.0
% INFO    : Bus 3544	: V=1.08117, theta=-35.095568 -> V=1.030252, theta=0.0
% INFO    : Bus 3545	: V=1.066771, theta=-13.193712 -> V=1.015722, theta=0.0
% INFO    : Bus 3546	: V=1.067746, theta=-14.352994 -> V=1.018962, theta=0.0
% INFO    : Bus 3547	: V=1.086199, theta=-28.443153 -> V=1.031832, theta=0.0
% INFO    : Bus 3548	: V=0.971465, theta=-35.488211 -> V=1.0, theta=0.0
% INFO    : Bus 3549	: V=1.007494, theta=-19.779663 -> V=1.0, theta=0.0
% INFO    : Bus 3550	: V=1.047416, theta=-1.613868 -> V=1.0054855, theta=0.0
% INFO    : Bus 3551	: V=0.935968, theta=-25.540106 -> V=1.0, theta=0.0
% INFO    : Bus 3552	: V=1.040182, theta=-18.120507 -> V=1.003076, theta=0.0
% INFO    : Bus 3553	: V=1.038501, theta=-25.219629 -> V=1.0, theta=0.0
% INFO    : Bus 3554	: V=0.96984, theta=-22.890323 -> V=1.0, theta=0.0
% INFO    : Bus 3555	: V=1.06179, theta=-23.375912 -> V=1.018021, theta=0.0
% INFO    : Bus 3556	: V=0.9431, theta=-24.373006 -> V=1.0, theta=0.0
% INFO    : Bus 3557	: V=0.99535, theta=10.385031 -> V=1.0, theta=0.0
% INFO    : Bus 3558	: V=1.078701, theta=-12.893344 -> V=1.024459, theta=0.0
% INFO    : Bus 3559	: V=0.950818, theta=-24.828633 -> V=1.0, theta=0.0
% INFO    : Bus 3560	: V=1.08469, theta=-9.064404 -> V=1.0147765, theta=0.0
% INFO    : Bus 3561	: V=1.060158, theta=20.472246 -> V=1.0, theta=0.0
% INFO    : Bus 3562	: V=1.073887, theta=-14.208011 -> V=1.015137, theta=0.0
% INFO    : Bus 3563	: V=1.078663, theta=-20.066917 -> V=1.0207165, theta=0.0
% INFO    : Bus 3564	: V=1.009743, theta=-7.307578 -> V=1.0, theta=0.0
% INFO    : Bus 3565	: V=0.935773, theta=-27.870196 -> V=1.0, theta=0.0
% INFO    : Bus 3566	: V=1.093076, theta=-8.303431 -> V=1.0236245, theta=0.0
% INFO    : Bus 3567	: V=1.075045, theta=-13.824356 -> V=1.0235105, theta=0.0
% INFO    : Bus 3568	: V=0.962106, theta=-27.631111 -> V=1.0, theta=0.0
% INFO    : Bus 3569	: V=1.07292, theta=-2.600542 -> V=1.017723, theta=0.0
% INFO    : Bus 3570	: V=1.07657, theta=-5.732215 -> V=1.0177205, theta=0.0
% INFO    : Bus 3571	: V=1.050316, theta=2.280779 -> V=1.0041, theta=0.0
% INFO    : Bus 3572	: V=1.010233, theta=-15.887108 -> V=1.0, theta=0.0
% INFO    : Bus 3573	: V=1.061184, theta=13.567723 -> V=1.00989, theta=0.0
% INFO    : Bus 3574	: V=1.011415, theta=-16.851129 -> V=1.0, theta=0.0
% INFO    : Bus 3575	: V=1.013293, theta=-24.476413 -> V=1.0, theta=0.0
% INFO    : Bus 3576	: V=1.076148, theta=-12.518107 -> V=1.0211345, theta=0.0
% INFO    : Bus 3577	: V=1.006941, theta=-38.602553 -> V=1.0, theta=0.0
% INFO    : Bus 3578	: V=0.956949, theta=-29.228607 -> V=0.996054, theta=0.0
% INFO    : Bus 3579	: V=1.080759, theta=-4.733418 -> V=1.0174155, theta=0.0
% INFO    : Bus 3580	: V=1.068029, theta=-19.233796 -> V=1.0181855, theta=0.0
% INFO    : Bus 3581	: V=1.013909, theta=-5.513233 -> V=1.0, theta=0.0
% INFO    : Bus 3582	: V=1.057866, theta=62.703284 -> V=1.0, theta=0.0
% INFO    : Bus 3583	: V=1.050552, theta=-30.688132 -> V=1.004026, theta=0.0
% INFO    : Bus 3584	: V=1.002231, theta=-23.130116 -> V=1.0, theta=0.0
% INFO    : Bus 3585	: V=1.001058, theta=7.062267 -> V=1.0, theta=0.0
% INFO    : Bus 3586	: V=1.076857, theta=-4.443736 -> V=1.017989, theta=0.0
% INFO    : Bus 3587	: V=1.064768, theta=-29.39372 -> V=1.014709, theta=0.0
% INFO    : Bus 3588	: V=1.008643, theta=-39.174216 -> V=1.0, theta=0.0
% INFO    : Bus 3589	: V=1.0215, theta=1.491485 -> V=1.011137, theta=0.0
% INFO    : Bus 3590	: V=1.048909, theta=-7.958413 -> V=1.0098825, theta=0.0
% INFO    : Bus 3591	: V=0.954148, theta=-27.099792 -> V=1.0, theta=0.0
% INFO    : Bus 3592	: V=1.031627, theta=-31.733573 -> V=1.0, theta=0.0
% INFO    : Bus 3593	: V=1.031928, theta=-11.500315 -> V=1.0, theta=0.0
% INFO    : Bus 3594	: V=1.048321, theta=-17.731256 -> V=1.004094, theta=0.0
% INFO    : Bus 3595	: V=0.9751, theta=-23.973836 -> V=1.0, theta=0.0
% INFO    : Bus 3596	: V=0.995271, theta=10.381773 -> V=1.0, theta=0.0
% INFO    : Bus 3597	: V=1.074727, theta=-34.666409 -> V=1.016009, theta=0.0
% INFO    : Bus 3598	: V=1.085273, theta=-10.7949 -> V=1.019622, theta=0.0
% INFO    : Bus 3599	: V=1.099322, theta=35.801664 -> V=1.0148655, theta=0.0
% INFO    : Bus 3600	: V=1.048044, theta=-12.578724 -> V=1.015832, theta=0.0
% INFO    : Bus 3601	: V=0.94802, theta=-27.275943 -> V=1.0, theta=0.0
% INFO    : Bus 3602	: V=1.059995, theta=7.895493 -> V=1.021583, theta=0.0
% INFO    : Bus 3603	: V=1.022115, theta=-51.464733 -> V=1.0, theta=0.0
% INFO    : Bus 3604	: V=0.978395, theta=-14.355986 -> V=1.0, theta=0.0
% INFO    : Bus 3605	: V=1.059793, theta=-22.957662 -> V=1.016877, theta=0.0
% INFO    : Bus 3606	: V=1.024049, theta=-40.441555 -> V=1.0, theta=0.0
% INFO    : Bus 3607	: V=1.074637, theta=-33.896706 -> V=1.027536, theta=0.0
% INFO    : Bus 3608	: V=1.08481, theta=7.909053 -> V=1.0195975, theta=0.0
% INFO    : Bus 3609	: V=1.030555, theta=-43.671454 -> V=1.0, theta=0.0
% INFO    : Bus 3610	: V=1.075322, theta=-22.490307 -> V=1.0298105, theta=0.0
% INFO    : Bus 3611	: V=1.054868, theta=-43.862044 -> V=1.012781, theta=0.0
% INFO    : Bus 3612	: V=0.992684, theta=-22.798285 -> V=1.0, theta=0.0
% INFO    : Bus 3613	: V=0.974334, theta=-27.319338 -> V=1.0, theta=0.0
% INFO    : Bus 3614	: V=1.076577, theta=-38.910371 -> V=1.014022, theta=0.0
% INFO    : Bus 3615	: V=1.071183, theta=-17.193598 -> V=1.010896, theta=0.0
% INFO    : Bus 3616	: V=1.083103, theta=16.348731 -> V=1.0139895, theta=0.0
% INFO    : Bus 3617	: V=1.067194, theta=-9.699079 -> V=1.0172595, theta=0.0
% INFO    : Bus 3618	: V=0.946776, theta=-26.482993 -> V=1.0, theta=0.0
% INFO    : Bus 3619	: V=1.063682, theta=-8.552007 -> V=1.0194155, theta=0.0
% INFO    : Bus 3620	: V=1.091642, theta=-17.694083 -> V=1.036798, theta=0.0
% INFO    : Bus 3621	: V=1.081274, theta=-26.218023 -> V=1.015888, theta=0.0
% INFO    : Bus 3622	: V=1.067558, theta=3.228612 -> V=1.019137, theta=0.0
% INFO    : Bus 3623	: V=1.009752, theta=-23.361745 -> V=1.0, theta=0.0
% INFO    : Bus 3624	: V=1.063096, theta=-14.469385 -> V=1.0156865, theta=0.0
% INFO    : Bus 3625	: V=1.084268, theta=-2.303352 -> V=1.02246, theta=0.0
% INFO    : Bus 3626	: V=1.094357, theta=-28.548815 -> V=1.025246, theta=0.0
% INFO    : Bus 3627	: V=1.074232, theta=-15.124951 -> V=1.01051, theta=0.0
% INFO    : Bus 3628	: V=1.0436, theta=14.72913 -> V=1.0, theta=0.0
% INFO    : Bus 3629	: V=1.018979, theta=-19.016221 -> V=1.0, theta=0.0
% INFO    : Bus 3630	: V=1.07378, theta=0.0421 -> V=1.024312, theta=0.0
% INFO    : Bus 3631	: V=0.991963, theta=-23.10158 -> V=1.0, theta=0.0
% INFO    : Bus 3632	: V=1.039364, theta=-29.376474 -> V=1.0, theta=0.0
% INFO    : Bus 3633	: V=1.014199, theta=-25.89686 -> V=1.0, theta=0.0
% INFO    : Bus 3634	: V=1.092266, theta=-44.323316 -> V=1.0246935, theta=0.0
% INFO    : Bus 3635	: V=1.067682, theta=4.421984 -> V=1.021741, theta=0.0
% INFO    : Bus 3636	: V=0.992061, theta=-20.283226 -> V=1.0, theta=0.0
% INFO    : Bus 3637	: V=1.020688, theta=-21.042891 -> V=1.0, theta=0.0
% INFO    : Bus 3638	: V=1.085047, theta=-3.381952 -> V=1.0245535, theta=0.0
% INFO    : Bus 3639	: V=1.016343, theta=-24.391481 -> V=1.0, theta=0.0
% INFO    : Bus 3640	: V=1.083955, theta=-5.197578 -> V=1.020438, theta=0.0
% INFO    : Bus 3641	: V=1.052116, theta=-11.919945 -> V=1.0120525, theta=0.0
% INFO    : Bus 3642	: V=1.038403, theta=-22.44711 -> V=1.0, theta=0.0
% INFO    : Bus 3643	: V=1.096946, theta=-6.233338 -> V=1.0320755, theta=0.0
% INFO    : Bus 3644	: V=1.051766, theta=-14.811315 -> V=1.0084835, theta=0.0
% INFO    : Bus 3645	: V=1.032109, theta=19.029613 -> V=1.0, theta=0.0
% INFO    : Bus 3646	: V=1.06829, theta=-11.615576 -> V=1.0106615, theta=0.0
% INFO    : Bus 3647	: V=1.030629, theta=-22.512233 -> V=1.0, theta=0.0
% INFO    : Bus 3648	: V=1.032834, theta=-32.131615 -> V=1.0115525, theta=0.0
% INFO    : Bus 3649	: V=1.06448, theta=9.242403 -> V=1.0, theta=0.0
% INFO    : Bus 3650	: V=1.094571, theta=-17.099839 -> V=1.0524755, theta=0.0
% INFO    : Bus 3651	: V=1.061727, theta=-4.32901 -> V=1.0184315, theta=0.0
% INFO    : Bus 3652	: V=1.011136, theta=-36.374143 -> V=1.0, theta=0.0
% INFO    : Bus 3653	: V=1.053759, theta=-49.171378 -> V=1.0055015, theta=0.0
% INFO    : Bus 3654	: V=1.020364, theta=64.057163 -> V=1.0, theta=0.0
% INFO    : Bus 3655	: V=1.027163, theta=-50.923902 -> V=1.0, theta=0.0
% INFO    : Bus 3656	: V=1.075765, theta=-12.897718 -> V=1.0149755, theta=0.0
% INFO    : Bus 3657	: V=0.963264, theta=-26.444045 -> V=1.0, theta=0.0
% INFO    : Bus 3658	: V=1.067909, theta=-38.757609 -> V=1.0075705, theta=0.0
% INFO    : Bus 3659	: V=1.042305, theta=-35.721932 -> V=1.0, theta=0.0
% INFO    : Bus 3660	: V=1.046549, theta=-20.83721 -> V=1.0, theta=0.0
% INFO    : Bus 3661	: V=1.074898, theta=-37.789987 -> V=1.0222235, theta=0.0
% INFO    : Bus 3662	: V=1.083574, theta=-45.423888 -> V=1.023114, theta=0.0
% INFO    : Bus 3663	: V=1.043276, theta=7.261274 -> V=1.0, theta=0.0
% INFO    : Bus 3664	: V=1.08898, theta=-27.054429 -> V=1.0262205, theta=0.0
% INFO    : Bus 3665	: V=1.068538, theta=2.613738 -> V=1.017498, theta=0.0
% INFO    : Bus 3666	: V=1.081342, theta=0.984154 -> V=1.0161935, theta=0.0
% INFO    : Bus 3667	: V=1.085184, theta=-3.371793 -> V=1.024617, theta=0.0
% INFO    : Bus 3668	: V=1.090552, theta=-37.139536 -> V=1.0184355, theta=0.0
% INFO    : Bus 3669	: V=1.092309, theta=-24.093282 -> V=1.02449, theta=0.0
% INFO    : Bus 3670	: V=1.030273, theta=-23.158216 -> V=1.0, theta=0.0
% INFO    : Bus 3671	: V=0.940967, theta=-24.81399 -> V=1.0, theta=0.0
% INFO    : Bus 3672	: V=1.030691, theta=-21.834225 -> V=1.003876, theta=0.0
% INFO    : Bus 3673	: V=1.065585, theta=-10.238579 -> V=1.0207535, theta=0.0
% INFO    : Bus 3674	: V=1.048489, theta=-10.805049 -> V=1.008404, theta=0.0
% INFO    : Bus 3675	: V=0.963242, theta=58.646711 -> V=1.0, theta=0.0
% INFO    : Bus 3676	: V=0.983852, theta=-21.579956 -> V=1.0, theta=0.0
% INFO    : Bus 3677	: V=1.065966, theta=-19.71325 -> V=1.0144095, theta=0.0
% INFO    : Bus 3678	: V=1.088645, theta=-27.736805 -> V=1.0349505, theta=0.0
% INFO    : Bus 3679	: V=1.083005, theta=-20.922373 -> V=1.0358985, theta=0.0
% INFO    : Bus 3680	: V=0.949911, theta=-31.576791 -> V=1.0, theta=0.0
% INFO    : Bus 3681	: V=1.064322, theta=-21.529542 -> V=1.020693, theta=0.0
% INFO    : Bus 3682	: V=1.090801, theta=-19.787733 -> V=1.027549, theta=0.0
% INFO    : Bus 3683	: V=1.07213, theta=30.569243 -> V=1.013785, theta=0.0
% INFO    : Bus 3684	: V=1.050963, theta=-10.176983 -> V=1.0148235, theta=0.0
% INFO    : Bus 3685	: V=0.949039, theta=-24.354578 -> V=1.0, theta=0.0
% INFO    : Bus 3686	: V=1.060105, theta=-0.462704 -> V=1.011929, theta=0.0
% INFO    : Bus 3687	: V=1.06324, theta=-15.145554 -> V=1.0089535, theta=0.0
% INFO    : Bus 3688	: V=1.097452, theta=-3.100422 -> V=1.0274185, theta=0.0
% INFO    : Bus 3689	: V=1.063148, theta=-9.400294 -> V=1.015246, theta=0.0
% INFO    : Bus 3690	: V=1.092336, theta=14.75044 -> V=1.035731, theta=0.0
% INFO    : Bus 3691	: V=1.0845, theta=50.910687 -> V=1.007382, theta=0.0
% INFO    : Bus 3692	: V=1.071965, theta=-42.498125 -> V=1.0098485, theta=0.0
% INFO    : Bus 3693	: V=1.081344, theta=-17.543032 -> V=1.023061, theta=0.0
% INFO    : Bus 3694	: V=1.082174, theta=-15.882183 -> V=1.0251335, theta=0.0
% INFO    : Bus 3695	: V=1.075227, theta=-9.059483 -> V=1.020788, theta=0.0
% INFO    : Bus 3696	: V=1.052651, theta=5.452255 -> V=1.010713, theta=0.0
% INFO    : Bus 3697	: V=1.028819, theta=-43.806995 -> V=1.0, theta=0.0
% INFO    : Bus 3698	: V=1.04025, theta=25.763647 -> V=1.0153195, theta=0.0
% INFO    : Bus 3699	: V=1.066186, theta=-14.05191 -> V=1.0241685, theta=0.0
% INFO    : Bus 3700	: V=1.039396, theta=-44.332749 -> V=1.0, theta=0.0
% INFO    : Bus 3701	: V=1.092661, theta=-10.335431 -> V=1.0344725, theta=0.0
% INFO    : Bus 3702	: V=1.070884, theta=-1.886866 -> V=1.018817, theta=0.0
% INFO    : Bus 3703	: V=1.041278, theta=-21.517762 -> V=1.023033, theta=0.0
% INFO    : Bus 3704	: V=1.052396, theta=-15.260266 -> V=1.0, theta=0.0
% INFO    : Bus 3705	: V=0.970924, theta=-28.074146 -> V=1.0, theta=0.0
% INFO    : Bus 3706	: V=1.025679, theta=-23.473784 -> V=1.013285, theta=0.0
% INFO    : Bus 3707	: V=0.987765, theta=-20.844105 -> V=1.0, theta=0.0
% INFO    : Bus 3708	: V=0.979002, theta=-12.010178 -> V=1.0, theta=0.0
% INFO    : Bus 3709	: V=1.033241, theta=-20.273278 -> V=1.006363, theta=0.0
% INFO    : Bus 3710	: V=1.026472, theta=-23.291768 -> V=1.0, theta=0.0
% INFO    : Bus 3711	: V=1.085591, theta=-13.332113 -> V=1.03505, theta=0.0
% INFO    : Bus 3712	: V=1.025864, theta=5.324589 -> V=1.0, theta=0.0
% INFO    : Bus 3713	: V=1.077886, theta=14.517397 -> V=1.012464, theta=0.0
% INFO    : Bus 3714	: V=1.059404, theta=-27.484015 -> V=1.015639, theta=0.0
% INFO    : Bus 3715	: V=1.027678, theta=-20.622708 -> V=1.002769, theta=0.0
% INFO    : Bus 3716	: V=1.061194, theta=-48.158996 -> V=1.009253, theta=0.0
% INFO    : Bus 3717	: V=1.08284, theta=10.639086 -> V=1.0178445, theta=0.0
% INFO    : Bus 3718	: V=1.011539, theta=-24.859836 -> V=1.0, theta=0.0
% INFO    : Bus 3719	: V=1.064455, theta=-8.499647 -> V=1.0197845, theta=0.0
% INFO    : Bus 3720	: V=1.009818, theta=39.753919 -> V=1.0, theta=0.0
% INFO    : Bus 3721	: V=1.081946, theta=15.961901 -> V=1.01348, theta=0.0
% INFO    : Bus 3722	: V=1.073517, theta=-18.270087 -> V=1.0044705, theta=0.0
% INFO    : Bus 3723	: V=1.001476, theta=-19.779203 -> V=1.0, theta=0.0
% INFO    : Bus 3724	: V=1.084051, theta=-18.258702 -> V=1.0275935, theta=0.0
% INFO    : Bus 3725	: V=1.024501, theta=15.617797 -> V=1.0, theta=0.0
% INFO    : Bus 3726	: V=1.045559, theta=-20.095596 -> V=1.0, theta=0.0
% INFO    : Bus 3727	: V=1.022909, theta=-39.727421 -> V=1.0101535, theta=0.0
% INFO    : Bus 3728	: V=1.062241, theta=-52.926721 -> V=1.0, theta=0.0
% INFO    : Bus 3729	: V=1.039981, theta=-44.216049 -> V=1.0025475, theta=0.0
% INFO    : Bus 3730	: V=0.981535, theta=-39.866648 -> V=1.0, theta=0.0
% INFO    : Bus 3731	: V=1.058735, theta=-15.483625 -> V=1.0114735, theta=0.0
% INFO    : Bus 3732	: V=1.096487, theta=-10.684474 -> V=1.0357465, theta=0.0
% INFO    : Bus 3733	: V=1.063115, theta=20.054679 -> V=1.016274, theta=0.0
% INFO    : Bus 3734	: V=0.961019, theta=-13.60166 -> V=1.0, theta=0.0
% INFO    : Bus 3735	: V=1.074832, theta=-20.610051 -> V=1.027116, theta=0.0
% INFO    : Bus 3736	: V=1.048112, theta=6.86009 -> V=1.011046, theta=0.0
% INFO    : Bus 3737	: V=1.066602, theta=-0.139882 -> V=1.019476, theta=0.0
% INFO    : Bus 3738	: V=0.974397, theta=53.78488 -> V=1.0, theta=0.0
% INFO    : Bus 3739	: V=0.988848, theta=-17.086098 -> V=1.0, theta=0.0
% INFO    : Bus 3740	: V=1.077565, theta=0.676145 -> V=1.025568, theta=0.0
% INFO    : Bus 3741	: V=1.074107, theta=-11.681952 -> V=1.018968, theta=0.0
% INFO    : Bus 3742	: V=1.014201, theta=-40.702792 -> V=1.0, theta=0.0
% INFO    : Bus 3743	: V=1.057548, theta=-15.161686 -> V=1.011815, theta=0.0
% INFO    : Bus 3744	: V=1.059024, theta=-23.342759 -> V=1.016549, theta=0.0
% INFO    : Bus 3745	: V=1.052521, theta=-7.619846 -> V=1.0059745, theta=0.0
% INFO    : Bus 3746	: V=1.023883, theta=-46.27732 -> V=1.0, theta=0.0
% INFO    : Bus 3747	: V=1.056585, theta=31.262238 -> V=1.0071685, theta=0.0
% INFO    : Bus 3748	: V=1.070909, theta=-13.878817 -> V=1.0202075, theta=0.0
% INFO    : Bus 3749	: V=1.088154, theta=44.187718 -> V=1.007982, theta=0.0
% INFO    : Bus 3750	: V=1.054954, theta=-17.922363 -> V=1.004805, theta=0.0
% INFO    : Bus 3751	: V=1.024935, theta=15.108963 -> V=1.0, theta=0.0
% INFO    : Bus 3752	: V=0.951818, theta=40.009831 -> V=1.0, theta=0.0
% INFO    : Bus 3753	: V=0.998005, theta=-23.696172 -> V=1.0, theta=0.0
% INFO    : Bus 3754	: V=1.029351, theta=-41.60243 -> V=1.0, theta=0.0
% INFO    : Bus 3755	: V=1.060789, theta=-8.129438 -> V=1.009941, theta=0.0
% INFO    : Bus 3756	: V=1.082716, theta=-15.99577 -> V=1.033278, theta=0.0
% INFO    : Bus 3757	: V=1.06857, theta=-19.177059 -> V=1.018437, theta=0.0
% INFO    : Bus 3758	: V=1.062773, theta=-14.1926 -> V=1.0098085, theta=0.0
% INFO    : Bus 3759	: V=1.040337, theta=61.753812 -> V=1.0, theta=0.0
% INFO    : Bus 3760	: V=1.059858, theta=9.042514 -> V=1.0, theta=0.0
% INFO    : Bus 3761	: V=0.996727, theta=-21.542915 -> V=1.0, theta=0.0
% INFO    : Bus 3762	: V=1.023686, theta=7.940798 -> V=1.0027095, theta=0.0
% INFO    : Bus 3763	: V=1.039069, theta=-45.937266 -> V=1.0, theta=0.0
% INFO    : Bus 3764	: V=1.074683, theta=-32.93662 -> V=1.0385715, theta=0.0
% INFO    : Bus 3765	: V=0.956189, theta=-26.43846 -> V=1.0, theta=0.0
% INFO    : Bus 3766	: V=1.010255, theta=-26.498574 -> V=1.0, theta=0.0
% INFO    : Bus 3767	: V=1.05456, theta=-30.014381 -> V=1.008811, theta=0.0
% INFO    : Bus 3768	: V=1.026799, theta=5.962987 -> V=1.0, theta=0.0
% INFO    : Bus 3769	: V=1.034312, theta=-19.471128 -> V=1.0, theta=0.0
% INFO    : Bus 3770	: V=1.040945, theta=-20.306635 -> V=1.0198415, theta=0.0
% INFO    : Bus 3771	: V=1.077334, theta=-18.7962 -> V=1.0254355, theta=0.0
% INFO    : Bus 3772	: V=1.08734, theta=-1.055089 -> V=1.026089, theta=0.0
% INFO    : Bus 3773	: V=1.050678, theta=-20.385913 -> V=1.019625, theta=0.0
% INFO    : Bus 3774	: V=1.042791, theta=61.914452 -> V=1.0, theta=0.0
% INFO    : Bus 3775	: V=1.000441, theta=10.623975 -> V=1.0, theta=0.0
% INFO    : Bus 3776	: V=1.057698, theta=-30.202046 -> V=1.011957, theta=0.0
% INFO    : Bus 3777	: V=1.025867, theta=-46.195649 -> V=1.0, theta=0.0
% INFO    : Bus 3778	: V=1.03468, theta=-11.144437 -> V=1.0, theta=0.0
% INFO    : Bus 3779	: V=1.020246, theta=-19.541099 -> V=1.0, theta=0.0
% INFO    : Bus 3780	: V=1.050539, theta=-1.068817 -> V=1.009339, theta=0.0
% INFO    : Bus 3781	: V=1.012941, theta=-47.518358 -> V=1.0, theta=0.0
% INFO    : Bus 3782	: V=1.049847, theta=57.88708 -> V=1.0, theta=0.0
% INFO    : Bus 3783	: V=1.001635, theta=10.627699 -> V=1.0, theta=0.0
% INFO    : Bus 3784	: V=0.978635, theta=-22.5794 -> V=1.0, theta=0.0
% INFO    : Bus 3785	: V=1.072302, theta=59.240391 -> V=1.0, theta=0.0
% INFO    : Bus 3786	: V=1.076576, theta=-25.454076 -> V=1.0332875, theta=0.0
% INFO    : Bus 3787	: V=1.054879, theta=-14.762284 -> V=1.009039, theta=0.0
% INFO    : Bus 3788	: V=1.091052, theta=-20.9094 -> V=1.031325, theta=0.0
% INFO    : Bus 3789	: V=1.028721, theta=-23.034342 -> V=1.0, theta=0.0
% INFO    : Bus 3790	: V=1.03492, theta=-15.23592 -> V=1.0125155, theta=0.0
% INFO    : Bus 3791	: V=1.095122, theta=-14.520712 -> V=1.0276095, theta=0.0
% INFO    : Bus 3792	: V=1.055273, theta=-0.189652 -> V=1.013322, theta=0.0
% INFO    : Bus 3793	: V=1.047501, theta=-14.859142 -> V=1.004432, theta=0.0
% INFO    : Bus 3794	: V=1.085132, theta=-40.714639 -> V=1.014598, theta=0.0
% INFO    : Bus 3795	: V=1.010428, theta=-19.574142 -> V=1.0, theta=0.0
% INFO    : Bus 3796	: V=1.068189, theta=-18.836288 -> V=1.0049615, theta=0.0
% INFO    : Bus 3797	: V=1.013096, theta=-47.479426 -> V=1.0, theta=0.0
% INFO    : Bus 3798	: V=0.953204, theta=-27.664137 -> V=1.0, theta=0.0
% INFO    : Bus 3799	: V=1.008252, theta=-28.370538 -> V=1.0, theta=0.0
% INFO    : Bus 3800	: V=1.013808, theta=-22.16545 -> V=1.0, theta=0.0
% INFO    : Bus 3801	: V=0.966545, theta=-31.741052 -> V=1.0, theta=0.0
% INFO    : Bus 3802	: V=0.983587, theta=-23.595676 -> V=1.0, theta=0.0
% INFO    : Bus 3803	: V=1.101868, theta=45.311653 -> V=1.005907, theta=0.0
% INFO    : Bus 3804	: V=1.047328, theta=-12.551433 -> V=1.0, theta=0.0
% INFO    : Bus 3805	: V=1.062628, theta=-40.401018 -> V=1.004372, theta=0.0
% INFO    : Bus 3806	: V=1.096211, theta=-37.018911 -> V=1.030914, theta=0.0
% INFO    : Bus 3807	: V=1.007364, theta=-23.796828 -> V=1.0, theta=0.0
% INFO    : Bus 3808	: V=1.066762, theta=-16.192717 -> V=1.0104335, theta=0.0
% INFO    : Bus 3809	: V=1.045876, theta=-41.672624 -> V=1.003898, theta=0.0
% INFO    : Bus 3810	: V=1.063474, theta=-39.969767 -> V=1.011972, theta=0.0
% INFO    : Bus 3811	: V=0.985, theta=-5.365432 -> V=1.0, theta=0.0
% INFO    : Bus 3812	: V=1.028911, theta=-16.650387 -> V=1.0149705, theta=0.0
% INFO    : Bus 3813	: V=1.05328, theta=-24.641276 -> V=1.0141905, theta=0.0
% INFO    : Bus 3814	: V=1.061693, theta=-22.104906 -> V=1.019669, theta=0.0
% INFO    : Bus 3815	: V=1.064474, theta=-14.293668 -> V=1.0145555, theta=0.0
% INFO    : Bus 3816	: V=1.055946, theta=-0.080088 -> V=1.0093945, theta=0.0
% INFO    : Bus 3817	: V=1.030601, theta=-25.385535 -> V=1.014478, theta=0.0
% INFO    : Bus 3818	: V=1.076708, theta=-9.123437 -> V=1.0260415, theta=0.0
% INFO    : Bus 3819	: V=0.959653, theta=-26.60083 -> V=1.0, theta=0.0
% INFO    : Bus 3820	: V=1.082763, theta=16.845003 -> V=1.0152965, theta=0.0
% INFO    : Bus 3821	: V=0.985059, theta=-23.231775 -> V=1.0, theta=0.0
% INFO    : Bus 3822	: V=1.047368, theta=5.606969 -> V=1.0, theta=0.0
% INFO    : Bus 3823	: V=1.092148, theta=-7.575205 -> V=1.023018, theta=0.0
% INFO    : Bus 3824	: V=1.079006, theta=0.891541 -> V=1.031529, theta=0.0
% INFO    : Bus 3825	: V=0.993211, theta=66.727836 -> V=1.0, theta=0.0
% INFO    : Bus 3826	: V=1.063701, theta=-19.150169 -> V=1.0081665, theta=0.0
% INFO    : Bus 3827	: V=1.040959, theta=-35.030321 -> V=1.0, theta=0.0
% INFO    : Bus 3828	: V=1.019307, theta=-29.651567 -> V=1.0, theta=0.0
% INFO    : Bus 3829	: V=1.080318, theta=-35.793108 -> V=1.0124585, theta=0.0
% INFO    : Bus 3830	: V=1.04835, theta=-12.376678 -> V=1.0168485, theta=0.0
% INFO    : Bus 3831	: V=1.07144, theta=-0.428931 -> V=1.0205755, theta=0.0
% INFO    : Bus 3832	: V=1.089, theta=-19.865745 -> V=1.0, theta=0.0
% INFO    : Bus 3833	: V=1.080086, theta=-17.643828 -> V=1.0312405, theta=0.0
% INFO    : Bus 3834	: V=1.082879, theta=16.336764 -> V=1.0140345, theta=0.0
% INFO    : Bus 3835	: V=1.046867, theta=-19.02746 -> V=1.0, theta=0.0
% INFO    : Bus 3836	: V=1.089227, theta=-21.241577 -> V=1.0133175, theta=0.0
% INFO    : Bus 3837	: V=1.008831, theta=-22.630018 -> V=1.0, theta=0.0
% INFO    : Bus 3838	: V=1.101507, theta=62.348958 -> V=1.009138, theta=0.0
% INFO    : Bus 3839	: V=1.084225, theta=-21.835902 -> V=1.0345025, theta=0.0
% INFO    : Bus 3840	: V=1.045861, theta=4.674371 -> V=1.0046835, theta=0.0
% INFO    : Bus 3841	: V=1.004933, theta=66.711146 -> V=1.0, theta=0.0
% INFO    : Bus 3842	: V=1.078, theta=28.771281 -> V=1.0083445, theta=0.0
% INFO    : Bus 3843	: V=0.988984, theta=-27.634709 -> V=1.0, theta=0.0
% INFO    : Bus 3844	: V=0.946964, theta=-27.282744 -> V=1.0, theta=0.0
% INFO    : Bus 3845	: V=1.027489, theta=-20.035917 -> V=1.0, theta=0.0
% INFO    : Bus 3846	: V=1.026423, theta=-15.435794 -> V=1.0, theta=0.0
% INFO    : Bus 3847	: V=1.07619, theta=-34.635339 -> V=1.012306, theta=0.0
% INFO    : Bus 3848	: V=1.07159, theta=-14.934968 -> V=1.0114125, theta=0.0
% INFO    : Bus 3849	: V=0.963793, theta=-19.836699 -> V=1.0, theta=0.0
% INFO    : Bus 3850	: V=1.078267, theta=64.156453 -> V=1.0, theta=0.0
% INFO    : Bus 3851	: V=0.940228, theta=-31.944613 -> V=0.971897, theta=0.0
% INFO    : Bus 3852	: V=1.00453, theta=-40.623486 -> V=1.0, theta=0.0
% INFO    : Bus 3853	: V=1.083974, theta=0.0 -> V=1.0241145, theta=0.0
% INFO    : Bus 3854	: V=1.029887, theta=-23.280801 -> V=1.0, theta=0.0
% INFO    : Bus 3855	: V=1.043215, theta=-20.959314 -> V=1.0, theta=0.0
% INFO    : Bus 3856	: V=1.093749, theta=-16.346568 -> V=1.034048, theta=0.0
% INFO    : Bus 3857	: V=1.028617, theta=-18.630928 -> V=1.019173, theta=0.0
% INFO    : Bus 3858	: V=1.01908, theta=-23.486433 -> V=1.0, theta=0.0
% INFO    : Bus 3859	: V=1.030819, theta=-43.578188 -> V=1.0, theta=0.0
% INFO    : Bus 3860	: V=1.047842, theta=-12.85216 -> V=1.0166015, theta=0.0
% INFO    : Bus 3861	: V=0.947071, theta=-27.269458 -> V=1.0, theta=0.0
% INFO    : Bus 3862	: V=1.073698, theta=-39.71224 -> V=1.0163025, theta=0.0
% INFO    : Bus 3863	: V=1.048641, theta=-23.694458 -> V=1.01533, theta=0.0
% INFO    : Bus 3864	: V=1.053918, theta=-27.023931 -> V=1.008254, theta=0.0
% INFO    : Bus 3865	: V=0.997658, theta=12.496136 -> V=1.0, theta=0.0
% INFO    : Bus 3866	: V=1.073626, theta=-9.667542 -> V=1.0221965, theta=0.0
% INFO    : Bus 3867	: V=1.031095, theta=-36.363067 -> V=1.0, theta=0.0
% INFO    : Bus 3868	: V=0.942113, theta=-33.245557 -> V=0.9611, theta=0.0
% INFO    : Bus 3869	: V=1.077131, theta=20.531055 -> V=1.0274855, theta=0.0
% INFO    : Bus 3870	: V=1.049036, theta=-49.861851 -> V=1.005879, theta=0.0
% INFO    : Bus 3871	: V=1.053234, theta=-18.165553 -> V=1.0041215, theta=0.0
% INFO    : Bus 3872	: V=1.062895, theta=-16.635169 -> V=1.01351, theta=0.0
% INFO    : Bus 3873	: V=1.042028, theta=-9.955603 -> V=1.0, theta=0.0
% INFO    : Bus 3874	: V=1.050687, theta=-49.415994 -> V=1.0066265, theta=0.0
% INFO    : Bus 3875	: V=0.99488, theta=-23.99917 -> V=1.0, theta=0.0
% INFO    : Bus 3876	: V=1.03293, theta=19.736789 -> V=1.0, theta=0.0
% INFO    : Bus 3877	: V=1.054759, theta=9.623756 -> V=1.0187045, theta=0.0
% INFO    : Bus 3878	: V=0.982366, theta=-23.700211 -> V=1.0, theta=0.0
% INFO    : Bus 3879	: V=1.0184, theta=-37.213663 -> V=1.0, theta=0.0
% INFO    : Bus 3880	: V=1.04993, theta=-15.217456 -> V=1.0, theta=0.0
% INFO    : Bus 3881	: V=1.034048, theta=3.91066 -> V=1.0029205, theta=0.0
% INFO    : Bus 3882	: V=1.005417, theta=-20.211066 -> V=1.0, theta=0.0
% INFO    : Bus 3883	: V=0.988349, theta=-19.311698 -> V=1.0, theta=0.0
% INFO    : Bus 3884	: V=0.975075, theta=-23.978347 -> V=1.0, theta=0.0
% INFO    : Bus 3885	: V=1.078943, theta=-8.276975 -> V=1.022761, theta=0.0
% INFO    : Bus 3886	: V=1.025091, theta=30.35014 -> V=1.0, theta=0.0
% INFO    : Bus 3887	: V=0.94067, theta=-28.449907 -> V=1.0, theta=0.0
% INFO    : Bus 3888	: V=1.033525, theta=-26.973656 -> V=1.0, theta=0.0
% INFO    : Bus 3889	: V=0.930821, theta=-13.291965 -> V=1.0, theta=0.0
% INFO    : Bus 3890	: V=1.062967, theta=1.01125 -> V=1.0184445, theta=0.0
% INFO    : Bus 3891	: V=1.004677, theta=-15.749941 -> V=1.0, theta=0.0
% INFO    : Bus 3892	: V=1.054952, theta=-48.882528 -> V=1.0062415, theta=0.0
% INFO    : Bus 3893	: V=1.04198, theta=-22.669645 -> V=1.022689, theta=0.0
% INFO    : Bus 3894	: V=1.077365, theta=-14.191463 -> V=1.0215675, theta=0.0
% INFO    : Bus 3895	: V=1.018405, theta=-35.062022 -> V=1.0, theta=0.0
% INFO    : Bus 3896	: V=1.034591, theta=-30.301036 -> V=1.0, theta=0.0
% INFO    : Bus 3897	: V=1.058925, theta=-4.08419 -> V=1.017216, theta=0.0
% INFO    : Bus 3898	: V=1.083085, theta=-11.591823 -> V=1.0278165, theta=0.0
% INFO    : Bus 3899	: V=1.018331, theta=-15.459762 -> V=1.0, theta=0.0
% INFO    : Bus 3900	: V=1.060523, theta=-32.534175 -> V=1.018084, theta=0.0
% INFO    : Bus 3901	: V=1.079739, theta=-15.228107 -> V=1.01058, theta=0.0
% INFO    : Bus 3902	: V=1.095499, theta=45.558148 -> V=1.0035205, theta=0.0
% INFO    : Bus 3903	: V=0.969689, theta=67.720595 -> V=1.0, theta=0.0
% INFO    : Bus 3904	: V=1.032928, theta=-18.145154 -> V=1.0, theta=0.0
% INFO    : Bus 3905	: V=1.077202, theta=-4.693793 -> V=1.01803, theta=0.0
% INFO    : Bus 3906	: V=1.041436, theta=-21.688367 -> V=1.0, theta=0.0
% INFO    : Bus 3907	: V=1.096125, theta=-36.684481 -> V=1.0312565, theta=0.0
% INFO    : Bus 3908	: V=1.084409, theta=-32.170484 -> V=1.0149435, theta=0.0
% INFO    : Bus 3909	: V=1.051092, theta=-49.564262 -> V=1.0, theta=0.0
% INFO    : Bus 3910	: V=1.060371, theta=19.875207 -> V=1.011733, theta=0.0
% INFO    : Bus 3911	: V=1.076143, theta=4.796241 -> V=1.02319, theta=0.0
% INFO    : Bus 3912	: V=1.086974, theta=57.283285 -> V=1.0, theta=0.0
% INFO    : Bus 3913	: V=1.038292, theta=-22.173538 -> V=1.0190995, theta=0.0
% INFO    : Bus 3914	: V=1.063747, theta=4.511367 -> V=1.014608, theta=0.0
% INFO    : Bus 3915	: V=1.019193, theta=-18.995192 -> V=1.0, theta=0.0
% INFO    : Bus 3916	: V=1.052473, theta=-15.786395 -> V=1.0110535, theta=0.0
% INFO    : Bus 3917	: V=1.078673, theta=-20.067288 -> V=1.0207375, theta=0.0
% INFO    : Bus 3918	: V=1.052692, theta=17.711595 -> V=1.013011, theta=0.0
% INFO    : Bus 3919	: V=1.070063, theta=-20.544144 -> V=1.013819, theta=0.0
% INFO    : Bus 3920	: V=1.0264, theta=-30.060736 -> V=1.0171135, theta=0.0
% INFO    : Bus 3921	: V=0.958878, theta=-31.644373 -> V=1.0, theta=0.0
% INFO    : Bus 3922	: V=1.011221, theta=-19.454291 -> V=1.0, theta=0.0
% INFO    : Bus 3923	: V=1.06015, theta=-25.367188 -> V=1.0, theta=0.0
% INFO    : Bus 3924	: V=0.997249, theta=-16.439426 -> V=1.0, theta=0.0
% INFO    : Bus 3925	: V=1.010453, theta=-19.644006 -> V=1.0, theta=0.0
% INFO    : Bus 3926	: V=1.0736, theta=-20.106255 -> V=1.0192705, theta=0.0
% INFO    : Bus 3927	: V=1.079743, theta=-13.997453 -> V=1.025969, theta=0.0
% INFO    : Bus 3928	: V=1.092396, theta=-34.693565 -> V=1.020512, theta=0.0
% INFO    : Bus 3929	: V=1.043686, theta=-20.653311 -> V=1.0, theta=0.0
% INFO    : Bus 3930	: V=1.017438, theta=-36.584025 -> V=1.0, theta=0.0
% INFO    : Bus 3931	: V=1.067732, theta=8.321653 -> V=1.018735, theta=0.0
% INFO    : Bus 3932	: V=1.07703, theta=20.478832 -> V=1.0274335, theta=0.0
% INFO    : Bus 3933	: V=1.026471, theta=-24.426502 -> V=1.0, theta=0.0
% INFO    : Bus 3934	: V=1.045273, theta=-19.771313 -> V=1.005848, theta=0.0
% INFO    : Bus 3935	: V=1.069342, theta=-21.373989 -> V=1.0118715, theta=0.0
% INFO    : Bus 3936	: V=0.998005, theta=-9.696315 -> V=1.0, theta=0.0
% INFO    : Bus 3937	: V=1.091581, theta=-20.460227 -> V=1.0288755, theta=0.0
% INFO    : Bus 3938	: V=0.935797, theta=-34.76331 -> V=1.0, theta=0.0
% INFO    : Bus 3939	: V=1.014445, theta=-24.357863 -> V=1.0, theta=0.0
% INFO    : Bus 3940	: V=1.030658, theta=-24.273923 -> V=1.0, theta=0.0
% INFO    : Bus 3941	: V=0.98395, theta=-24.710057 -> V=1.0, theta=0.0
% INFO    : Bus 3942	: V=1.092763, theta=-25.255419 -> V=1.023729, theta=0.0
% INFO    : Bus 3943	: V=1.054591, theta=-10.111801 -> V=1.01067, theta=0.0
% INFO    : Bus 3944	: V=1.097207, theta=36.015856 -> V=1.014876, theta=0.0
% INFO    : Bus 3945	: V=1.014227, theta=-26.725579 -> V=1.0, theta=0.0
% INFO    : Bus 3946	: V=1.095447, theta=55.752356 -> V=1.0076185, theta=0.0
% INFO    : Bus 3947	: V=1.077003, theta=-18.805732 -> V=1.0256285, theta=0.0
% INFO    : Bus 3948	: V=1.049832, theta=-49.655239 -> V=1.006244, theta=0.0
% INFO    : Bus 3949	: V=1.044921, theta=7.483766 -> V=1.0, theta=0.0
% INFO    : Bus 3950	: V=1.066318, theta=-43.246925 -> V=1.007477, theta=0.0
% INFO    : Bus 3951	: V=1.051462, theta=-15.07259 -> V=1.006984, theta=0.0
% INFO    : Bus 3952	: V=1.079226, theta=20.57903 -> V=1.031963, theta=0.0
% INFO    : Bus 3953	: V=0.975311, theta=-17.714619 -> V=1.0, theta=0.0
% INFO    : Bus 3954	: V=1.075911, theta=-18.410025 -> V=1.013248, theta=0.0
% INFO    : Bus 3955	: V=0.973339, theta=-25.651445 -> V=1.0, theta=0.0
% INFO    : Bus 3956	: V=1.034792, theta=-46.679354 -> V=1.0, theta=0.0
% INFO    : Bus 3957	: V=1.06523, theta=20.598022 -> V=1.013577, theta=0.0
% INFO    : Bus 3958	: V=1.07755, theta=-15.532525 -> V=1.020873, theta=0.0
% INFO    : Bus 3959	: V=1.08109, theta=-41.139967 -> V=1.0262715, theta=0.0
% INFO    : Bus 3960	: V=1.088647, theta=45.996413 -> V=1.0, theta=0.0
% INFO    : Bus 3961	: V=1.055909, theta=61.549473 -> V=1.004645, theta=0.0
% INFO    : Bus 3962	: V=0.948388, theta=-27.271074 -> V=1.0, theta=0.0
% INFO    : Bus 3963	: V=1.072445, theta=-28.863104 -> V=1.0165935, theta=0.0
% INFO    : Bus 3964	: V=1.072007, theta=-25.850951 -> V=1.031981, theta=0.0
% INFO    : Bus 3965	: V=1.026367, theta=-27.007514 -> V=1.0, theta=0.0
% INFO    : Bus 3966	: V=1.075498, theta=-25.553377 -> V=1.032543, theta=0.0
% INFO    : Bus 3967	: V=0.991352, theta=-29.877064 -> V=1.0, theta=0.0
% INFO    : Bus 3968	: V=1.040209, theta=-15.658925 -> V=1.013729, theta=0.0
% INFO    : Bus 3969	: V=0.984768, theta=-7.189316 -> V=1.0, theta=0.0
% INFO    : Bus 3970	: V=1.034831, theta=-48.015438 -> V=1.0, theta=0.0
% INFO    : Bus 3971	: V=0.985551, theta=-23.569968 -> V=1.0, theta=0.0
% INFO    : Bus 3972	: V=1.063029, theta=3.26198 -> V=1.0169825, theta=0.0
% INFO    : Bus 3973	: V=1.066496, theta=-36.264284 -> V=1.019012, theta=0.0
% INFO    : Bus 3974	: V=0.991, theta=-20.008916 -> V=1.0, theta=0.0
% INFO    : Bus 3975	: V=1.040288, theta=-20.641387 -> V=1.0, theta=0.0
% INFO    : Bus 3976	: V=1.06719, theta=-7.793532 -> V=1.0177285, theta=0.0
% INFO    : Bus 3977	: V=1.00425, theta=-29.766196 -> V=1.0, theta=0.0
% INFO    : Bus 3978	: V=1.070102, theta=-24.427404 -> V=1.0299035, theta=0.0
% INFO    : Bus 3979	: V=1.047906, theta=-13.010346 -> V=1.0, theta=0.0
% INFO    : Bus 3980	: V=1.051636, theta=-49.808087 -> V=1.0, theta=0.0
% INFO    : Bus 3981	: V=1.054306, theta=-14.156331 -> V=1.019113, theta=0.0
% INFO    : Bus 3982	: V=1.034041, theta=-36.562107 -> V=1.0, theta=0.0
% INFO    : Bus 3983	: V=1.035034, theta=-21.258987 -> V=1.0, theta=0.0
% INFO    : Bus 3984	: V=1.029, theta=-21.657253 -> V=1.0, theta=0.0
% INFO    : Bus 3985	: V=1.043667, theta=63.713755 -> V=1.0, theta=0.0
% INFO    : Bus 3986	: V=0.979105, theta=-11.840289 -> V=1.0, theta=0.0
% INFO    : Bus 3987	: V=1.077542, theta=1.833654 -> V=1.0130655, theta=0.0
% INFO    : Bus 3988	: V=1.068963, theta=0.904206 -> V=1.015537, theta=0.0
% INFO    : Bus 3989	: V=1.051954, theta=-41.961877 -> V=1.004623, theta=0.0
% INFO    : Bus 3990	: V=1.029912, theta=-31.623105 -> V=1.0, theta=0.0
% INFO    : Bus 3991	: V=0.970894, theta=-25.209083 -> V=1.0, theta=0.0
% INFO    : Bus 3992	: V=1.042345, theta=-29.631758 -> V=1.0, theta=0.0
% INFO    : Bus 3993	: V=1.016991, theta=-32.765201 -> V=1.0, theta=0.0
% INFO    : Bus 3994	: V=1.009187, theta=-31.867895 -> V=1.0, theta=0.0
% INFO    : Bus 3995	: V=1.068268, theta=-19.329558 -> V=1.037267, theta=0.0
% INFO    : Bus 3996	: V=1.071153, theta=13.160519 -> V=1.0144605, theta=0.0
% INFO    : Bus 3997	: V=1.090753, theta=-35.344485 -> V=1.023263, theta=0.0
% INFO    : Bus 3998	: V=1.007584, theta=-15.550276 -> V=1.0, theta=0.0
% INFO    : Bus 3999	: V=0.986813, theta=-22.778239 -> V=1.0, theta=0.0
% INFO    : Bus 4000	: V=1.099526, theta=-40.339835 -> V=1.02737, theta=0.0
% INFO    : Bus 4001	: V=1.087392, theta=-20.406711 -> V=1.027893, theta=0.0
% INFO    : Bus 4002	: V=1.076864, theta=-19.639272 -> V=1.020294, theta=0.0
% INFO    : Bus 4003	: V=1.077053, theta=-15.846428 -> V=1.0215475, theta=0.0
% INFO    : Bus 4004	: V=1.041008, theta=-43.15916 -> V=1.0, theta=0.0
% INFO    : Bus 4005	: V=1.093526, theta=-23.497068 -> V=1.024739, theta=0.0
% INFO    : Bus 4006	: V=1.022818, theta=-21.595331 -> V=1.0, theta=0.0
% INFO    : Bus 4007	: V=1.097789, theta=8.752249 -> V=1.0147585, theta=0.0
% INFO    : Bus 4008	: V=1.042849, theta=-18.928465 -> V=1.0, theta=0.0
% INFO    : Bus 4009	: V=1.100012, theta=-14.656288 -> V=1.040326, theta=0.0
% INFO    : Bus 4010	: V=1.014307, theta=-29.510158 -> V=1.0, theta=0.0
% INFO    : Bus 4011	: V=1.001476, theta=-22.902653 -> V=1.0, theta=0.0
% INFO    : Bus 4012	: V=0.994519, theta=-16.682469 -> V=1.0, theta=0.0
% INFO    : Bus 4013	: V=0.980571, theta=-23.778608 -> V=1.0, theta=0.0
% INFO    : Bus 4014	: V=1.090622, theta=-36.977069 -> V=1.025783, theta=0.0
% INFO    : Bus 4015	: V=1.014537, theta=-36.845749 -> V=1.0, theta=0.0
% INFO    : Bus 4016	: V=1.066048, theta=15.355651 -> V=1.0029205, theta=0.0
% INFO    : Bus 4017	: V=1.040412, theta=-36.39555 -> V=1.0244275, theta=0.0
% INFO    : Bus 4018	: V=1.040845, theta=-7.843844 -> V=1.0050295, theta=0.0
% INFO    : Bus 4019	: V=1.077458, theta=9.793654 -> V=1.015535, theta=0.0
% INFO    : Bus 4020	: V=1.074397, theta=-33.503691 -> V=1.0264095, theta=0.0
% INFO    : Bus 4021	: V=1.045331, theta=5.236048 -> V=1.0059555, theta=0.0
% INFO    : Bus 4022	: V=1.047135, theta=-12.812109 -> V=1.0, theta=0.0
% INFO    : Bus 4023	: V=1.010248, theta=-33.109723 -> V=1.0, theta=0.0
% INFO    : Bus 4024	: V=1.070451, theta=-23.607654 -> V=1.0358355, theta=0.0
% INFO    : Bus 4025	: V=1.082684, theta=4.402257 -> V=1.0260205, theta=0.0
% INFO    : Bus 4026	: V=0.94362, theta=-24.166616 -> V=1.0, theta=0.0
% INFO    : Bus 4027	: V=0.994049, theta=-24.64024 -> V=1.0, theta=0.0
% INFO    : Bus 4028	: V=1.074532, theta=-11.651248 -> V=1.0172705, theta=0.0
% INFO    : Bus 4029	: V=1.064715, theta=-14.797502 -> V=1.014356, theta=0.0
% INFO    : Bus 4030	: V=1.002109, theta=10.648094 -> V=1.0, theta=0.0
% INFO    : Bus 4031	: V=1.042198, theta=-46.216765 -> V=1.0319015, theta=0.0
% INFO    : Bus 4032	: V=1.067982, theta=-11.022866 -> V=1.0174265, theta=0.0
% INFO    : Bus 4033	: V=1.049818, theta=-39.007952 -> V=1.0, theta=0.0
% INFO    : Bus 4034	: V=1.041122, theta=-18.611066 -> V=1.0, theta=0.0
% INFO    : Bus 4035	: V=1.060975, theta=6.976965 -> V=1.0051715, theta=0.0
% INFO    : Bus 4036	: V=1.076575, theta=-25.454051 -> V=1.033284, theta=0.0
% INFO    : Bus 4037	: V=1.098796, theta=-17.3085 -> V=1.033219, theta=0.0
% INFO    : Bus 4038	: V=1.069009, theta=25.391957 -> V=1.0126645, theta=0.0
% INFO    : Bus 4039	: V=1.046203, theta=-8.01519 -> V=1.0, theta=0.0
% INFO    : Bus 4040	: V=1.099656, theta=-17.304305 -> V=1.0368185, theta=0.0
% INFO    : Bus 4041	: V=0.99178, theta=-22.452823 -> V=1.0, theta=0.0
% INFO    : Bus 4042	: V=1.058854, theta=-20.795987 -> V=1.009364, theta=0.0
% INFO    : Bus 4043	: V=1.002972, theta=-29.839446 -> V=1.0, theta=0.0
% INFO    : Bus 4044	: V=0.973067, theta=62.692821 -> V=1.0, theta=0.0
% INFO    : Bus 4045	: V=0.994095, theta=-5.900606 -> V=1.0, theta=0.0
% INFO    : Bus 4046	: V=1.086053, theta=-45.526518 -> V=1.0129895, theta=0.0
% INFO    : Bus 4047	: V=1.004302, theta=-24.117059 -> V=1.0, theta=0.0
% INFO    : Bus 4048	: V=0.980177, theta=-19.981623 -> V=1.0, theta=0.0
% INFO    : Bus 4049	: V=1.053342, theta=-35.247991 -> V=1.0090555, theta=0.0
% INFO    : Bus 4050	: V=1.073811, theta=-35.366732 -> V=1.012282, theta=0.0
% INFO    : Bus 4051	: V=1.082211, theta=-19.10634 -> V=1.0297585, theta=0.0
% INFO    : Bus 4052	: V=0.997408, theta=-49.35051 -> V=1.0, theta=0.0
% INFO    : Bus 4053	: V=1.055155, theta=-49.489684 -> V=1.007043, theta=0.0
% INFO    : Bus 4054	: V=0.943691, theta=-23.456261 -> V=1.0, theta=0.0
% INFO    : Bus 4055	: V=1.070499, theta=-9.766049 -> V=1.0138845, theta=0.0
% INFO    : Bus 4056	: V=1.054086, theta=-20.329333 -> V=1.0066585, theta=0.0
% INFO    : Bus 4057	: V=1.010258, theta=-22.6726 -> V=1.0, theta=0.0
% INFO    : Bus 4058	: V=1.095749, theta=-17.5494 -> V=1.022612, theta=0.0
% INFO    : Bus 4059	: V=1.039735, theta=-24.332115 -> V=1.0, theta=0.0
% INFO    : Bus 4060	: V=0.999744, theta=-28.699449 -> V=1.0, theta=0.0
% INFO    : Bus 4061	: V=1.039099, theta=-9.655578 -> V=1.0039485, theta=0.0
% INFO    : Bus 4062	: V=1.047, theta=-22.224689 -> V=1.0, theta=0.0
% INFO    : Bus 4063	: V=0.961345, theta=-26.850621 -> V=1.0, theta=0.0
% INFO    : Bus 4064	: V=0.994217, theta=11.442369 -> V=1.0, theta=0.0
% INFO    : Bus 4065	: V=1.016185, theta=-42.158651 -> V=1.0, theta=0.0
% INFO    : Bus 4066	: V=1.01762, theta=-33.51645 -> V=1.0, theta=0.0
% INFO    : Bus 4067	: V=1.014701, theta=8.411271 -> V=1.0, theta=0.0
% INFO    : Bus 4068	: V=1.046308, theta=3.543641 -> V=1.007971, theta=0.0
% INFO    : Bus 4069	: V=1.036268, theta=-21.544554 -> V=1.0065835, theta=0.0
% INFO    : Bus 4070	: V=1.039434, theta=19.43199 -> V=1.0, theta=0.0
% INFO    : Bus 4071	: V=1.002386, theta=-26.000495 -> V=1.0, theta=0.0
% INFO    : Bus 4072	: V=0.967426, theta=-30.526625 -> V=1.0, theta=0.0
% INFO    : Bus 4073	: V=1.068652, theta=2.4194 -> V=1.02009, theta=0.0
% INFO    : Bus 4074	: V=1.100421, theta=58.422931 -> V=1.009366, theta=0.0
% INFO    : Bus 4075	: V=1.030546, theta=-24.479822 -> V=1.0, theta=0.0
% INFO    : Bus 4076	: V=1.046091, theta=8.293152 -> V=1.009543, theta=0.0
% INFO    : Bus 4077	: V=1.038758, theta=-29.676596 -> V=1.0, theta=0.0
% INFO    : Bus 4078	: V=1.051318, theta=-6.118834 -> V=1.019677, theta=0.0
% INFO    : Bus 4079	: V=1.020672, theta=-23.361982 -> V=1.0, theta=0.0
% INFO    : Bus 4080	: V=1.04702, theta=-12.992685 -> V=1.01626, theta=0.0
% INFO    : Bus 4081	: V=1.073878, theta=13.755568 -> V=1.011255, theta=0.0
% INFO    : Bus 4082	: V=1.001, theta=-23.029485 -> V=1.0, theta=0.0
% INFO    : Bus 4083	: V=1.082659, theta=-40.0038 -> V=1.026185, theta=0.0
% INFO    : Bus 4084	: V=1.042812, theta=-18.944555 -> V=1.0, theta=0.0
% INFO    : Bus 4085	: V=1.06927, theta=-42.639377 -> V=1.0092255, theta=0.0
% INFO    : Bus 4086	: V=1.023391, theta=-33.01377 -> V=1.0, theta=0.0
% INFO    : Bus 4087	: V=1.039984, theta=-25.124667 -> V=1.019309, theta=0.0
% INFO    : Bus 4088	: V=1.078228, theta=39.435629 -> V=1.010354, theta=0.0
% INFO    : Bus 4089	: V=1.050617, theta=-36.710174 -> V=1.0, theta=0.0
% INFO    : Bus 4090	: V=1.069052, theta=-1.85991 -> V=1.0139865, theta=0.0
% INFO    : Bus 4091	: V=1.066296, theta=-11.384689 -> V=1.0154695, theta=0.0
% INFO    : Bus 4092	: V=1.005964, theta=12.583351 -> V=1.0, theta=0.0
% INFO    : Bus 4093	: V=0.944452, theta=-11.809313 -> V=1.0, theta=0.0
% INFO    : Bus 4094	: V=1.103553, theta=46.223869 -> V=1.010155, theta=0.0
% INFO    : Bus 4095	: V=1.007153, theta=46.705412 -> V=1.0, theta=0.0
% INFO    : Bus 4096	: V=1.019862, theta=14.993557 -> V=1.0, theta=0.0
% INFO    : Bus 4097	: V=1.06427, theta=36.367054 -> V=1.013137, theta=0.0
% INFO    : Bus 4098	: V=1.053091, theta=-42.381896 -> V=1.004436, theta=0.0
% INFO    : Bus 4099	: V=0.932838, theta=-33.0364 -> V=1.0, theta=0.0
% INFO    : Bus 4100	: V=1.050857, theta=-41.715254 -> V=1.0425495, theta=0.0
% INFO    : Bus 4101	: V=1.040479, theta=-15.625301 -> V=1.0138505, theta=0.0
% INFO    : Bus 4102	: V=1.073364, theta=-6.535664 -> V=1.019656, theta=0.0
% INFO    : Bus 4103	: V=1.073413, theta=-38.210279 -> V=1.019169, theta=0.0
% INFO    : Bus 4104	: V=1.015363, theta=61.626304 -> V=1.0, theta=0.0
% INFO    : Bus 4105	: V=1.067525, theta=1.756894 -> V=1.019117, theta=0.0
% INFO    : Bus 4106	: V=1.029634, theta=-35.314381 -> V=1.0, theta=0.0
% INFO    : Bus 4107	: V=1.052525, theta=-24.762366 -> V=1.013755, theta=0.0
% INFO    : Bus 4108	: V=1.058016, theta=-43.869719 -> V=1.013292, theta=0.0
% INFO    : Bus 4109	: V=1.058092, theta=-9.147235 -> V=1.009398, theta=0.0
% INFO    : Bus 4110	: V=1.019764, theta=-23.851115 -> V=1.0, theta=0.0
% INFO    : Bus 4111	: V=1.048682, theta=-44.410211 -> V=1.0, theta=0.0
% INFO    : Bus 4112	: V=1.02573, theta=-14.659571 -> V=1.0125215, theta=0.0
% INFO    : Bus 4113	: V=1.063149, theta=-9.400285 -> V=1.0152465, theta=0.0
% INFO    : Bus 4114	: V=1.083148, theta=-40.524383 -> V=1.025882, theta=0.0
% INFO    : Bus 4115	: V=1.00394, theta=11.679232 -> V=1.0, theta=0.0
% INFO    : Bus 4116	: V=1.096775, theta=-8.474033 -> V=1.0289405, theta=0.0
% INFO    : Bus 4117	: V=1.0565, theta=-40.946308 -> V=1.007605, theta=0.0
% INFO    : Bus 4118	: V=1.026443, theta=-23.796336 -> V=1.0, theta=0.0
% INFO    : Bus 4119	: V=0.975964, theta=-25.309434 -> V=1.0, theta=0.0
% INFO    : Bus 4120	: V=1.082712, theta=-14.587335 -> V=1.0303715, theta=0.0
% INFO    : Bus 4121	: V=1.035034, theta=-21.258987 -> V=1.0, theta=0.0
% INFO    : Bus 4122	: V=0.962405, theta=-12.134583 -> V=1.0, theta=0.0
% INFO    : Bus 4123	: V=1.079289, theta=13.798602 -> V=1.02518, theta=0.0
% INFO    : Bus 4124	: V=1.02249, theta=-16.061245 -> V=1.0, theta=0.0
% INFO    : Bus 4125	: V=1.064697, theta=10.205544 -> V=1.012888, theta=0.0
% INFO    : Bus 4126	: V=1.037323, theta=-18.972928 -> V=1.0115985, theta=0.0
% INFO    : Bus 4127	: V=0.989624, theta=-27.669548 -> V=1.0, theta=0.0
% INFO    : Bus 4128	: V=1.017432, theta=-21.981306 -> V=1.0, theta=0.0
% INFO    : Bus 4129	: V=1.030702, theta=-33.955807 -> V=1.0, theta=0.0
% INFO    : Bus 4130	: V=1.048802, theta=-22.276481 -> V=1.0, theta=0.0
% INFO    : Bus 4131	: V=1.072106, theta=-9.190276 -> V=1.014816, theta=0.0
% INFO    : Bus 4132	: V=1.072857, theta=-39.076192 -> V=1.0108275, theta=0.0
% INFO    : Bus 4133	: V=1.086411, theta=-41.19112 -> V=1.023103, theta=0.0
% INFO    : Bus 4134	: V=1.071563, theta=-13.757737 -> V=1.017739, theta=0.0
% INFO    : Bus 4135	: V=1.043285, theta=-21.001055 -> V=1.0, theta=0.0
% INFO    : Bus 4136	: V=0.999423, theta=-23.719985 -> V=1.0, theta=0.0
% INFO    : Bus 4137	: V=0.948388, theta=-28.03577 -> V=1.0, theta=0.0
% INFO    : Bus 4138	: V=0.969693, theta=-25.755992 -> V=1.0, theta=0.0
% INFO    : Bus 4139	: V=1.096039, theta=-11.176902 -> V=1.026011, theta=0.0
% INFO    : Bus 4140	: V=1.07864, theta=-10.074395 -> V=1.016352, theta=0.0
% INFO    : Bus 4141	: V=0.994202, theta=-23.538525 -> V=1.0, theta=0.0
% INFO    : Bus 4142	: V=1.053675, theta=-12.931186 -> V=1.0059105, theta=0.0
% INFO    : Bus 4143	: V=1.075032, theta=-9.588126 -> V=1.022853, theta=0.0
% INFO    : Bus 4144	: V=0.946555, theta=-27.924428 -> V=1.0, theta=0.0
% INFO    : Bus 4145	: V=1.026623, theta=-44.440042 -> V=1.0, theta=0.0
% INFO    : Bus 4146	: V=1.007228, theta=14.501841 -> V=1.0, theta=0.0
% INFO    : Bus 4147	: V=1.057325, theta=-21.009721 -> V=1.007566, theta=0.0
% INFO    : Bus 4148	: V=0.994045, theta=-19.21757 -> V=1.0, theta=0.0
% INFO    : Bus 4149	: V=0.910416, theta=-29.478081 -> V=1.0, theta=0.0
% INFO    : Bus 4150	: V=1.072404, theta=-42.308435 -> V=1.017891, theta=0.0
% INFO    : Bus 4151	: V=1.078281, theta=-15.796259 -> V=1.0206495, theta=0.0
% INFO    : Bus 4152	: V=0.966331, theta=-19.670432 -> V=1.0, theta=0.0
% INFO    : Bus 4153	: V=1.083955, theta=-15.561807 -> V=1.0341015, theta=0.0
% INFO    : Bus 4154	: V=1.067604, theta=9.787942 -> V=1.0, theta=0.0
% INFO    : Bus 4155	: V=1.082409, theta=-26.854166 -> V=1.044508, theta=0.0
% INFO    : Bus 4156	: V=1.008261, theta=-26.57636 -> V=1.0, theta=0.0
% INFO    : Bus 4157	: V=1.029131, theta=-21.49625 -> V=1.0, theta=0.0
% INFO    : Bus 4158	: V=1.024882, theta=-18.153663 -> V=1.009088, theta=0.0
% INFO    : Bus 4159	: V=1.051976, theta=33.85445 -> V=1.0, theta=0.0
% INFO    : Bus 4160	: V=1.054688, theta=-35.876203 -> V=1.01833, theta=0.0
% INFO    : Bus 4161	: V=1.039896, theta=-45.77026 -> V=1.0, theta=0.0
% INFO    : Bus 4162	: V=0.97618, theta=-32.14869 -> V=1.0, theta=0.0
% INFO    : Bus 4163	: V=1.054413, theta=-42.452836 -> V=1.011514, theta=0.0
% INFO    : Bus 4164	: V=1.027136, theta=-50.927306 -> V=1.0, theta=0.0
% INFO    : Bus 4165	: V=1.043594, theta=11.026839 -> V=1.0, theta=0.0
% INFO    : Bus 4166	: V=1.019552, theta=-23.406185 -> V=1.0, theta=0.0
% INFO    : Bus 4167	: V=1.069928, theta=-11.904726 -> V=1.021195, theta=0.0
% INFO    : Bus 4168	: V=1.092728, theta=11.517878 -> V=1.0344365, theta=0.0
% INFO    : Bus 4169	: V=1.053958, theta=-28.394206 -> V=1.0, theta=0.0
% INFO    : Bus 4170	: V=1.071628, theta=-12.597343 -> V=1.017759, theta=0.0
% INFO    : Bus 4171	: V=1.000933, theta=-23.445073 -> V=1.0, theta=0.0
% INFO    : Bus 4172	: V=1.075, theta=-11.523575 -> V=1.0192775, theta=0.0
% INFO    : Bus 4173	: V=0.976442, theta=-6.492301 -> V=1.0, theta=0.0
% INFO    : Bus 4174	: V=1.086541, theta=-45.4787 -> V=1.024787, theta=0.0
% INFO    : Bus 4175	: V=1.028661, theta=-23.307923 -> V=1.0, theta=0.0
% INFO    : Bus 4176	: V=1.051996, theta=-20.135056 -> V=1.0029865, theta=0.0
% INFO    : Bus 4177	: V=1.009796, theta=-30.615157 -> V=1.0, theta=0.0
% INFO    : Bus 4178	: V=1.028337, theta=-44.139756 -> V=1.0, theta=0.0
% INFO    : Bus 4179	: V=1.026389, theta=9.933989 -> V=1.0, theta=0.0
% INFO    : Bus 4180	: V=1.045696, theta=-5.875555 -> V=1.005437, theta=0.0
% INFO    : Bus 4181	: V=1.076509, theta=11.129908 -> V=1.028508, theta=0.0
% INFO    : Bus 4182	: V=0.977538, theta=-30.445331 -> V=1.0, theta=0.0
% INFO    : Bus 4183	: V=0.989972, theta=37.961196 -> V=1.0, theta=0.0
% INFO    : Bus 4184	: V=1.073572, theta=-6.947927 -> V=1.0138345, theta=0.0
% INFO    : Bus 4185	: V=1.066632, theta=-16.528473 -> V=1.0207855, theta=0.0
% INFO    : Bus 4186	: V=1.085121, theta=-45.332854 -> V=1.012077, theta=0.0
% INFO    : Bus 4187	: V=1.041676, theta=63.002162 -> V=1.0, theta=0.0
% INFO    : Bus 4188	: V=1.086526, theta=-18.760126 -> V=1.03064, theta=0.0
% INFO    : Bus 4189	: V=1.076936, theta=-47.446677 -> V=1.01289, theta=0.0
% INFO    : Bus 4190	: V=1.052382, theta=-19.853903 -> V=1.0029465, theta=0.0
% INFO    : Bus 4191	: V=1.06125, theta=-20.538706 -> V=1.010719, theta=0.0
% INFO    : Bus 4192	: V=1.094706, theta=-38.343507 -> V=1.0301475, theta=0.0
% INFO    : Bus 4193	: V=1.013763, theta=-17.084142 -> V=1.0, theta=0.0
% INFO    : Bus 4194	: V=1.063724, theta=-39.49242 -> V=1.0160045, theta=0.0
% INFO    : Bus 4195	: V=1.049235, theta=-28.78343 -> V=1.0, theta=0.0
% INFO    : Bus 4196	: V=1.039383, theta=4.338386 -> V=1.0030195, theta=0.0
% INFO    : Bus 4197	: V=1.09292, theta=-24.589657 -> V=1.042705, theta=0.0
% INFO    : Bus 4198	: V=1.043164, theta=14.675638 -> V=1.0, theta=0.0
% INFO    : Bus 4199	: V=0.980215, theta=-22.065702 -> V=1.0, theta=0.0
% INFO    : Bus 4200	: V=0.967889, theta=-34.590758 -> V=1.0, theta=0.0
% INFO    : Bus 4201	: V=1.035945, theta=-29.496065 -> V=1.0, theta=0.0
% INFO    : Bus 4202	: V=1.101947, theta=38.288093 -> V=1.009991, theta=0.0
% INFO    : Bus 4203	: V=0.979163, theta=-23.955021 -> V=1.0, theta=0.0
% INFO    : Bus 4204	: V=1.03064, theta=29.734469 -> V=1.0, theta=0.0
% INFO    : Bus 4205	: V=1.050235, theta=-16.00925 -> V=1.0080625, theta=0.0
% INFO    : Bus 4206	: V=1.053999, theta=-14.76471 -> V=1.0040965, theta=0.0
% INFO    : Bus 4207	: V=0.97763, theta=-25.388779 -> V=1.0, theta=0.0
% INFO    : Bus 4208	: V=1.067102, theta=-18.559882 -> V=1.004223, theta=0.0
% INFO    : Bus 4209	: V=1.011057, theta=-44.66348 -> V=1.0, theta=0.0
% INFO    : Bus 4210	: V=1.049939, theta=-10.542285 -> V=1.009122, theta=0.0
% INFO    : Bus 4211	: V=1.036901, theta=-19.655021 -> V=1.003221, theta=0.0
% INFO    : Bus 4212	: V=1.000669, theta=-29.584385 -> V=1.0, theta=0.0
% INFO    : Bus 4213	: V=1.055046, theta=-11.959949 -> V=1.0114805, theta=0.0
% INFO    : Bus 4214	: V=1.094263, theta=-5.58809 -> V=1.0229825, theta=0.0
% INFO    : Bus 4215	: V=0.985688, theta=-23.096643 -> V=1.0, theta=0.0
% INFO    : Bus 4216	: V=0.989871, theta=-23.037821 -> V=1.0, theta=0.0
% INFO    : Bus 4217	: V=1.074434, theta=-17.92228 -> V=1.0, theta=0.0
% INFO    : Bus 4218	: V=1.045717, theta=-20.751565 -> V=1.004365, theta=0.0
% INFO    : Bus 4219	: V=1.071019, theta=-40.264213 -> V=1.0173565, theta=0.0
% INFO    : Bus 4220	: V=1.06827, theta=2.55233 -> V=1.0169505, theta=0.0
% INFO    : Bus 4221	: V=1.077906, theta=-5.35564 -> V=1.0180335, theta=0.0
% INFO    : Bus 4222	: V=1.070105, theta=32.261058 -> V=1.018631, theta=0.0
% INFO    : Bus 4223	: V=1.059328, theta=-29.819851 -> V=1.0102025, theta=0.0
% INFO    : Bus 4224	: V=0.981737, theta=-22.797891 -> V=1.0, theta=0.0
% INFO    : Bus 4225	: V=1.033826, theta=-49.22739 -> V=1.0, theta=0.0
% INFO    : Bus 4226	: V=1.051614, theta=-49.224479 -> V=1.007053, theta=0.0
% INFO    : Bus 4227	: V=1.089157, theta=-40.725654 -> V=1.031179, theta=0.0
% INFO    : Bus 4228	: V=0.960691, theta=-13.481854 -> V=1.0, theta=0.0
% INFO    : Bus 4229	: V=1.063635, theta=-20.07853 -> V=1.0103675, theta=0.0
% INFO    : Bus 4230	: V=1.027531, theta=-19.1411 -> V=1.01872, theta=0.0
% INFO    : Bus 4231	: V=1.085864, theta=-34.505422 -> V=1.011825, theta=0.0
% INFO    : Bus 4232	: V=1.027362, theta=-43.454938 -> V=1.0, theta=0.0
% INFO    : Bus 4233	: V=1.067156, theta=-14.601085 -> V=1.0094535, theta=0.0
% INFO    : Bus 4234	: V=0.941654, theta=-25.0239 -> V=1.0, theta=0.0
% INFO    : Bus 4235	: V=1.059682, theta=-26.196637 -> V=1.0134925, theta=0.0
% INFO    : Bus 4236	: V=1.090237, theta=44.220786 -> V=1.0, theta=0.0
% INFO    : Bus 4237	: V=1.048864, theta=-45.608306 -> V=1.0056925, theta=0.0
% INFO    : Bus 4238	: V=1.01346, theta=-14.793221 -> V=1.0, theta=0.0
% INFO    : Bus 4239	: V=1.069223, theta=-11.967137 -> V=1.016246, theta=0.0
% INFO    : Bus 4240	: V=1.018455, theta=-21.944802 -> V=1.0, theta=0.0
% INFO    : Bus 4241	: V=1.033472, theta=-22.89406 -> V=1.015665, theta=0.0
% INFO    : Bus 4242	: V=1.012655, theta=-19.192307 -> V=1.0, theta=0.0
% INFO    : Bus 4243	: V=1.088079, theta=50.472051 -> V=1.0, theta=0.0
% INFO    : Bus 4244	: V=0.9467, theta=-27.010076 -> V=1.0, theta=0.0
% INFO    : Bus 4245	: V=1.049435, theta=-30.184971 -> V=1.006629, theta=0.0
% INFO    : Bus 4246	: V=1.006513, theta=-25.963756 -> V=1.0, theta=0.0
% INFO    : Bus 4247	: V=1.038694, theta=-12.596835 -> V=1.0046605, theta=0.0
% INFO    : Bus 4248	: V=1.069407, theta=25.410656 -> V=1.0128485, theta=0.0
% INFO    : Bus 4249	: V=1.098238, theta=-7.55811 -> V=1.02627, theta=0.0
% INFO    : Bus 4250	: V=1.038353, theta=-25.050669 -> V=1.0, theta=0.0
% INFO    : Bus 4251	: V=1.057572, theta=-13.412354 -> V=1.005326, theta=0.0
% INFO    : Bus 4252	: V=1.078615, theta=-19.618381 -> V=1.0214235, theta=0.0
% INFO    : Bus 4253	: V=1.084447, theta=-26.093145 -> V=1.0204525, theta=0.0
% INFO    : Bus 4254	: V=1.081155, theta=-17.641661 -> V=1.015071, theta=0.0
% INFO    : Bus 4255	: V=0.916759, theta=-29.652145 -> V=1.0, theta=0.0
% INFO    : Bus 4256	: V=1.086485, theta=-3.753567 -> V=1.019704, theta=0.0
% INFO    : Bus 4257	: V=1.008487, theta=-17.950507 -> V=1.0, theta=0.0
% INFO    : Bus 4258	: V=1.053569, theta=-24.626352 -> V=1.014232, theta=0.0
% INFO    : Bus 4259	: V=1.048578, theta=5.684158 -> V=1.0081985, theta=0.0
% INFO    : Bus 4260	: V=1.062107, theta=0.616986 -> V=1.012268, theta=0.0
% INFO    : Bus 4261	: V=1.050479, theta=-30.528475 -> V=1.024003, theta=0.0
% INFO    : Bus 4262	: V=1.086447, theta=-40.259436 -> V=1.015537, theta=0.0
% INFO    : Bus 4263	: V=1.006885, theta=-27.664636 -> V=1.046881, theta=0.0
% INFO    : Bus 4264	: V=1.059561, theta=-0.784545 -> V=1.0117285, theta=0.0
% INFO    : Bus 4265	: V=1.047338, theta=-18.569332 -> V=1.0155635, theta=0.0
% INFO    : Bus 4266	: V=0.996842, theta=-20.261029 -> V=1.0, theta=0.0
% INFO    : Bus 4267	: V=1.027636, theta=0.997562 -> V=1.012377, theta=0.0
% INFO    : Bus 4268	: V=0.969912, theta=-24.810045 -> V=1.0, theta=0.0
% INFO    : Bus 4269	: V=1.099212, theta=-10.183285 -> V=1.0288645, theta=0.0
% INFO    : Bus 4270	: V=1.031284, theta=-30.255669 -> V=1.0, theta=0.0
% INFO    : Bus 4271	: V=0.979671, theta=-26.689733 -> V=1.0, theta=0.0
% INFO    : Bus 4272	: V=1.032868, theta=-23.644151 -> V=1.0, theta=0.0
% INFO    : Bus 4273	: V=1.090737, theta=-9.839942 -> V=1.0274355, theta=0.0
% INFO    : Bus 4274	: V=1.07824, theta=-13.267959 -> V=1.01681, theta=0.0
% INFO    : Bus 4275	: V=0.964291, theta=-19.057794 -> V=1.0, theta=0.0
% INFO    : Bus 4276	: V=1.094193, theta=-31.741966 -> V=1.032407, theta=0.0
% INFO    : Bus 4277	: V=1.018363, theta=-15.400151 -> V=1.0, theta=0.0
% INFO    : Bus 4278	: V=1.08754, theta=-41.885151 -> V=1.0293345, theta=0.0
% INFO    : Bus 4279	: V=1.032608, theta=-24.958809 -> V=1.0, theta=0.0
% INFO    : Bus 4280	: V=0.968182, theta=-13.027538 -> V=1.0, theta=0.0
% INFO    : Bus 4281	: V=1.038405, theta=5.179927 -> V=1.006533, theta=0.0
% INFO    : Bus 4282	: V=1.058228, theta=-8.598386 -> V=1.010349, theta=0.0
% INFO    : Bus 4283	: V=1.045373, theta=-11.497824 -> V=1.0084415, theta=0.0
% INFO    : Bus 4284	: V=1.056725, theta=-30.707986 -> V=1.0060065, theta=0.0
% INFO    : Bus 4285	: V=1.004281, theta=-19.833901 -> V=1.0, theta=0.0
% INFO    : Bus 4286	: V=1.059431, theta=4.674702 -> V=1.008786, theta=0.0
% INFO    : Bus 4287	: V=1.072408, theta=-45.257425 -> V=1.014659, theta=0.0
% INFO    : Bus 4288	: V=1.032358, theta=-15.190106 -> V=1.0, theta=0.0
% INFO    : Bus 4289	: V=1.079914, theta=-38.536331 -> V=1.0210085, theta=0.0
% INFO    : Bus 4290	: V=1.071826, theta=-10.535682 -> V=1.0198795, theta=0.0
% INFO    : Bus 4291	: V=1.057064, theta=-36.152006 -> V=1.0188955, theta=0.0
% INFO    : Bus 4292	: V=1.062746, theta=63.163944 -> V=1.0, theta=0.0
% INFO    : Bus 4293	: V=1.029898, theta=-49.788336 -> V=1.0, theta=0.0
% INFO    : Bus 4294	: V=1.040693, theta=4.127604 -> V=1.0071035, theta=0.0
% INFO    : Bus 4295	: V=1.031963, theta=-24.998566 -> V=1.0, theta=0.0
% INFO    : Bus 4296	: V=1.062082, theta=-9.808739 -> V=1.014822, theta=0.0
% INFO    : Bus 4297	: V=0.962984, theta=-27.688024 -> V=1.0, theta=0.0
% INFO    : Bus 4298	: V=0.931299, theta=-27.969929 -> V=1.0, theta=0.0
% INFO    : Bus 4299	: V=1.070482, theta=-20.321034 -> V=1.017742, theta=0.0
% INFO    : Bus 4300	: V=1.052137, theta=-9.681277 -> V=1.0136455, theta=0.0
% INFO    : Bus 4301	: V=1.000766, theta=-22.844685 -> V=1.0, theta=0.0
% INFO    : Bus 4302	: V=1.054515, theta=-16.045688 -> V=1.0049785, theta=0.0
% INFO    : Bus 4303	: V=1.081015, theta=17.598362 -> V=1.0165965, theta=0.0
% INFO    : Bus 4304	: V=1.082671, theta=16.232982 -> V=1.0138215, theta=0.0
% INFO    : Bus 4305	: V=1.047412, theta=-9.451486 -> V=1.0, theta=0.0
% INFO    : Bus 4306	: V=1.039981, theta=-41.264288 -> V=1.0101155, theta=0.0
% INFO    : Bus 4307	: V=1.095863, theta=-10.91828 -> V=1.027183, theta=0.0
% INFO    : Bus 4308	: V=1.060398, theta=1.706701 -> V=1.0074455, theta=0.0
% INFO    : Bus 4309	: V=1.078886, theta=-10.124128 -> V=1.026337, theta=0.0
% INFO    : Bus 4310	: V=0.992, theta=-7.358111 -> V=1.0, theta=0.0
% INFO    : Bus 4311	: V=1.070183, theta=12.147358 -> V=1.0237795, theta=0.0
% INFO    : Bus 4312	: V=0.979616, theta=-11.99626 -> V=1.0, theta=0.0
% INFO    : Bus 4313	: V=1.076091, theta=0.506627 -> V=1.014282, theta=0.0
% INFO    : Bus 4314	: V=1.010753, theta=-25.094185 -> V=1.0310465, theta=0.0
% INFO    : Bus 4315	: V=0.991428, theta=-37.216439 -> V=1.0, theta=0.0
% INFO    : Bus 4316	: V=1.070783, theta=-20.644255 -> V=1.003967, theta=0.0
% INFO    : Bus 4317	: V=1.025565, theta=-23.738907 -> V=1.0, theta=0.0
% INFO    : Bus 4318	: V=1.045099, theta=-12.282161 -> V=1.008856, theta=0.0
% INFO    : Bus 4319	: V=1.081531, theta=-11.890355 -> V=1.023674, theta=0.0
% INFO    : Bus 4320	: V=1.02218, theta=-41.645191 -> V=1.0, theta=0.0
% INFO    : Bus 4321	: V=1.032685, theta=-25.351507 -> V=1.0, theta=0.0
% INFO    : Bus 4322	: V=1.027045, theta=-43.838747 -> V=1.0, theta=0.0
% INFO    : Bus 4323	: V=1.011428, theta=60.623275 -> V=1.0, theta=0.0
% INFO    : Bus 4324	: V=1.005229, theta=-21.055889 -> V=1.0, theta=0.0
% INFO    : Bus 4325	: V=0.907012, theta=-32.943513 -> V=1.0, theta=0.0
% INFO    : Bus 4326	: V=1.064239, theta=1.868594 -> V=1.0183935, theta=0.0
% INFO    : Bus 4327	: V=1.043368, theta=13.643526 -> V=1.0041955, theta=0.0
% INFO    : Bus 4328	: V=1.003426, theta=-15.781133 -> V=1.0, theta=0.0
% INFO    : Bus 4329	: V=1.019758, theta=-16.952213 -> V=1.0, theta=0.0
% INFO    : Bus 4330	: V=1.042697, theta=-22.998136 -> V=1.0, theta=0.0
% INFO    : Bus 4331	: V=1.06526, theta=-26.019192 -> V=1.01464, theta=0.0
% INFO    : Bus 4332	: V=0.921341, theta=-28.145224 -> V=1.0, theta=0.0
% INFO    : Bus 4333	: V=0.986537, theta=-25.013876 -> V=1.0, theta=0.0
% INFO    : Bus 4334	: V=1.039575, theta=-11.714717 -> V=1.0, theta=0.0
% INFO    : Bus 4335	: V=1.068366, theta=48.04628 -> V=1.0100305, theta=0.0
% INFO    : Bus 4336	: V=0.947442, theta=-34.591343 -> V=1.0, theta=0.0
% INFO    : Bus 4337	: V=1.058026, theta=-35.635612 -> V=1.019783, theta=0.0
% INFO    : Bus 4338	: V=1.018034, theta=-32.649591 -> V=1.0, theta=0.0
% INFO    : Bus 4339	: V=1.0615, theta=-43.639945 -> V=1.0066945, theta=0.0
% INFO    : Bus 4340	: V=1.064636, theta=-38.40314 -> V=1.002932, theta=0.0
% INFO    : Bus 4341	: V=1.073546, theta=0.807311 -> V=1.0235705, theta=0.0
% INFO    : Bus 4342	: V=1.055795, theta=-22.305694 -> V=1.0, theta=0.0
% INFO    : Bus 4343	: V=1.103711, theta=24.36166 -> V=1.020261, theta=0.0
% INFO    : Bus 4344	: V=0.991964, theta=-25.104251 -> V=1.0, theta=0.0
% INFO    : Bus 4345	: V=1.059289, theta=31.671955 -> V=1.0181025, theta=0.0
% INFO    : Bus 4346	: V=0.966936, theta=-25.731264 -> V=1.0, theta=0.0
% INFO    : Bus 4347	: V=1.030389, theta=-24.498815 -> V=1.0, theta=0.0
% INFO    : Bus 4348	: V=1.006609, theta=-23.355737 -> V=1.0, theta=0.0
% INFO    : Bus 4349	: V=1.046182, theta=8.611679 -> V=1.0095615, theta=0.0
% INFO    : Bus 4350	: V=0.949674, theta=-29.544673 -> V=1.0, theta=0.0
% INFO    : Bus 4351	: V=1.066755, theta=-0.140506 -> V=1.019548, theta=0.0
% INFO    : Bus 4352	: V=1.047289, theta=20.724263 -> V=1.0, theta=0.0
% INFO    : Bus 4353	: V=1.048876, theta=-14.073472 -> V=1.0085575, theta=0.0
% INFO    : Bus 4354	: V=1.024545, theta=-4.932416 -> V=1.0, theta=0.0
% INFO    : Bus 4355	: V=1.08818, theta=2.779791 -> V=1.0254145, theta=0.0
% INFO    : Bus 4356	: V=0.954046, theta=-25.902941 -> V=1.0, theta=0.0
% INFO    : Bus 4357	: V=1.011489, theta=-29.162385 -> V=1.0, theta=0.0
% INFO    : Bus 4358	: V=1.022725, theta=-23.284679 -> V=1.0, theta=0.0
% INFO    : Bus 4359	: V=1.03694, theta=-2.805018 -> V=1.0036715, theta=0.0
% INFO    : Bus 4360	: V=1.078611, theta=-12.67781 -> V=1.0215555, theta=0.0
% INFO    : Bus 4361	: V=1.100344, theta=-39.798051 -> V=1.0304375, theta=0.0
% INFO    : Bus 4362	: V=1.048945, theta=-17.63162 -> V=1.0114855, theta=0.0
% INFO    : Bus 4363	: V=1.040725, theta=25.76517 -> V=1.015348, theta=0.0
% INFO    : Bus 4364	: V=0.979163, theta=-23.955021 -> V=1.0, theta=0.0
% INFO    : Bus 4365	: V=1.046872, theta=7.405599 -> V=1.0, theta=0.0
% INFO    : Bus 4366	: V=1.018248, theta=-23.608019 -> V=1.0, theta=0.0
% INFO    : Bus 4367	: V=1.070689, theta=-21.45181 -> V=1.0228825, theta=0.0
% INFO    : Bus 4368	: V=0.996281, theta=-24.746663 -> V=1.0, theta=0.0
% INFO    : Bus 4369	: V=0.972783, theta=-26.493774 -> V=1.0, theta=0.0
% INFO    : Bus 4370	: V=1.064592, theta=-18.590147 -> V=1.0, theta=0.0
% INFO    : Bus 4371	: V=1.060364, theta=6.841014 -> V=1.0241955, theta=0.0
% INFO    : Bus 4372	: V=1.073593, theta=-42.303446 -> V=1.011104, theta=0.0
% INFO    : Bus 4373	: V=1.081436, theta=-37.859784 -> V=1.0198645, theta=0.0
% INFO    : Bus 4374	: V=1.05943, theta=-27.29641 -> V=1.014248, theta=0.0
% INFO    : Bus 4375	: V=1.019533, theta=-41.713093 -> V=1.0, theta=0.0
% INFO    : Bus 4376	: V=1.037732, theta=-24.672947 -> V=1.0, theta=0.0
% INFO    : Bus 4377	: V=1.09007, theta=-5.057312 -> V=1.0243855, theta=0.0
% INFO    : Bus 4378	: V=1.015533, theta=-47.147028 -> V=1.0, theta=0.0
% INFO    : Bus 4379	: V=0.941942, theta=-25.941252 -> V=1.0, theta=0.0
% INFO    : Bus 4380	: V=0.993748, theta=-21.817459 -> V=1.0, theta=0.0
% INFO    : Bus 4381	: V=1.076364, theta=-23.178405 -> V=1.032605, theta=0.0
% INFO    : Bus 4382	: V=1.097805, theta=-21.480439 -> V=1.02356, theta=0.0
% INFO    : Bus 4383	: V=1.081342, theta=0.192816 -> V=1.021471, theta=0.0
% INFO    : Bus 4384	: V=1.096716, theta=-44.758513 -> V=1.036631, theta=0.0
% INFO    : Bus 4385	: V=1.003822, theta=-23.875344 -> V=1.0, theta=0.0
% INFO    : Bus 4386	: V=0.979605, theta=-24.633729 -> V=1.0, theta=0.0
% INFO    : Bus 4387	: V=1.066409, theta=-14.026379 -> V=1.024252, theta=0.0
% INFO    : Bus 4388	: V=1.099237, theta=-10.241415 -> V=1.0297645, theta=0.0
% INFO    : Bus 4389	: V=1.02929, theta=7.56658 -> V=1.0, theta=0.0
% INFO    : Bus 4390	: V=1.070451, theta=-23.607654 -> V=1.0358345, theta=0.0
% INFO    : Bus 4391	: V=0.996058, theta=59.965117 -> V=1.0, theta=0.0
% INFO    : Bus 4392	: V=1.018733, theta=-22.368868 -> V=1.0, theta=0.0
% INFO    : Bus 4393	: V=1.039839, theta=-5.318729 -> V=1.012223, theta=0.0
% INFO    : Bus 4394	: V=1.08867, theta=-10.255363 -> V=1.0232795, theta=0.0
% INFO    : Bus 4395	: V=1.066339, theta=-14.340888 -> V=1.011012, theta=0.0
% INFO    : Bus 4396	: V=1.083908, theta=-41.437345 -> V=1.0278615, theta=0.0
% INFO    : Bus 4397	: V=0.913653, theta=-29.37562 -> V=1.0, theta=0.0
% INFO    : Bus 4398	: V=1.006878, theta=-27.666196 -> V=1.0469515, theta=0.0
% INFO    : Bus 4399	: V=1.08582, theta=-28.312985 -> V=1.021487, theta=0.0
% INFO    : Bus 4400	: V=1.036552, theta=-10.371872 -> V=1.0, theta=0.0
% INFO    : Bus 4401	: V=0.966067, theta=-25.801762 -> V=1.0, theta=0.0
% INFO    : Bus 4402	: V=0.994178, theta=7.354863 -> V=1.0, theta=0.0
% INFO    : Bus 4403	: V=1.047127, theta=-14.854499 -> V=1.003267, theta=0.0
% INFO    : Bus 4404	: V=0.968059, theta=-24.775992 -> V=1.0, theta=0.0
% INFO    : Bus 4405	: V=1.080177, theta=-26.077615 -> V=1.010402, theta=0.0
% INFO    : Bus 4406	: V=1.080053, theta=-38.296895 -> V=1.025342, theta=0.0
% INFO    : Bus 4407	: V=0.923591, theta=36.005668 -> V=1.0, theta=0.0
% INFO    : Bus 4408	: V=1.023933, theta=62.246724 -> V=1.0, theta=0.0
% INFO    : Bus 4409	: V=1.0762, theta=11.426402 -> V=1.00397, theta=0.0
% INFO    : Bus 4410	: V=1.062789, theta=13.975286 -> V=1.0153125, theta=0.0
% INFO    : Bus 4411	: V=1.021136, theta=-20.441527 -> V=1.005971, theta=0.0
% INFO    : Bus 4412	: V=1.078653, theta=-6.58426 -> V=1.016917, theta=0.0
% INFO    : Bus 4413	: V=1.067091, theta=-13.061327 -> V=1.009452, theta=0.0
% INFO    : Bus 4414	: V=0.954094, theta=-23.46733 -> V=1.0, theta=0.0
% INFO    : Bus 4415	: V=1.079166, theta=-19.349807 -> V=1.021508, theta=0.0
% INFO    : Bus 4416	: V=1.017297, theta=-24.487789 -> V=1.0, theta=0.0
% INFO    : Bus 4417	: V=0.985698, theta=8.182729 -> V=1.0, theta=0.0
% INFO    : Bus 4418	: V=1.061419, theta=-54.168785 -> V=1.0, theta=0.0
% INFO    : Bus 4419	: V=1.058645, theta=-40.945979 -> V=1.0041275, theta=0.0
% INFO    : Bus 4420	: V=1.01292, theta=-27.735152 -> V=1.0, theta=0.0
% INFO    : Bus 4421	: V=1.050164, theta=23.850522 -> V=1.0135995, theta=0.0
% INFO    : Bus 4422	: V=1.093863, theta=56.369655 -> V=1.0072375, theta=0.0
% INFO    : Bus 4423	: V=1.071205, theta=-2.590788 -> V=1.014295, theta=0.0
% INFO    : Bus 4424	: V=1.004056, theta=-21.217422 -> V=1.0, theta=0.0
% INFO    : Bus 4425	: V=0.982253, theta=-19.814483 -> V=1.0, theta=0.0
% INFO    : Bus 4426	: V=1.066342, theta=9.614521 -> V=1.0, theta=0.0
% INFO    : Bus 4427	: V=1.054868, theta=-12.447754 -> V=1.0193405, theta=0.0
% INFO    : Bus 4428	: V=1.03595, theta=-46.107851 -> V=1.0, theta=0.0
% INFO    : Bus 4429	: V=1.058737, theta=21.347659 -> V=1.0136145, theta=0.0
% INFO    : Bus 4430	: V=1.075838, theta=-4.346949 -> V=1.0185965, theta=0.0
% INFO    : Bus 4431	: V=1.031506, theta=-43.461893 -> V=1.0, theta=0.0
% INFO    : Bus 4432	: V=1.083942, theta=-15.5845 -> V=1.033992, theta=0.0
% INFO    : Bus 4433	: V=1.078545, theta=-18.836987 -> V=1.0, theta=0.0
% INFO    : Bus 4434	: V=1.037211, theta=3.990298 -> V=1.0, theta=0.0
% INFO    : Bus 4435	: V=1.009809, theta=-46.035611 -> V=1.0, theta=0.0
% INFO    : Bus 4436	: V=1.056306, theta=-38.450266 -> V=1.0448115, theta=0.0
% INFO    : Bus 4437	: V=0.993293, theta=11.080085 -> V=1.0, theta=0.0
% INFO    : Bus 4438	: V=1.050406, theta=-21.616362 -> V=1.0, theta=0.0
% INFO    : Bus 4439	: V=1.057299, theta=-20.043859 -> V=1.0076135, theta=0.0
% INFO    : Bus 4440	: V=0.997044, theta=-29.475195 -> V=1.0, theta=0.0
% INFO    : Bus 4441	: V=1.036081, theta=-0.498374 -> V=1.002615, theta=0.0
% INFO    : Bus 4442	: V=1.071818, theta=-14.320246 -> V=1.0139465, theta=0.0
% INFO    : Bus 4443	: V=0.941711, theta=-27.396493 -> V=1.0, theta=0.0
% INFO    : Bus 4444	: V=0.963971, theta=-25.25361 -> V=1.0, theta=0.0
% INFO    : Bus 4445	: V=1.075826, theta=0.245464 -> V=1.014406, theta=0.0
% INFO    : Bus 4446	: V=1.076195, theta=-25.467685 -> V=1.0320395, theta=0.0
% INFO    : Bus 4447	: V=1.099789, theta=61.333768 -> V=1.0085755, theta=0.0
% INFO    : Bus 4448	: V=1.027424, theta=-21.729128 -> V=1.0, theta=0.0
% INFO    : Bus 4449	: V=1.040619, theta=-12.407295 -> V=1.0055655, theta=0.0
% INFO    : Bus 4450	: V=1.061738, theta=-43.893605 -> V=1.005933, theta=0.0
% INFO    : Bus 4451	: V=1.084818, theta=-2.229715 -> V=1.0226035, theta=0.0
% INFO    : Bus 4452	: V=1.064341, theta=5.336883 -> V=1.0, theta=0.0
% INFO    : Bus 4453	: V=1.065196, theta=-12.842837 -> V=1.028832, theta=0.0
% INFO    : Bus 4454	: V=1.060759, theta=-14.417897 -> V=1.0054635, theta=0.0
% INFO    : Bus 4455	: V=1.055538, theta=-53.154312 -> V=1.0, theta=0.0
% INFO    : Bus 4456	: V=1.043409, theta=-42.033559 -> V=1.0, theta=0.0
% INFO    : Bus 4457	: V=1.002514, theta=-23.821989 -> V=1.0, theta=0.0
% INFO    : Bus 4458	: V=1.005859, theta=-24.704675 -> V=1.0, theta=0.0
% INFO    : Bus 4459	: V=0.988886, theta=-27.73563 -> V=1.0, theta=0.0
% INFO    : Bus 4460	: V=1.10389, theta=-9.233376 -> V=1.023804, theta=0.0
% INFO    : Bus 4461	: V=1.052691, theta=-36.236867 -> V=1.0175845, theta=0.0
% INFO    : Bus 4462	: V=1.002974, theta=-29.839566 -> V=1.0, theta=0.0
% INFO    : Bus 4463	: V=1.049919, theta=-41.783587 -> V=1.0, theta=0.0
% INFO    : Bus 4464	: V=1.085075, theta=-13.051716 -> V=1.029404, theta=0.0
% INFO    : Bus 4465	: V=1.078205, theta=-20.248238 -> V=1.020556, theta=0.0
% INFO    : Bus 4466	: V=1.065279, theta=-19.06845 -> V=1.0092225, theta=0.0
% INFO    : Bus 4467	: V=1.072999, theta=-42.384618 -> V=1.0107775, theta=0.0
% INFO    : Bus 4468	: V=1.051365, theta=-20.177973 -> V=1.0026445, theta=0.0
% INFO    : Bus 4469	: V=1.073931, theta=-19.173675 -> V=1.0054605, theta=0.0
% INFO    : Bus 4470	: V=1.054668, theta=-19.075202 -> V=1.0, theta=0.0
% INFO    : Bus 4471	: V=1.060948, theta=-21.95364 -> V=1.01923, theta=0.0
% INFO    : Bus 4472	: V=0.958901, theta=-25.606606 -> V=1.0, theta=0.0
% INFO    : Bus 4473	: V=1.039965, theta=-10.180746 -> V=1.0, theta=0.0
% INFO    : Bus 4474	: V=1.099818, theta=-10.968893 -> V=1.0362345, theta=0.0
% INFO    : Bus 4475	: V=1.024299, theta=-23.111209 -> V=1.0, theta=0.0
% INFO    : Bus 4476	: V=1.062251, theta=7.638396 -> V=1.01075, theta=0.0
% INFO    : Bus 4477	: V=1.072414, theta=-15.25219 -> V=1.011208, theta=0.0
% INFO    : Bus 4478	: V=1.08334, theta=-16.091468 -> V=1.0234835, theta=0.0
% INFO    : Bus 4479	: V=1.094008, theta=-15.962661 -> V=1.0384355, theta=0.0
% INFO    : Bus 4480	: V=1.072713, theta=-21.341778 -> V=1.027801, theta=0.0
% INFO    : Bus 4481	: V=1.08221, theta=-37.878541 -> V=1.0202755, theta=0.0
% INFO    : Bus 4482	: V=1.056218, theta=-44.357876 -> V=1.012234, theta=0.0
% INFO    : Bus 4483	: V=1.087634, theta=0.767244 -> V=1.018466, theta=0.0
% INFO    : Bus 4484	: V=0.980598, theta=-21.829479 -> V=1.0, theta=0.0
% INFO    : Bus 4485	: V=1.072578, theta=-39.303479 -> V=1.019824, theta=0.0
% INFO    : Bus 4486	: V=0.987765, theta=-20.844105 -> V=1.0, theta=0.0
% INFO    : Bus 4487	: V=1.01794, theta=-22.770842 -> V=1.0, theta=0.0
% INFO    : Bus 4488	: V=0.957465, theta=-34.604332 -> V=1.0, theta=0.0
% INFO    : Bus 4489	: V=1.036207, theta=-26.663395 -> V=1.0, theta=0.0
% INFO    : Bus 4490	: V=1.050578, theta=-30.435543 -> V=1.0240055, theta=0.0
% INFO    : Bus 4491	: V=1.032027, theta=-30.788814 -> V=1.0, theta=0.0
% INFO    : Bus 4492	: V=1.080737, theta=-7.655879 -> V=1.0173165, theta=0.0
% INFO    : Bus 4493	: V=1.074646, theta=-4.535258 -> V=1.014127, theta=0.0
% INFO    : Bus 4494	: V=0.957307, theta=-29.216707 -> V=0.9961515, theta=0.0
% INFO    : Bus 4495	: V=1.000647, theta=10.159957 -> V=1.0, theta=0.0
% INFO    : Bus 4496	: V=1.077931, theta=-12.319855 -> V=1.0219985, theta=0.0
% INFO    : Bus 4497	: V=1.099869, theta=-17.488973 -> V=1.032975, theta=0.0
% INFO    : Bus 4498	: V=0.983182, theta=-18.272465 -> V=1.0, theta=0.0
% INFO    : Bus 4499	: V=1.087605, theta=-36.861058 -> V=1.020348, theta=0.0
% INFO    : Bus 4500	: V=1.04564, theta=-12.310538 -> V=1.0057295, theta=0.0
% INFO    : Bus 4501	: V=1.075191, theta=-35.539772 -> V=1.008575, theta=0.0
% INFO    : Bus 4502	: V=1.035978, theta=-32.271315 -> V=1.0078785, theta=0.0
% INFO    : Bus 4503	: V=1.058727, theta=6.239312 -> V=1.0234855, theta=0.0
% INFO    : Bus 4504	: V=1.034657, theta=-39.455268 -> V=1.022067, theta=0.0
% INFO    : Bus 4505	: V=1.088869, theta=-2.863272 -> V=1.0212565, theta=0.0
% INFO    : Bus 4506	: V=1.059182, theta=-16.316058 -> V=1.005819, theta=0.0
% INFO    : Bus 4507	: V=1.053757, theta=-47.038258 -> V=1.0, theta=0.0
% INFO    : Bus 4508	: V=1.054591, theta=-38.321649 -> V=1.0031085, theta=0.0
% INFO    : Bus 4509	: V=1.067246, theta=-0.419665 -> V=1.019547, theta=0.0
% INFO    : Bus 4510	: V=1.088895, theta=-34.997542 -> V=1.0200415, theta=0.0
% INFO    : Bus 4511	: V=1.051241, theta=-41.375725 -> V=1.0, theta=0.0
% INFO    : Bus 4512	: V=0.949173, theta=-27.31455 -> V=1.0, theta=0.0
% INFO    : Bus 4513	: V=0.952525, theta=-17.591369 -> V=1.0, theta=0.0
% INFO    : Bus 4514	: V=0.987295, theta=-24.257215 -> V=1.0, theta=0.0
% INFO    : Bus 4515	: V=0.998124, theta=-23.701706 -> V=1.0, theta=0.0
% INFO    : Bus 4516	: V=1.053374, theta=9.835532 -> V=1.006306, theta=0.0
% INFO    : Bus 4517	: V=0.990985, theta=-23.000704 -> V=1.0, theta=0.0
% INFO    : Bus 4518	: V=1.032942, theta=-37.502485 -> V=1.0, theta=0.0
% INFO    : Bus 4519	: V=1.045955, theta=-37.806223 -> V=1.0, theta=0.0
% INFO    : Bus 4520	: V=1.067878, theta=9.943282 -> V=1.0109025, theta=0.0
% INFO    : Bus 4521	: V=1.092211, theta=-8.103558 -> V=1.014167, theta=0.0
% INFO    : Bus 4522	: V=1.071349, theta=-17.101581 -> V=1.0262405, theta=0.0
% INFO    : Bus 4523	: V=1.021631, theta=-13.268766 -> V=1.0, theta=0.0
% INFO    : Bus 4524	: V=1.057605, theta=-15.320527 -> V=1.0, theta=0.0
% INFO    : Bus 4525	: V=1.060616, theta=-13.068609 -> V=1.0129695, theta=0.0
% INFO    : Bus 4526	: V=0.919681, theta=-29.100332 -> V=0.9844065, theta=0.0
% INFO    : Bus 4527	: V=0.969994, theta=-24.860406 -> V=1.0, theta=0.0
% INFO    : Bus 4528	: V=1.054452, theta=-25.05058 -> V=1.01305, theta=0.0
% INFO    : Bus 4529	: V=1.030827, theta=-24.328356 -> V=1.0, theta=0.0
% INFO    : Bus 4530	: V=1.093262, theta=-20.244147 -> V=1.0319955, theta=0.0
% INFO    : Bus 4531	: V=1.01869, theta=-24.764279 -> V=1.0, theta=0.0
% INFO    : Bus 4532	: V=0.98737, theta=-36.979224 -> V=1.0, theta=0.0
% INFO    : Bus 4533	: V=0.969373, theta=-24.065598 -> V=1.0, theta=0.0
% INFO    : Bus 4534	: V=1.086419, theta=-15.479273 -> V=1.022056, theta=0.0
% INFO    : Bus 4535	: V=1.042295, theta=-20.455497 -> V=1.0, theta=0.0
% INFO    : Bus 4536	: V=1.016203, theta=-21.877494 -> V=1.0, theta=0.0
% INFO    : Bus 4537	: V=1.02456, theta=-16.232778 -> V=1.0, theta=0.0
% INFO    : Bus 4538	: V=0.978572, theta=-20.060492 -> V=1.0, theta=0.0
% INFO    : Bus 4539	: V=1.013508, theta=-21.823066 -> V=1.0, theta=0.0
% INFO    : Bus 4540	: V=1.055878, theta=-43.384709 -> V=1.012108, theta=0.0
% INFO    : Bus 4541	: V=0.943149, theta=-13.573815 -> V=1.0, theta=0.0
% INFO    : Bus 4542	: V=1.040962, theta=25.90764 -> V=1.016075, theta=0.0
% INFO    : Bus 4543	: V=1.074816, theta=-26.772268 -> V=1.0157105, theta=0.0
% INFO    : Bus 4544	: V=1.066561, theta=-23.468244 -> V=1.0049095, theta=0.0
% INFO    : Bus 4545	: V=0.996273, theta=-28.146012 -> V=1.0, theta=0.0
% INFO    : Bus 4546	: V=1.001315, theta=-21.173616 -> V=1.0, theta=0.0
% INFO    : Bus 4547	: V=0.961174, theta=-21.556367 -> V=1.0, theta=0.0
% INFO    : Bus 4548	: V=1.001314, theta=-21.173562 -> V=1.0, theta=0.0
% INFO    : Bus 4549	: V=1.073307, theta=10.735459 -> V=1.027905, theta=0.0
% INFO    : Bus 4550	: V=1.068938, theta=-12.076088 -> V=1.0262795, theta=0.0
% INFO    : Bus 4551	: V=1.076083, theta=-9.472581 -> V=1.023347, theta=0.0
% INFO    : Bus 4552	: V=1.065591, theta=-14.768536 -> V=1.024169, theta=0.0
% INFO    : Bus 4553	: V=1.097553, theta=56.225682 -> V=1.0089185, theta=0.0
% INFO    : Bus 4554	: V=1.01839, theta=-33.288526 -> V=1.0, theta=0.0
% INFO    : Bus 4555	: V=1.053272, theta=-14.274504 -> V=1.0036865, theta=0.0
% INFO    : Bus 4556	: V=1.042848, theta=9.633576 -> V=1.0025615, theta=0.0
% INFO    : Bus 4557	: V=1.100288, theta=-10.065255 -> V=1.026033, theta=0.0
% INFO    : Bus 4558	: V=1.034985, theta=13.119172 -> V=1.0, theta=0.0
% INFO    : Bus 4559	: V=0.940141, theta=-24.955574 -> V=1.0, theta=0.0
% INFO    : Bus 4560	: V=1.025672, theta=-24.44021 -> V=1.0, theta=0.0
% INFO    : Bus 4561	: V=1.083341, theta=-15.597036 -> V=1.0324765, theta=0.0
% INFO    : Bus 4562	: V=1.010608, theta=-17.153665 -> V=1.004445, theta=0.0
% INFO    : Bus 4563	: V=1.068705, theta=-4.662019 -> V=1.0155605, theta=0.0
% INFO    : Bus 4564	: V=1.070612, theta=-18.15395 -> V=1.0, theta=0.0
% INFO    : Bus 4565	: V=0.997088, theta=-22.788396 -> V=1.0, theta=0.0
% INFO    : Bus 4566	: V=1.060455, theta=-12.5075 -> V=1.022118, theta=0.0
% INFO    : Bus 4567	: V=1.045136, theta=-22.772074 -> V=1.0, theta=0.0
% INFO    : Bus 4568	: V=0.964441, theta=53.98231 -> V=1.0, theta=0.0
% INFO    : Bus 4569	: V=0.999834, theta=-23.487068 -> V=1.0, theta=0.0
% INFO    : Bus 4570	: V=1.02044, theta=-17.759741 -> V=1.0091205, theta=0.0
% INFO    : Bus 4571	: V=1.026136, theta=-43.747876 -> V=1.0, theta=0.0
% INFO    : Bus 4572	: V=1.060413, theta=-5.735082 -> V=1.0171955, theta=0.0
% INFO    : Bus 4573	: V=1.063, theta=-14.108078 -> V=1.0098865, theta=0.0
% INFO    : Bus 4574	: V=1.037937, theta=-11.667277 -> V=1.0, theta=0.0
% INFO    : Bus 4575	: V=1.037624, theta=-25.230646 -> V=1.0, theta=0.0
% INFO    : Bus 4576	: V=1.058828, theta=6.781396 -> V=1.005282, theta=0.0
% INFO    : Bus 4577	: V=1.024728, theta=-31.130941 -> V=1.0, theta=0.0
% INFO    : Bus 4578	: V=1.058657, theta=-47.061638 -> V=1.005593, theta=0.0
% INFO    : Bus 4579	: V=1.056358, theta=-40.996321 -> V=1.0054205, theta=0.0
% INFO    : Bus 4580	: V=1.014, theta=-16.846087 -> V=1.0, theta=0.0
% INFO    : Bus 4581	: V=0.947039, theta=-27.426829 -> V=1.0, theta=0.0
% INFO    : Bus 4582	: V=1.075845, theta=-10.542346 -> V=1.016673, theta=0.0
% INFO    : Bus 4583	: V=0.94672, theta=-27.1454 -> V=1.0, theta=0.0
% INFO    : Bus 4584	: V=1.023955, theta=-22.466353 -> V=1.025831, theta=0.0
% INFO    : Bus 4585	: V=1.08974, theta=-45.143135 -> V=1.0156635, theta=0.0
% INFO    : Bus 4586	: V=1.053318, theta=-14.913589 -> V=1.0106655, theta=0.0
% INFO    : Bus 4587	: V=1.09376, theta=-36.343942 -> V=1.0228735, theta=0.0
% INFO    : Bus 4588	: V=1.002344, theta=-15.881011 -> V=1.0, theta=0.0
% INFO    : Bus 4589	: V=1.040662, theta=65.88704 -> V=1.0, theta=0.0
% INFO    : Bus 4590	: V=1.059779, theta=-12.210974 -> V=1.0106995, theta=0.0
% INFO    : Bus 4591	: V=0.986966, theta=-25.381029 -> V=1.0, theta=0.0
% INFO    : Bus 4592	: V=1.089107, theta=54.287863 -> V=1.0069965, theta=0.0
% INFO    : Bus 4593	: V=1.075825, theta=-19.261997 -> V=1.0285885, theta=0.0
% INFO    : Bus 4594	: V=1.045799, theta=-17.469101 -> V=1.005283, theta=0.0
% INFO    : Bus 4595	: V=1.033409, theta=-15.59446 -> V=1.0119185, theta=0.0
% INFO    : Bus 4596	: V=1.001538, theta=-20.313715 -> V=1.0, theta=0.0
% INFO    : Bus 4597	: V=1.017705, theta=-23.44175 -> V=1.0, theta=0.0
% INFO    : Bus 4598	: V=1.084738, theta=37.869513 -> V=1.002565, theta=0.0
% INFO    : Bus 4599	: V=1.015359, theta=-17.407 -> V=1.0, theta=0.0
% INFO    : Bus 4600	: V=0.976015, theta=-25.068242 -> V=1.0, theta=0.0
% INFO    : Bus 4601	: V=1.035345, theta=-24.815021 -> V=1.0, theta=0.0
% INFO    : Bus 4602	: V=1.058868, theta=-29.713317 -> V=1.012295, theta=0.0
% INFO    : Bus 4603	: V=1.095816, theta=-36.759679 -> V=1.030251, theta=0.0
% INFO    : Bus 4604	: V=1.045552, theta=9.71944 -> V=1.0, theta=0.0
% INFO    : Bus 4605	: V=1.098776, theta=-22.783276 -> V=1.0222515, theta=0.0
% INFO    : Bus 4606	: V=0.985443, theta=-25.578358 -> V=1.0, theta=0.0
% INFO    : Bus 4607	: V=0.932214, theta=-32.391678 -> V=1.0, theta=0.0
% INFO    : Bus 4608	: V=1.103421, theta=25.837074 -> V=1.0202765, theta=0.0
% INFO    : Bus 4609	: V=0.939995, theta=-29.215258 -> V=0.9956795, theta=0.0
% INFO    : Bus 4610	: V=1.041632, theta=-7.700924 -> V=1.014614, theta=0.0
% INFO    : Bus 4611	: V=0.977454, theta=-22.53634 -> V=1.0, theta=0.0
% INFO    : Bus 4612	: V=1.080718, theta=-26.093129 -> V=1.0110645, theta=0.0
% INFO    : Bus 4613	: V=0.94683, theta=-31.833015 -> V=1.0, theta=0.0
% INFO    : Bus 4614	: V=0.976502, theta=-9.172641 -> V=1.0, theta=0.0
% INFO    : Bus 4615	: V=1.010426, theta=-27.437893 -> V=1.0466685, theta=0.0
% INFO    : Bus 4616	: V=0.926511, theta=-29.214484 -> V=1.0, theta=0.0
% INFO    : Bus 4617	: V=1.061864, theta=-7.162268 -> V=1.0099555, theta=0.0
% INFO    : Bus 4618	: V=0.940098, theta=-25.620147 -> V=1.0, theta=0.0
% INFO    : Bus 4619	: V=1.069, theta=-18.766423 -> V=1.007225, theta=0.0
% INFO    : Bus 4620	: V=1.051469, theta=-31.449458 -> V=1.018279, theta=0.0
% INFO    : Bus 4621	: V=1.039943, theta=-25.059294 -> V=1.0, theta=0.0
% INFO    : Bus 4622	: V=0.941342, theta=-18.315441 -> V=1.0, theta=0.0
% INFO    : Bus 4623	: V=1.049925, theta=-21.326045 -> V=1.0053195, theta=0.0
% INFO    : Bus 4624	: V=1.04144, theta=-12.29925 -> V=1.006501, theta=0.0
% INFO    : Bus 4625	: V=1.045476, theta=-13.967777 -> V=1.008856, theta=0.0
% INFO    : Bus 4626	: V=1.070682, theta=-6.883058 -> V=1.0152655, theta=0.0
% INFO    : Bus 4627	: V=1.033767, theta=-13.764787 -> V=1.0091965, theta=0.0
% INFO    : Bus 4628	: V=1.06504, theta=-11.133413 -> V=1.013456, theta=0.0
% INFO    : Bus 4629	: V=1.059732, theta=-20.417722 -> V=1.00594, theta=0.0
% INFO    : Bus 4630	: V=1.031187, theta=-32.682592 -> V=1.0, theta=0.0
% INFO    : Bus 4631	: V=1.090684, theta=-35.319448 -> V=1.022696, theta=0.0
% INFO    : Bus 4632	: V=1.103658, theta=-8.449869 -> V=1.0210935, theta=0.0
% INFO    : Bus 4633	: V=1.060618, theta=-14.558014 -> V=1.0145265, theta=0.0
% INFO    : Bus 4634	: V=1.050384, theta=-30.723795 -> V=1.0039755, theta=0.0
% INFO    : Bus 4635	: V=0.951708, theta=-23.940019 -> V=1.0, theta=0.0
% INFO    : Bus 4636	: V=1.085077, theta=-35.099296 -> V=1.0179235, theta=0.0
% INFO    : Bus 4637	: V=1.086212, theta=-9.132152 -> V=1.0257865, theta=0.0
% INFO    : Bus 4638	: V=1.090709, theta=1.488574 -> V=1.029156, theta=0.0
% INFO    : Bus 4639	: V=1.071547, theta=-7.297108 -> V=1.019851, theta=0.0
% INFO    : Bus 4640	: V=1.054999, theta=65.866145 -> V=1.0, theta=0.0
% INFO    : Bus 4641	: V=1.08398, theta=34.189139 -> V=1.0166865, theta=0.0
% INFO    : Bus 4642	: V=0.970217, theta=-10.333919 -> V=1.0, theta=0.0
% INFO    : Bus 4643	: V=1.06119, theta=-18.485624 -> V=1.0074945, theta=0.0
% INFO    : Bus 4644	: V=1.062295, theta=-30.692825 -> V=1.044216, theta=0.0
% INFO    : Bus 4645	: V=1.084805, theta=-16.310524 -> V=1.0259985, theta=0.0
% INFO    : Bus 4646	: V=1.076205, theta=10.475753 -> V=1.027323, theta=0.0
% INFO    : Bus 4647	: V=1.086327, theta=-25.719984 -> V=1.0221485, theta=0.0
% INFO    : Bus 4648	: V=1.068545, theta=-9.50534 -> V=1.014255, theta=0.0
% INFO    : Bus 4649	: V=1.034865, theta=-48.036195 -> V=1.0, theta=0.0
% INFO    : Bus 4650	: V=1.030629, theta=-22.512233 -> V=1.0, theta=0.0
% INFO    : Bus 4651	: V=1.086043, theta=-17.156453 -> V=1.0342745, theta=0.0
% INFO    : Bus 4652	: V=0.99876, theta=64.434016 -> V=1.0, theta=0.0
% INFO    : Bus 4653	: V=1.028106, theta=7.590633 -> V=1.0, theta=0.0
% INFO    : Bus 4654	: V=1.066165, theta=-42.327939 -> V=1.006696, theta=0.0
% INFO    : Bus 4655	: V=0.997369, theta=-22.465399 -> V=1.0, theta=0.0
% INFO    : Bus 4656	: V=1.079727, theta=-23.869736 -> V=1.0198145, theta=0.0
% INFO    : Bus 4657	: V=1.048658, theta=-38.89454 -> V=1.0, theta=0.0
% INFO    : Bus 4658	: V=0.956255, theta=-26.392192 -> V=1.0, theta=0.0
% INFO    : Bus 4659	: V=1.057574, theta=-30.223524 -> V=1.011667, theta=0.0
% INFO    : Bus 4660	: V=1.09066, theta=28.271356 -> V=1.0377535, theta=0.0
% INFO    : Bus 4661	: V=0.966355, theta=-23.226656 -> V=1.0, theta=0.0
% INFO    : Bus 4662	: V=0.968649, theta=-25.640513 -> V=1.0, theta=0.0
% INFO    : Bus 4663	: V=1.056172, theta=-31.71744 -> V=1.0095685, theta=0.0
% INFO    : Bus 4664	: V=1.076647, theta=-25.454886 -> V=1.033316, theta=0.0
% INFO    : Bus 4665	: V=0.934696, theta=-25.719967 -> V=1.0, theta=0.0
% INFO    : Bus 4666	: V=1.0207, theta=-21.043057 -> V=1.0, theta=0.0
% INFO    : Bus 4667	: V=0.961018, theta=-22.397335 -> V=1.0, theta=0.0
% INFO    : Bus 4668	: V=1.038421, theta=-29.258697 -> V=1.0, theta=0.0
% INFO    : Bus 4669	: V=1.081626, theta=-15.392458 -> V=1.0222265, theta=0.0
% INFO    : Bus 4670	: V=1.090316, theta=-24.189717 -> V=1.023778, theta=0.0
% INFO    : Bus 4671	: V=1.068106, theta=4.616363 -> V=1.0219765, theta=0.0
% INFO    : Bus 4672	: V=1.021887, theta=-24.085723 -> V=1.0, theta=0.0
% INFO    : Bus 4673	: V=0.98599, theta=-25.575448 -> V=1.0, theta=0.0
% INFO    : Bus 4674	: V=1.002507, theta=56.960561 -> V=1.0, theta=0.0
% INFO    : Bus 4675	: V=0.975669, theta=-24.74531 -> V=1.0, theta=0.0
% INFO    : Bus 4676	: V=1.082895, theta=-2.884645 -> V=1.0220825, theta=0.0
% INFO    : Bus 4677	: V=1.042136, theta=-18.612008 -> V=1.0, theta=0.0
% INFO    : Bus 4678	: V=1.010513, theta=-33.792788 -> V=1.0041945, theta=0.0
% INFO    : Bus 4679	: V=1.082158, theta=1.047433 -> V=1.016377, theta=0.0
% INFO    : Bus 4680	: V=1.069794, theta=-6.708376 -> V=1.0124895, theta=0.0
% INFO    : Bus 4681	: V=1.014024, theta=13.924802 -> V=1.0, theta=0.0
% INFO    : Bus 4682	: V=1.029384, theta=-23.369523 -> V=1.0, theta=0.0
% INFO    : Bus 4683	: V=1.041908, theta=-25.420228 -> V=1.0, theta=0.0
% INFO    : Bus 4684	: V=1.06941, theta=25.410658 -> V=1.0128555, theta=0.0
% INFO    : Bus 4685	: V=0.920097, theta=-31.459301 -> V=1.0, theta=0.0
% INFO    : Bus 4686	: V=0.968333, theta=67.547457 -> V=1.0, theta=0.0
% INFO    : Bus 4687	: V=1.067018, theta=-10.886588 -> V=1.017913, theta=0.0
% INFO    : Bus 4688	: V=1.062308, theta=-20.249085 -> V=1.0, theta=0.0
% INFO    : Bus 4689	: V=1.005754, theta=-19.847241 -> V=1.0, theta=0.0
% INFO    : Bus 4690	: V=0.986302, theta=-35.119387 -> V=1.0, theta=0.0
% INFO    : Bus 4691	: V=1.058642, theta=-4.454718 -> V=1.017101, theta=0.0
% INFO    : Bus 4692	: V=1.02952, theta=-9.384755 -> V=1.0054815, theta=0.0
% INFO    : Bus 4693	: V=1.048129, theta=-31.924771 -> V=1.0, theta=0.0
% INFO    : Bus 4694	: V=1.042472, theta=-44.049702 -> V=1.005977, theta=0.0
% INFO    : Bus 4695	: V=1.023038, theta=-29.597008 -> V=1.007312, theta=0.0
% INFO    : Bus 4696	: V=1.094105, theta=36.653001 -> V=1.0074705, theta=0.0
% INFO    : Bus 4697	: V=1.044394, theta=7.37431 -> V=1.0, theta=0.0
% INFO    : Bus 4698	: V=0.967196, theta=-28.04469 -> V=1.0, theta=0.0
% INFO    : Bus 4699	: V=1.055635, theta=61.518383 -> V=1.004537, theta=0.0
% INFO    : Bus 4700	: V=1.0134, theta=-31.245433 -> V=1.0, theta=0.0
% INFO    : Bus 4701	: V=1.060262, theta=13.426192 -> V=1.009638, theta=0.0
% INFO    : Bus 4702	: V=1.053927, theta=-48.624156 -> V=1.008497, theta=0.0
% INFO    : Bus 4703	: V=1.047, theta=-42.547385 -> V=1.0027645, theta=0.0
% INFO    : Bus 4704	: V=1.081002, theta=-17.369417 -> V=1.0140155, theta=0.0
% INFO    : Bus 4705	: V=0.966002, theta=-29.140275 -> V=1.0, theta=0.0
% INFO    : Bus 4706	: V=1.075055, theta=-20.009507 -> V=1.0199555, theta=0.0
% INFO    : Bus 4707	: V=1.041295, theta=-11.828016 -> V=1.0, theta=0.0
% INFO    : Bus 4708	: V=1.030302, theta=-23.049432 -> V=1.0, theta=0.0
% INFO    : Bus 4709	: V=1.082112, theta=-17.269677 -> V=1.01565, theta=0.0
% INFO    : Bus 4710	: V=1.080124, theta=36.567759 -> V=1.0133945, theta=0.0
% INFO    : Bus 4711	: V=1.051405, theta=-30.188682 -> V=1.0244845, theta=0.0
% INFO    : Bus 4712	: V=1.052372, theta=-36.135814 -> V=1.0173295, theta=0.0
% INFO    : Bus 4713	: V=1.081768, theta=-7.412341 -> V=1.0240535, theta=0.0
% INFO    : Bus 4714	: V=1.050061, theta=-22.805199 -> V=1.0, theta=0.0
% INFO    : Bus 4715	: V=1.028239, theta=-4.422104 -> V=1.0, theta=0.0
% INFO    : Bus 4716	: V=1.049627, theta=-11.095204 -> V=1.006454, theta=0.0
% INFO    : Bus 4717	: V=0.995695, theta=-20.48945 -> V=1.0, theta=0.0
% INFO    : Bus 4718	: V=1.058834, theta=0.30698 -> V=1.010269, theta=0.0
% INFO    : Bus 4719	: V=1.070214, theta=-42.473416 -> V=1.0084565, theta=0.0
% INFO    : Bus 4720	: V=0.973925, theta=-25.040553 -> V=1.0, theta=0.0
% INFO    : Bus 4721	: V=1.052688, theta=-45.508297 -> V=1.008551, theta=0.0
% INFO    : Bus 4722	: V=1.075727, theta=-16.552721 -> V=1.021159, theta=0.0
% INFO    : Bus 4723	: V=1.041091, theta=-9.961801 -> V=1.0, theta=0.0
% INFO    : Bus 4724	: V=1.084166, theta=37.671212 -> V=1.0, theta=0.0
% INFO    : Bus 4725	: V=0.916305, theta=-30.954277 -> V=1.0, theta=0.0
% INFO    : Bus 4726	: V=1.038135, theta=-26.184523 -> V=1.0, theta=0.0
% INFO    : Bus 4727	: V=1.003341, theta=-16.394774 -> V=1.0, theta=0.0
% INFO    : Bus 4728	: V=1.005743, theta=-18.393766 -> V=1.0, theta=0.0
% INFO    : Bus 4729	: V=1.029982, theta=-21.168518 -> V=1.0, theta=0.0
% INFO    : Bus 4730	: V=1.043554, theta=-21.729684 -> V=1.0, theta=0.0
% INFO    : Bus 4731	: V=1.056494, theta=-48.67117 -> V=1.007222, theta=0.0
% INFO    : Bus 4732	: V=1.064708, theta=3.812117 -> V=1.017827, theta=0.0
% INFO    : Bus 4733	: V=1.0354, theta=-42.694636 -> V=1.0095365, theta=0.0
% INFO    : Bus 4734	: V=1.048251, theta=-18.174211 -> V=1.0, theta=0.0
% INFO    : Bus 4735	: V=0.938334, theta=-35.31118 -> V=1.0, theta=0.0
% INFO    : Bus 4736	: V=0.977679, theta=-28.272654 -> V=1.0, theta=0.0
% INFO    : Bus 4737	: V=1.030177, theta=3.029891 -> V=1.0108595, theta=0.0
% INFO    : Bus 4738	: V=1.069389, theta=-4.900056 -> V=1.0134945, theta=0.0
% INFO    : Bus 4739	: V=1.087783, theta=-19.574419 -> V=1.023955, theta=0.0
% INFO    : Bus 4740	: V=1.046834, theta=-11.033265 -> V=1.009248, theta=0.0
% INFO    : Bus 4741	: V=1.049622, theta=-25.523965 -> V=1.0290685, theta=0.0
% INFO    : Bus 4742	: V=1.089791, theta=-2.79084 -> V=1.024396, theta=0.0
% INFO    : Bus 4743	: V=1.066716, theta=-5.866607 -> V=1.0111485, theta=0.0
% INFO    : Bus 4744	: V=1.040273, theta=-18.73954 -> V=1.0, theta=0.0
% INFO    : Bus 4745	: V=1.03883, theta=-44.012045 -> V=1.0, theta=0.0
% INFO    : Bus 4746	: V=0.976451, theta=-26.066799 -> V=1.0, theta=0.0
% INFO    : Bus 4747	: V=1.044651, theta=-21.20515 -> V=1.00321, theta=0.0
% INFO    : Bus 4748	: V=0.949041, theta=-24.332914 -> V=1.0, theta=0.0
% INFO    : Bus 4749	: V=1.007964, theta=-17.835064 -> V=1.0, theta=0.0
% INFO    : Bus 4750	: V=0.977287, theta=-27.162776 -> V=1.0, theta=0.0
% INFO    : Bus 4751	: V=1.086636, theta=-14.643227 -> V=1.0182255, theta=0.0
% INFO    : Bus 4752	: V=1.104553, theta=-13.906648 -> V=1.0092655, theta=0.0
% INFO    : Bus 4753	: V=1.029192, theta=-13.403481 -> V=1.0, theta=0.0
% INFO    : Bus 4754	: V=1.044709, theta=-3.96431 -> V=1.0, theta=0.0
% INFO    : Bus 4755	: V=1.046747, theta=-31.689706 -> V=1.0, theta=0.0
% INFO    : Bus 4756	: V=1.021818, theta=-21.141219 -> V=1.0, theta=0.0
% INFO    : Bus 4757	: V=1.00488, theta=10.738319 -> V=1.0, theta=0.0
% INFO    : Bus 4758	: V=1.082534, theta=-10.991796 -> V=1.027075, theta=0.0
% INFO    : Bus 4759	: V=1.051435, theta=31.059389 -> V=1.0, theta=0.0
% INFO    : Bus 4760	: V=0.970786, theta=-32.495668 -> V=1.0, theta=0.0
% INFO    : Bus 4761	: V=1.086227, theta=-13.690711 -> V=1.013699, theta=0.0
% INFO    : Bus 4762	: V=1.066364, theta=-13.811698 -> V=1.009363, theta=0.0
% INFO    : Bus 4763	: V=0.970652, theta=-26.656231 -> V=1.0, theta=0.0
% INFO    : Bus 4764	: V=1.05, theta=-43.418123 -> V=1.0114235, theta=0.0
% INFO    : Bus 4765	: V=1.049162, theta=-3.27079 -> V=1.0175545, theta=0.0
% INFO    : Bus 4766	: V=1.08518, theta=-21.647686 -> V=1.016749, theta=0.0
% INFO    : Bus 4767	: V=0.987562, theta=-17.297195 -> V=1.0, theta=0.0
% INFO    : Bus 4768	: V=1.082877, theta=10.646155 -> V=1.0179725, theta=0.0
% INFO    : Bus 4769	: V=1.07815, theta=0.274164 -> V=1.023804, theta=0.0
% INFO    : Bus 4770	: V=0.997172, theta=-23.491067 -> V=1.0, theta=0.0
% INFO    : Bus 4771	: V=0.944964, theta=-25.465574 -> V=1.0, theta=0.0
% INFO    : Bus 4772	: V=0.998351, theta=-27.112844 -> V=1.0, theta=0.0
% INFO    : Bus 4773	: V=0.988545, theta=-16.29827 -> V=1.0, theta=0.0
% INFO    : Bus 4774	: V=1.005788, theta=-16.189925 -> V=1.0, theta=0.0
% INFO    : Bus 4775	: V=1.081223, theta=-41.51288 -> V=1.0264825, theta=0.0
% INFO    : Bus 4776	: V=1.045586, theta=-20.095589 -> V=1.0, theta=0.0
% INFO    : Bus 4777	: V=1.083661, theta=7.639683 -> V=1.019074, theta=0.0
% INFO    : Bus 4778	: V=1.049267, theta=-16.242423 -> V=1.010149, theta=0.0
% INFO    : Bus 4779	: V=1.076102, theta=-5.913744 -> V=1.017823, theta=0.0
% INFO    : Bus 4780	: V=1.071954, theta=26.976004 -> V=1.0, theta=0.0
% INFO    : Bus 4781	: V=1.039671, theta=-11.504496 -> V=1.0, theta=0.0
% INFO    : Bus 4782	: V=1.041236, theta=8.979767 -> V=1.0, theta=0.0
% INFO    : Bus 4783	: V=1.102816, theta=-10.818244 -> V=1.0208975, theta=0.0
% INFO    : Bus 4784	: V=1.086821, theta=-40.551615 -> V=1.02186, theta=0.0
% INFO    : Bus 4785	: V=0.999827, theta=-23.664813 -> V=1.0, theta=0.0
% INFO    : Bus 4786	: V=1.050378, theta=-30.724477 -> V=1.003973, theta=0.0
% INFO    : Bus 4787	: V=0.973252, theta=-24.235149 -> V=1.0, theta=0.0
% INFO    : Bus 4788	: V=1.031959, theta=-25.555762 -> V=1.0, theta=0.0
% INFO    : Bus 4789	: V=0.963767, theta=-26.782877 -> V=1.0, theta=0.0
% INFO    : Bus 4790	: V=1.078236, theta=-20.068303 -> V=1.0286695, theta=0.0
% INFO    : Bus 4791	: V=1.062271, theta=7.179293 -> V=1.00578, theta=0.0
% INFO    : Bus 4792	: V=1.094046, theta=34.601912 -> V=1.0136135, theta=0.0
% INFO    : Bus 4793	: V=1.053533, theta=63.973823 -> V=1.0, theta=0.0
% INFO    : Bus 4794	: V=1.028919, theta=-42.99778 -> V=1.0, theta=0.0
% INFO    : Bus 4795	: V=1.021892, theta=-17.227422 -> V=1.0121485, theta=0.0
% INFO    : Bus 4796	: V=1.049149, theta=-39.438556 -> V=1.0, theta=0.0
% INFO    : Bus 4797	: V=1.073909, theta=-23.063208 -> V=1.0197025, theta=0.0
% INFO    : Bus 4798	: V=1.043149, theta=14.673862 -> V=1.0, theta=0.0
% INFO    : Bus 4799	: V=1.063773, theta=-36.704728 -> V=1.009144, theta=0.0
% INFO    : Bus 4800	: V=1.010428, theta=-19.574142 -> V=1.0, theta=0.0
% INFO    : Bus 4801	: V=0.974878, theta=-19.542096 -> V=1.0, theta=0.0
% INFO    : Bus 4802	: V=1.036501, theta=-17.961905 -> V=1.0, theta=0.0
% INFO    : Bus 4803	: V=1.0435, theta=-23.922628 -> V=1.0, theta=0.0
% INFO    : Bus 4804	: V=1.073769, theta=-21.045717 -> V=1.027889, theta=0.0
% INFO    : Bus 4805	: V=1.05486, theta=-14.422877 -> V=1.0082225, theta=0.0
% INFO    : Bus 4806	: V=1.096637, theta=-34.29802 -> V=1.0295525, theta=0.0
% INFO    : Bus 4807	: V=1.030273, theta=-31.891158 -> V=1.0, theta=0.0
% INFO    : Bus 4808	: V=1.025055, theta=-45.602752 -> V=1.0, theta=0.0
% INFO    : Bus 4809	: V=1.050525, theta=16.067937 -> V=1.015201, theta=0.0
% INFO    : Bus 4810	: V=1.046035, theta=13.884545 -> V=1.0112955, theta=0.0
% INFO    : Bus 4811	: V=1.073243, theta=-23.159959 -> V=1.0191625, theta=0.0
% INFO    : Bus 4812	: V=1.04067, theta=-19.935673 -> V=1.010121, theta=0.0
% INFO    : Bus 4813	: V=1.056658, theta=27.937802 -> V=1.0146215, theta=0.0
% INFO    : Bus 4814	: V=1.047315, theta=-11.106511 -> V=1.0091635, theta=0.0
% INFO    : Bus 4815	: V=1.067455, theta=60.881157 -> V=1.006588, theta=0.0
% INFO    : Bus 4816	: V=1.060992, theta=-33.523982 -> V=1.0112095, theta=0.0
% INFO    : Bus 4817	: V=1.019886, theta=-46.661502 -> V=1.0, theta=0.0
% INFO    : Bus 4818	: V=1.03039, theta=-23.440764 -> V=1.0, theta=0.0
% INFO    : Bus 4819	: V=1.072773, theta=-4.667877 -> V=1.0146625, theta=0.0
% INFO    : Bus 4820	: V=0.997323, theta=-23.673346 -> V=1.0, theta=0.0
% INFO    : Bus 4821	: V=1.04141, theta=-21.688395 -> V=1.0, theta=0.0
% INFO    : Bus 4822	: V=1.032163, theta=-17.256489 -> V=1.0044235, theta=0.0
% INFO    : Bus 4823	: V=1.087, theta=-15.831137 -> V=1.016131, theta=0.0
% INFO    : Bus 4824	: V=1.049752, theta=-1.181911 -> V=1.0107905, theta=0.0
% INFO    : Bus 4825	: V=1.021569, theta=12.035196 -> V=1.0, theta=0.0
% INFO    : Bus 4826	: V=0.961571, theta=-26.17277 -> V=1.0, theta=0.0
% INFO    : Bus 4827	: V=1.009387, theta=-17.49788 -> V=1.0, theta=0.0
% INFO    : Bus 4828	: V=1.089097, theta=-23.922758 -> V=1.02216, theta=0.0
% INFO    : Bus 4829	: V=1.030837, theta=17.054427 -> V=1.0, theta=0.0
% INFO    : Bus 4830	: V=1.084658, theta=39.435245 -> V=1.0, theta=0.0
% INFO    : Bus 4831	: V=1.026737, theta=-41.933265 -> V=1.009245, theta=0.0
% INFO    : Bus 4832	: V=1.033259, theta=-25.194893 -> V=1.0, theta=0.0
% INFO    : Bus 4833	: V=1.046145, theta=-21.100661 -> V=1.0, theta=0.0
% INFO    : Bus 4834	: V=1.066895, theta=2.975479 -> V=1.01327, theta=0.0
% INFO    : Bus 4835	: V=0.95776, theta=-15.22782 -> V=1.0, theta=0.0
% INFO    : Bus 4836	: V=1.047364, theta=57.449027 -> V=1.003868, theta=0.0
% INFO    : Bus 4837	: V=1.042046, theta=-3.617375 -> V=1.0, theta=0.0
% INFO    : Bus 4838	: V=1.060378, theta=-19.108647 -> V=1.0, theta=0.0
% INFO    : Bus 4839	: V=1.022847, theta=-21.872746 -> V=1.00442, theta=0.0
% INFO    : Bus 4840	: V=1.053123, theta=-20.442133 -> V=1.018426, theta=0.0
% INFO    : Bus 4841	: V=1.085003, theta=-39.915583 -> V=1.0266655, theta=0.0
% INFO    : Bus 4842	: V=1.060455, theta=-39.111329 -> V=1.0, theta=0.0
% INFO    : Bus 4843	: V=1.006939, theta=-21.709092 -> V=1.0, theta=0.0
% INFO    : Bus 4844	: V=1.023579, theta=-32.305575 -> V=1.0, theta=0.0
% INFO    : Bus 4845	: V=1.075864, theta=-46.22102 -> V=1.006307, theta=0.0
% INFO    : Bus 4846	: V=1.02961, theta=-42.704703 -> V=1.0, theta=0.0
% INFO    : Bus 4847	: V=1.042526, theta=-12.74454 -> V=1.007322, theta=0.0
% INFO    : Bus 4848	: V=0.974612, theta=-25.003966 -> V=1.0, theta=0.0
% INFO    : Bus 4849	: V=1.031785, theta=-12.187347 -> V=1.0, theta=0.0
% INFO    : Bus 4850	: V=1.006573, theta=-25.159987 -> V=1.0, theta=0.0
% INFO    : Bus 4851	: V=1.011796, theta=-28.59804 -> V=1.0, theta=0.0
% INFO    : Bus 4852	: V=1.052182, theta=-10.84262 -> V=1.0163785, theta=0.0
% INFO    : Bus 4853	: V=1.06789, theta=-20.36213 -> V=1.0251625, theta=0.0
% INFO    : Bus 4854	: V=1.08071, theta=0.061128 -> V=1.0241755, theta=0.0
% INFO    : Bus 4855	: V=1.053792, theta=-5.091263 -> V=1.010688, theta=0.0
% INFO    : Bus 4856	: V=0.953872, theta=-27.609472 -> V=1.0, theta=0.0
% INFO    : Bus 4857	: V=1.06784, theta=22.273412 -> V=1.0078825, theta=0.0
% INFO    : Bus 4858	: V=0.971881, theta=-27.629697 -> V=1.0, theta=0.0
% INFO    : Bus 4859	: V=1.052136, theta=-38.766772 -> V=1.0, theta=0.0
% INFO    : Bus 4860	: V=0.985502, theta=-24.258087 -> V=1.0, theta=0.0
% INFO    : Bus 4861	: V=1.079975, theta=-12.777536 -> V=1.0170545, theta=0.0
% INFO    : Bus 4862	: V=1.013738, theta=-28.91817 -> V=1.0, theta=0.0
% INFO    : Bus 4863	: V=1.081969, theta=-8.528901 -> V=1.0260675, theta=0.0
% INFO    : Bus 4864	: V=1.094905, theta=-37.289029 -> V=1.030417, theta=0.0
% INFO    : Bus 4865	: V=0.988075, theta=-24.241803 -> V=1.0, theta=0.0
% INFO    : Bus 4866	: V=1.02444, theta=-25.67911 -> V=1.0, theta=0.0
% INFO    : Bus 4867	: V=0.961889, theta=-29.652528 -> V=0.988615, theta=0.0
% INFO    : Bus 4868	: V=1.043815, theta=-13.729485 -> V=1.0034525, theta=0.0
% INFO    : Bus 4869	: V=0.987688, theta=-38.98641 -> V=1.0, theta=0.0
% INFO    : Bus 4870	: V=1.077029, theta=-22.99678 -> V=1.03095, theta=0.0
% INFO    : Bus 4871	: V=1.030584, theta=-24.499978 -> V=1.0, theta=0.0
% INFO    : Bus 4872	: V=1.062704, theta=-2.539532 -> V=1.020318, theta=0.0
% INFO    : Bus 4873	: V=1.095182, theta=-11.36468 -> V=1.034989, theta=0.0
% INFO    : Bus 4874	: V=1.092636, theta=2.719886 -> V=1.0272145, theta=0.0
% INFO    : Bus 4875	: V=1.058909, theta=7.002481 -> V=1.0215475, theta=0.0
% INFO    : Bus 4876	: V=0.964731, theta=-9.392736 -> V=1.0, theta=0.0
% INFO    : Bus 4877	: V=1.023866, theta=-22.456237 -> V=1.024947, theta=0.0
% INFO    : Bus 4878	: V=1.087438, theta=-36.671155 -> V=1.015725, theta=0.0
% INFO    : Bus 4879	: V=1.016275, theta=-24.275268 -> V=1.0, theta=0.0
% INFO    : Bus 4880	: V=1.022265, theta=61.683559 -> V=1.0, theta=0.0
% INFO    : Bus 4881	: V=1.054522, theta=-34.987516 -> V=1.008303, theta=0.0
% INFO    : Bus 4882	: V=1.051864, theta=65.950176 -> V=1.0, theta=0.0
% INFO    : Bus 4883	: V=0.998202, theta=-40.055334 -> V=1.0, theta=0.0
% INFO    : Bus 4884	: V=1.101474, theta=-6.061233 -> V=1.043736, theta=0.0
% INFO    : Bus 4885	: V=1.028972, theta=4.138976 -> V=1.0, theta=0.0
% INFO    : Bus 4886	: V=1.03201, theta=-25.666017 -> V=1.0, theta=0.0
% INFO    : Bus 4887	: V=1.003203, theta=-24.362845 -> V=1.0, theta=0.0
% INFO    : Bus 4888	: V=1.058946, theta=-23.324369 -> V=1.0164925, theta=0.0
% INFO    : Bus 4889	: V=1.018169, theta=-24.787152 -> V=1.0, theta=0.0
% INFO    : Bus 4890	: V=1.087668, theta=-19.637637 -> V=1.0238705, theta=0.0
% INFO    : Bus 4891	: V=0.990794, theta=-6.358469 -> V=1.0, theta=0.0
% INFO    : Bus 4892	: V=1.050389, theta=10.637937 -> V=1.0034965, theta=0.0
% INFO    : Bus 4893	: V=1.06617, theta=3.92527 -> V=1.0057845, theta=0.0
% INFO    : Bus 4894	: V=1.026274, theta=-12.986511 -> V=1.0, theta=0.0
% INFO    : Bus 4895	: V=0.990677, theta=-24.273303 -> V=1.0, theta=0.0
% INFO    : Bus 4896	: V=1.063267, theta=-43.871415 -> V=1.006412, theta=0.0
% INFO    : Bus 4897	: V=1.043641, theta=-20.98115 -> V=1.0, theta=0.0
% INFO    : Bus 4898	: V=1.065072, theta=-14.814066 -> V=1.0239515, theta=0.0
% INFO    : Bus 4899	: V=1.067938, theta=-34.303317 -> V=1.0363905, theta=0.0
% INFO    : Bus 4900	: V=1.00045, theta=-17.105601 -> V=1.0, theta=0.0
% INFO    : Bus 4901	: V=0.976364, theta=-25.47293 -> V=1.0, theta=0.0
% INFO    : Bus 4902	: V=1.054289, theta=-39.692653 -> V=1.013431, theta=0.0
% INFO    : Bus 4903	: V=1.076242, theta=-13.307428 -> V=1.0215005, theta=0.0
% INFO    : Bus 4904	: V=1.094237, theta=55.306032 -> V=1.008996, theta=0.0
% INFO    : Bus 4905	: V=1.000758, theta=-24.420775 -> V=1.0, theta=0.0
% INFO    : Bus 4906	: V=1.021316, theta=14.202934 -> V=1.0, theta=0.0
% INFO    : Bus 4907	: V=1.02604, theta=-27.370287 -> V=1.0, theta=0.0
% INFO    : Bus 4908	: V=0.99488, theta=-23.99917 -> V=1.0, theta=0.0
% INFO    : Bus 4909	: V=1.09547, theta=-17.547933 -> V=1.022476, theta=0.0
% INFO    : Bus 4910	: V=0.996858, theta=-22.784044 -> V=1.0, theta=0.0
% INFO    : Bus 4911	: V=1.021698, theta=-21.446636 -> V=1.0, theta=0.0
% INFO    : Bus 4912	: V=1.060864, theta=-35.231323 -> V=1.0047605, theta=0.0
% INFO    : Bus 4913	: V=1.052011, theta=-20.447909 -> V=1.010691, theta=0.0
% INFO    : Bus 4914	: V=1.092763, theta=9.585602 -> V=1.0133985, theta=0.0
% INFO    : Bus 4915	: V=1.092164, theta=-17.089345 -> V=1.032844, theta=0.0
% INFO    : Bus 4916	: V=1.047716, theta=-25.536527 -> V=1.0, theta=0.0
% INFO    : Bus 4917	: V=1.073939, theta=1.972031 -> V=1.012504, theta=0.0
% INFO    : Bus 4918	: V=1.091409, theta=-11.958431 -> V=1.033299, theta=0.0
% INFO    : Bus 4919	: V=1.07824, theta=-20.248633 -> V=1.0205745, theta=0.0
% INFO    : Bus 4920	: V=1.022737, theta=-14.448106 -> V=1.0, theta=0.0
% INFO    : Bus 4921	: V=1.047569, theta=-22.417358 -> V=1.014508, theta=0.0
% INFO    : Bus 4922	: V=1.054859, theta=-14.422786 -> V=1.0081935, theta=0.0
% INFO    : Bus 4923	: V=1.019296, theta=2.766325 -> V=1.0, theta=0.0
% INFO    : Bus 4924	: V=1.076892, theta=-19.367186 -> V=1.0175855, theta=0.0
% INFO    : Bus 4925	: V=1.092737, theta=-31.886777 -> V=1.032148, theta=0.0
% INFO    : Bus 4926	: V=1.060005, theta=2.206369 -> V=1.009857, theta=0.0
% INFO    : Bus 4927	: V=1.063202, theta=27.238018 -> V=1.012841, theta=0.0
% INFO    : Bus 4928	: V=1.039955, theta=13.009838 -> V=1.0, theta=0.0
% INFO    : Bus 4929	: V=1.030718, theta=-25.984664 -> V=1.02822, theta=0.0
% INFO    : Bus 4930	: V=1.031814, theta=-43.155048 -> V=1.0, theta=0.0
% INFO    : Bus 4931	: V=0.981264, theta=-19.880686 -> V=1.0, theta=0.0
% INFO    : Bus 4932	: V=1.060752, theta=-14.796115 -> V=1.006343, theta=0.0
% INFO    : Bus 4933	: V=1.081761, theta=-15.459274 -> V=1.0140025, theta=0.0
% INFO    : Bus 4934	: V=1.08474, theta=57.231504 -> V=1.0, theta=0.0
% INFO    : Bus 4935	: V=1.081727, theta=-9.225019 -> V=1.0170625, theta=0.0
% INFO    : Bus 4936	: V=1.081788, theta=-3.806726 -> V=1.0214025, theta=0.0
% INFO    : Bus 4937	: V=1.042938, theta=14.663837 -> V=1.0, theta=0.0
% INFO    : Bus 4938	: V=1.033976, theta=-22.768329 -> V=1.0064625, theta=0.0
% INFO    : Bus 4939	: V=1.050579, theta=10.648082 -> V=1.0040005, theta=0.0
% INFO    : Bus 4940	: V=1.019726, theta=-23.879442 -> V=1.0, theta=0.0
% INFO    : Bus 4941	: V=0.989307, theta=-17.364248 -> V=1.0, theta=0.0
% INFO    : Bus 4942	: V=0.951174, theta=-26.909034 -> V=1.0, theta=0.0
% INFO    : Bus 4943	: V=1.061409, theta=-26.838087 -> V=1.0142955, theta=0.0
% INFO    : Bus 4944	: V=1.089135, theta=-0.220896 -> V=1.0324805, theta=0.0
% INFO    : Bus 4945	: V=1.065434, theta=-40.084315 -> V=1.011879, theta=0.0
% INFO    : Bus 4946	: V=1.031065, theta=-43.537885 -> V=1.0, theta=0.0
% INFO    : Bus 4947	: V=0.988442, theta=63.228004 -> V=1.0, theta=0.0
% INFO    : Bus 4948	: V=1.019852, theta=-18.597204 -> V=1.0, theta=0.0
% INFO    : Bus 4949	: V=1.081763, theta=-7.412323 -> V=1.0240505, theta=0.0
% INFO    : Bus 4950	: V=0.944069, theta=-18.310009 -> V=1.0, theta=0.0
% INFO    : Bus 4951	: V=1.061273, theta=-6.009379 -> V=1.0184085, theta=0.0
% INFO    : Bus 4952	: V=1.076531, theta=-20.35319 -> V=1.0278705, theta=0.0
% INFO    : Bus 4953	: V=1.010906, theta=-47.175229 -> V=1.0, theta=0.0
% INFO    : Bus 4954	: V=0.995489, theta=-17.918991 -> V=1.0, theta=0.0
% INFO    : Bus 4955	: V=1.067632, theta=-17.816115 -> V=1.0251175, theta=0.0
% INFO    : Bus 4956	: V=1.054592, theta=9.631356 -> V=1.017836, theta=0.0
% INFO    : Bus 4957	: V=1.04718, theta=-37.939527 -> V=1.0, theta=0.0
% INFO    : Bus 4958	: V=1.089663, theta=-34.962151 -> V=1.0198915, theta=0.0
% INFO    : Bus 4959	: V=1.021727, theta=-42.753892 -> V=1.0, theta=0.0
% INFO    : Bus 4960	: V=1.024373, theta=-23.536247 -> V=1.0124995, theta=0.0
% INFO    : Bus 4961	: V=1.012138, theta=-8.852713 -> V=1.0, theta=0.0
% INFO    : Bus 4962	: V=1.044249, theta=-37.512326 -> V=1.039065, theta=0.0
% INFO    : Bus 4963	: V=1.051385, theta=-28.604445 -> V=1.0, theta=0.0
% INFO    : Bus 4964	: V=1.041263, theta=-45.097116 -> V=1.004608, theta=0.0
% INFO    : Bus 4965	: V=1.032697, theta=-15.908548 -> V=1.0, theta=0.0
% INFO    : Bus 4966	: V=1.022946, theta=31.456988 -> V=1.0, theta=0.0
% INFO    : Bus 4967	: V=0.956588, theta=-23.592797 -> V=1.0, theta=0.0
% INFO    : Bus 4968	: V=1.046831, theta=-19.647359 -> V=1.00468, theta=0.0
% INFO    : Bus 4969	: V=1.051463, theta=-44.12176 -> V=1.009205, theta=0.0
% INFO    : Bus 4970	: V=1.077392, theta=-25.285642 -> V=1.0336, theta=0.0
% INFO    : Bus 4971	: V=1.018737, theta=30.799273 -> V=1.0, theta=0.0
% INFO    : Bus 4972	: V=1.071861, theta=-25.870434 -> V=1.031918, theta=0.0
% INFO    : Bus 4973	: V=1.100684, theta=-8.723889 -> V=1.035727, theta=0.0
% INFO    : Bus 4974	: V=1.052406, theta=-36.555686 -> V=1.017056, theta=0.0
% INFO    : Bus 4975	: V=1.007473, theta=-27.596761 -> V=1.0463805, theta=0.0
% INFO    : Bus 4976	: V=1.022262, theta=-1.872114 -> V=1.0, theta=0.0
% INFO    : Bus 4977	: V=1.082763, theta=4.401725 -> V=1.0260545, theta=0.0
% INFO    : Bus 4978	: V=1.031727, theta=-13.531246 -> V=1.0039515, theta=0.0
% INFO    : Bus 4979	: V=1.035545, theta=-29.482161 -> V=1.01428, theta=0.0
% INFO    : Bus 4980	: V=0.967355, theta=-12.901202 -> V=1.0, theta=0.0
% INFO    : Bus 4981	: V=1.079815, theta=-14.655749 -> V=1.0292935, theta=0.0
% INFO    : Bus 4982	: V=1.05562, theta=3.031422 -> V=1.00592, theta=0.0
% INFO    : Bus 4983	: V=1.014599, theta=7.654459 -> V=1.0, theta=0.0
% INFO    : Bus 4984	: V=1.035171, theta=-44.706388 -> V=1.004665, theta=0.0
% INFO    : Bus 4985	: V=1.018058, theta=-33.211081 -> V=1.0, theta=0.0
% INFO    : Bus 4986	: V=1.063786, theta=54.079777 -> V=1.0, theta=0.0
% INFO    : Bus 4987	: V=1.03063, theta=-24.285357 -> V=1.0, theta=0.0
% INFO    : Bus 4988	: V=1.016639, theta=-17.037746 -> V=1.0, theta=0.0
% INFO    : Bus 4989	: V=1.042213, theta=-33.792438 -> V=1.003095, theta=0.0
% INFO    : Bus 4990	: V=0.991493, theta=-20.407539 -> V=1.0, theta=0.0
% INFO    : Bus 4991	: V=1.054646, theta=-48.98724 -> V=1.0049935, theta=0.0
% INFO    : Bus 4992	: V=0.990979, theta=-33.803375 -> V=1.0, theta=0.0
% INFO    : Bus 4993	: V=1.07706, theta=-19.521274 -> V=1.020514, theta=0.0
% INFO    : Bus 4994	: V=1.100084, theta=-11.49184 -> V=1.0210605, theta=0.0
% INFO    : Bus 4995	: V=1.021909, theta=-34.118747 -> V=1.0, theta=0.0
% INFO    : Bus 4996	: V=1.093887, theta=-7.200508 -> V=1.0258755, theta=0.0
% INFO    : Bus 4997	: V=0.92637, theta=-29.465867 -> V=0.9823165, theta=0.0
% INFO    : Bus 4998	: V=1.012557, theta=-35.136778 -> V=1.0, theta=0.0
% INFO    : Bus 4999	: V=0.976226, theta=-23.965635 -> V=1.0, theta=0.0
% INFO    : Bus 5000	: V=1.026492, theta=-4.778401 -> V=1.0, theta=0.0
% INFO    : Bus 5001	: V=1.058661, theta=-43.962347 -> V=1.0130455, theta=0.0
% INFO    : Bus 5002	: V=1.058873, theta=-54.041713 -> V=1.0, theta=0.0
% INFO    : Bus 5003	: V=1.038318, theta=-37.281212 -> V=1.0, theta=0.0
% INFO    : Bus 5004	: V=1.042773, theta=-3.644362 -> V=1.007759, theta=0.0
% INFO    : Bus 5005	: V=1.012716, theta=54.217215 -> V=1.0, theta=0.0
% INFO    : Bus 5006	: V=1.022567, theta=-15.118502 -> V=1.0113715, theta=0.0
% INFO    : Bus 5007	: V=0.960809, theta=-29.36477 -> V=1.0, theta=0.0
% INFO    : Bus 5008	: V=0.999475, theta=-38.73639 -> V=1.0, theta=0.0
% INFO    : Bus 5009	: V=1.047313, theta=-32.872392 -> V=1.0, theta=0.0
% INFO    : Bus 5010	: V=1.059198, theta=-23.383655 -> V=1.0166305, theta=0.0
% INFO    : Bus 5011	: V=1.042055, theta=-19.357263 -> V=1.0244255, theta=0.0
% INFO    : Bus 5012	: V=1.079127, theta=0.900468 -> V=1.031584, theta=0.0
% INFO    : Bus 5013	: V=1.069888, theta=2.301633 -> V=1.005046, theta=0.0
% INFO    : Bus 5014	: V=0.974359, theta=-17.671904 -> V=1.0, theta=0.0
% INFO    : Bus 5015	: V=1.078794, theta=-13.377441 -> V=1.019328, theta=0.0
% INFO    : Bus 5016	: V=1.070866, theta=15.596049 -> V=1.0052575, theta=0.0
% INFO    : Bus 5017	: V=1.068356, theta=-15.137081 -> V=1.010251, theta=0.0
% INFO    : Bus 5018	: V=1.047422, theta=20.739742 -> V=1.0029495, theta=0.0
% INFO    : Bus 5019	: V=1.081809, theta=-3.806916 -> V=1.0214135, theta=0.0
% INFO    : Bus 5020	: V=1.021364, theta=5.965106 -> V=1.0, theta=0.0
% INFO    : Bus 5021	: V=1.055375, theta=61.495633 -> V=1.004436, theta=0.0
% INFO    : Bus 5022	: V=1.08235, theta=-41.084062 -> V=1.026776, theta=0.0
% INFO    : Bus 5023	: V=1.084273, theta=-12.350951 -> V=1.019165, theta=0.0
% INFO    : Bus 5024	: V=1.05236, theta=-28.525907 -> V=1.011124, theta=0.0
% INFO    : Bus 5025	: V=1.030337, theta=-25.114039 -> V=1.0, theta=0.0
% INFO    : Bus 5026	: V=1.069062, theta=-20.703581 -> V=1.020003, theta=0.0
% INFO    : Bus 5027	: V=0.947832, theta=-18.693605 -> V=1.0, theta=0.0
% INFO    : Bus 5028	: V=0.997558, theta=-16.556263 -> V=1.0, theta=0.0
% INFO    : Bus 5029	: V=1.027357, theta=-31.05218 -> V=1.0, theta=0.0
% INFO    : Bus 5030	: V=0.985585, theta=-20.677355 -> V=1.0, theta=0.0
% INFO    : Bus 5031	: V=1.053645, theta=-12.549097 -> V=1.010846, theta=0.0
% INFO    : Bus 5032	: V=0.961864, theta=-29.660638 -> V=0.988194, theta=0.0
% INFO    : Bus 5033	: V=1.00243, theta=-39.868186 -> V=1.0, theta=0.0
% INFO    : Bus 5034	: V=1.079182, theta=-23.957885 -> V=1.0196425, theta=0.0
% INFO    : Bus 5035	: V=0.966752, theta=-26.950565 -> V=1.0, theta=0.0
% INFO    : Bus 5036	: V=0.994643, theta=-25.42766 -> V=1.0, theta=0.0
% INFO    : Bus 5037	: V=1.07847, theta=0.167244 -> V=1.0239415, theta=0.0
% INFO    : Bus 5038	: V=1.044181, theta=-24.964292 -> V=1.0204125, theta=0.0
% INFO    : Bus 5039	: V=0.93541, theta=-34.037955 -> V=1.0, theta=0.0
% INFO    : Bus 5040	: V=1.04051, theta=-20.687933 -> V=1.0, theta=0.0
% INFO    : Bus 5041	: V=0.989936, theta=-25.381475 -> V=1.0, theta=0.0
% INFO    : Bus 5042	: V=0.912694, theta=-28.341696 -> V=1.0, theta=0.0
% INFO    : Bus 5043	: V=1.033411, theta=9.14053 -> V=1.0041015, theta=0.0
% INFO    : Bus 5044	: V=1.049026, theta=12.691023 -> V=1.004821, theta=0.0
% INFO    : Bus 5045	: V=0.973821, theta=-27.371839 -> V=1.0, theta=0.0
% INFO    : Bus 5046	: V=1.041647, theta=13.58319 -> V=1.004908, theta=0.0
% INFO    : Bus 5047	: V=1.023019, theta=-38.798322 -> V=1.0, theta=0.0
% INFO    : Bus 5048	: V=1.02325, theta=-21.644839 -> V=1.0, theta=0.0
% INFO    : Bus 5049	: V=0.986222, theta=-21.061048 -> V=1.0, theta=0.0
% INFO    : Bus 5050	: V=1.100943, theta=-41.681361 -> V=1.030249, theta=0.0
% INFO    : Bus 5051	: V=1.03022, theta=-14.985172 -> V=1.01962, theta=0.0
% INFO    : Bus 5052	: V=1.072818, theta=-11.68441 -> V=1.016298, theta=0.0
% INFO    : Bus 5053	: V=1.055226, theta=-5.635792 -> V=1.015823, theta=0.0
% INFO    : Bus 5054	: V=1.060166, theta=2.069044 -> V=1.0075515, theta=0.0
% INFO    : Bus 5055	: V=1.052872, theta=-17.751422 -> V=1.008874, theta=0.0
% INFO    : Bus 5056	: V=1.040438, theta=-29.183477 -> V=1.0, theta=0.0
% INFO    : Bus 5057	: V=0.977676, theta=-11.998185 -> V=1.0, theta=0.0
% INFO    : Bus 5058	: V=1.005654, theta=-22.603518 -> V=1.0, theta=0.0
% INFO    : Bus 5059	: V=1.072705, theta=-21.341834 -> V=1.027804, theta=0.0
% INFO    : Bus 5060	: V=1.085591, theta=-13.374423 -> V=1.035068, theta=0.0
% INFO    : Bus 5061	: V=1.084934, theta=-23.600508 -> V=1.0215315, theta=0.0
% INFO    : Bus 5062	: V=1.045969, theta=-12.045469 -> V=1.0080365, theta=0.0
% INFO    : Bus 5063	: V=1.063738, theta=-38.618842 -> V=1.014463, theta=0.0
% INFO    : Bus 5064	: V=1.063826, theta=-21.424801 -> V=1.0, theta=0.0
% INFO    : Bus 5065	: V=1.088644, theta=-27.736759 -> V=1.034947, theta=0.0
% INFO    : Bus 5066	: V=0.922125, theta=-30.37203 -> V=1.0, theta=0.0
% INFO    : Bus 5067	: V=0.935217, theta=-31.814997 -> V=1.0, theta=0.0
% INFO    : Bus 5068	: V=1.027526, theta=-4.458232 -> V=1.0, theta=0.0
% INFO    : Bus 5069	: V=1.022735, theta=-15.026146 -> V=1.0, theta=0.0
% INFO    : Bus 5070	: V=1.020412, theta=-16.099983 -> V=1.0113075, theta=0.0
% INFO    : Bus 5071	: V=1.050954, theta=16.948067 -> V=1.0, theta=0.0
% INFO    : Bus 5072	: V=1.024268, theta=-33.75346 -> V=1.0, theta=0.0
% INFO    : Bus 5073	: V=1.074792, theta=2.456204 -> V=1.027462, theta=0.0
% INFO    : Bus 5074	: V=1.073472, theta=-10.96851 -> V=1.019339, theta=0.0
% INFO    : Bus 5075	: V=0.981817, theta=-25.683296 -> V=1.0, theta=0.0
% INFO    : Bus 5076	: V=1.0264, theta=-30.060688 -> V=1.01711, theta=0.0
% INFO    : Bus 5077	: V=1.061639, theta=-2.598967 -> V=1.01978, theta=0.0
% INFO    : Bus 5078	: V=1.042954, theta=-46.936243 -> V=1.0, theta=0.0
% INFO    : Bus 5079	: V=1.006074, theta=-19.84962 -> V=1.0, theta=0.0
% INFO    : Bus 5080	: V=1.078456, theta=-27.703272 -> V=1.0134935, theta=0.0
% INFO    : Bus 5081	: V=1.074597, theta=2.141231 -> V=1.0225145, theta=0.0
% INFO    : Bus 5082	: V=1.058722, theta=-15.489879 -> V=1.011262, theta=0.0
% INFO    : Bus 5083	: V=1.066986, theta=-8.35975 -> V=1.0145835, theta=0.0
% INFO    : Bus 5084	: V=1.089323, theta=68.732225 -> V=1.0, theta=0.0
% INFO    : Bus 5085	: V=1.027633, theta=-19.398775 -> V=1.0, theta=0.0
% INFO    : Bus 5086	: V=1.043365, theta=-30.281415 -> V=1.0033745, theta=0.0
% INFO    : Bus 5087	: V=1.025887, theta=-23.238837 -> V=1.0, theta=0.0
% INFO    : Bus 5088	: V=1.055788, theta=-20.770248 -> V=1.0066255, theta=0.0
% INFO    : Bus 5089	: V=1.086575, theta=-45.850231 -> V=1.01423, theta=0.0
% INFO    : Bus 5090	: V=1.042074, theta=60.842738 -> V=1.0, theta=0.0
% INFO    : Bus 5091	: V=1.077771, theta=-22.928705 -> V=1.031523, theta=0.0
% INFO    : Bus 5092	: V=1.101816, theta=58.124549 -> V=1.0300395, theta=0.0
% INFO    : Bus 5093	: V=0.996214, theta=-24.120702 -> V=1.0, theta=0.0
% INFO    : Bus 5094	: V=1.073155, theta=-34.531887 -> V=1.0368535, theta=0.0
% INFO    : Bus 5095	: V=1.029672, theta=-44.691559 -> V=1.0, theta=0.0
% INFO    : Bus 5096	: V=1.066954, theta=-3.076842 -> V=1.0186005, theta=0.0
% INFO    : Bus 5097	: V=1.024571, theta=-22.341365 -> V=1.0, theta=0.0
% INFO    : Bus 5098	: V=1.05, theta=11.662187 -> V=1.0, theta=0.0
% INFO    : Bus 5099	: V=0.936303, theta=-25.846412 -> V=1.0, theta=0.0
% INFO    : Bus 5100	: V=1.060615, theta=-15.034148 -> V=1.014384, theta=0.0
% INFO    : Bus 5101	: V=1.078285, theta=-33.032181 -> V=1.0288785, theta=0.0
% INFO    : Bus 5102	: V=1.07111, theta=-24.929929 -> V=1.0167785, theta=0.0
% INFO    : Bus 5103	: V=1.092905, theta=-26.273766 -> V=1.028456, theta=0.0
% INFO    : Bus 5104	: V=0.948294, theta=-24.111507 -> V=1.0, theta=0.0
% INFO    : Bus 5105	: V=1.034318, theta=-32.48517 -> V=1.017284, theta=0.0
% INFO    : Bus 5106	: V=0.948178, theta=-24.463149 -> V=1.0, theta=0.0
% INFO    : Bus 5107	: V=0.939484, theta=-29.984236 -> V=1.0, theta=0.0
% INFO    : Bus 5108	: V=1.08242, theta=-4.285377 -> V=1.0188655, theta=0.0
% INFO    : Bus 5109	: V=1.008572, theta=-39.150101 -> V=1.0, theta=0.0
% INFO    : Bus 5110	: V=0.9545, theta=-25.785317 -> V=1.0, theta=0.0
% INFO    : Bus 5111	: V=0.987314, theta=-51.222018 -> V=1.0, theta=0.0
% INFO    : Bus 5112	: V=1.027479, theta=-25.796733 -> V=1.0, theta=0.0
% INFO    : Bus 5113	: V=0.980798, theta=-28.746266 -> V=1.0, theta=0.0
% INFO    : Bus 5114	: V=1.033124, theta=-22.980448 -> V=1.0, theta=0.0
% INFO    : Bus 5115	: V=1.050197, theta=-21.21685 -> V=1.027068, theta=0.0
% INFO    : Bus 5116	: V=1.027798, theta=-24.471899 -> V=1.0, theta=0.0
% INFO    : Bus 5117	: V=1.027854, theta=-11.101795 -> V=1.0, theta=0.0
% INFO    : Bus 5118	: V=1.04324, theta=9.33319 -> V=1.0119885, theta=0.0
% INFO    : Bus 5119	: V=1.046587, theta=-28.5271 -> V=1.0068485, theta=0.0
% INFO    : Bus 5120	: V=1.024103, theta=-27.828033 -> V=1.0, theta=0.0
% INFO    : Bus 5121	: V=1.030938, theta=-51.273949 -> V=1.0, theta=0.0
% INFO    : Bus 5122	: V=0.994677, theta=9.895038 -> V=1.0, theta=0.0
% INFO    : Bus 5123	: V=1.004818, theta=-47.686658 -> V=1.0, theta=0.0
% INFO    : Bus 5124	: V=0.95373, theta=-19.019817 -> V=1.0, theta=0.0
% INFO    : Bus 5125	: V=0.968883, theta=-25.519409 -> V=1.0, theta=0.0
% INFO    : Bus 5126	: V=1.044202, theta=-12.962089 -> V=1.008238, theta=0.0
% INFO    : Bus 5127	: V=1.073731, theta=15.027848 -> V=1.0147185, theta=0.0
% INFO    : Bus 5128	: V=0.979605, theta=-24.633729 -> V=1.0, theta=0.0
% INFO    : Bus 5129	: V=1.079676, theta=-23.06798 -> V=1.0160485, theta=0.0
% INFO    : Bus 5130	: V=1.011642, theta=-7.301264 -> V=1.006361, theta=0.0
% INFO    : Bus 5131	: V=0.998327, theta=-34.518067 -> V=1.0, theta=0.0
% INFO    : Bus 5132	: V=1.055681, theta=2.027819 -> V=1.007587, theta=0.0
% INFO    : Bus 5133	: V=1.054409, theta=-0.594917 -> V=1.01303, theta=0.0
% INFO    : Bus 5134	: V=1.019214, theta=-21.266957 -> V=1.0, theta=0.0
% INFO    : Bus 5135	: V=1.038053, theta=-22.736158 -> V=1.014867, theta=0.0
% INFO    : Bus 5136	: V=1.041037, theta=-20.248675 -> V=1.0, theta=0.0
% INFO    : Bus 5137	: V=0.957467, theta=-31.668028 -> V=1.0, theta=0.0
% INFO    : Bus 5138	: V=0.970726, theta=-24.528316 -> V=1.0, theta=0.0
% INFO    : Bus 5139	: V=1.030655, theta=-38.060656 -> V=1.0, theta=0.0
% INFO    : Bus 5140	: V=1.010122, theta=-23.832912 -> V=1.0, theta=0.0
% INFO    : Bus 5141	: V=1.081, theta=1.148113 -> V=1.0322335, theta=0.0
% INFO    : Bus 5142	: V=1.065707, theta=33.567766 -> V=1.0, theta=0.0
% INFO    : Bus 5143	: V=1.052665, theta=-10.96252 -> V=1.011143, theta=0.0
% INFO    : Bus 5144	: V=1.049228, theta=-39.992266 -> V=1.0, theta=0.0
% INFO    : Bus 5145	: V=1.013182, theta=-30.312424 -> V=1.0, theta=0.0
% INFO    : Bus 5146	: V=1.036545, theta=-42.689597 -> V=1.003768, theta=0.0
% INFO    : Bus 5147	: V=0.985989, theta=-24.54982 -> V=1.0, theta=0.0
% INFO    : Bus 5148	: V=0.995926, theta=-37.31835 -> V=1.0, theta=0.0
% INFO    : Bus 5149	: V=1.061976, theta=0.847725 -> V=1.0190695, theta=0.0
% INFO    : Bus 5150	: V=1.04207, theta=7.12458 -> V=1.0, theta=0.0
% INFO    : Bus 5151	: V=1.018035, theta=-36.440764 -> V=1.0, theta=0.0
% INFO    : Bus 5152	: V=1.041729, theta=-20.442445 -> V=1.0, theta=0.0
% INFO    : Bus 5153	: V=1.068591, theta=-19.036287 -> V=1.0153835, theta=0.0
% INFO    : Bus 5154	: V=0.94804, theta=-27.202569 -> V=1.0, theta=0.0
% INFO    : Bus 5155	: V=1.0404, theta=63.390913 -> V=1.0, theta=0.0
% INFO    : Bus 5156	: V=1.049013, theta=-12.938199 -> V=1.006197, theta=0.0
% INFO    : Bus 5157	: V=1.053553, theta=-48.770605 -> V=1.008287, theta=0.0
% INFO    : Bus 5158	: V=1.069096, theta=2.602341 -> V=1.0047135, theta=0.0
% INFO    : Bus 5159	: V=1.083534, theta=-19.155472 -> V=1.0294965, theta=0.0
% INFO    : Bus 5160	: V=1.075022, theta=-39.231893 -> V=1.0199575, theta=0.0
% INFO    : Bus 5161	: V=1.063529, theta=-9.480673 -> V=1.0118685, theta=0.0
% INFO    : Bus 5162	: V=0.98826, theta=-24.112721 -> V=1.0, theta=0.0
% INFO    : Bus 5163	: V=1.077391, theta=-7.518845 -> V=1.0215305, theta=0.0
% INFO    : Bus 5164	: V=1.060318, theta=-17.527667 -> V=1.0135395, theta=0.0
% INFO    : Bus 5165	: V=1.046688, theta=-44.655582 -> V=1.031691, theta=0.0
% INFO    : Bus 5166	: V=1.087632, theta=-26.850351 -> V=1.0224265, theta=0.0
% INFO    : Bus 5167	: V=1.073103, theta=-15.458439 -> V=1.010763, theta=0.0
% INFO    : Bus 5168	: V=1.054677, theta=-34.229073 -> V=1.016304, theta=0.0
% INFO    : Bus 5169	: V=1.046025, theta=-26.691916 -> V=1.0151625, theta=0.0
% INFO    : Bus 5170	: V=1.062261, theta=-20.249097 -> V=1.0, theta=0.0
% INFO    : Bus 5171	: V=1.045946, theta=-42.371403 -> V=1.0, theta=0.0
% INFO    : Bus 5172	: V=0.996908, theta=-30.458105 -> V=1.0, theta=0.0
% INFO    : Bus 5173	: V=1.05047, theta=-6.18502 -> V=1.01937, theta=0.0
% INFO    : Bus 5174	: V=1.011277, theta=-37.0678 -> V=1.0, theta=0.0
% INFO    : Bus 5175	: V=1.017749, theta=-27.199363 -> V=1.0, theta=0.0
% INFO    : Bus 5176	: V=1.061731, theta=-18.470734 -> V=1.0, theta=0.0
% INFO    : Bus 5177	: V=1.013167, theta=-47.625393 -> V=1.0, theta=0.0
% INFO    : Bus 5178	: V=1.09675, theta=-44.75309 -> V=1.036701, theta=0.0
% INFO    : Bus 5179	: V=1.044542, theta=-21.852502 -> V=1.0027595, theta=0.0
% INFO    : Bus 5180	: V=1.030488, theta=-26.508284 -> V=1.0, theta=0.0
% INFO    : Bus 5181	: V=1.088605, theta=-8.5472 -> V=1.021751, theta=0.0
% INFO    : Bus 5182	: V=0.987063, theta=-25.893547 -> V=1.0, theta=0.0
% INFO    : Bus 5183	: V=1.03458, theta=10.575531 -> V=1.0, theta=0.0
% INFO    : Bus 5184	: V=1.075474, theta=-4.567192 -> V=1.0145615, theta=0.0
% INFO    : Bus 5185	: V=0.977641, theta=-22.809325 -> V=1.0, theta=0.0
% INFO    : Bus 5186	: V=1.048317, theta=-33.124522 -> V=1.0055955, theta=0.0
% INFO    : Bus 5187	: V=1.048313, theta=62.141167 -> V=1.0, theta=0.0
% INFO    : Bus 5188	: V=1.067198, theta=23.060115 -> V=1.0101525, theta=0.0
% INFO    : Bus 5189	: V=1.098289, theta=62.830076 -> V=1.0070195, theta=0.0
% INFO    : Bus 5190	: V=0.940762, theta=-34.413098 -> V=1.0, theta=0.0
% INFO    : Bus 5191	: V=1.053425, theta=56.316615 -> V=1.0, theta=0.0
% INFO    : Bus 5192	: V=1.058599, theta=-21.119309 -> V=1.0111535, theta=0.0
% INFO    : Bus 5193	: V=1.012204, theta=-25.153549 -> V=1.0, theta=0.0
% INFO    : Bus 5194	: V=1.075636, theta=-30.848461 -> V=1.004199, theta=0.0
% INFO    : Bus 5195	: V=1.057156, theta=-9.168029 -> V=1.006346, theta=0.0
% INFO    : Bus 5196	: V=0.970027, theta=-22.858793 -> V=1.0, theta=0.0
% INFO    : Bus 5197	: V=0.974839, theta=-27.251443 -> V=1.0, theta=0.0
% INFO    : Bus 5198	: V=1.064318, theta=-38.442621 -> V=1.002849, theta=0.0
% INFO    : Bus 5199	: V=0.969067, theta=-29.024191 -> V=1.0, theta=0.0
% INFO    : Bus 5200	: V=0.993204, theta=-25.271184 -> V=1.0, theta=0.0
% INFO    : Bus 5201	: V=1.028916, theta=-24.443996 -> V=1.0, theta=0.0
% INFO    : Bus 5202	: V=1.051748, theta=-21.283409 -> V=1.006093, theta=0.0
% INFO    : Bus 5203	: V=1.01583, theta=-19.909253 -> V=1.0, theta=0.0
% INFO    : Bus 5204	: V=1.037352, theta=2.446505 -> V=1.00644, theta=0.0
% INFO    : Bus 5205	: V=1.048838, theta=-15.521327 -> V=1.0088415, theta=0.0
% INFO    : Bus 5206	: V=1.08384, theta=-26.056992 -> V=1.0382235, theta=0.0
% INFO    : Bus 5207	: V=1.018542, theta=-12.021067 -> V=1.0, theta=0.0
% INFO    : Bus 5208	: V=0.979545, theta=-22.109928 -> V=1.0, theta=0.0
% INFO    : Bus 5209	: V=1.061615, theta=-9.755699 -> V=1.014552, theta=0.0
% INFO    : Bus 5210	: V=1.033281, theta=-16.836889 -> V=1.0, theta=0.0
% INFO    : Bus 5211	: V=1.053128, theta=3.80764 -> V=1.004602, theta=0.0
% INFO    : Bus 5212	: V=1.011777, theta=-22.531672 -> V=1.0, theta=0.0
% INFO    : Bus 5213	: V=1.079682, theta=20.341577 -> V=1.0289355, theta=0.0
% INFO    : Bus 5214	: V=1.062645, theta=-22.991952 -> V=1.0183975, theta=0.0
% INFO    : Bus 5215	: V=0.957394, theta=-31.68357 -> V=1.0, theta=0.0
% INFO    : Bus 5216	: V=1.056754, theta=-33.389872 -> V=1.0167345, theta=0.0
% INFO    : Bus 5217	: V=1.054758, theta=-44.334477 -> V=1.011704, theta=0.0
% INFO    : Bus 5218	: V=1.065874, theta=-3.054446 -> V=1.0179655, theta=0.0
% INFO    : Bus 5219	: V=1.062781, theta=13.637912 -> V=1.0146455, theta=0.0
% INFO    : Bus 5220	: V=1.024727, theta=-35.880095 -> V=1.0, theta=0.0
% INFO    : Bus 5221	: V=1.024061, theta=-25.852448 -> V=1.0, theta=0.0
% INFO    : Bus 5222	: V=1.078182, theta=-4.168825 -> V=1.019708, theta=0.0
% INFO    : Bus 5223	: V=1.03961, theta=11.947993 -> V=1.0, theta=0.0
% INFO    : Bus 5224	: V=1.025485, theta=-23.559049 -> V=1.0, theta=0.0
% INFO    : Bus 5225	: V=1.00757, theta=-27.670908 -> V=1.0, theta=0.0
% INFO    : Bus 5226	: V=1.098447, theta=-10.167082 -> V=1.0267535, theta=0.0
% INFO    : Bus 5227	: V=1.079449, theta=5.584069 -> V=1.0244055, theta=0.0
% INFO    : Bus 5228	: V=1.034262, theta=-19.908208 -> V=1.007035, theta=0.0
% INFO    : Bus 5229	: V=1.057292, theta=0.508753 -> V=1.0107985, theta=0.0
% INFO    : Bus 5230	: V=1.066701, theta=-1.300022 -> V=1.0172055, theta=0.0
% INFO    : Bus 5231	: V=1.022245, theta=-24.832235 -> V=1.0129595, theta=0.0
% INFO    : Bus 5232	: V=1.000607, theta=-28.391153 -> V=1.0, theta=0.0
% INFO    : Bus 5233	: V=1.06495, theta=-43.927039 -> V=1.006828, theta=0.0
% INFO    : Bus 5234	: V=1.071201, theta=-2.650765 -> V=1.0143345, theta=0.0
% INFO    : Bus 5235	: V=1.033527, theta=-25.154105 -> V=1.0, theta=0.0
% INFO    : Bus 5236	: V=1.020822, theta=-20.979814 -> V=1.0, theta=0.0
% INFO    : Bus 5237	: V=1.051016, theta=-43.03966 -> V=1.0100045, theta=0.0
% INFO    : Bus 5238	: V=1.084502, theta=4.007361 -> V=1.026489, theta=0.0
% INFO    : Bus 5239	: V=1.088675, theta=-2.785482 -> V=1.023964, theta=0.0
% INFO    : Bus 5240	: V=1.071168, theta=32.825632 -> V=1.020323, theta=0.0
% INFO    : Bus 5241	: V=0.967978, theta=-26.879847 -> V=1.0, theta=0.0
% INFO    : Bus 5242	: V=1.077081, theta=-8.979341 -> V=1.011999, theta=0.0
% INFO    : Bus 5243	: V=1.030141, theta=-25.359954 -> V=1.0, theta=0.0
% INFO    : Bus 5244	: V=1.053018, theta=-28.279883 -> V=1.0, theta=0.0
% INFO    : Bus 5245	: V=1.042988, theta=-3.956599 -> V=1.0, theta=0.0
% INFO    : Bus 5246	: V=1.055964, theta=-48.589282 -> V=1.005716, theta=0.0
% INFO    : Bus 5247	: V=1.067816, theta=-10.846116 -> V=1.0094445, theta=0.0
% INFO    : Bus 5248	: V=1.030753, theta=-25.975063 -> V=1.026585, theta=0.0
% INFO    : Bus 5249	: V=1.075693, theta=8.620576 -> V=1.0221685, theta=0.0
% INFO    : Bus 5250	: V=1.013947, theta=54.226407 -> V=1.0, theta=0.0
% INFO    : Bus 5251	: V=1.004273, theta=-39.755826 -> V=1.0, theta=0.0
% INFO    : Bus 5252	: V=1.039818, theta=-39.680795 -> V=1.0, theta=0.0
% INFO    : Bus 5253	: V=1.054144, theta=-15.632721 -> V=1.01184, theta=0.0
% INFO    : Bus 5254	: V=1.046819, theta=-32.283292 -> V=1.002648, theta=0.0
% INFO    : Bus 5255	: V=0.989124, theta=-24.046929 -> V=1.0, theta=0.0
% INFO    : Bus 5256	: V=1.071092, theta=0.343159 -> V=1.0172545, theta=0.0
% INFO    : Bus 5257	: V=1.030557, theta=-43.676057 -> V=1.0, theta=0.0
% INFO    : Bus 5258	: V=0.980294, theta=64.238657 -> V=1.0, theta=0.0
% INFO    : Bus 5259	: V=1.041043, theta=-22.069678 -> V=1.0, theta=0.0
% INFO    : Bus 5260	: V=0.957976, theta=-28.060539 -> V=1.0, theta=0.0
% INFO    : Bus 5261	: V=1.02471, theta=-51.361638 -> V=1.0, theta=0.0
% INFO    : Bus 5262	: V=1.041592, theta=-21.215923 -> V=1.0089485, theta=0.0
% INFO    : Bus 5263	: V=1.050972, theta=-31.365034 -> V=1.031419, theta=0.0
% INFO    : Bus 5264	: V=1.103459, theta=-16.255802 -> V=1.031641, theta=0.0
% INFO    : Bus 5265	: V=1.034248, theta=-25.406123 -> V=1.0, theta=0.0
% INFO    : Bus 5266	: V=1.075061, theta=-13.824476 -> V=1.023519, theta=0.0
% INFO    : Bus 5267	: V=0.970123, theta=-17.73643 -> V=1.0, theta=0.0
% INFO    : Bus 5268	: V=1.029315, theta=-50.016274 -> V=1.0, theta=0.0
% INFO    : Bus 5269	: V=1.004611, theta=12.444126 -> V=1.0, theta=0.0
% INFO    : Bus 5270	: V=1.043364, theta=-21.670608 -> V=1.0, theta=0.0
% INFO    : Bus 5271	: V=1.062111, theta=-15.142547 -> V=1.002773, theta=0.0
% INFO    : Bus 5272	: V=0.994227, theta=-16.787644 -> V=1.0, theta=0.0
% INFO    : Bus 5273	: V=0.99, theta=-24.172807 -> V=1.0, theta=0.0
% INFO    : Bus 5274	: V=1.025818, theta=11.683296 -> V=1.0, theta=0.0
% INFO    : Bus 5275	: V=0.939253, theta=-25.672555 -> V=1.0, theta=0.0
% INFO    : Bus 5276	: V=1.053727, theta=-11.951964 -> V=1.0114985, theta=0.0
% INFO    : Bus 5277	: V=1.081707, theta=-46.636699 -> V=1.0193265, theta=0.0
% INFO    : Bus 5278	: V=0.98995, theta=-23.171232 -> V=1.0, theta=0.0
% INFO    : Bus 5279	: V=1.030833, theta=-24.134994 -> V=1.0, theta=0.0
% INFO    : Bus 5280	: V=1.071488, theta=-15.757207 -> V=1.019657, theta=0.0
% INFO    : Bus 5281	: V=0.961293, theta=58.446793 -> V=1.0, theta=0.0
% INFO    : Bus 5282	: V=1.065365, theta=-39.933325 -> V=1.004335, theta=0.0
% INFO    : Bus 5283	: V=1.103763, theta=19.112191 -> V=1.035427, theta=0.0
% INFO    : Bus 5284	: V=1.082474, theta=-35.321601 -> V=1.0162505, theta=0.0
% INFO    : Bus 5285	: V=1.089868, theta=-31.223352 -> V=1.013404, theta=0.0
% INFO    : Bus 5286	: V=1.002682, theta=-33.045353 -> V=1.0, theta=0.0
% INFO    : Bus 5287	: V=1.030445, theta=-26.504949 -> V=1.0, theta=0.0
% INFO    : Bus 5288	: V=1.081591, theta=-33.319262 -> V=1.016276, theta=0.0
% INFO    : Bus 5289	: V=1.059444, theta=-0.781765 -> V=1.011217, theta=0.0
% INFO    : Bus 5290	: V=0.933829, theta=-27.860892 -> V=1.0, theta=0.0
% INFO    : Bus 5291	: V=1.086947, theta=-43.378128 -> V=1.0163295, theta=0.0
% INFO    : Bus 5292	: V=0.923046, theta=-28.924124 -> V=0.9861785, theta=0.0
% INFO    : Bus 5293	: V=1.04489, theta=-15.267517 -> V=1.0, theta=0.0
% INFO    : Bus 5294	: V=1.060839, theta=-29.460457 -> V=1.012711, theta=0.0
% INFO    : Bus 5295	: V=1.04309, theta=14.665291 -> V=1.0, theta=0.0
% INFO    : Bus 5296	: V=1.042389, theta=-12.134736 -> V=1.006946, theta=0.0
% INFO    : Bus 5297	: V=1.046315, theta=-9.832747 -> V=1.0148745, theta=0.0
% INFO    : Bus 5298	: V=1.042909, theta=-44.786728 -> V=1.0, theta=0.0
% INFO    : Bus 5299	: V=1.092306, theta=-24.093277 -> V=1.02449, theta=0.0
% INFO    : Bus 5300	: V=1.003453, theta=-24.232525 -> V=1.0, theta=0.0
% INFO    : Bus 5301	: V=1.065589, theta=13.076699 -> V=1.0078345, theta=0.0
% INFO    : Bus 5302	: V=1.089227, theta=-15.879341 -> V=1.01305, theta=0.0
% INFO    : Bus 5303	: V=1.072125, theta=-20.630428 -> V=1.0057315, theta=0.0
% INFO    : Bus 5304	: V=1.036108, theta=-0.782672 -> V=1.0, theta=0.0
% INFO    : Bus 5305	: V=0.972582, theta=-24.772902 -> V=1.0, theta=0.0
% INFO    : Bus 5306	: V=1.068911, theta=-18.536889 -> V=1.010921, theta=0.0
% INFO    : Bus 5307	: V=1.040337, theta=61.753812 -> V=1.0, theta=0.0
% INFO    : Bus 5308	: V=1.069029, theta=-7.023066 -> V=1.0144805, theta=0.0
% INFO    : Bus 5309	: V=1.063317, theta=-31.395123 -> V=1.013257, theta=0.0
% INFO    : Bus 5310	: V=1.092368, theta=-8.075315 -> V=1.01417, theta=0.0
% INFO    : Bus 5311	: V=1.087409, theta=-11.150147 -> V=1.0263895, theta=0.0
% INFO    : Bus 5312	: V=1.071928, theta=-20.314126 -> V=1.0379915, theta=0.0
% INFO    : Bus 5313	: V=1.034403, theta=-24.995026 -> V=1.0, theta=0.0
% INFO    : Bus 5314	: V=0.996478, theta=-25.753619 -> V=1.0, theta=0.0
% INFO    : Bus 5315	: V=1.024563, theta=-23.569742 -> V=1.0, theta=0.0
% INFO    : Bus 5316	: V=0.960386, theta=-25.429701 -> V=1.0, theta=0.0
% INFO    : Bus 5317	: V=1.084553, theta=50.904537 -> V=1.0075215, theta=0.0
% INFO    : Bus 5318	: V=1.054955, theta=5.758469 -> V=1.0145125, theta=0.0
% INFO    : Bus 5319	: V=0.939517, theta=-27.096282 -> V=1.0, theta=0.0
% INFO    : Bus 5320	: V=1.083482, theta=-41.20359 -> V=1.027402, theta=0.0
% INFO    : Bus 5321	: V=1.029874, theta=-24.505648 -> V=1.0, theta=0.0
% INFO    : Bus 5322	: V=1.087263, theta=-26.964113 -> V=1.0217545, theta=0.0
% INFO    : Bus 5323	: V=1.062767, theta=-9.945994 -> V=1.0150095, theta=0.0
% INFO    : Bus 5324	: V=1.040116, theta=-29.192576 -> V=1.0, theta=0.0
% INFO    : Bus 5325	: V=1.019083, theta=-34.799984 -> V=1.0, theta=0.0
% INFO    : Bus 5326	: V=1.064852, theta=9.49322 -> V=1.0, theta=0.0
% INFO    : Bus 5327	: V=1.062112, theta=-41.498515 -> V=1.013341, theta=0.0
% INFO    : Bus 5328	: V=0.9792, theta=64.87197 -> V=1.0, theta=0.0
% INFO    : Bus 5329	: V=0.961703, theta=-24.666757 -> V=1.0, theta=0.0
% INFO    : Bus 5330	: V=1.013244, theta=-22.629287 -> V=1.0, theta=0.0
% INFO    : Bus 5331	: V=1.086009, theta=-45.528106 -> V=1.024384, theta=0.0
% INFO    : Bus 5332	: V=1.043755, theta=-18.442865 -> V=1.0, theta=0.0
% INFO    : Bus 5333	: V=0.966103, theta=-25.11584 -> V=1.0, theta=0.0
% INFO    : Bus 5334	: V=1.038727, theta=25.751839 -> V=1.0, theta=0.0
% INFO    : Bus 5335	: V=1.067909, theta=-10.001935 -> V=1.021604, theta=0.0
% INFO    : Bus 5336	: V=1.097763, theta=8.751083 -> V=1.0149175, theta=0.0
% INFO    : Bus 5337	: V=1.104658, theta=-11.877837 -> V=1.0427925, theta=0.0
% INFO    : Bus 5338	: V=1.087051, theta=-35.841413 -> V=1.0166265, theta=0.0
% INFO    : Bus 5339	: V=1.067136, theta=-19.13722 -> V=1.0149145, theta=0.0
% INFO    : Bus 5340	: V=0.960675, theta=-20.129332 -> V=1.0, theta=0.0
% INFO    : Bus 5341	: V=1.028892, theta=16.248611 -> V=1.0, theta=0.0
% INFO    : Bus 5342	: V=1.083759, theta=15.065877 -> V=1.0147425, theta=0.0
% INFO    : Bus 5343	: V=1.071432, theta=-41.626287 -> V=1.01139, theta=0.0
% INFO    : Bus 5344	: V=1.043458, theta=-12.279921 -> V=1.006866, theta=0.0
% INFO    : Bus 5345	: V=1.065021, theta=-43.914517 -> V=1.006831, theta=0.0
% INFO    : Bus 5346	: V=1.063365, theta=11.010672 -> V=1.021216, theta=0.0
% INFO    : Bus 5347	: V=1.045455, theta=-3.852874 -> V=1.0, theta=0.0
% INFO    : Bus 5348	: V=1.002737, theta=-27.984949 -> V=1.0, theta=0.0
% INFO    : Bus 5349	: V=1.0245, theta=15.617812 -> V=1.0, theta=0.0
% INFO    : Bus 5350	: V=1.082411, theta=16.159047 -> V=1.013576, theta=0.0
% INFO    : Bus 5351	: V=1.092334, theta=-13.202235 -> V=1.0200865, theta=0.0
% INFO    : Bus 5352	: V=1.032264, theta=-21.776765 -> V=1.0046025, theta=0.0
% INFO    : Bus 5353	: V=0.979196, theta=-21.3216 -> V=1.0, theta=0.0
% INFO    : Bus 5354	: V=1.005349, theta=-23.450164 -> V=1.0, theta=0.0
% INFO    : Bus 5355	: V=1.010566, theta=-21.646959 -> V=1.0, theta=0.0
% INFO    : Bus 5356	: V=1.058254, theta=-12.587404 -> V=1.0082145, theta=0.0
% INFO    : Bus 5357	: V=0.938814, theta=-24.951004 -> V=1.0, theta=0.0
% INFO    : Bus 5358	: V=1.083328, theta=-8.373115 -> V=1.026698, theta=0.0
% INFO    : Bus 5359	: V=0.989263, theta=-27.684044 -> V=1.0, theta=0.0
% INFO    : Bus 5360	: V=1.02502, theta=-18.249224 -> V=1.0, theta=0.0
% INFO    : Bus 5361	: V=0.940579, theta=-33.679373 -> V=1.0, theta=0.0
% INFO    : Bus 5362	: V=1.04617, theta=-22.229073 -> V=1.0, theta=0.0
% INFO    : Bus 5363	: V=1.055662, theta=-19.329187 -> V=1.003909, theta=0.0
% INFO    : Bus 5364	: V=1.055861, theta=-27.174209 -> V=1.009207, theta=0.0
% INFO    : Bus 5365	: V=1.054684, theta=1.623613 -> V=1.005972, theta=0.0
% INFO    : Bus 5366	: V=0.98066, theta=-23.884148 -> V=1.0, theta=0.0
% INFO    : Bus 5367	: V=1.075388, theta=12.779146 -> V=1.0261125, theta=0.0
% INFO    : Bus 5368	: V=1.046918, theta=-21.640492 -> V=1.003735, theta=0.0
% INFO    : Bus 5369	: V=1.052776, theta=-25.634557 -> V=1.0158075, theta=0.0
% INFO    : Bus 5370	: V=1.085404, theta=-45.401785 -> V=1.0210515, theta=0.0
% INFO    : Bus 5371	: V=1.007818, theta=-33.751404 -> V=1.0, theta=0.0
% INFO    : Bus 5372	: V=1.055739, theta=-49.281017 -> V=1.0066795, theta=0.0
% INFO    : Bus 5373	: V=1.002636, theta=-26.096245 -> V=1.0, theta=0.0
% INFO    : Bus 5374	: V=1.044962, theta=-22.909957 -> V=1.0, theta=0.0
% INFO    : Bus 5375	: V=1.038526, theta=-47.392008 -> V=1.0334715, theta=0.0
% INFO    : Bus 5376	: V=1.018029, theta=-32.680373 -> V=1.0, theta=0.0
% INFO    : Bus 5377	: V=0.999702, theta=-21.934678 -> V=1.0, theta=0.0
% INFO    : Bus 5378	: V=1.025625, theta=64.659771 -> V=1.0, theta=0.0
% INFO    : Bus 5379	: V=1.039954, theta=-26.359635 -> V=1.0, theta=0.0
% INFO    : Bus 5380	: V=0.968366, theta=-25.979549 -> V=1.0, theta=0.0
% INFO    : Bus 5381	: V=1.044387, theta=-43.573767 -> V=1.0, theta=0.0
% INFO    : Bus 5382	: V=1.072534, theta=-21.989444 -> V=1.0232545, theta=0.0
% INFO    : Bus 5383	: V=1.042763, theta=-15.701583 -> V=1.0, theta=0.0
% INFO    : Bus 5384	: V=1.038839, theta=-25.408015 -> V=1.0130205, theta=0.0
% INFO    : Bus 5385	: V=1.093191, theta=-30.278888 -> V=1.0168655, theta=0.0
% INFO    : Bus 5386	: V=1.03518, theta=-20.117592 -> V=1.0061265, theta=0.0
% INFO    : Bus 5387	: V=1.055636, theta=-13.503388 -> V=1.008751, theta=0.0
% INFO    : Bus 5388	: V=1.087711, theta=53.903087 -> V=1.0098355, theta=0.0
% INFO    : Bus 5389	: V=1.008753, theta=-28.358028 -> V=1.0, theta=0.0
% INFO    : Bus 5390	: V=1.007449, theta=12.777621 -> V=1.0, theta=0.0
% INFO    : Bus 5391	: V=1.073376, theta=-25.148663 -> V=1.0320715, theta=0.0
% INFO    : Bus 5392	: V=1.075188, theta=-45.425084 -> V=1.0162145, theta=0.0
% INFO    : Bus 5393	: V=1.048353, theta=-37.98018 -> V=1.0, theta=0.0
% INFO    : Bus 5394	: V=1.048518, theta=-15.80688 -> V=1.0028495, theta=0.0
% INFO    : Bus 5395	: V=1.06458, theta=-44.072293 -> V=1.0065895, theta=0.0
% INFO    : Bus 5396	: V=1.055269, theta=2.023613 -> V=1.007391, theta=0.0
% INFO    : Bus 5397	: V=1.005313, theta=-23.226242 -> V=1.0, theta=0.0
% INFO    : Bus 5398	: V=0.982186, theta=-23.807483 -> V=1.0, theta=0.0
% INFO    : Bus 5399	: V=1.073562, theta=3.158101 -> V=1.021711, theta=0.0
% INFO    : Bus 5400	: V=1.032635, theta=-26.851724 -> V=1.0, theta=0.0
% INFO    : Bus 5401	: V=1.06489, theta=-14.11963 -> V=1.011189, theta=0.0
% INFO    : Bus 5402	: V=1.031818, theta=-10.743343 -> V=1.0, theta=0.0
% INFO    : Bus 5403	: V=1.017238, theta=-23.748086 -> V=1.0, theta=0.0
% INFO    : Bus 5404	: V=1.069805, theta=-15.727219 -> V=1.022473, theta=0.0
% INFO    : Bus 5405	: V=1.011129, theta=-20.287747 -> V=1.0, theta=0.0
% INFO    : Bus 5406	: V=1.043875, theta=-34.3488 -> V=1.003315, theta=0.0
% INFO    : Bus 5407	: V=1.038689, theta=-29.674826 -> V=1.0, theta=0.0
% INFO    : Bus 5408	: V=1.004319, theta=-42.659386 -> V=1.0, theta=0.0
% INFO    : Bus 5409	: V=1.05066, theta=-19.481806 -> V=1.004206, theta=0.0
% INFO    : Bus 5410	: V=1.094748, theta=45.096924 -> V=1.0086165, theta=0.0
% INFO    : Bus 5411	: V=0.986545, theta=-19.43431 -> V=1.0, theta=0.0
% INFO    : Bus 5412	: V=0.994571, theta=10.38781 -> V=1.0, theta=0.0
% INFO    : Bus 5413	: V=1.029851, theta=-23.204077 -> V=1.0, theta=0.0
% INFO    : Bus 5414	: V=1.069033, theta=-18.970343 -> V=1.0, theta=0.0
% INFO    : Bus 5415	: V=1.074474, theta=-17.808032 -> V=1.0, theta=0.0
% INFO    : Bus 5416	: V=1.027232, theta=13.660125 -> V=1.0, theta=0.0
% INFO    : Bus 5417	: V=1.060182, theta=-37.199521 -> V=1.0038385, theta=0.0
% INFO    : Bus 5418	: V=1.100527, theta=4.470687 -> V=1.020125, theta=0.0
% INFO    : Bus 5419	: V=1.046885, theta=-14.837735 -> V=1.0029095, theta=0.0
% INFO    : Bus 5420	: V=1.094273, theta=-11.646662 -> V=1.0217835, theta=0.0
% INFO    : Bus 5421	: V=1.067604, theta=9.787942 -> V=1.0, theta=0.0
% INFO    : Bus 5422	: V=0.966818, theta=-29.040951 -> V=1.0, theta=0.0
% INFO    : Bus 5423	: V=1.007624, theta=-22.114318 -> V=1.0, theta=0.0
% INFO    : Bus 5424	: V=0.979763, theta=67.633441 -> V=1.0, theta=0.0
% INFO    : Bus 5425	: V=0.997903, theta=-24.722002 -> V=1.0, theta=0.0
% INFO    : Bus 5426	: V=1.078993, theta=20.514616 -> V=1.031669, theta=0.0
% INFO    : Bus 5427	: V=1.077532, theta=-17.610691 -> V=1.0, theta=0.0
% INFO    : Bus 5428	: V=0.987885, theta=-23.526922 -> V=1.0, theta=0.0
% INFO    : Bus 5429	: V=1.074177, theta=-33.734227 -> V=1.025693, theta=0.0
% INFO    : Bus 5430	: V=1.087026, theta=-14.363254 -> V=1.030716, theta=0.0
% INFO    : Bus 5431	: V=1.043169, theta=-30.760662 -> V=1.0, theta=0.0
% INFO    : Bus 5432	: V=1.086553, theta=-18.645224 -> V=1.030761, theta=0.0
% INFO    : Bus 5433	: V=1.089921, theta=33.59766 -> V=1.00352, theta=0.0
% INFO    : Bus 5434	: V=1.081318, theta=-13.350588 -> V=1.024461, theta=0.0
% INFO    : Bus 5435	: V=1.076947, theta=7.418721 -> V=1.012449, theta=0.0
% INFO    : Bus 5436	: V=1.006911, theta=-22.38241 -> V=1.0, theta=0.0
% INFO    : Bus 5437	: V=1.071912, theta=-9.450336 -> V=1.019631, theta=0.0
% INFO    : Bus 5438	: V=1.055318, theta=-45.59038 -> V=1.0, theta=0.0
% INFO    : Bus 5439	: V=1.041988, theta=-23.021134 -> V=1.0, theta=0.0
% INFO    : Bus 5440	: V=1.04683, theta=-11.033199 -> V=1.0092455, theta=0.0
% INFO    : Bus 5441	: V=1.069183, theta=-13.841014 -> V=1.0121745, theta=0.0
% INFO    : Bus 5442	: V=0.970718, theta=-26.651895 -> V=1.0, theta=0.0
% INFO    : Bus 5443	: V=1.057243, theta=0.508939 -> V=1.0107725, theta=0.0
% INFO    : Bus 5444	: V=1.075324, theta=-16.687618 -> V=1.0210335, theta=0.0
% INFO    : Bus 5445	: V=1.060093, theta=-21.39214 -> V=1.0132195, theta=0.0
% INFO    : Bus 5446	: V=1.086447, theta=15.302727 -> V=1.0164435, theta=0.0
% INFO    : Bus 5447	: V=1.020788, theta=-21.380238 -> V=1.0, theta=0.0
% INFO    : Bus 5448	: V=0.953733, theta=-32.247596 -> V=1.0, theta=0.0
% INFO    : Bus 5449	: V=1.101192, theta=-43.269517 -> V=1.028456, theta=0.0
% INFO    : Bus 5450	: V=1.100652, theta=-13.514071 -> V=1.022905, theta=0.0
% INFO    : Bus 5451	: V=1.082411, theta=-17.766259 -> V=1.0457515, theta=0.0
% INFO    : Bus 5452	: V=1.09119, theta=-8.229532 -> V=1.0139745, theta=0.0
% INFO    : Bus 5453	: V=1.045416, theta=-46.866537 -> V=1.0, theta=0.0
% INFO    : Bus 5454	: V=1.098256, theta=-21.885663 -> V=1.0448475, theta=0.0
% INFO    : Bus 5455	: V=1.020976, theta=-14.482205 -> V=1.0, theta=0.0
% INFO    : Bus 5456	: V=0.99828, theta=-22.259085 -> V=1.0, theta=0.0
% INFO    : Bus 5457	: V=1.03686, theta=-29.382527 -> V=1.0, theta=0.0
% INFO    : Bus 5458	: V=1.017958, theta=-1.215397 -> V=1.0, theta=0.0
% INFO    : Bus 5459	: V=1.064108, theta=-2.429522 -> V=1.021237, theta=0.0
% INFO    : Bus 5460	: V=0.994486, theta=-49.605106 -> V=1.0, theta=0.0
% INFO    : Bus 5461	: V=1.051282, theta=9.664234 -> V=1.005849, theta=0.0
% INFO    : Bus 5462	: V=0.99822, theta=-23.421572 -> V=1.0, theta=0.0
% INFO    : Bus 5463	: V=1.064457, theta=-14.461155 -> V=1.0083665, theta=0.0
% INFO    : Bus 5464	: V=1.067234, theta=-18.379332 -> V=1.0, theta=0.0
% INFO    : Bus 5465	: V=1.021539, theta=-34.037449 -> V=1.0, theta=0.0
% INFO    : Bus 5466	: V=1.01016, theta=-22.01165 -> V=1.0, theta=0.0
% INFO    : Bus 5467	: V=1.026575, theta=-23.564669 -> V=1.0, theta=0.0
% INFO    : Bus 5468	: V=1.066762, theta=10.142309 -> V=1.022927, theta=0.0
% INFO    : Bus 5469	: V=1.019757, theta=-23.38694 -> V=1.0, theta=0.0
% INFO    : Bus 5470	: V=1.060132, theta=19.875737 -> V=1.0104025, theta=0.0
% INFO    : Bus 5471	: V=1.045734, theta=4.676754 -> V=1.0046225, theta=0.0
% INFO    : Bus 5472	: V=0.972038, theta=-34.824014 -> V=1.0, theta=0.0
% INFO    : Bus 5473	: V=1.053332, theta=-14.826721 -> V=1.0037905, theta=0.0
% INFO    : Bus 5474	: V=1.044125, theta=-23.321334 -> V=1.0, theta=0.0
% INFO    : Bus 5475	: V=1.018091, theta=-20.223937 -> V=1.0, theta=0.0
% INFO    : Bus 5476	: V=0.994399, theta=-21.760484 -> V=1.0, theta=0.0
% INFO    : Bus 5477	: V=1.003955, theta=-21.150202 -> V=1.0, theta=0.0
% INFO    : Bus 5478	: V=1.052289, theta=-0.671313 -> V=1.0185955, theta=0.0
% INFO    : Bus 5479	: V=0.97111, theta=-22.792228 -> V=1.0, theta=0.0
% INFO    : Bus 5480	: V=1.050117, theta=-41.505473 -> V=1.006008, theta=0.0
% INFO    : Bus 5481	: V=1.080407, theta=-46.273385 -> V=1.022276, theta=0.0
% INFO    : Bus 5482	: V=1.061088, theta=-40.1389 -> V=1.0095245, theta=0.0
% INFO    : Bus 5483	: V=1.038567, theta=-47.392266 -> V=1.0334945, theta=0.0
% INFO    : Bus 5484	: V=0.967167, theta=-28.002039 -> V=1.0, theta=0.0
% INFO    : Bus 5485	: V=0.916053, theta=-29.563462 -> V=1.0, theta=0.0
% INFO    : Bus 5486	: V=1.078087, theta=0.269769 -> V=1.023781, theta=0.0
% INFO    : Bus 5487	: V=1.049727, theta=-8.944492 -> V=1.023099, theta=0.0
% INFO    : Bus 5488	: V=1.063018, theta=7.20133 -> V=1.006137, theta=0.0
% INFO    : Bus 5489	: V=0.974726, theta=-25.973328 -> V=1.0, theta=0.0
% INFO    : Bus 5490	: V=1.012192, theta=-7.348013 -> V=1.0, theta=0.0
% INFO    : Bus 5491	: V=0.955902, theta=-14.775444 -> V=1.0, theta=0.0
% INFO    : Bus 5492	: V=1.082684, theta=16.349883 -> V=1.0137925, theta=0.0
% INFO    : Bus 5493	: V=1.078937, theta=-25.786209 -> V=1.0355785, theta=0.0
% INFO    : Bus 5494	: V=0.995906, theta=-28.182808 -> V=1.0, theta=0.0
% INFO    : Bus 5495	: V=1.059284, theta=-2.475132 -> V=1.015129, theta=0.0
% INFO    : Bus 5496	: V=1.047004, theta=-21.590936 -> V=1.00344, theta=0.0
% INFO    : Bus 5497	: V=1.074657, theta=-0.444655 -> V=1.021144, theta=0.0
% INFO    : Bus 5498	: V=1.048974, theta=5.661309 -> V=1.0084065, theta=0.0
% INFO    : Bus 5499	: V=1.014238, theta=-34.649929 -> V=1.0, theta=0.0
% INFO    : Bus 5500	: V=1.09753, theta=-34.313294 -> V=1.030023, theta=0.0
% INFO    : Bus 5501	: V=0.963866, theta=-25.258412 -> V=1.0, theta=0.0
% INFO    : Bus 5502	: V=0.997954, theta=-22.492518 -> V=1.0, theta=0.0
% INFO    : Bus 5503	: V=1.000917, theta=-23.444175 -> V=1.0, theta=0.0
% INFO    : Bus 5504	: V=1.103538, theta=-13.743719 -> V=1.042355, theta=0.0
% INFO    : Bus 5505	: V=1.004978, theta=-17.256884 -> V=1.0, theta=0.0
% INFO    : Bus 5506	: V=1.053778, theta=-11.696454 -> V=1.0108245, theta=0.0
% INFO    : Bus 5507	: V=1.051479, theta=-33.926783 -> V=1.0069515, theta=0.0
% INFO    : Bus 5508	: V=1.062399, theta=11.210977 -> V=1.0074905, theta=0.0
% INFO    : Bus 5509	: V=1.021429, theta=-6.494634 -> V=1.0, theta=0.0
% INFO    : Bus 5510	: V=1.058392, theta=-21.711891 -> V=1.011142, theta=0.0
% INFO    : Bus 5511	: V=1.046379, theta=-15.449733 -> V=1.0, theta=0.0
% INFO    : Bus 5512	: V=1.091453, theta=-14.44708 -> V=1.03142, theta=0.0
% INFO    : Bus 5513	: V=0.962661, theta=-31.45214 -> V=1.0, theta=0.0
% INFO    : Bus 5514	: V=1.083002, theta=-12.82591 -> V=1.0181465, theta=0.0
% INFO    : Bus 5515	: V=1.028706, theta=-15.341709 -> V=1.0159425, theta=0.0
% INFO    : Bus 5516	: V=1.080322, theta=-9.759686 -> V=1.005784, theta=0.0
% INFO    : Bus 5517	: V=0.992271, theta=-20.268219 -> V=1.0, theta=0.0
% INFO    : Bus 5518	: V=1.042575, theta=-15.702618 -> V=1.0, theta=0.0
% INFO    : Bus 5519	: V=1.086715, theta=-38.336899 -> V=1.021033, theta=0.0
% INFO    : Bus 5520	: V=0.999285, theta=-22.541653 -> V=1.0, theta=0.0
% INFO    : Bus 5521	: V=0.982483, theta=-24.025538 -> V=1.0, theta=0.0
% INFO    : Bus 5522	: V=1.03114, theta=12.478573 -> V=1.0, theta=0.0
% INFO    : Bus 5523	: V=0.992487, theta=66.347787 -> V=1.0, theta=0.0
% INFO    : Bus 5524	: V=1.066053, theta=5.732402 -> V=1.006573, theta=0.0
% INFO    : Bus 5525	: V=1.0049, theta=-29.725638 -> V=1.0, theta=0.0
% INFO    : Bus 5526	: V=1.0825, theta=-34.619493 -> V=1.014888, theta=0.0
% INFO    : Bus 5527	: V=1.044339, theta=-8.888837 -> V=1.0079625, theta=0.0
% INFO    : Bus 5528	: V=1.094658, theta=-35.860203 -> V=1.0157715, theta=0.0
% INFO    : Bus 5529	: V=1.035956, theta=-36.414903 -> V=1.0, theta=0.0
% INFO    : Bus 5530	: V=1.014582, theta=-22.626233 -> V=1.0, theta=0.0
% INFO    : Bus 5531	: V=1.08464, theta=53.191273 -> V=1.0098415, theta=0.0
% INFO    : Bus 5532	: V=1.022842, theta=-19.179077 -> V=1.0, theta=0.0
% INFO    : Bus 5533	: V=1.03082, theta=17.054492 -> V=1.0, theta=0.0
% INFO    : Bus 5534	: V=1.080055, theta=-18.867896 -> V=1.025654, theta=0.0
% INFO    : Bus 5535	: V=1.006741, theta=-0.784501 -> V=1.0, theta=0.0
% INFO    : Bus 5536	: V=1.044636, theta=2.192575 -> V=1.0112545, theta=0.0
% INFO    : Bus 5537	: V=1.068594, theta=-10.09756 -> V=1.0196155, theta=0.0
% INFO    : Bus 5538	: V=0.993738, theta=-23.426386 -> V=1.0, theta=0.0
% INFO    : Bus 5539	: V=1.040363, theta=-19.037852 -> V=1.0, theta=0.0
% INFO    : Bus 5540	: V=1.056517, theta=-11.734603 -> V=1.0179745, theta=0.0
% INFO    : Bus 5541	: V=0.978091, theta=-23.36938 -> V=1.0, theta=0.0
% INFO    : Bus 5542	: V=0.951334, theta=-26.861221 -> V=1.0, theta=0.0
% INFO    : Bus 5543	: V=1.043336, theta=-34.217279 -> V=1.0030305, theta=0.0
% INFO    : Bus 5544	: V=1.093855, theta=35.179654 -> V=1.0151725, theta=0.0
% INFO    : Bus 5545	: V=1.020195, theta=-8.914341 -> V=1.0033365, theta=0.0
% INFO    : Bus 5546	: V=1.054953, theta=-35.309127 -> V=1.0301715, theta=0.0
% INFO    : Bus 5547	: V=1.070914, theta=-8.629408 -> V=1.018763, theta=0.0
% INFO    : Bus 5548	: V=1.030193, theta=-24.334844 -> V=1.0, theta=0.0
% INFO    : Bus 5549	: V=1.050232, theta=-10.468122 -> V=1.0102125, theta=0.0
% INFO    : Bus 5550	: V=1.040677, theta=-12.912468 -> V=1.0104275, theta=0.0
% INFO    : Bus 5551	: V=1.03169, theta=-13.531282 -> V=1.0038405, theta=0.0
% INFO    : Bus 5552	: V=1.032493, theta=-23.307444 -> V=1.0, theta=0.0
% INFO    : Bus 5553	: V=1.07896, theta=20.273749 -> V=1.0286335, theta=0.0
% INFO    : Bus 5554	: V=1.063956, theta=-14.98634 -> V=1.0142265, theta=0.0
% INFO    : Bus 5555	: V=1.047909, theta=21.260442 -> V=1.002718, theta=0.0
% INFO    : Bus 5556	: V=1.069534, theta=-15.058313 -> V=1.013907, theta=0.0
% INFO    : Bus 5557	: V=1.018329, theta=-15.922496 -> V=1.0, theta=0.0
% INFO    : Bus 5558	: V=1.052033, theta=-20.563178 -> V=1.0, theta=0.0
% INFO    : Bus 5559	: V=1.067639, theta=-42.923665 -> V=1.0157245, theta=0.0
% INFO    : Bus 5560	: V=1.005081, theta=-32.316496 -> V=1.0, theta=0.0
% INFO    : Bus 5561	: V=1.088763, theta=-13.874493 -> V=1.0405975, theta=0.0
% INFO    : Bus 5562	: V=1.032727, theta=39.12418 -> V=1.0, theta=0.0
% INFO    : Bus 5563	: V=1.099466, theta=17.411888 -> V=1.0318815, theta=0.0
% INFO    : Bus 5564	: V=1.046803, theta=-45.218904 -> V=1.0, theta=0.0
% INFO    : Bus 5565	: V=1.043633, theta=-20.867765 -> V=1.0, theta=0.0
% INFO    : Bus 5566	: V=1.053359, theta=-48.363389 -> V=1.0056705, theta=0.0
% INFO    : Bus 5567	: V=1.007418, theta=-51.035744 -> V=1.0, theta=0.0
% INFO    : Bus 5568	: V=1.08663, theta=45.263414 -> V=1.010394, theta=0.0
% INFO    : Bus 5569	: V=1.048091, theta=-40.131078 -> V=1.0, theta=0.0
% INFO    : Bus 5570	: V=1.088952, theta=-0.217408 -> V=1.032382, theta=0.0
% INFO    : Bus 5571	: V=0.943051, theta=-33.563738 -> V=1.0, theta=0.0
% INFO    : Bus 5572	: V=0.977431, theta=-23.917326 -> V=1.0, theta=0.0
% INFO    : Bus 5573	: V=0.985818, theta=-24.913546 -> V=1.0, theta=0.0
% INFO    : Bus 5574	: V=1.038773, theta=-29.114269 -> V=1.0, theta=0.0
% INFO    : Bus 5575	: V=1.092606, theta=-11.682996 -> V=1.024434, theta=0.0
% INFO    : Bus 5576	: V=1.013775, theta=-22.290041 -> V=1.0, theta=0.0
% INFO    : Bus 5577	: V=0.973131, theta=-27.816607 -> V=1.0, theta=0.0
% INFO    : Bus 5578	: V=1.042936, theta=14.663812 -> V=1.0, theta=0.0
% INFO    : Bus 5579	: V=1.001695, theta=-19.038118 -> V=1.0, theta=0.0
% INFO    : Bus 5580	: V=1.064798, theta=-22.746035 -> V=1.024922, theta=0.0
% INFO    : Bus 5581	: V=0.94979, theta=55.935489 -> V=1.0, theta=0.0
% INFO    : Bus 5582	: V=1.069816, theta=-17.233074 -> V=1.0149875, theta=0.0
% INFO    : Bus 5583	: V=1.03834, theta=-25.051439 -> V=1.0, theta=0.0
% INFO    : Bus 5584	: V=1.014786, theta=29.780394 -> V=1.0, theta=0.0
% INFO    : Bus 5585	: V=1.053863, theta=-36.176784 -> V=1.0181405, theta=0.0
% INFO    : Bus 5586	: V=1.039748, theta=-15.692148 -> V=1.0, theta=0.0
% INFO    : Bus 5587	: V=1.036274, theta=-11.739288 -> V=1.01656, theta=0.0
% INFO    : Bus 5588	: V=1.030426, theta=-21.783103 -> V=1.0, theta=0.0
% INFO    : Bus 5589	: V=1.037493, theta=9.020762 -> V=1.0063275, theta=0.0
% INFO    : Bus 5590	: V=1.055469, theta=-43.54985 -> V=1.011991, theta=0.0
% INFO    : Bus 5591	: V=1.020394, theta=-23.553821 -> V=1.0, theta=0.0
% INFO    : Bus 5592	: V=1.074048, theta=-20.851833 -> V=1.026817, theta=0.0
% INFO    : Bus 5593	: V=1.042454, theta=13.487558 -> V=1.0038265, theta=0.0
% INFO    : Bus 5594	: V=1.000341, theta=-23.805127 -> V=1.0, theta=0.0
% INFO    : Bus 5595	: V=1.074803, theta=-5.681992 -> V=1.0160795, theta=0.0
% INFO    : Bus 5596	: V=1.05978, theta=9.032617 -> V=1.0, theta=0.0
% INFO    : Bus 5597	: V=1.087545, theta=-12.147224 -> V=1.0203195, theta=0.0
% INFO    : Bus 5598	: V=1.028591, theta=9.773039 -> V=1.010281, theta=0.0
% INFO    : Bus 5599	: V=0.965996, theta=21.692667 -> V=1.0, theta=0.0
% INFO    : Bus 5600	: V=1.003978, theta=-21.347285 -> V=1.0, theta=0.0
% INFO    : Bus 5601	: V=0.984977, theta=38.283168 -> V=1.0, theta=0.0
% INFO    : Bus 5602	: V=1.030999, theta=-43.443289 -> V=1.0, theta=0.0
% INFO    : Bus 5603	: V=0.961309, theta=-32.071063 -> V=1.0, theta=0.0
% INFO    : Bus 5604	: V=0.99346, theta=-22.872313 -> V=1.0, theta=0.0
% INFO    : Bus 5605	: V=1.072196, theta=-23.386527 -> V=1.018713, theta=0.0
% INFO    : Bus 5606	: V=1.047364, theta=-32.592401 -> V=1.01146, theta=0.0
% INFO    : Bus 5607	: V=1.071873, theta=13.345648 -> V=1.015095, theta=0.0
% INFO    : Bus 5608	: V=1.038909, theta=-25.035541 -> V=1.0, theta=0.0
% INFO    : Bus 5609	: V=1.054943, theta=-48.805042 -> V=1.0058225, theta=0.0
% INFO    : Bus 5610	: V=0.937076, theta=-35.110129 -> V=1.0, theta=0.0
% INFO    : Bus 5611	: V=1.00277, theta=-21.521905 -> V=1.0, theta=0.0
% INFO    : Bus 5612	: V=1.053832, theta=-48.993828 -> V=1.005456, theta=0.0
% INFO    : Bus 5613	: V=1.082558, theta=-37.272077 -> V=1.019396, theta=0.0
% INFO    : Bus 5614	: V=1.017807, theta=-46.385761 -> V=1.0, theta=0.0
% INFO    : Bus 5615	: V=1.069196, theta=-39.361633 -> V=1.0171755, theta=0.0
% INFO    : Bus 5616	: V=1.086483, theta=-11.013389 -> V=1.0255955, theta=0.0
% INFO    : Bus 5617	: V=1.057064, theta=-36.152006 -> V=1.0188955, theta=0.0
% INFO    : Bus 5618	: V=1.01135, theta=-39.082784 -> V=1.0, theta=0.0
% INFO    : Bus 5619	: V=1.048696, theta=-10.481131 -> V=1.0087285, theta=0.0
% INFO    : Bus 5620	: V=1.082866, theta=-15.357375 -> V=1.022872, theta=0.0
% INFO    : Bus 5621	: V=1.049772, theta=-28.989033 -> V=1.0099735, theta=0.0
% INFO    : Bus 5622	: V=1.055003, theta=-13.239009 -> V=1.0113005, theta=0.0
% INFO    : Bus 5623	: V=1.033368, theta=-13.059743 -> V=1.0, theta=0.0
% INFO    : Bus 5624	: V=1.070872, theta=-11.906164 -> V=1.034006, theta=0.0
% INFO    : Bus 5625	: V=0.987616, theta=-17.278852 -> V=1.0, theta=0.0
% INFO    : Bus 5626	: V=1.0855, theta=-28.63908 -> V=1.0216605, theta=0.0
% INFO    : Bus 5627	: V=1.080731, theta=2.939529 -> V=1.0255205, theta=0.0
% INFO    : Bus 5628	: V=1.077066, theta=-26.516567 -> V=1.042708, theta=0.0
% INFO    : Bus 5629	: V=1.068591, theta=-19.041391 -> V=1.0, theta=0.0
% INFO    : Bus 5630	: V=0.994821, theta=-18.120521 -> V=1.0, theta=0.0
% INFO    : Bus 5631	: V=1.072851, theta=0.067024 -> V=1.0185175, theta=0.0
% INFO    : Bus 5632	: V=1.099211, theta=-15.427181 -> V=1.0438015, theta=0.0
% INFO    : Bus 5633	: V=1.002423, theta=-23.254579 -> V=1.0, theta=0.0
% INFO    : Bus 5634	: V=1.064996, theta=-43.94067 -> V=1.00696, theta=0.0
% INFO    : Bus 5635	: V=1.017567, theta=-24.058204 -> V=1.0, theta=0.0
% INFO    : Bus 5636	: V=1.019099, theta=-4.698393 -> V=1.0, theta=0.0
% INFO    : Bus 5637	: V=1.002461, theta=-20.008582 -> V=1.0, theta=0.0
% INFO    : Bus 5638	: V=0.994749, theta=-30.777664 -> V=1.0, theta=0.0
% INFO    : Bus 5639	: V=1.031712, theta=-24.876266 -> V=1.0, theta=0.0
% INFO    : Bus 5640	: V=1.009069, theta=-32.228006 -> V=1.0, theta=0.0
% INFO    : Bus 5641	: V=1.082394, theta=-42.003919 -> V=1.0229315, theta=0.0
% INFO    : Bus 5642	: V=1.067651, theta=3.742862 -> V=1.018606, theta=0.0
% INFO    : Bus 5643	: V=1.042533, theta=-12.744628 -> V=1.007326, theta=0.0
% INFO    : Bus 5644	: V=1.068592, theta=-22.024249 -> V=1.0306245, theta=0.0
% INFO    : Bus 5645	: V=1.006207, theta=60.405804 -> V=1.0, theta=0.0
% INFO    : Bus 5646	: V=1.063403, theta=54.132585 -> V=1.0, theta=0.0
% INFO    : Bus 5647	: V=1.003861, theta=-25.992135 -> V=1.0, theta=0.0
% INFO    : Bus 5648	: V=1.068544, theta=-12.436724 -> V=1.0135805, theta=0.0
% INFO    : Bus 5649	: V=1.064121, theta=-17.025128 -> V=1.0, theta=0.0
% INFO    : Bus 5650	: V=0.972134, theta=-24.848285 -> V=1.0, theta=0.0
% INFO    : Bus 5651	: V=1.052631, theta=19.936817 -> V=1.0063375, theta=0.0
% INFO    : Bus 5652	: V=1.004128, theta=-38.547321 -> V=1.0, theta=0.0
% INFO    : Bus 5653	: V=0.990131, theta=-25.365867 -> V=1.0, theta=0.0
% INFO    : Bus 5654	: V=1.077753, theta=-7.475284 -> V=1.0216965, theta=0.0
% INFO    : Bus 5655	: V=1.05351, theta=-24.629846 -> V=1.0142025, theta=0.0
% INFO    : Bus 5656	: V=1.086474, theta=1.563116 -> V=1.017732, theta=0.0
% INFO    : Bus 5657	: V=1.037424, theta=-16.885309 -> V=1.0, theta=0.0
% INFO    : Bus 5658	: V=1.036973, theta=-21.791816 -> V=1.0068075, theta=0.0
% INFO    : Bus 5659	: V=1.038586, theta=-10.425594 -> V=1.0, theta=0.0
% INFO    : Bus 5660	: V=1.075529, theta=1.305281 -> V=1.02307, theta=0.0
% INFO    : Bus 5661	: V=1.071363, theta=-40.279815 -> V=1.0124245, theta=0.0
% INFO    : Bus 5662	: V=1.075591, theta=-33.570278 -> V=1.039635, theta=0.0
% INFO    : Bus 5663	: V=1.032712, theta=-25.347593 -> V=1.0, theta=0.0
% INFO    : Bus 5664	: V=1.015364, theta=-18.606987 -> V=1.0, theta=0.0
% INFO    : Bus 5665	: V=1.053974, theta=-40.153574 -> V=1.0096245, theta=0.0
% INFO    : Bus 5666	: V=1.031465, theta=-44.836838 -> V=1.0, theta=0.0
% INFO    : Bus 5667	: V=1.104118, theta=-9.182671 -> V=1.02776, theta=0.0
% INFO    : Bus 5668	: V=1.05959, theta=-34.322172 -> V=1.018329, theta=0.0
% INFO    : Bus 5669	: V=0.997042, theta=-23.625232 -> V=1.0, theta=0.0
% INFO    : Bus 5670	: V=1.082017, theta=-19.140171 -> V=1.0291035, theta=0.0
% INFO    : Bus 5671	: V=1.054079, theta=-39.690856 -> V=1.0133135, theta=0.0
% INFO    : Bus 5672	: V=0.972387, theta=-20.796309 -> V=1.0, theta=0.0
% INFO    : Bus 5673	: V=1.048972, theta=-2.225213 -> V=1.007191, theta=0.0
% INFO    : Bus 5674	: V=1.011903, theta=-32.914373 -> V=1.0, theta=0.0
% INFO    : Bus 5675	: V=1.053746, theta=-24.589696 -> V=1.0144035, theta=0.0
% INFO    : Bus 5676	: V=1.032107, theta=-49.880605 -> V=1.0, theta=0.0
% INFO    : Bus 5677	: V=1.010392, theta=-27.447382 -> V=1.0472645, theta=0.0
% INFO    : Bus 5678	: V=1.083407, theta=-17.404382 -> V=1.028457, theta=0.0
% INFO    : Bus 5679	: V=1.106467, theta=-16.572509 -> V=1.031388, theta=0.0
% INFO    : Bus 5680	: V=0.988362, theta=-17.78243 -> V=1.0, theta=0.0
% INFO    : Bus 5681	: V=1.048214, theta=-23.326949 -> V=1.0, theta=0.0
% INFO    : Bus 5682	: V=1.033686, theta=-21.485099 -> V=1.0, theta=0.0
% INFO    : Bus 5683	: V=1.051541, theta=-49.725979 -> V=1.006242, theta=0.0
% INFO    : Bus 5684	: V=0.98922, theta=-24.114922 -> V=1.0, theta=0.0
% INFO    : Bus 5685	: V=1.062698, theta=11.250878 -> V=1.0076235, theta=0.0
% INFO    : Bus 5686	: V=0.990982, theta=-24.260269 -> V=1.0, theta=0.0
% INFO    : Bus 5687	: V=0.99851, theta=-22.44434 -> V=1.0, theta=0.0
% INFO    : Bus 5688	: V=1.073039, theta=-23.189883 -> V=1.0190675, theta=0.0
% INFO    : Bus 5689	: V=1.079629, theta=-9.374264 -> V=1.014128, theta=0.0
% INFO    : Bus 5690	: V=1.076862, theta=-19.321458 -> V=1.0376965, theta=0.0
% INFO    : Bus 5691	: V=1.077167, theta=39.182513 -> V=1.0090335, theta=0.0
% INFO    : Bus 5692	: V=1.01824, theta=-37.214561 -> V=1.0, theta=0.0
% INFO    : Bus 5693	: V=1.05092, theta=-12.781007 -> V=1.009662, theta=0.0
% INFO    : Bus 5694	: V=1.066788, theta=-3.235896 -> V=1.018566, theta=0.0
% INFO    : Bus 5695	: V=1.010808, theta=-27.34916 -> V=1.0, theta=0.0
% INFO    : Bus 5696	: V=0.975791, theta=-25.884266 -> V=1.0, theta=0.0
% INFO    : Bus 5697	: V=0.979455, theta=-22.124893 -> V=1.0, theta=0.0
% INFO    : Bus 5698	: V=1.037955, theta=-29.573567 -> V=1.0, theta=0.0
% INFO    : Bus 5699	: V=1.07943, theta=20.61835 -> V=1.0321725, theta=0.0
% INFO    : Bus 5700	: V=1.073943, theta=13.768887 -> V=1.0112925, theta=0.0
% INFO    : Bus 5701	: V=1.094237, theta=55.26009 -> V=1.009252, theta=0.0
% INFO    : Bus 5702	: V=0.966357, theta=-23.228813 -> V=1.0, theta=0.0
% INFO    : Bus 5703	: V=1.047021, theta=39.861532 -> V=1.0, theta=0.0
% INFO    : Bus 5704	: V=1.0535, theta=0.387504 -> V=1.011239, theta=0.0
% INFO    : Bus 5705	: V=1.072926, theta=-2.196351 -> V=1.021278, theta=0.0
% INFO    : Bus 5706	: V=1.055498, theta=-12.314331 -> V=1.020163, theta=0.0
% INFO    : Bus 5707	: V=1.042182, theta=-23.269032 -> V=1.016996, theta=0.0
% INFO    : Bus 5708	: V=1.057962, theta=-44.353688 -> V=1.0108775, theta=0.0
% INFO    : Bus 5709	: V=1.024798, theta=-4.720058 -> V=1.0, theta=0.0
% INFO    : Bus 5710	: V=1.090326, theta=6.998132 -> V=1.028301, theta=0.0
% INFO    : Bus 5711	: V=1.053186, theta=-22.11449 -> V=1.0, theta=0.0
% INFO    : Bus 5712	: V=1.051153, theta=-22.694482 -> V=1.0, theta=0.0
% INFO    : Bus 5713	: V=1.084675, theta=-43.832909 -> V=1.0207, theta=0.0
% INFO    : Bus 5714	: V=1.057836, theta=-40.76727 -> V=1.00979, theta=0.0
% INFO    : Bus 5715	: V=1.04657, theta=-22.327199 -> V=1.0, theta=0.0
% INFO    : Bus 5716	: V=1.056632, theta=-27.090292 -> V=1.009537, theta=0.0
% INFO    : Bus 5717	: V=1.012924, theta=-47.760563 -> V=1.0, theta=0.0
% INFO    : Bus 5718	: V=1.0371, theta=-20.040738 -> V=1.0, theta=0.0
% INFO    : Bus 5719	: V=0.905869, theta=-32.770463 -> V=1.0, theta=0.0
% INFO    : Bus 5720	: V=1.07083, theta=-23.5476 -> V=1.0365275, theta=0.0
% INFO    : Bus 5721	: V=1.049286, theta=-15.665896 -> V=1.006731, theta=0.0
% INFO    : Bus 5722	: V=1.055202, theta=-24.38554 -> V=1.014966, theta=0.0
% INFO    : Bus 5723	: V=1.032846, theta=-25.473853 -> V=1.0, theta=0.0
% INFO    : Bus 5724	: V=0.97153, theta=-26.060266 -> V=1.0, theta=0.0
% INFO    : Bus 5725	: V=0.987704, theta=-38.981186 -> V=1.0, theta=0.0
% INFO    : Bus 5726	: V=1.065884, theta=-12.098673 -> V=1.0124235, theta=0.0
% INFO    : Bus 5727	: V=1.06613, theta=-22.654098 -> V=1.025541, theta=0.0
% INFO    : Bus 5728	: V=1.039174, theta=-19.849128 -> V=1.0, theta=0.0
% INFO    : Bus 5729	: V=1.012443, theta=-38.860558 -> V=1.0, theta=0.0
% INFO    : Bus 5730	: V=1.082936, theta=-40.335175 -> V=1.025908, theta=0.0
% INFO    : Bus 5731	: V=1.041674, theta=-18.455056 -> V=1.0084585, theta=0.0
% INFO    : Bus 5732	: V=0.961438, theta=-25.178362 -> V=1.0, theta=0.0
% INFO    : Bus 5733	: V=1.067591, theta=-13.09912 -> V=1.0143055, theta=0.0
% INFO    : Bus 5734	: V=1.068652, theta=2.4194 -> V=1.02009, theta=0.0
% INFO    : Bus 5735	: V=1.001218, theta=11.782514 -> V=1.0, theta=0.0
% INFO    : Bus 5736	: V=0.975789, theta=-26.967136 -> V=1.0, theta=0.0
% INFO    : Bus 5737	: V=1.052033, theta=1.962158 -> V=1.005541, theta=0.0
% INFO    : Bus 5738	: V=1.020036, theta=-46.648939 -> V=1.0, theta=0.0
% INFO    : Bus 5739	: V=0.982366, theta=-23.700211 -> V=1.0, theta=0.0
% INFO    : Bus 5740	: V=1.027532, theta=-40.104457 -> V=1.0, theta=0.0
% INFO    : Bus 5741	: V=1.035274, theta=-24.810791 -> V=1.0, theta=0.0
% INFO    : Bus 5742	: V=1.089773, theta=-0.773888 -> V=1.0270365, theta=0.0
% INFO    : Bus 5743	: V=1.096, theta=-11.219086 -> V=1.0352985, theta=0.0
% INFO    : Bus 5744	: V=1.019418, theta=-36.710513 -> V=1.0, theta=0.0
% INFO    : Bus 5745	: V=1.014727, theta=-47.173148 -> V=1.0, theta=0.0
% INFO    : Bus 5746	: V=1.043413, theta=-22.959619 -> V=1.0, theta=0.0
% INFO    : Bus 5747	: V=1.011752, theta=10.817904 -> V=1.0, theta=0.0
% INFO    : Bus 5748	: V=1.086362, theta=-8.942949 -> V=1.0392065, theta=0.0
% INFO    : Bus 5749	: V=0.998, theta=-23.282478 -> V=1.0, theta=0.0
% INFO    : Bus 5750	: V=0.954658, theta=-26.736884 -> V=1.0, theta=0.0
% INFO    : Bus 5751	: V=1.086411, theta=-41.19112 -> V=1.0231025, theta=0.0
% INFO    : Bus 5752	: V=0.994519, theta=-22.83765 -> V=1.0, theta=0.0
% INFO    : Bus 5753	: V=1.072667, theta=12.661962 -> V=1.024828, theta=0.0
% INFO    : Bus 5754	: V=1.023621, theta=5.281931 -> V=1.0, theta=0.0
% INFO    : Bus 5755	: V=1.021466, theta=-39.914182 -> V=1.0, theta=0.0
% INFO    : Bus 5756	: V=1.029145, theta=7.525305 -> V=1.0, theta=0.0
% INFO    : Bus 5757	: V=0.945982, theta=-33.207225 -> V=1.0, theta=0.0
% INFO    : Bus 5758	: V=1.008251, theta=-22.247869 -> V=1.0, theta=0.0
% INFO    : Bus 5759	: V=0.980371, theta=-25.247316 -> V=1.0, theta=0.0
% INFO    : Bus 5760	: V=1.062065, theta=-43.925498 -> V=1.0059815, theta=0.0
% INFO    : Bus 5761	: V=0.981723, theta=-23.44267 -> V=1.0, theta=0.0
% INFO    : Bus 5762	: V=1.063409, theta=-15.60069 -> V=1.023474, theta=0.0
% INFO    : Bus 5763	: V=0.948832, theta=-29.405654 -> V=1.0, theta=0.0
% INFO    : Bus 5764	: V=0.979687, theta=-19.948005 -> V=1.0, theta=0.0
% INFO    : Bus 5765	: V=1.075797, theta=4.793244 -> V=1.023027, theta=0.0
% INFO    : Bus 5766	: V=1.053729, theta=-20.965708 -> V=1.007155, theta=0.0
% INFO    : Bus 5767	: V=1.057041, theta=5.957605 -> V=1.0050255, theta=0.0
% INFO    : Bus 5768	: V=1.003632, theta=-23.378834 -> V=1.0, theta=0.0
% INFO    : Bus 5769	: V=0.954182, theta=-29.44919 -> V=1.0, theta=0.0
% INFO    : Bus 5770	: V=1.055053, theta=-49.210492 -> V=1.0065165, theta=0.0
% INFO    : Bus 5771	: V=1.072528, theta=-14.468789 -> V=1.0147375, theta=0.0
% INFO    : Bus 5772	: V=0.971546, theta=-27.955302 -> V=1.0, theta=0.0
% INFO    : Bus 5773	: V=1.098766, theta=-36.088649 -> V=1.038642, theta=0.0
% INFO    : Bus 5774	: V=0.977652, theta=-12.003639 -> V=1.0, theta=0.0
% INFO    : Bus 5775	: V=1.018279, theta=-22.190256 -> V=1.0, theta=0.0
% INFO    : Bus 5776	: V=1.037476, theta=-24.936872 -> V=1.0, theta=0.0
% INFO    : Bus 5777	: V=1.098447, theta=8.810252 -> V=1.014845, theta=0.0
% INFO    : Bus 5778	: V=0.996383, theta=-10.998077 -> V=1.0, theta=0.0
% INFO    : Bus 5779	: V=1.008409, theta=-7.954941 -> V=1.004781, theta=0.0
% INFO    : Bus 5780	: V=1.065226, theta=19.880823 -> V=1.014172, theta=0.0
% INFO    : Bus 5781	: V=1.075198, theta=-0.680671 -> V=1.022117, theta=0.0
% INFO    : Bus 5782	: V=1.037429, theta=-29.288299 -> V=1.0, theta=0.0
% INFO    : Bus 5783	: V=1.011955, theta=-2.014009 -> V=1.0, theta=0.0
% INFO    : Bus 5784	: V=1.079342, theta=59.368644 -> V=1.0, theta=0.0
% INFO    : Bus 5785	: V=1.065535, theta=-23.175093 -> V=1.011683, theta=0.0
% INFO    : Bus 5786	: V=1.072273, theta=-0.161958 -> V=1.02205, theta=0.0
% INFO    : Bus 5787	: V=1.019307, theta=-29.651567 -> V=1.0, theta=0.0
% INFO    : Bus 5788	: V=0.986684, theta=-32.330576 -> V=1.0, theta=0.0
% INFO    : Bus 5789	: V=1.027176, theta=-20.591632 -> V=1.0030975, theta=0.0
% INFO    : Bus 5790	: V=1.029253, theta=-51.424782 -> V=1.0, theta=0.0
% INFO    : Bus 5791	: V=1.075959, theta=-9.450845 -> V=1.023289, theta=0.0
% INFO    : Bus 5792	: V=1.042477, theta=17.342064 -> V=1.0059985, theta=0.0
% INFO    : Bus 5793	: V=1.077974, theta=-1.499889 -> V=1.022182, theta=0.0
% INFO    : Bus 5794	: V=0.99733, theta=-20.487354 -> V=1.0, theta=0.0
% INFO    : Bus 5795	: V=1.06272, theta=-30.53261 -> V=1.0056845, theta=0.0
% INFO    : Bus 5796	: V=1.027889, theta=-24.465849 -> V=1.0, theta=0.0
% INFO    : Bus 5797	: V=1.101218, theta=-43.269742 -> V=1.0284695, theta=0.0
% INFO    : Bus 5798	: V=1.064842, theta=62.849891 -> V=1.0, theta=0.0
% INFO    : Bus 5799	: V=0.970943, theta=-20.197249 -> V=1.0, theta=0.0
% INFO    : Bus 5800	: V=1.034495, theta=3.851565 -> V=1.0, theta=0.0
% INFO    : Bus 5801	: V=1.062031, theta=-41.724824 -> V=1.004826, theta=0.0
% INFO    : Bus 5802	: V=1.07822, theta=6.970501 -> V=1.016505, theta=0.0
% INFO    : Bus 5803	: V=0.919573, theta=-29.126124 -> V=0.9843485, theta=0.0
% INFO    : Bus 5804	: V=1.030601, theta=-38.034428 -> V=1.0, theta=0.0
% INFO    : Bus 5805	: V=1.049716, theta=-11.431567 -> V=1.0043665, theta=0.0
% INFO    : Bus 5806	: V=1.078463, theta=-0.231901 -> V=1.023492, theta=0.0
% INFO    : Bus 5807	: V=0.991108, theta=-28.621634 -> V=1.0, theta=0.0
% INFO    : Bus 5808	: V=0.964719, theta=-30.558951 -> V=1.0, theta=0.0
% INFO    : Bus 5809	: V=1.060272, theta=-15.022399 -> V=1.015625, theta=0.0
% INFO    : Bus 5810	: V=0.992838, theta=-18.310234 -> V=1.0, theta=0.0
% INFO    : Bus 5811	: V=1.067196, theta=-0.143455 -> V=1.0197555, theta=0.0
% INFO    : Bus 5812	: V=1.102372, theta=-17.243849 -> V=1.036647, theta=0.0
% INFO    : Bus 5813	: V=0.938651, theta=-25.707202 -> V=1.0, theta=0.0
% INFO    : Bus 5814	: V=1.048206, theta=-21.666726 -> V=1.0, theta=0.0
% INFO    : Bus 5815	: V=0.958421, theta=-29.660795 -> V=0.992154, theta=0.0
% INFO    : Bus 5816	: V=1.066684, theta=1.65306 -> V=1.0098615, theta=0.0
% INFO    : Bus 5817	: V=0.996409, theta=-34.255155 -> V=1.0, theta=0.0
% INFO    : Bus 5818	: V=1.047739, theta=-9.444683 -> V=1.010005, theta=0.0
% INFO    : Bus 5819	: V=1.032668, theta=-26.85174 -> V=1.0, theta=0.0
% INFO    : Bus 5820	: V=1.026608, theta=9.79188 -> V=1.0, theta=0.0
% INFO    : Bus 5821	: V=1.068842, theta=17.040124 -> V=1.011431, theta=0.0
% INFO    : Bus 5822	: V=0.958791, theta=-29.071349 -> V=0.9974555, theta=0.0
% INFO    : Bus 5823	: V=1.076082, theta=-2.019354 -> V=1.02157, theta=0.0
% INFO    : Bus 5824	: V=0.952368, theta=-25.971974 -> V=1.0, theta=0.0
% INFO    : Bus 5825	: V=1.06721, theta=-3.055136 -> V=1.0187195, theta=0.0
% INFO    : Bus 5826	: V=1.083153, theta=16.348945 -> V=1.014014, theta=0.0
% INFO    : Bus 5827	: V=1.033318, theta=-25.434967 -> V=1.0, theta=0.0
% INFO    : Bus 5828	: V=1.086915, theta=1.477847 -> V=1.028541, theta=0.0
% INFO    : Bus 5829	: V=1.038958, theta=-12.623077 -> V=1.010258, theta=0.0
% INFO    : Bus 5830	: V=1.032295, theta=-25.224724 -> V=1.0, theta=0.0
% INFO    : Bus 5831	: V=1.074727, theta=-17.478054 -> V=1.0208485, theta=0.0
% INFO    : Bus 5832	: V=1.032963, theta=-28.360713 -> V=1.019255, theta=0.0
% INFO    : Bus 5833	: V=0.994738, theta=-29.030251 -> V=1.0, theta=0.0
% INFO    : Bus 5834	: V=1.033591, theta=67.189089 -> V=1.0, theta=0.0
% INFO    : Bus 5835	: V=1.049125, theta=-29.884519 -> V=1.0, theta=0.0
% INFO    : Bus 5836	: V=1.062955, theta=-8.295414 -> V=1.0274545, theta=0.0
% INFO    : Bus 5837	: V=1.008145, theta=-31.626375 -> V=1.0, theta=0.0
% INFO    : Bus 5838	: V=1.038864, theta=-43.935745 -> V=1.0, theta=0.0
% INFO    : Bus 5839	: V=1.02585, theta=-23.240517 -> V=1.0, theta=0.0
% INFO    : Bus 5840	: V=0.984638, theta=7.853647 -> V=1.0, theta=0.0
% INFO    : Bus 5841	: V=1.069406, theta=4.526731 -> V=1.0197215, theta=0.0
% INFO    : Bus 5842	: V=1.031909, theta=38.690583 -> V=1.0, theta=0.0
% INFO    : Bus 5843	: V=0.950208, theta=-23.686499 -> V=1.0, theta=0.0
% INFO    : Bus 5844	: V=1.079855, theta=10.325486 -> V=1.0165085, theta=0.0
% INFO    : Bus 5845	: V=1.052421, theta=-45.359057 -> V=1.0072825, theta=0.0
% INFO    : Bus 5846	: V=1.088221, theta=-28.504615 -> V=1.0373595, theta=0.0
% INFO    : Bus 5847	: V=1.074288, theta=-15.033789 -> V=1.010445, theta=0.0
% INFO    : Bus 5848	: V=1.07351, theta=-10.406022 -> V=1.0192665, theta=0.0
% INFO    : Bus 5849	: V=1.060084, theta=-29.771965 -> V=1.010549, theta=0.0
% INFO    : Bus 5850	: V=0.94391, theta=-27.963865 -> V=1.0, theta=0.0
% INFO    : Bus 5851	: V=1.076723, theta=-20.749304 -> V=1.023658, theta=0.0
% INFO    : Bus 5852	: V=1.059015, theta=-10.103849 -> V=1.0133915, theta=0.0
% INFO    : Bus 5853	: V=1.06197, theta=-30.509053 -> V=1.0160055, theta=0.0
% INFO    : Bus 5854	: V=1.036869, theta=-4.376082 -> V=1.004259, theta=0.0
% INFO    : Bus 5855	: V=1.06264, theta=-14.052799 -> V=1.0103595, theta=0.0
% INFO    : Bus 5856	: V=1.055393, theta=-49.17299 -> V=1.0066685, theta=0.0
% INFO    : Bus 5857	: V=1.06156, theta=-21.070554 -> V=1.0192865, theta=0.0
% INFO    : Bus 5858	: V=1.069563, theta=-42.539063 -> V=1.0082675, theta=0.0
% INFO    : Bus 5859	: V=1.074241, theta=21.819732 -> V=1.0097005, theta=0.0
% INFO    : Bus 5860	: V=1.089263, theta=57.155542 -> V=1.0, theta=0.0
% INFO    : Bus 5861	: V=1.024533, theta=-34.312593 -> V=1.0, theta=0.0
% INFO    : Bus 5862	: V=1.083122, theta=-29.908244 -> V=1.0218045, theta=0.0
% INFO    : Bus 5863	: V=0.996957, theta=-21.649002 -> V=1.0, theta=0.0
% INFO    : Bus 5864	: V=0.973755, theta=-19.289463 -> V=1.0, theta=0.0
% INFO    : Bus 5865	: V=1.087009, theta=-26.234847 -> V=1.0304505, theta=0.0
% INFO    : Bus 5866	: V=0.995916, theta=-26.366452 -> V=1.0, theta=0.0
% INFO    : Bus 5867	: V=1.094112, theta=45.731275 -> V=1.002923, theta=0.0
% INFO    : Bus 5868	: V=1.056673, theta=8.818928 -> V=1.0, theta=0.0
% INFO    : Bus 5869	: V=1.050785, theta=57.535591 -> V=1.0, theta=0.0
% INFO    : Bus 5870	: V=1.016674, theta=14.555252 -> V=1.0, theta=0.0
% INFO    : Bus 5871	: V=0.973501, theta=-26.007539 -> V=1.0, theta=0.0
% INFO    : Bus 5872	: V=1.076553, theta=-22.778637 -> V=1.0305835, theta=0.0
% INFO    : Bus 5873	: V=1.073318, theta=-7.552976 -> V=1.0217855, theta=0.0
% INFO    : Bus 5874	: V=1.087891, theta=-8.703125 -> V=1.020781, theta=0.0
% INFO    : Bus 5875	: V=1.050526, theta=16.066956 -> V=1.0152055, theta=0.0
% INFO    : Bus 5876	: V=1.077528, theta=-13.726173 -> V=1.0173095, theta=0.0
% INFO    : Bus 5877	: V=1.036978, theta=-25.085194 -> V=1.0, theta=0.0
% INFO    : Bus 5878	: V=1.055674, theta=2.027724 -> V=1.0075835, theta=0.0
% INFO    : Bus 5879	: V=1.066753, theta=-13.398469 -> V=1.013562, theta=0.0
% INFO    : Bus 5880	: V=1.054478, theta=-40.557794 -> V=1.006651, theta=0.0
% INFO    : Bus 5881	: V=1.023182, theta=-14.855462 -> V=1.0, theta=0.0
% INFO    : Bus 5882	: V=1.089921, theta=-41.334228 -> V=1.016731, theta=0.0
% INFO    : Bus 5883	: V=1.072853, theta=-8.310527 -> V=1.0174975, theta=0.0
% INFO    : Bus 5884	: V=1.077938, theta=-3.993865 -> V=1.0155775, theta=0.0
% INFO    : Bus 5885	: V=0.988561, theta=-20.052075 -> V=1.0, theta=0.0
% INFO    : Bus 5886	: V=1.041142, theta=25.766352 -> V=1.015541, theta=0.0
% INFO    : Bus 5887	: V=1.057111, theta=-47.954706 -> V=1.0054675, theta=0.0
% INFO    : Bus 5888	: V=1.086685, theta=-23.373311 -> V=1.02689, theta=0.0
% INFO    : Bus 5889	: V=1.032237, theta=66.125334 -> V=1.0, theta=0.0
% INFO    : Bus 5890	: V=0.984596, theta=-25.618529 -> V=1.0, theta=0.0
% INFO    : Bus 5891	: V=1.087236, theta=-37.608004 -> V=1.020741, theta=0.0
% INFO    : Bus 5892	: V=1.049382, theta=-20.83599 -> V=1.009519, theta=0.0
% INFO    : Bus 5893	: V=1.087088, theta=-36.918893 -> V=1.015434, theta=0.0
% INFO    : Bus 5894	: V=1.071789, theta=33.183569 -> V=1.0214495, theta=0.0
% INFO    : Bus 5895	: V=1.056964, theta=-41.040463 -> V=1.009475, theta=0.0
% INFO    : Bus 5896	: V=1.01602, theta=-17.273256 -> V=1.0, theta=0.0
% INFO    : Bus 5897	: V=1.022696, theta=-23.404539 -> V=1.0101335, theta=0.0
% INFO    : Bus 5898	: V=1.024091, theta=-23.300389 -> V=1.010627, theta=0.0
% INFO    : Bus 5899	: V=1.079191, theta=-12.979237 -> V=1.0221435, theta=0.0
% INFO    : Bus 5900	: V=1.024049, theta=-40.441555 -> V=1.0, theta=0.0
% INFO    : Bus 5901	: V=1.024515, theta=-20.770843 -> V=1.0, theta=0.0
% INFO    : Bus 5902	: V=1.059239, theta=61.761821 -> V=1.0, theta=0.0
% INFO    : Bus 5903	: V=1.067761, theta=2.89451 -> V=1.0170705, theta=0.0
% INFO    : Bus 5904	: V=1.03971, theta=-15.695364 -> V=1.0, theta=0.0
% INFO    : Bus 5905	: V=1.049528, theta=-26.186212 -> V=1.014367, theta=0.0
% INFO    : Bus 5906	: V=0.97439, theta=-24.833898 -> V=1.0, theta=0.0
% INFO    : Bus 5907	: V=1.031013, theta=-49.289345 -> V=1.0, theta=0.0
% INFO    : Bus 5908	: V=0.951163, theta=-13.633756 -> V=1.0, theta=0.0
% INFO    : Bus 5909	: V=1.086417, theta=4.967047 -> V=1.026485, theta=0.0
% INFO    : Bus 5910	: V=0.953921, theta=-30.29828 -> V=1.0, theta=0.0
% INFO    : Bus 5911	: V=1.087182, theta=-3.635396 -> V=1.019982, theta=0.0
% INFO    : Bus 5912	: V=0.980909, theta=-24.198521 -> V=1.0, theta=0.0
% INFO    : Bus 5913	: V=1.068152, theta=9.782387 -> V=1.0, theta=0.0
% INFO    : Bus 5914	: V=1.084396, theta=-23.396692 -> V=1.0103785, theta=0.0
% INFO    : Bus 5915	: V=1.080873, theta=-4.716217 -> V=1.0174705, theta=0.0
% INFO    : Bus 5916	: V=0.975858, theta=-20.255317 -> V=1.0, theta=0.0
% INFO    : Bus 5917	: V=1.049556, theta=-4.477922 -> V=1.012799, theta=0.0
% INFO    : Bus 5918	: V=1.027077, theta=13.7058 -> V=1.0, theta=0.0
% INFO    : Bus 5919	: V=1.030505, theta=8.632899 -> V=1.0057935, theta=0.0
% INFO    : Bus 5920	: V=1.027075, theta=-20.600248 -> V=1.0027635, theta=0.0
% INFO    : Bus 5921	: V=1.055358, theta=-35.62604 -> V=1.0183655, theta=0.0
% INFO    : Bus 5922	: V=1.044447, theta=-36.871401 -> V=1.0061875, theta=0.0
% INFO    : Bus 5923	: V=1.026475, theta=-36.050383 -> V=1.0, theta=0.0
% INFO    : Bus 5924	: V=1.04845, theta=-25.548613 -> V=1.0, theta=0.0
% INFO    : Bus 5925	: V=1.040241, theta=-31.266163 -> V=1.0174825, theta=0.0
% INFO    : Bus 5926	: V=1.007427, theta=-27.603015 -> V=1.0463705, theta=0.0
% INFO    : Bus 5927	: V=1.046867, theta=-19.02746 -> V=1.0, theta=0.0
% INFO    : Bus 5928	: V=1.036215, theta=-19.868752 -> V=1.0, theta=0.0
% INFO    : Bus 5929	: V=1.100919, theta=57.840858 -> V=1.009875, theta=0.0
% INFO    : Bus 5930	: V=1.063891, theta=0.75733 -> V=1.0132045, theta=0.0
% INFO    : Bus 5931	: V=1.018009, theta=-32.682929 -> V=1.0, theta=0.0
% INFO    : Bus 5932	: V=1.031697, theta=-7.88345 -> V=1.0, theta=0.0
% INFO    : Bus 5933	: V=1.087188, theta=-2.777686 -> V=1.023383, theta=0.0
% INFO    : Bus 5934	: V=1.064529, theta=-44.086637 -> V=1.0065575, theta=0.0
% INFO    : Bus 5935	: V=1.015545, theta=-39.165468 -> V=1.0, theta=0.0
% INFO    : Bus 5936	: V=1.023892, theta=-14.330241 -> V=1.0, theta=0.0
% INFO    : Bus 5937	: V=0.953015, theta=-31.147533 -> V=1.0, theta=0.0
% INFO    : Bus 5938	: V=0.942568, theta=-27.781795 -> V=1.0, theta=0.0
% INFO    : Bus 5939	: V=0.949519, theta=-30.776944 -> V=0.982209, theta=0.0
% INFO    : Bus 5940	: V=1.027329, theta=-14.644898 -> V=1.0, theta=0.0
% INFO    : Bus 5941	: V=1.053545, theta=-20.204923 -> V=1.0113975, theta=0.0
% INFO    : Bus 5942	: V=1.032209, theta=3.928209 -> V=1.0, theta=0.0
% INFO    : Bus 5943	: V=1.018516, theta=-42.885414 -> V=1.0212055, theta=0.0
% INFO    : Bus 5944	: V=1.048385, theta=-12.37184 -> V=1.0168645, theta=0.0
% INFO    : Bus 5945	: V=1.057777, theta=-20.696203 -> V=1.007593, theta=0.0
% INFO    : Bus 5946	: V=1.033974, theta=5.282982 -> V=1.003872, theta=0.0
% INFO    : Bus 5947	: V=1.076348, theta=-0.353141 -> V=1.0221675, theta=0.0
% INFO    : Bus 5948	: V=1.07277, theta=-31.674175 -> V=1.016307, theta=0.0
% INFO    : Bus 5949	: V=1.029934, theta=-45.003029 -> V=1.0, theta=0.0
% INFO    : Bus 5950	: V=0.9464, theta=-27.90981 -> V=1.0, theta=0.0
% INFO    : Bus 5951	: V=1.072568, theta=-23.431129 -> V=1.018899, theta=0.0
% INFO    : Bus 5952	: V=1.081286, theta=-39.281876 -> V=1.015879, theta=0.0
% INFO    : Bus 5953	: V=1.038673, theta=-6.925344 -> V=1.014964, theta=0.0
% INFO    : Bus 5954	: V=1.054552, theta=-34.527629 -> V=1.0164805, theta=0.0
% INFO    : Bus 5955	: V=1.055765, theta=-27.087956 -> V=1.00915, theta=0.0
% INFO    : Bus 5956	: V=1.082332, theta=-16.235945 -> V=1.0185905, theta=0.0
% INFO    : Bus 5957	: V=1.080647, theta=7.793171 -> V=1.003767, theta=0.0
% INFO    : Bus 5958	: V=1.075468, theta=-19.759654 -> V=1.0200705, theta=0.0
% INFO    : Bus 5959	: V=1.002186, theta=-22.335738 -> V=1.0, theta=0.0
% INFO    : Bus 5960	: V=0.933918, theta=-29.143855 -> V=1.0, theta=0.0
% INFO    : Bus 5961	: V=1.01001, theta=-19.585828 -> V=1.0, theta=0.0
% INFO    : Bus 5962	: V=1.079308, theta=-16.365113 -> V=1.0181925, theta=0.0
% INFO    : Bus 5963	: V=1.064363, theta=1.88895 -> V=1.0208695, theta=0.0
% INFO    : Bus 5964	: V=1.019818, theta=-30.289894 -> V=1.0, theta=0.0
% INFO    : Bus 5965	: V=1.017721, theta=-26.785907 -> V=1.0, theta=0.0
% INFO    : Bus 5966	: V=0.990852, theta=-25.023866 -> V=1.0, theta=0.0
% INFO    : Bus 5967	: V=0.999106, theta=-22.353072 -> V=1.0, theta=0.0
% INFO    : Bus 5968	: V=1.083585, theta=-2.832034 -> V=1.022287, theta=0.0
% INFO    : Bus 5969	: V=1.081261, theta=10.439151 -> V=1.0171965, theta=0.0
% INFO    : Bus 5970	: V=1.027424, theta=-21.729128 -> V=1.0, theta=0.0
% INFO    : Bus 5971	: V=1.095569, theta=57.196065 -> V=1.0062045, theta=0.0
% INFO    : Bus 5972	: V=1.03143, theta=-22.823498 -> V=1.0, theta=0.0
% INFO    : Bus 5973	: V=1.068601, theta=-8.940777 -> V=1.017883, theta=0.0
% INFO    : Bus 5974	: V=1.032226, theta=16.675612 -> V=1.0, theta=0.0
% INFO    : Bus 5975	: V=1.076322, theta=-17.416168 -> V=1.0192085, theta=0.0
% INFO    : Bus 5976	: V=1.057273, theta=0.385796 -> V=1.014176, theta=0.0
% INFO    : Bus 5977	: V=0.949704, theta=-27.156203 -> V=1.0, theta=0.0
% INFO    : Bus 5978	: V=0.965656, theta=-27.541312 -> V=1.0, theta=0.0
% INFO    : Bus 5979	: V=1.059909, theta=-26.674879 -> V=1.0108275, theta=0.0
% INFO    : Bus 5980	: V=0.994758, theta=-29.613872 -> V=1.0, theta=0.0
% INFO    : Bus 5981	: V=1.03768, theta=-49.745802 -> V=1.0, theta=0.0
% INFO    : Bus 5982	: V=1.065344, theta=-43.914276 -> V=1.0071375, theta=0.0
% INFO    : Bus 5983	: V=1.025271, theta=-31.165653 -> V=1.0, theta=0.0
% INFO    : Bus 5984	: V=1.061826, theta=-4.201612 -> V=1.01758, theta=0.0
% INFO    : Bus 5985	: V=1.077163, theta=9.472921 -> V=1.023051, theta=0.0
% INFO    : Bus 5986	: V=1.019773, theta=15.722766 -> V=1.0, theta=0.0
% INFO    : Bus 5987	: V=1.036743, theta=-27.395713 -> V=1.0, theta=0.0
% INFO    : Bus 5988	: V=1.022805, theta=-17.463685 -> V=1.0, theta=0.0
% INFO    : Bus 5989	: V=1.067813, theta=-36.042723 -> V=1.010253, theta=0.0
% INFO    : Bus 5990	: V=1.051816, theta=-15.081333 -> V=1.004789, theta=0.0
% INFO    : Bus 5991	: V=1.014528, theta=-24.673955 -> V=1.0, theta=0.0
% INFO    : Bus 5992	: V=1.086034, theta=-37.480475 -> V=1.015243, theta=0.0
% INFO    : Bus 5993	: V=1.013, theta=62.491973 -> V=1.0, theta=0.0
% INFO    : Bus 5994	: V=1.038566, theta=-23.423552 -> V=1.0, theta=0.0
% INFO    : Bus 5995	: V=1.022897, theta=-21.327496 -> V=1.0, theta=0.0
% INFO    : Bus 5996	: V=1.09907, theta=60.570057 -> V=1.0084895, theta=0.0
% INFO    : Bus 5997	: V=1.050203, theta=-31.221003 -> V=1.019195, theta=0.0
% INFO    : Bus 5998	: V=1.085914, theta=-2.507452 -> V=1.023043, theta=0.0
% INFO    : Bus 5999	: V=0.995327, theta=-16.051557 -> V=1.0, theta=0.0
% INFO    : Bus 6000	: V=1.077932, theta=41.758959 -> V=1.0077995, theta=0.0
% INFO    : Bus 6001	: V=1.057361, theta=-14.887035 -> V=1.0053485, theta=0.0
% INFO    : Bus 6002	: V=1.043607, theta=-15.093164 -> V=1.0152485, theta=0.0
% INFO    : Bus 6003	: V=0.995816, theta=-22.6443 -> V=1.0, theta=0.0
% INFO    : Bus 6004	: V=1.070318, theta=48.334417 -> V=1.0, theta=0.0
% INFO    : Bus 6005	: V=1.046862, theta=-34.257461 -> V=1.004711, theta=0.0
% INFO    : Bus 6006	: V=1.081926, theta=4.176302 -> V=1.0257925, theta=0.0
% INFO    : Bus 6007	: V=1.064212, theta=-51.695776 -> V=1.0, theta=0.0
% INFO    : Bus 6008	: V=1.010636, theta=-22.814195 -> V=1.0, theta=0.0
% INFO    : Bus 6009	: V=1.024545, theta=-17.662628 -> V=1.005609, theta=0.0
% INFO    : Bus 6010	: V=0.943035, theta=-28.85938 -> V=1.0, theta=0.0
% INFO    : Bus 6011	: V=1.096201, theta=-11.296894 -> V=1.034496, theta=0.0
% INFO    : Bus 6012	: V=1.076419, theta=-22.873563 -> V=1.030888, theta=0.0
% INFO    : Bus 6013	: V=1.051427, theta=-35.986504 -> V=1.016563, theta=0.0
% INFO    : Bus 6014	: V=1.100184, theta=-36.835036 -> V=1.0212545, theta=0.0
% INFO    : Bus 6015	: V=1.063503, theta=-22.635004 -> V=1.00935, theta=0.0
% INFO    : Bus 6016	: V=1.097928, theta=18.233552 -> V=1.0370475, theta=0.0
% INFO    : Bus 6017	: V=0.99237, theta=-23.526985 -> V=1.0, theta=0.0
% INFO    : Bus 6018	: V=1.088472, theta=-0.354998 -> V=1.0244215, theta=0.0
% INFO    : Bus 6019	: V=1.087798, theta=-24.889604 -> V=1.0233455, theta=0.0
% INFO    : Bus 6020	: V=1.061794, theta=-13.970465 -> V=1.0165805, theta=0.0
% INFO    : Bus 6021	: V=1.099042, theta=-2.830485 -> V=1.0281365, theta=0.0
% INFO    : Bus 6022	: V=1.005364, theta=-39.657197 -> V=1.0, theta=0.0
% INFO    : Bus 6023	: V=0.997261, theta=-16.599221 -> V=1.0, theta=0.0
% INFO    : Bus 6024	: V=0.926407, theta=-29.465863 -> V=0.9823165, theta=0.0
% INFO    : Bus 6025	: V=0.979261, theta=-23.950358 -> V=1.0, theta=0.0
% INFO    : Bus 6026	: V=0.985004, theta=-23.231746 -> V=1.0, theta=0.0
% INFO    : Bus 6027	: V=0.992868, theta=-23.666406 -> V=1.0, theta=0.0
% INFO    : Bus 6028	: V=1.095255, theta=-11.352283 -> V=1.0350235, theta=0.0
% INFO    : Bus 6029	: V=1.054765, theta=-36.049798 -> V=1.0183735, theta=0.0
% INFO    : Bus 6030	: V=0.976271, theta=-28.877187 -> V=1.0, theta=0.0
% INFO    : Bus 6031	: V=1.023128, theta=-17.130944 -> V=1.0126385, theta=0.0
% INFO    : Bus 6032	: V=1.062421, theta=-0.730386 -> V=1.015266, theta=0.0
% INFO    : Bus 6033	: V=1.03662, theta=65.964673 -> V=1.0, theta=0.0
% INFO    : Bus 6034	: V=1.072091, theta=-42.140952 -> V=1.00886, theta=0.0
% INFO    : Bus 6035	: V=1.04931, theta=-15.6741 -> V=1.006786, theta=0.0
% INFO    : Bus 6036	: V=1.081364, theta=-33.664365 -> V=1.016218, theta=0.0
% INFO    : Bus 6037	: V=1.070912, theta=26.947116 -> V=1.0072505, theta=0.0
% INFO    : Bus 6038	: V=0.923661, theta=-34.977629 -> V=1.0, theta=0.0
% INFO    : Bus 6039	: V=1.085649, theta=-41.781945 -> V=1.0158015, theta=0.0
% INFO    : Bus 6040	: V=1.04832, theta=-45.58922 -> V=1.0, theta=0.0
% INFO    : Bus 6041	: V=0.993273, theta=11.063676 -> V=1.0, theta=0.0
% INFO    : Bus 6042	: V=1.068652, theta=2.4194 -> V=1.02009, theta=0.0
% INFO    : Bus 6043	: V=1.038859, theta=-44.171832 -> V=1.0, theta=0.0
% INFO    : Bus 6044	: V=1.042707, theta=-45.732589 -> V=1.032257, theta=0.0
% INFO    : Bus 6045	: V=1.051072, theta=-18.544256 -> V=1.009134, theta=0.0
% INFO    : Bus 6046	: V=1.063637, theta=-23.173622 -> V=1.0108575, theta=0.0
% INFO    : Bus 6047	: V=1.057483, theta=-2.587818 -> V=1.014118, theta=0.0
% INFO    : Bus 6048	: V=1.093868, theta=56.369567 -> V=1.0072665, theta=0.0
% INFO    : Bus 6049	: V=1.028209, theta=-48.562922 -> V=1.0, theta=0.0
% INFO    : Bus 6050	: V=1.063028, theta=-22.975395 -> V=1.013838, theta=0.0
% INFO    : Bus 6051	: V=1.091, theta=-15.940599 -> V=1.039931, theta=0.0
% INFO    : Bus 6052	: V=0.962593, theta=-21.559922 -> V=1.0, theta=0.0
% INFO    : Bus 6053	: V=0.975625, theta=-25.689073 -> V=1.0, theta=0.0
% INFO    : Bus 6054	: V=1.060896, theta=-22.255199 -> V=1.0193175, theta=0.0
% INFO    : Bus 6055	: V=0.999672, theta=-21.935927 -> V=1.0, theta=0.0
% INFO    : Bus 6056	: V=1.05306, theta=-48.841622 -> V=1.005329, theta=0.0
% INFO    : Bus 6057	: V=1.060182, theta=-43.538599 -> V=1.0051435, theta=0.0
% INFO    : Bus 6058	: V=1.09621, theta=-36.709521 -> V=1.0315605, theta=0.0
% INFO    : Bus 6059	: V=1.027994, theta=-30.888148 -> V=1.0, theta=0.0
% INFO    : Bus 6060	: V=1.062327, theta=-19.761968 -> V=1.0, theta=0.0
% INFO    : Bus 6061	: V=1.055201, theta=-24.385563 -> V=1.0149655, theta=0.0
% INFO    : Bus 6062	: V=1.026703, theta=-21.407059 -> V=1.0, theta=0.0
% INFO    : Bus 6063	: V=1.020236, theta=-17.246564 -> V=1.0, theta=0.0
% INFO    : Bus 6064	: V=1.082942, theta=16.343348 -> V=1.014054, theta=0.0
% INFO    : Bus 6065	: V=1.10196, theta=-24.275897 -> V=1.029685, theta=0.0
% INFO    : Bus 6066	: V=0.943281, theta=-24.86378 -> V=1.0, theta=0.0
% INFO    : Bus 6067	: V=1.037347, theta=-29.423816 -> V=1.0, theta=0.0
% INFO    : Bus 6068	: V=1.080564, theta=-33.35747 -> V=1.0377485, theta=0.0
% INFO    : Bus 6069	: V=1.08393, theta=-14.704322 -> V=1.02238, theta=0.0
% INFO    : Bus 6070	: V=1.099764, theta=-16.504415 -> V=1.028424, theta=0.0
% INFO    : Bus 6071	: V=1.039667, theta=-39.179092 -> V=1.0, theta=0.0
% INFO    : Bus 6072	: V=1.048484, theta=-20.418873 -> V=1.0025255, theta=0.0
% INFO    : Bus 6073	: V=0.989976, theta=-24.007308 -> V=1.0, theta=0.0
% INFO    : Bus 6074	: V=1.044687, theta=-36.46346 -> V=1.025456, theta=0.0
% INFO    : Bus 6075	: V=1.054196, theta=-18.35252 -> V=1.0043265, theta=0.0
% INFO    : Bus 6076	: V=1.03054, theta=-24.947004 -> V=1.0, theta=0.0
% INFO    : Bus 6077	: V=1.06171, theta=-7.190667 -> V=1.0098835, theta=0.0
% INFO    : Bus 6078	: V=1.002231, theta=-23.130116 -> V=1.0, theta=0.0
% INFO    : Bus 6079	: V=1.105368, theta=-8.714115 -> V=1.0238195, theta=0.0
% INFO    : Bus 6080	: V=1.036985, theta=-4.734042 -> V=1.0, theta=0.0
% INFO    : Bus 6081	: V=1.020382, theta=-23.331467 -> V=1.0, theta=0.0
% INFO    : Bus 6082	: V=0.978369, theta=-11.9913 -> V=1.0, theta=0.0
% INFO    : Bus 6083	: V=1.065299, theta=9.496505 -> V=1.0, theta=0.0
% INFO    : Bus 6084	: V=1.054613, theta=1.746885 -> V=1.0146945, theta=0.0
% INFO    : Bus 6085	: V=0.932706, theta=-28.535798 -> V=1.0, theta=0.0
% INFO    : Bus 6086	: V=1.091239, theta=-20.218299 -> V=1.028671, theta=0.0
% INFO    : Bus 6087	: V=0.960569, theta=-21.666921 -> V=1.0, theta=0.0
% INFO    : Bus 6088	: V=0.937567, theta=-28.026039 -> V=1.0, theta=0.0
% INFO    : Bus 6089	: V=1.037304, theta=-29.42381 -> V=1.0, theta=0.0
% INFO    : Bus 6090	: V=1.075197, theta=-0.680619 -> V=1.022116, theta=0.0
% INFO    : Bus 6091	: V=1.045409, theta=59.25741 -> V=1.0, theta=0.0
% INFO    : Bus 6092	: V=1.075828, theta=-3.806387 -> V=1.0178075, theta=0.0
% INFO    : Bus 6093	: V=1.043545, theta=-42.082383 -> V=1.0, theta=0.0
% INFO    : Bus 6094	: V=1.059143, theta=-18.845121 -> V=1.006832, theta=0.0
% INFO    : Bus 6095	: V=1.050581, theta=-13.061337 -> V=1.004131, theta=0.0
% INFO    : Bus 6096	: V=0.988761, theta=-29.661967 -> V=1.0, theta=0.0
% INFO    : Bus 6097	: V=0.975779, theta=-21.700551 -> V=1.0, theta=0.0
% INFO    : Bus 6098	: V=0.941107, theta=-31.117418 -> V=1.0, theta=0.0
% INFO    : Bus 6099	: V=1.059886, theta=-8.819501 -> V=1.010194, theta=0.0
% INFO    : Bus 6100	: V=1.072116, theta=16.080958 -> V=1.019929, theta=0.0
% INFO    : Bus 6101	: V=1.057279, theta=-42.230886 -> V=1.0139275, theta=0.0
% INFO    : Bus 6102	: V=0.951031, theta=-27.309906 -> V=1.0, theta=0.0
% INFO    : Bus 6103	: V=0.981805, theta=-25.683128 -> V=1.0, theta=0.0
% INFO    : Bus 6104	: V=1.078594, theta=-15.019484 -> V=1.021306, theta=0.0
% INFO    : Bus 6105	: V=1.078673, theta=-20.067238 -> V=1.020738, theta=0.0
% INFO    : Bus 6106	: V=1.049342, theta=-14.361741 -> V=1.0217105, theta=0.0
% INFO    : Bus 6107	: V=0.959147, theta=-20.264117 -> V=1.0, theta=0.0
% INFO    : Bus 6108	: V=1.087909, theta=-3.435881 -> V=1.0207365, theta=0.0
% INFO    : Bus 6109	: V=1.077344, theta=-1.394687 -> V=1.0139365, theta=0.0
% INFO    : Bus 6110	: V=1.079105, theta=-33.580962 -> V=1.0289355, theta=0.0
% INFO    : Bus 6111	: V=1.069231, theta=-9.742623 -> V=1.0182795, theta=0.0
% INFO    : Bus 6112	: V=1.026168, theta=-23.994746 -> V=1.019194, theta=0.0
% INFO    : Bus 6113	: V=1.057182, theta=-13.903916 -> V=1.0194965, theta=0.0
% INFO    : Bus 6114	: V=1.105619, theta=-13.114636 -> V=1.0415715, theta=0.0
% INFO    : Bus 6115	: V=1.07556, theta=-20.425849 -> V=1.027423, theta=0.0
% INFO    : Bus 6116	: V=1.10042, theta=-18.790943 -> V=1.0326905, theta=0.0
% INFO    : Bus 6117	: V=1.075038, theta=-9.508839 -> V=1.022639, theta=0.0
% INFO    : Bus 6118	: V=1.049914, theta=-35.838739 -> V=1.0, theta=0.0
% INFO    : Bus 6119	: V=1.063143, theta=1.007039 -> V=1.019222, theta=0.0
% INFO    : Bus 6120	: V=1.050952, theta=-31.314431 -> V=1.0188245, theta=0.0
% INFO    : Bus 6121	: V=1.051179, theta=-44.679871 -> V=1.00704, theta=0.0
% INFO    : Bus 6122	: V=1.048235, theta=-34.103675 -> V=1.0058045, theta=0.0
% INFO    : Bus 6123	: V=1.024163, theta=-15.493635 -> V=1.0, theta=0.0
% INFO    : Bus 6124	: V=1.070632, theta=33.324996 -> V=1.0, theta=0.0
% INFO    : Bus 6125	: V=1.085381, theta=-13.686767 -> V=1.0262825, theta=0.0
% INFO    : Bus 6126	: V=0.956632, theta=-29.130177 -> V=1.0, theta=0.0
% INFO    : Bus 6127	: V=1.060727, theta=-43.480472 -> V=1.005288, theta=0.0
% INFO    : Bus 6128	: V=1.051721, theta=-0.958968 -> V=1.0185, theta=0.0
% INFO    : Bus 6129	: V=1.035538, theta=-23.061156 -> V=1.0, theta=0.0
% INFO    : Bus 6130	: V=1.069992, theta=-15.035183 -> V=1.0108415, theta=0.0
% INFO    : Bus 6131	: V=1.076469, theta=-38.296951 -> V=1.0184235, theta=0.0
% INFO    : Bus 6132	: V=1.017453, theta=-19.982289 -> V=1.0036395, theta=0.0
% INFO    : Bus 6133	: V=1.041344, theta=-17.213487 -> V=1.0123615, theta=0.0
% INFO    : Bus 6134	: V=1.077093, theta=-22.997539 -> V=1.0309845, theta=0.0
% INFO    : Bus 6135	: V=0.988455, theta=-24.586053 -> V=1.0, theta=0.0
% INFO    : Bus 6136	: V=1.025855, theta=-23.24051 -> V=1.0, theta=0.0
% INFO    : Bus 6137	: V=1.051039, theta=9.645424 -> V=1.0057905, theta=0.0
% INFO    : Bus 6138	: V=0.959856, theta=-29.494059 -> V=0.993723, theta=0.0
% INFO    : Bus 6139	: V=1.068604, theta=-41.187665 -> V=1.016729, theta=0.0
% INFO    : Bus 6140	: V=1.027551, theta=-40.400441 -> V=1.0, theta=0.0
% INFO    : Bus 6141	: V=0.99894, theta=-22.299386 -> V=1.0, theta=0.0
% INFO    : Bus 6142	: V=1.068515, theta=-39.425881 -> V=1.007116, theta=0.0
% INFO    : Bus 6143	: V=1.076461, theta=-22.862519 -> V=1.0309665, theta=0.0
% INFO    : Bus 6144	: V=1.073824, theta=-23.07646 -> V=1.019452, theta=0.0
% INFO    : Bus 6145	: V=0.987472, theta=-25.207427 -> V=1.0, theta=0.0
% INFO    : Bus 6146	: V=1.057096, theta=-15.673053 -> V=1.0044475, theta=0.0
% INFO    : Bus 6147	: V=1.003628, theta=-29.120001 -> V=1.0, theta=0.0
% INFO    : Bus 6148	: V=1.083907, theta=-6.534223 -> V=1.0243925, theta=0.0
% INFO    : Bus 6149	: V=1.068079, theta=-34.685433 -> V=1.015396, theta=0.0
% INFO    : Bus 6150	: V=1.030141, theta=-25.359954 -> V=1.0, theta=0.0
% INFO    : Bus 6151	: V=1.077474, theta=-15.03894 -> V=1.011931, theta=0.0
% INFO    : Bus 6152	: V=1.054894, theta=-49.226841 -> V=1.0061985, theta=0.0
% INFO    : Bus 6153	: V=1.001384, theta=-18.125567 -> V=1.0, theta=0.0
% INFO    : Bus 6154	: V=1.092494, theta=-1.989532 -> V=1.0229275, theta=0.0
% INFO    : Bus 6155	: V=1.032778, theta=-15.915349 -> V=1.0, theta=0.0
% INFO    : Bus 6156	: V=1.031108, theta=-13.813238 -> V=1.003245, theta=0.0
% INFO    : Bus 6157	: V=0.980423, theta=-24.240767 -> V=1.0, theta=0.0
% INFO    : Bus 6158	: V=1.028981, theta=-24.438798 -> V=1.0, theta=0.0
% INFO    : Bus 6159	: V=1.098209, theta=-21.68584 -> V=1.0233535, theta=0.0
% INFO    : Bus 6160	: V=1.05749, theta=-24.073933 -> V=1.016084, theta=0.0
% INFO    : Bus 6161	: V=0.93588, theta=-25.880533 -> V=1.0, theta=0.0
% INFO    : Bus 6162	: V=1.092773, theta=-30.360135 -> V=1.0221785, theta=0.0
% INFO    : Bus 6163	: V=1.089613, theta=27.619926 -> V=1.0377705, theta=0.0
% INFO    : Bus 6164	: V=1.031019, theta=-44.81095 -> V=1.0, theta=0.0
% INFO    : Bus 6165	: V=1.06228, theta=-45.954433 -> V=1.0073675, theta=0.0
% INFO    : Bus 6166	: V=1.086974, theta=1.804658 -> V=1.017973, theta=0.0
% INFO    : Bus 6167	: V=0.988843, theta=-21.431804 -> V=1.0, theta=0.0
% INFO    : Bus 6168	: V=1.063195, theta=-11.384981 -> V=1.0125765, theta=0.0
% INFO    : Bus 6169	: V=0.961765, theta=-13.582751 -> V=1.0, theta=0.0
% INFO    : Bus 6170	: V=1.074043, theta=-6.617969 -> V=1.0200645, theta=0.0
% INFO    : Bus 6171	: V=1.02534, theta=-11.788186 -> V=1.0, theta=0.0
% INFO    : Bus 6172	: V=1.013522, theta=-27.244383 -> V=1.0, theta=0.0
% INFO    : Bus 6173	: V=0.986089, theta=-24.902563 -> V=1.0, theta=0.0
% INFO    : Bus 6174	: V=1.052874, theta=-20.338728 -> V=1.0110845, theta=0.0
% INFO    : Bus 6175	: V=1.072818, theta=-18.704207 -> V=1.0155255, theta=0.0
% INFO    : Bus 6176	: V=0.9765, theta=6.846003 -> V=1.0, theta=0.0
% INFO    : Bus 6177	: V=1.056814, theta=-35.770686 -> V=1.019319, theta=0.0
% INFO    : Bus 6178	: V=1.059937, theta=-35.375246 -> V=1.0208205, theta=0.0
% INFO    : Bus 6179	: V=1.079868, theta=46.300064 -> V=1.0, theta=0.0
% INFO    : Bus 6180	: V=1.057454, theta=-27.547532 -> V=1.013264, theta=0.0
% INFO    : Bus 6181	: V=1.048086, theta=-25.500506 -> V=1.0, theta=0.0
% INFO    : Bus 6182	: V=0.983494, theta=-17.071732 -> V=1.0, theta=0.0
% INFO    : Bus 6183	: V=1.075455, theta=-24.368691 -> V=1.018431, theta=0.0
% INFO    : Bus 6184	: V=1.062929, theta=-22.61292 -> V=1.0045025, theta=0.0
% INFO    : Bus 6185	: V=1.035265, theta=-23.333976 -> V=1.0060085, theta=0.0
% INFO    : Bus 6186	: V=0.987316, theta=-25.219959 -> V=1.0, theta=0.0
% INFO    : Bus 6187	: V=1.078273, theta=-6.286875 -> V=1.0184665, theta=0.0
% INFO    : Bus 6188	: V=1.093237, theta=-20.241901 -> V=1.0319475, theta=0.0
% INFO    : Bus 6189	: V=1.080237, theta=2.913046 -> V=1.025293, theta=0.0
% INFO    : Bus 6190	: V=1.063691, theta=-3.19073 -> V=1.0169375, theta=0.0
% INFO    : Bus 6191	: V=0.953481, theta=-18.655188 -> V=1.0, theta=0.0
% INFO    : Bus 6192	: V=1.081447, theta=-9.210569 -> V=1.016633, theta=0.0
% INFO    : Bus 6193	: V=0.918738, theta=-30.074142 -> V=1.0, theta=0.0
% INFO    : Bus 6194	: V=1.05393, theta=-13.405807 -> V=1.0122735, theta=0.0
% INFO    : Bus 6195	: V=0.923923, theta=33.397245 -> V=1.0, theta=0.0
% INFO    : Bus 6196	: V=0.995041, theta=9.043046 -> V=1.0, theta=0.0
% INFO    : Bus 6197	: V=1.058864, theta=-9.105654 -> V=1.009763, theta=0.0
% INFO    : Bus 6198	: V=1.041152, theta=25.766409 -> V=1.0155455, theta=0.0
% INFO    : Bus 6199	: V=1.013401, theta=-7.172885 -> V=1.0, theta=0.0
% INFO    : Bus 6200	: V=0.981372, theta=-24.251981 -> V=1.0, theta=0.0
% INFO    : Bus 6201	: V=1.029304, theta=13.664973 -> V=1.003369, theta=0.0
% INFO    : Bus 6202	: V=1.064999, theta=-43.928154 -> V=1.006916, theta=0.0
% INFO    : Bus 6203	: V=1.091573, theta=-7.368307 -> V=1.029979, theta=0.0
% INFO    : Bus 6204	: V=1.082267, theta=4.269472 -> V=1.024553, theta=0.0
% INFO    : Bus 6205	: V=1.040728, theta=62.167298 -> V=1.0, theta=0.0
% INFO    : Bus 6206	: V=1.05604, theta=-48.746295 -> V=1.007008, theta=0.0
% INFO    : Bus 6207	: V=1.080678, theta=-7.852401 -> V=1.0235165, theta=0.0
% INFO    : Bus 6208	: V=0.973091, theta=-23.833649 -> V=1.0, theta=0.0
% INFO    : Bus 6209	: V=1.046585, theta=-27.76032 -> V=1.0178025, theta=0.0
% INFO    : Bus 6210	: V=1.052455, theta=-10.823202 -> V=1.0169225, theta=0.0
% INFO    : Bus 6211	: V=1.078412, theta=-4.506437 -> V=1.016288, theta=0.0
% INFO    : Bus 6212	: V=1.036579, theta=3.883812 -> V=1.003571, theta=0.0
% INFO    : Bus 6213	: V=0.959606, theta=-22.494479 -> V=1.0, theta=0.0
% INFO    : Bus 6214	: V=0.980347, theta=-21.877488 -> V=1.0, theta=0.0
% INFO    : Bus 6215	: V=1.015, theta=-18.792091 -> V=1.0028255, theta=0.0
% INFO    : Bus 6216	: V=0.975061, theta=-24.159228 -> V=1.0, theta=0.0
% INFO    : Bus 6217	: V=1.095931, theta=-11.242293 -> V=1.0343025, theta=0.0
% INFO    : Bus 6218	: V=0.946027, theta=-27.486371 -> V=1.0, theta=0.0
% INFO    : Bus 6219	: V=1.045531, theta=-35.177286 -> V=1.0, theta=0.0
% INFO    : Bus 6220	: V=1.086447, theta=-8.592839 -> V=1.016174, theta=0.0
% INFO    : Bus 6221	: V=1.04497, theta=-20.907482 -> V=1.0, theta=0.0
% INFO    : Bus 6222	: V=1.010707, theta=-25.084076 -> V=1.0304195, theta=0.0
% INFO    : Bus 6223	: V=1.005096, theta=-18.336722 -> V=1.0, theta=0.0
% INFO    : Bus 6224	: V=1.058864, theta=6.987348 -> V=1.021109, theta=0.0
% INFO    : Bus 6225	: V=1.024096, theta=-25.846291 -> V=1.0, theta=0.0
% INFO    : Bus 6226	: V=1.060964, theta=-27.358247 -> V=1.011432, theta=0.0
% INFO    : Bus 6227	: V=1.054789, theta=24.887974 -> V=1.0079635, theta=0.0
% INFO    : Bus 6228	: V=1.029322, theta=-21.484523 -> V=1.0, theta=0.0
% INFO    : Bus 6229	: V=1.035599, theta=-31.299201 -> V=1.0, theta=0.0
% INFO    : Bus 6230	: V=1.054042, theta=-21.107295 -> V=1.028508, theta=0.0
% INFO    : Bus 6231	: V=1.05659, theta=-48.427341 -> V=1.005323, theta=0.0
% INFO    : Bus 6232	: V=1.045079, theta=66.081108 -> V=1.0, theta=0.0
% INFO    : Bus 6233	: V=1.065951, theta=-18.662121 -> V=1.0, theta=0.0
% INFO    : Bus 6234	: V=1.010953, theta=-22.101037 -> V=1.0, theta=0.0
% INFO    : Bus 6235	: V=0.994049, theta=-24.64024 -> V=1.0, theta=0.0
% INFO    : Bus 6236	: V=1.0875, theta=-13.992504 -> V=1.0401115, theta=0.0
% INFO    : Bus 6237	: V=1.026604, theta=-23.597996 -> V=1.0, theta=0.0
% INFO    : Bus 6238	: V=0.98638, theta=-34.264429 -> V=1.0, theta=0.0
% INFO    : Bus 6239	: V=1.093026, theta=-37.597184 -> V=1.020546, theta=0.0
% INFO    : Bus 6240	: V=0.970511, theta=-28.863462 -> V=1.0, theta=0.0
% INFO    : Bus 6241	: V=1.043894, theta=-41.480492 -> V=1.002889, theta=0.0
% INFO    : Bus 6242	: V=1.075884, theta=-4.451664 -> V=1.014719, theta=0.0
% INFO    : Bus 6243	: V=0.918147, theta=-29.40424 -> V=1.0, theta=0.0
% INFO    : Bus 6244	: V=1.051191, theta=-49.012108 -> V=1.0, theta=0.0
% INFO    : Bus 6245	: V=1.093723, theta=-36.345894 -> V=1.022868, theta=0.0
% INFO    : Bus 6246	: V=1.040622, theta=25.765263 -> V=1.015491, theta=0.0
% INFO    : Bus 6247	: V=0.983818, theta=-25.515252 -> V=1.0, theta=0.0
% INFO    : Bus 6248	: V=0.994148, theta=11.205777 -> V=1.0, theta=0.0
% INFO    : Bus 6249	: V=1.081589, theta=-2.852752 -> V=1.023212, theta=0.0
% INFO    : Bus 6250	: V=1.086045, theta=-12.355378 -> V=1.0196565, theta=0.0
% INFO    : Bus 6251	: V=1.081051, theta=0.960035 -> V=1.016066, theta=0.0
% INFO    : Bus 6252	: V=1.076, theta=-14.115553 -> V=1.0241, theta=0.0
% INFO    : Bus 6253	: V=1.098701, theta=-26.515796 -> V=1.028442, theta=0.0
% INFO    : Bus 6254	: V=1.092189, theta=55.845924 -> V=1.0068605, theta=0.0
% INFO    : Bus 6255	: V=1.063904, theta=-41.034613 -> V=1.0137785, theta=0.0
% INFO    : Bus 6256	: V=0.982119, theta=-28.764297 -> V=1.0, theta=0.0
% INFO    : Bus 6257	: V=1.071421, theta=-15.937999 -> V=1.0248935, theta=0.0
% INFO    : Bus 6258	: V=0.975228, theta=-27.287982 -> V=1.0, theta=0.0
% INFO    : Bus 6259	: V=1.014743, theta=-28.455318 -> V=1.0, theta=0.0
% INFO    : Bus 6260	: V=1.100105, theta=48.797681 -> V=1.0075495, theta=0.0
% INFO    : Bus 6261	: V=1.000005, theta=-31.20713 -> V=1.010941, theta=0.0
% INFO    : Bus 6262	: V=1.063401, theta=0.831232 -> V=1.019755, theta=0.0
% INFO    : Bus 6263	: V=1.069651, theta=-50.753656 -> V=1.0, theta=0.0
% INFO    : Bus 6264	: V=0.998941, theta=-27.323126 -> V=1.0, theta=0.0
% INFO    : Bus 6265	: V=1.042609, theta=12.84083 -> V=1.003168, theta=0.0
% INFO    : Bus 6266	: V=1.088264, theta=-32.758278 -> V=1.017925, theta=0.0
% INFO    : Bus 6267	: V=1.035769, theta=-39.464583 -> V=1.0226795, theta=0.0
% INFO    : Bus 6268	: V=1.061237, theta=-22.100636 -> V=1.019429, theta=0.0
% INFO    : Bus 6269	: V=1.052026, theta=-35.416196 -> V=1.0089025, theta=0.0
% INFO    : Bus 6270	: V=1.001862, theta=-35.322511 -> V=1.0, theta=0.0
% INFO    : Bus 6271	: V=1.009874, theta=-22.688716 -> V=1.0, theta=0.0
% INFO    : Bus 6272	: V=0.945991, theta=-31.812812 -> V=1.0, theta=0.0
% INFO    : Bus 6273	: V=1.096447, theta=55.364659 -> V=1.003164, theta=0.0
% INFO    : Bus 6274	: V=1.043106, theta=9.307185 -> V=1.011887, theta=0.0
% INFO    : Bus 6275	: V=1.040833, theta=-19.936292 -> V=1.0102015, theta=0.0
% INFO    : Bus 6276	: V=1.101371, theta=-38.529556 -> V=1.0267255, theta=0.0
% INFO    : Bus 6277	: V=0.954492, theta=-23.37845 -> V=1.0, theta=0.0
% INFO    : Bus 6278	: V=0.971366, theta=-22.740743 -> V=1.0, theta=0.0
% INFO    : Bus 6279	: V=1.050657, theta=-1.399408 -> V=1.0182365, theta=0.0
% INFO    : Bus 6280	: V=1.055623, theta=-8.074091 -> V=1.0084045, theta=0.0
% INFO    : Bus 6281	: V=1.07276, theta=10.330624 -> V=1.0256965, theta=0.0
% INFO    : Bus 6282	: V=1.0475, theta=-31.568458 -> V=1.0, theta=0.0
% INFO    : Bus 6283	: V=1.039853, theta=-29.777016 -> V=1.0, theta=0.0
% INFO    : Bus 6284	: V=1.035432, theta=-11.883466 -> V=1.0, theta=0.0
% INFO    : Bus 6285	: V=0.994648, theta=-23.35805 -> V=1.0, theta=0.0
% INFO    : Bus 6286	: V=1.076684, theta=-12.404791 -> V=1.020528, theta=0.0
% INFO    : Bus 6287	: V=1.055493, theta=-48.713966 -> V=1.006015, theta=0.0
% INFO    : Bus 6288	: V=1.049103, theta=-21.285338 -> V=1.0050045, theta=0.0
% INFO    : Bus 6289	: V=1.058267, theta=63.062459 -> V=1.0, theta=0.0
% INFO    : Bus 6290	: V=0.987205, theta=-17.426307 -> V=1.0, theta=0.0
% INFO    : Bus 6291	: V=1.032044, theta=-35.062416 -> V=1.0, theta=0.0
% INFO    : Bus 6292	: V=1.084727, theta=-6.293475 -> V=1.013943, theta=0.0
% INFO    : Bus 6293	: V=1.04701, theta=-29.321258 -> V=1.005665, theta=0.0
% INFO    : Bus 6294	: V=1.067822, theta=-34.734715 -> V=1.0148525, theta=0.0
% INFO    : Bus 6295	: V=1.069514, theta=-26.567806 -> V=1.033418, theta=0.0
% INFO    : Bus 6296	: V=1.007633, theta=-19.412386 -> V=1.0, theta=0.0
% INFO    : Bus 6297	: V=1.007693, theta=-22.365392 -> V=1.0, theta=0.0
% INFO    : Bus 6298	: V=1.01936, theta=-22.34446 -> V=1.0, theta=0.0
% INFO    : Bus 6299	: V=1.05217, theta=56.873664 -> V=1.0, theta=0.0
% INFO    : Bus 6300	: V=1.0795, theta=-3.758793 -> V=1.0162935, theta=0.0
% INFO    : Bus 6301	: V=1.010227, theta=13.127002 -> V=1.0, theta=0.0
% INFO    : Bus 6302	: V=1.051972, theta=-49.131983 -> V=1.005574, theta=0.0
% INFO    : Bus 6303	: V=1.059317, theta=-24.461569 -> V=1.030258, theta=0.0
% INFO    : Bus 6304	: V=1.045134, theta=-45.684949 -> V=1.0, theta=0.0
% INFO    : Bus 6305	: V=1.069232, theta=-19.083733 -> V=1.018604, theta=0.0
% INFO    : Bus 6306	: V=1.017703, theta=-18.376038 -> V=1.0, theta=0.0
% INFO    : Bus 6307	: V=1.071593, theta=26.944148 -> V=1.0, theta=0.0
% INFO    : Bus 6308	: V=1.016274, theta=-26.865265 -> V=1.0423845, theta=0.0
% INFO    : Bus 6309	: V=1.060401, theta=-35.397056 -> V=1.020803, theta=0.0
% INFO    : Bus 6310	: V=1.076564, theta=-13.516974 -> V=1.0151, theta=0.0
% INFO    : Bus 6311	: V=1.032366, theta=-51.30807 -> V=1.0, theta=0.0
% INFO    : Bus 6312	: V=1.074754, theta=0.052937 -> V=1.0224155, theta=0.0
% INFO    : Bus 6313	: V=1.084948, theta=-21.280627 -> V=1.0068395, theta=0.0
% INFO    : Bus 6314	: V=1.082516, theta=-16.246016 -> V=1.032393, theta=0.0
% INFO    : Bus 6315	: V=1.035614, theta=-41.0876 -> V=1.0, theta=0.0
% INFO    : Bus 6316	: V=1.027718, theta=9.28457 -> V=1.0, theta=0.0
% INFO    : Bus 6317	: V=1.047273, theta=-18.139366 -> V=1.0092705, theta=0.0
% INFO    : Bus 6318	: V=1.072264, theta=-23.048182 -> V=1.0, theta=0.0
% INFO    : Bus 6319	: V=1.086045, theta=-23.492834 -> V=1.021865, theta=0.0
% INFO    : Bus 6320	: V=1.081234, theta=-42.537364 -> V=1.0169805, theta=0.0
% INFO    : Bus 6321	: V=1.03074, theta=-12.507289 -> V=1.0116275, theta=0.0
% INFO    : Bus 6322	: V=1.085918, theta=-4.552233 -> V=1.0232815, theta=0.0
% INFO    : Bus 6323	: V=1.015854, theta=9.200173 -> V=1.0, theta=0.0
% INFO    : Bus 6324	: V=0.987718, theta=-16.757718 -> V=1.0, theta=0.0
% INFO    : Bus 6325	: V=0.993291, theta=-22.846945 -> V=1.0, theta=0.0
% INFO    : Bus 6326	: V=0.956692, theta=-29.273887 -> V=0.9956255, theta=0.0
% INFO    : Bus 6327	: V=1.054602, theta=-0.478484 -> V=1.006242, theta=0.0
% INFO    : Bus 6328	: V=1.04282, theta=59.90484 -> V=1.014405, theta=0.0
% INFO    : Bus 6329	: V=1.007794, theta=7.207557 -> V=1.0, theta=0.0
% INFO    : Bus 6330	: V=1.053818, theta=-20.475751 -> V=1.0193695, theta=0.0
% INFO    : Bus 6331	: V=1.016608, theta=14.370089 -> V=1.0, theta=0.0
% INFO    : Bus 6332	: V=0.942169, theta=-33.245566 -> V=0.9611, theta=0.0
% INFO    : Bus 6333	: V=1.056467, theta=-49.256756 -> V=1.0070795, theta=0.0
% INFO    : Bus 6334	: V=1.01197, theta=54.192839 -> V=1.0, theta=0.0
% INFO    : Bus 6335	: V=1.073208, theta=2.290341 -> V=1.021769, theta=0.0
% INFO    : Bus 6336	: V=0.954112, theta=-27.589869 -> V=1.0, theta=0.0
% INFO    : Bus 6337	: V=1.077312, theta=-22.776803 -> V=1.0313615, theta=0.0
% INFO    : Bus 6338	: V=1.059879, theta=-22.960138 -> V=1.0169235, theta=0.0
% INFO    : Bus 6339	: V=0.99434, theta=-24.147533 -> V=1.0, theta=0.0
% INFO    : Bus 6340	: V=1.039552, theta=-35.759806 -> V=1.0, theta=0.0
% INFO    : Bus 6341	: V=1.084474, theta=35.430297 -> V=1.006033, theta=0.0
% INFO    : Bus 6342	: V=1.060278, theta=-37.225419 -> V=1.0044185, theta=0.0
% INFO    : Bus 6343	: V=1.011983, theta=3.688734 -> V=1.0, theta=0.0
% INFO    : Bus 6344	: V=1.054314, theta=-15.855879 -> V=1.0036225, theta=0.0
% INFO    : Bus 6345	: V=1.009557, theta=-6.776649 -> V=1.0, theta=0.0
% INFO    : Bus 6346	: V=1.060377, theta=7.03155 -> V=1.006021, theta=0.0
% INFO    : Bus 6347	: V=1.101579, theta=-10.395554 -> V=1.014909, theta=0.0
% INFO    : Bus 6348	: V=1.025834, theta=-16.804169 -> V=1.013839, theta=0.0
% INFO    : Bus 6349	: V=1.017672, theta=-18.376018 -> V=1.0, theta=0.0
% INFO    : Bus 6350	: V=1.028204, theta=-38.133456 -> V=1.0, theta=0.0
% INFO    : Bus 6351	: V=1.036493, theta=-11.89682 -> V=1.0, theta=0.0
% INFO    : Bus 6352	: V=1.082724, theta=16.347499 -> V=1.013807, theta=0.0
% INFO    : Bus 6353	: V=1.058359, theta=-27.618851 -> V=1.014584, theta=0.0
% INFO    : Bus 6354	: V=0.952939, theta=54.709651 -> V=1.0, theta=0.0
% INFO    : Bus 6355	: V=1.004515, theta=-24.876005 -> V=1.0, theta=0.0
% INFO    : Bus 6356	: V=1.073182, theta=-25.360554 -> V=1.0071315, theta=0.0
% INFO    : Bus 6357	: V=1.027663, theta=-23.877185 -> V=1.0, theta=0.0
% INFO    : Bus 6358	: V=1.041863, theta=4.586964 -> V=1.004123, theta=0.0
% INFO    : Bus 6359	: V=1.054549, theta=-18.221883 -> V=1.004497, theta=0.0
% INFO    : Bus 6360	: V=1.081878, theta=-3.594659 -> V=1.0176635, theta=0.0
% INFO    : Bus 6361	: V=1.053194, theta=-18.336218 -> V=1.0040935, theta=0.0
% INFO    : Bus 6362	: V=1.053794, theta=-36.464733 -> V=1.0177255, theta=0.0
% INFO    : Bus 6363	: V=1.068978, theta=-12.883753 -> V=1.0147485, theta=0.0
% INFO    : Bus 6364	: V=1.067604, theta=9.787942 -> V=1.0, theta=0.0
% INFO    : Bus 6365	: V=1.053173, theta=-24.65335 -> V=1.0139865, theta=0.0
% INFO    : Bus 6366	: V=0.996651, theta=-27.472636 -> V=1.0, theta=0.0
% INFO    : Bus 6367	: V=1.052226, theta=-16.169514 -> V=1.010816, theta=0.0
% INFO    : Bus 6368	: V=1.048236, theta=-19.459921 -> V=1.004962, theta=0.0
% INFO    : Bus 6369	: V=1.029908, theta=-24.505692 -> V=1.0, theta=0.0
% INFO    : Bus 6370	: V=1.032639, theta=-24.956846 -> V=1.0, theta=0.0
% INFO    : Bus 6371	: V=0.999818, theta=9.906003 -> V=1.0, theta=0.0
% INFO    : Bus 6372	: V=1.078864, theta=-15.523704 -> V=1.0101625, theta=0.0
% INFO    : Bus 6373	: V=1.030868, theta=15.99602 -> V=1.0, theta=0.0
% INFO    : Bus 6374	: V=1.091553, theta=-33.351982 -> V=1.0253705, theta=0.0
% INFO    : Bus 6375	: V=1.073322, theta=-7.553 -> V=1.0217875, theta=0.0
% INFO    : Bus 6376	: V=1.056617, theta=-32.522846 -> V=1.010047, theta=0.0
% INFO    : Bus 6377	: V=1.044091, theta=-14.586824 -> V=1.008234, theta=0.0
% INFO    : Bus 6378	: V=1.026456, theta=-23.784051 -> V=1.0, theta=0.0
% INFO    : Bus 6379	: V=1.068128, theta=24.8825 -> V=1.006974, theta=0.0
% INFO    : Bus 6380	: V=1.072864, theta=-11.677848 -> V=1.0162995, theta=0.0
% INFO    : Bus 6381	: V=1.032512, theta=-50.871762 -> V=1.0, theta=0.0
% INFO    : Bus 6382	: V=0.982894, theta=-29.717833 -> V=1.0, theta=0.0
% INFO    : Bus 6383	: V=1.075675, theta=-10.068429 -> V=1.019687, theta=0.0
% INFO    : Bus 6384	: V=1.0041, theta=-24.176487 -> V=1.0, theta=0.0
% INFO    : Bus 6385	: V=1.033556, theta=-37.877381 -> V=1.0, theta=0.0
% INFO    : Bus 6386	: V=1.019, theta=-32.16571 -> V=1.0, theta=0.0
% INFO    : Bus 6387	: V=1.038819, theta=-10.276338 -> V=1.0, theta=0.0
% INFO    : Bus 6388	: V=1.072805, theta=-31.841984 -> V=1.0164715, theta=0.0
% INFO    : Bus 6389	: V=1.027257, theta=-15.260431 -> V=1.0, theta=0.0
% INFO    : Bus 6390	: V=1.039017, theta=-21.371631 -> V=1.0077495, theta=0.0
% INFO    : Bus 6391	: V=1.074284, theta=-20.797503 -> V=1.026908, theta=0.0
% INFO    : Bus 6392	: V=1.004928, theta=-19.836462 -> V=1.0, theta=0.0
% INFO    : Bus 6393	: V=1.055409, theta=-13.537061 -> V=1.0047385, theta=0.0
% INFO    : Bus 6394	: V=1.07828, theta=-20.216472 -> V=1.020581, theta=0.0
% INFO    : Bus 6395	: V=1.054461, theta=-2.935294 -> V=1.0046005, theta=0.0
% INFO    : Bus 6396	: V=1.049001, theta=-11.740495 -> V=1.0, theta=0.0
% INFO    : Bus 6397	: V=1.089432, theta=-37.120585 -> V=1.0235405, theta=0.0
% INFO    : Bus 6398	: V=1.029894, theta=-23.578135 -> V=1.0, theta=0.0
% INFO    : Bus 6399	: V=1.049259, theta=-12.552286 -> V=1.0070675, theta=0.0
% INFO    : Bus 6400	: V=1.052421, theta=-4.774741 -> V=1.008367, theta=0.0
% INFO    : Bus 6401	: V=1.03057, theta=-24.302841 -> V=1.0, theta=0.0
% INFO    : Bus 6402	: V=1.014636, theta=-25.16249 -> V=1.0051975, theta=0.0
% INFO    : Bus 6403	: V=1.065955, theta=7.709858 -> V=1.007495, theta=0.0
% INFO    : Bus 6404	: V=1.03535, theta=-11.369884 -> V=1.0, theta=0.0
% INFO    : Bus 6405	: V=1.068174, theta=-18.299794 -> V=1.0, theta=0.0
% INFO    : Bus 6406	: V=1.102368, theta=-13.737786 -> V=1.023741, theta=0.0
% INFO    : Bus 6407	: V=1.03317, theta=-42.812728 -> V=1.0, theta=0.0
% INFO    : Bus 6408	: V=1.037545, theta=-17.653059 -> V=1.0, theta=0.0
% INFO    : Bus 6409	: V=1.085382, theta=-39.425543 -> V=1.028062, theta=0.0
% INFO    : Bus 6410	: V=0.950601, theta=-26.897435 -> V=1.0, theta=0.0
% INFO    : Bus 6411	: V=1.023958, theta=-18.178164 -> V=1.008782, theta=0.0
% INFO    : Bus 6412	: V=1.043125, theta=-7.630374 -> V=1.016112, theta=0.0
% INFO    : Bus 6413	: V=1.046649, theta=-13.060636 -> V=1.016106, theta=0.0
% INFO    : Bus 6414	: V=1.045005, theta=-34.389209 -> V=1.0038645, theta=0.0
% INFO    : Bus 6415	: V=1.031993, theta=-31.371938 -> V=1.0, theta=0.0
% INFO    : Bus 6416	: V=1.082159, theta=6.989116 -> V=1.024586, theta=0.0
% INFO    : Bus 6417	: V=0.978165, theta=-24.260489 -> V=1.0, theta=0.0
% INFO    : Bus 6418	: V=1.0245, theta=-38.932567 -> V=1.0, theta=0.0
% INFO    : Bus 6419	: V=1.03884, theta=-12.57322 -> V=1.0047295, theta=0.0
% INFO    : Bus 6420	: V=1.030835, theta=-22.917884 -> V=1.0, theta=0.0
% INFO    : Bus 6421	: V=0.981876, theta=-23.418564 -> V=1.0, theta=0.0
% INFO    : Bus 6422	: V=1.079519, theta=-47.003717 -> V=1.0181955, theta=0.0
% INFO    : Bus 6423	: V=1.039782, theta=-15.690408 -> V=1.0, theta=0.0
% INFO    : Bus 6424	: V=1.088338, theta=-33.115167 -> V=1.0192865, theta=0.0
% INFO    : Bus 6425	: V=1.074205, theta=-6.195953 -> V=1.012498, theta=0.0
% INFO    : Bus 6426	: V=1.036591, theta=11.960313 -> V=1.0, theta=0.0
% INFO    : Bus 6427	: V=0.933849, theta=-34.308822 -> V=1.0, theta=0.0
% INFO    : Bus 6428	: V=1.017845, theta=-19.970386 -> V=1.0038125, theta=0.0
% INFO    : Bus 6429	: V=1.040675, theta=-25.193133 -> V=1.0, theta=0.0
% INFO    : Bus 6430	: V=1.058342, theta=12.596166 -> V=1.019365, theta=0.0
% INFO    : Bus 6431	: V=1.095332, theta=9.125398 -> V=1.0247925, theta=0.0
% INFO    : Bus 6432	: V=0.999681, theta=-21.93368 -> V=1.0, theta=0.0
% INFO    : Bus 6433	: V=1.058674, theta=-23.947784 -> V=1.016634, theta=0.0
% INFO    : Bus 6434	: V=1.094605, theta=36.287029 -> V=1.014825, theta=0.0
% INFO    : Bus 6435	: V=1.009268, theta=-22.948292 -> V=1.0, theta=0.0
% INFO    : Bus 6436	: V=1.096434, theta=-36.625065 -> V=1.031223, theta=0.0
% INFO    : Bus 6437	: V=1.014339, theta=8.381863 -> V=1.0, theta=0.0
% INFO    : Bus 6438	: V=1.085954, theta=-3.230672 -> V=1.023608, theta=0.0
% INFO    : Bus 6439	: V=1.024153, theta=37.846255 -> V=1.0, theta=0.0
% INFO    : Bus 6440	: V=0.971835, theta=-27.334067 -> V=1.0, theta=0.0
% INFO    : Bus 6441	: V=1.044719, theta=-21.786113 -> V=1.022524, theta=0.0
% INFO    : Bus 6442	: V=1.068341, theta=2.568749 -> V=1.0169635, theta=0.0
% INFO    : Bus 6443	: V=1.053328, theta=-26.347794 -> V=1.007975, theta=0.0
% INFO    : Bus 6444	: V=1.02, theta=-25.041055 -> V=1.0, theta=0.0
% INFO    : Bus 6445	: V=1.086052, theta=-26.949954 -> V=1.024967, theta=0.0
% INFO    : Bus 6446	: V=1.035446, theta=-20.101947 -> V=1.0073745, theta=0.0
% INFO    : Bus 6447	: V=1.007727, theta=-4.671612 -> V=1.0, theta=0.0
% INFO    : Bus 6448	: V=1.043512, theta=-39.423441 -> V=1.0054645, theta=0.0
% INFO    : Bus 6449	: V=0.963277, theta=-13.510739 -> V=1.0, theta=0.0
% INFO    : Bus 6450	: V=1.067629, theta=-37.496046 -> V=1.011105, theta=0.0
% INFO    : Bus 6451	: V=1.070271, theta=-34.585119 -> V=1.011455, theta=0.0
% INFO    : Bus 6452	: V=1.062041, theta=-20.988119 -> V=1.009956, theta=0.0
% INFO    : Bus 6453	: V=1.077368, theta=5.472904 -> V=1.0038115, theta=0.0
% INFO    : Bus 6454	: V=1.074864, theta=-18.40872 -> V=1.0162945, theta=0.0
% INFO    : Bus 6455	: V=1.031799, theta=2.599251 -> V=1.0, theta=0.0
% INFO    : Bus 6456	: V=1.061211, theta=21.183032 -> V=1.0064605, theta=0.0
% INFO    : Bus 6457	: V=1.084207, theta=-15.954934 -> V=1.0216285, theta=0.0
% INFO    : Bus 6458	: V=1.059528, theta=-15.386704 -> V=1.0142455, theta=0.0
% INFO    : Bus 6459	: V=1.07519, theta=-9.143774 -> V=1.0274325, theta=0.0
% INFO    : Bus 6460	: V=1.038743, theta=-21.34799 -> V=1.0222615, theta=0.0
% INFO    : Bus 6461	: V=1.095636, theta=-13.769323 -> V=1.0322195, theta=0.0
% INFO    : Bus 6462	: V=1.056409, theta=-35.931589 -> V=1.0189975, theta=0.0
% INFO    : Bus 6463	: V=1.078627, theta=-26.350347 -> V=1.043361, theta=0.0
% INFO    : Bus 6464	: V=1.007849, theta=12.817054 -> V=1.0, theta=0.0
% INFO    : Bus 6465	: V=0.963904, theta=-19.825086 -> V=1.0, theta=0.0
% INFO    : Bus 6466	: V=1.023852, theta=-16.403982 -> V=1.0, theta=0.0
% INFO    : Bus 6467	: V=1.081662, theta=-3.825748 -> V=1.021343, theta=0.0
% INFO    : Bus 6468	: V=1.023463, theta=-19.578524 -> V=1.0061105, theta=0.0
% INFO    : Bus 6469	: V=1.072578, theta=-19.095663 -> V=1.007529, theta=0.0
% INFO    : Bus 6470	: V=1.06056, theta=-14.373026 -> V=1.0084555, theta=0.0
% INFO    : Bus 6471	: V=1.081051, theta=-12.900996 -> V=1.0175645, theta=0.0
% INFO    : Bus 6472	: V=1.076419, theta=-9.823569 -> V=1.0200305, theta=0.0
% INFO    : Bus 6473	: V=1.040873, theta=4.455223 -> V=1.0046185, theta=0.0
% INFO    : Bus 6474	: V=1.087026, theta=-41.330686 -> V=1.017023, theta=0.0
% INFO    : Bus 6475	: V=1.067445, theta=-2.877794 -> V=1.018758, theta=0.0
% INFO    : Bus 6476	: V=1.052837, theta=-49.088959 -> V=1.005152, theta=0.0
% INFO    : Bus 6477	: V=1.002192, theta=-22.473139 -> V=1.0, theta=0.0
% INFO    : Bus 6478	: V=0.958677, theta=-24.853407 -> V=1.0, theta=0.0
% INFO    : Bus 6479	: V=0.984963, theta=-25.556308 -> V=1.0, theta=0.0
% INFO    : Bus 6480	: V=1.039663, theta=-12.953042 -> V=1.006325, theta=0.0
% INFO    : Bus 6481	: V=1.061896, theta=-52.852314 -> V=1.0, theta=0.0
% INFO    : Bus 6482	: V=1.041091, theta=25.762276 -> V=1.0155805, theta=0.0
% INFO    : Bus 6483	: V=1.080008, theta=-22.122891 -> V=1.0326935, theta=0.0
% INFO    : Bus 6484	: V=1.060706, theta=-13.125439 -> V=1.006535, theta=0.0
% INFO    : Bus 6485	: V=1.073863, theta=-19.463842 -> V=1.008131, theta=0.0
% INFO    : Bus 6486	: V=0.949534, theta=-24.621387 -> V=1.0, theta=0.0
% INFO    : Bus 6487	: V=1.072216, theta=-24.991216 -> V=1.0173435, theta=0.0
% INFO    : Bus 6488	: V=1.075, theta=-23.26968 -> V=1.020159, theta=0.0
% INFO    : Bus 6489	: V=1.068403, theta=-1.424278 -> V=1.0187305, theta=0.0
% INFO    : Bus 6490	: V=0.955879, theta=-26.369848 -> V=1.0, theta=0.0
% INFO    : Bus 6491	: V=1.082583, theta=6.947018 -> V=1.024967, theta=0.0
% INFO    : Bus 6492	: V=1.082711, theta=4.406445 -> V=1.026022, theta=0.0
% INFO    : Bus 6493	: V=1.06449, theta=4.604321 -> V=1.006292, theta=0.0
% INFO    : Bus 6494	: V=0.993031, theta=11.180845 -> V=1.0, theta=0.0
% INFO    : Bus 6495	: V=1.046813, theta=-13.063111 -> V=1.0161935, theta=0.0
% INFO    : Bus 6496	: V=1.060405, theta=-23.719799 -> V=1.017281, theta=0.0
% INFO    : Bus 6497	: V=1.052168, theta=-21.951725 -> V=1.013731, theta=0.0
% INFO    : Bus 6498	: V=1.070943, theta=-33.530036 -> V=1.037098, theta=0.0
% INFO    : Bus 6499	: V=0.963182, theta=-22.295935 -> V=1.0, theta=0.0
% INFO    : Bus 6500	: V=1.051773, theta=-34.95763 -> V=1.015517, theta=0.0
% INFO    : Bus 6501	: V=1.031383, theta=-16.111646 -> V=1.0, theta=0.0
% INFO    : Bus 6502	: V=1.104553, theta=43.071515 -> V=1.009295, theta=0.0
% INFO    : Bus 6503	: V=1.084483, theta=-5.902296 -> V=1.025944, theta=0.0
% INFO    : Bus 6504	: V=1.070617, theta=-18.153815 -> V=1.0, theta=0.0
% INFO    : Bus 6505	: V=1.026574, theta=-23.570041 -> V=1.0, theta=0.0
% INFO    : Bus 6506	: V=1.042571, theta=3.016788 -> V=1.0170125, theta=0.0
% INFO    : Bus 6507	: V=1.067886, theta=24.236579 -> V=1.0081715, theta=0.0
% INFO    : Bus 6508	: V=1.041318, theta=-30.682819 -> V=1.003448, theta=0.0
% INFO    : Bus 6509	: V=0.970543, theta=-33.427373 -> V=1.0, theta=0.0
% INFO    : Bus 6510	: V=1.062878, theta=-13.937703 -> V=1.0151485, theta=0.0
% INFO    : Bus 6511	: V=1.012958, theta=-7.260364 -> V=1.0, theta=0.0
% INFO    : Bus 6512	: V=1.053969, theta=-20.664877 -> V=1.0077475, theta=0.0
% INFO    : Bus 6513	: V=1.042657, theta=-40.385792 -> V=1.004938, theta=0.0
% INFO    : Bus 6514	: V=1.101368, theta=-6.115232 -> V=1.0436935, theta=0.0
% INFO    : Bus 6515	: V=1.004132, theta=-21.313701 -> V=1.0, theta=0.0
% INFO    : Bus 6516	: V=0.967222, theta=-19.816326 -> V=1.0, theta=0.0
% INFO    : Bus 6517	: V=0.986616, theta=-36.455833 -> V=1.0, theta=0.0
% INFO    : Bus 6518	: V=1.064958, theta=-14.763438 -> V=1.0146615, theta=0.0
% INFO    : Bus 6519	: V=0.986643, theta=-24.276248 -> V=1.0, theta=0.0
% INFO    : Bus 6520	: V=1.065181, theta=-43.894138 -> V=1.007076, theta=0.0
% INFO    : Bus 6521	: V=1.050826, theta=-20.668445 -> V=1.0, theta=0.0
% INFO    : Bus 6522	: V=1.038628, theta=-42.632862 -> V=1.0, theta=0.0
% INFO    : Bus 6523	: V=0.967657, theta=53.590673 -> V=1.0, theta=0.0
% INFO    : Bus 6524	: V=1.063702, theta=0.930173 -> V=1.012962, theta=0.0
% INFO    : Bus 6525	: V=1.04923, theta=-49.917687 -> V=1.005977, theta=0.0
% INFO    : Bus 6526	: V=1.064053, theta=-41.124704 -> V=1.01732, theta=0.0
% INFO    : Bus 6527	: V=1.031448, theta=-2.293725 -> V=1.004693, theta=0.0
% INFO    : Bus 6528	: V=0.994536, theta=-22.619568 -> V=1.0, theta=0.0
% INFO    : Bus 6529	: V=0.983636, theta=-24.837459 -> V=1.0, theta=0.0
% INFO    : Bus 6530	: V=0.962399, theta=-21.030095 -> V=1.0, theta=0.0
% INFO    : Bus 6531	: V=1.078501, theta=-3.935434 -> V=1.015821, theta=0.0
% INFO    : Bus 6532	: V=1.04643, theta=-21.671367 -> V=1.003301, theta=0.0
% INFO    : Bus 6533	: V=1.02852, theta=-20.106955 -> V=1.007503, theta=0.0
% INFO    : Bus 6534	: V=0.97477, theta=-24.706521 -> V=1.0, theta=0.0
% INFO    : Bus 6535	: V=1.094263, theta=36.299529 -> V=1.0147585, theta=0.0
% INFO    : Bus 6536	: V=0.908812, theta=-31.131009 -> V=1.0, theta=0.0
% INFO    : Bus 6537	: V=1.080091, theta=-6.180893 -> V=1.0192955, theta=0.0
% INFO    : Bus 6538	: V=1.036157, theta=-30.28049 -> V=1.0, theta=0.0
% INFO    : Bus 6539	: V=0.994179, theta=-16.827128 -> V=1.0, theta=0.0
% INFO    : Bus 6540	: V=1.062947, theta=-42.049394 -> V=1.0141875, theta=0.0
% INFO    : Bus 6541	: V=1.092711, theta=9.587763 -> V=1.013369, theta=0.0
% INFO    : Bus 6542	: V=1.038222, theta=-10.209517 -> V=1.0, theta=0.0
% INFO    : Bus 6543	: V=0.923128, theta=-30.310974 -> V=1.0, theta=0.0
% INFO    : Bus 6544	: V=1.053254, theta=-8.06051 -> V=1.0096535, theta=0.0
% INFO    : Bus 6545	: V=1.054514, theta=-20.632637 -> V=1.0, theta=0.0
% INFO    : Bus 6546	: V=1.037175, theta=-2.80582 -> V=1.0037975, theta=0.0
% INFO    : Bus 6547	: V=0.910729, theta=-29.454934 -> V=1.0, theta=0.0
% INFO    : Bus 6548	: V=1.078039, theta=-23.194243 -> V=1.0335065, theta=0.0
% INFO    : Bus 6549	: V=1.002627, theta=-23.356594 -> V=1.0, theta=0.0
% INFO    : Bus 6550	: V=1.030528, theta=-18.705006 -> V=1.0, theta=0.0
% INFO    : Bus 6551	: V=1.047565, theta=-15.409626 -> V=1.010265, theta=0.0
% INFO    : Bus 6552	: V=1.103895, theta=-12.562017 -> V=1.042424, theta=0.0
% INFO    : Bus 6553	: V=1.030312, theta=-24.549974 -> V=1.0, theta=0.0
% INFO    : Bus 6554	: V=1.065416, theta=9.498234 -> V=1.0, theta=0.0
% INFO    : Bus 6555	: V=1.044682, theta=-11.480405 -> V=1.008477, theta=0.0
% INFO    : Bus 6556	: V=0.988346, theta=-27.616885 -> V=1.0, theta=0.0
% INFO    : Bus 6557	: V=1.041547, theta=-24.708334 -> V=1.0, theta=0.0
% INFO    : Bus 6558	: V=1.044996, theta=-39.746904 -> V=1.0059465, theta=0.0
% INFO    : Bus 6559	: V=1.058036, theta=33.159322 -> V=1.0, theta=0.0
% INFO    : Bus 6560	: V=0.982156, theta=-39.812704 -> V=1.0, theta=0.0
% INFO    : Bus 6561	: V=1.024611, theta=-23.90432 -> V=1.0, theta=0.0
% INFO    : Bus 6562	: V=1.056532, theta=-27.332784 -> V=1.0, theta=0.0
% INFO    : Bus 6563	: V=1.052224, theta=56.873514 -> V=1.0, theta=0.0
% INFO    : Bus 6564	: V=0.955782, theta=-34.938343 -> V=1.0, theta=0.0
% INFO    : Bus 6565	: V=1.030216, theta=-23.049638 -> V=1.0, theta=0.0
% INFO    : Bus 6566	: V=0.969928, theta=-28.747934 -> V=1.0, theta=0.0
% INFO    : Bus 6567	: V=0.998103, theta=10.514609 -> V=1.0, theta=0.0
% INFO    : Bus 6568	: V=1.018562, theta=-21.540622 -> V=1.0, theta=0.0
% INFO    : Bus 6569	: V=1.04175, theta=-21.833152 -> V=1.0, theta=0.0
% INFO    : Bus 6570	: V=1.077044, theta=-30.674868 -> V=1.0251835, theta=0.0
% INFO    : Bus 6571	: V=1.018224, theta=-38.267476 -> V=1.0, theta=0.0
% INFO    : Bus 6572	: V=1.044455, theta=-20.404642 -> V=1.0, theta=0.0
% INFO    : Bus 6573	: V=1.001996, theta=-23.702615 -> V=1.0, theta=0.0
% INFO    : Bus 6574	: V=0.981264, theta=-40.200668 -> V=1.0, theta=0.0
% INFO    : Bus 6575	: V=1.090239, theta=-2.826944 -> V=1.02457, theta=0.0
% INFO    : Bus 6576	: V=1.043756, theta=-18.442847 -> V=1.0, theta=0.0
% INFO    : Bus 6577	: V=0.972979, theta=-35.84018 -> V=1.0, theta=0.0
% INFO    : Bus 6578	: V=1.018513, theta=-37.690182 -> V=1.015925, theta=0.0
% INFO    : Bus 6579	: V=1.076553, theta=-42.643792 -> V=1.016291, theta=0.0
% INFO    : Bus 6580	: V=1.031908, theta=-31.47972 -> V=1.0, theta=0.0
% INFO    : Bus 6581	: V=1.07312, theta=-7.620202 -> V=1.0216925, theta=0.0
% INFO    : Bus 6582	: V=1.058317, theta=16.617411 -> V=1.0, theta=0.0
% INFO    : Bus 6583	: V=1.026787, theta=32.026056 -> V=1.0, theta=0.0
% INFO    : Bus 6584	: V=1.090517, theta=-28.744771 -> V=1.02964, theta=0.0
% INFO    : Bus 6585	: V=1.049586, theta=-10.978673 -> V=1.0106915, theta=0.0
% INFO    : Bus 6586	: V=1.024596, theta=-16.266443 -> V=1.0, theta=0.0
% INFO    : Bus 6587	: V=1.070213, theta=-5.54753 -> V=1.012869, theta=0.0
% INFO    : Bus 6588	: V=1.055947, theta=-7.77533 -> V=1.0115795, theta=0.0
% INFO    : Bus 6589	: V=1.062509, theta=-17.116173 -> V=1.016316, theta=0.0
% INFO    : Bus 6590	: V=1.035313, theta=-24.808034 -> V=1.0, theta=0.0
% INFO    : Bus 6591	: V=1.104158, theta=23.683351 -> V=1.020345, theta=0.0
% INFO    : Bus 6592	: V=1.02524, theta=-20.413349 -> V=1.0, theta=0.0
% INFO    : Bus 6593	: V=0.992107, theta=-20.381648 -> V=1.0, theta=0.0
% INFO    : Bus 6594	: V=1.063174, theta=-23.339564 -> V=1.031431, theta=0.0
% INFO    : Bus 6595	: V=1.079255, theta=-4.446303 -> V=1.017012, theta=0.0
% INFO    : Bus 6596	: V=1.077889, theta=3.477923 -> V=1.023029, theta=0.0
% INFO    : Bus 6597	: V=1.051548, theta=-19.561747 -> V=1.0, theta=0.0
% INFO    : Bus 6598	: V=1.087318, theta=-12.011419 -> V=1.0194325, theta=0.0
% INFO    : Bus 6599	: V=1.075613, theta=-12.897724 -> V=1.0149755, theta=0.0
% INFO    : Bus 6600	: V=1.005859, theta=-18.787501 -> V=1.0, theta=0.0
% INFO    : Bus 6601	: V=1.102974, theta=-5.117309 -> V=1.0250465, theta=0.0
% INFO    : Bus 6602	: V=1.033298, theta=-41.751036 -> V=1.0, theta=0.0
% INFO    : Bus 6603	: V=1.141889, theta=-1.859861 -> V=1.05227, theta=0.0
% INFO    : Bus 6604	: V=1.092623, theta=-24.681524 -> V=1.0273825, theta=0.0
% INFO    : Bus 6605	: V=1.00158, theta=-18.110757 -> V=1.0, theta=0.0
% INFO    : Bus 6606	: V=1.088312, theta=-36.997976 -> V=1.0161205, theta=0.0
% INFO    : Bus 6607	: V=1.099068, theta=-5.804519 -> V=1.032968, theta=0.0
% INFO    : Bus 6608	: V=0.979515, theta=-25.47388 -> V=1.0, theta=0.0
% INFO    : Bus 6609	: V=1.08295, theta=-10.345392 -> V=1.0203005, theta=0.0
% INFO    : Bus 6610	: V=1.001078, theta=-29.590634 -> V=1.0, theta=0.0
% INFO    : Bus 6611	: V=1.086591, theta=-7.929386 -> V=1.015559, theta=0.0
% INFO    : Bus 6612	: V=0.988153, theta=-23.419976 -> V=1.0, theta=0.0
% INFO    : Bus 6613	: V=1.080717, theta=2.034615 -> V=1.0259295, theta=0.0
% INFO    : Bus 6614	: V=1.032678, theta=-12.831957 -> V=1.0, theta=0.0
% INFO    : Bus 6615	: V=1.080706, theta=2.034053 -> V=1.025923, theta=0.0
% INFO    : Bus 6616	: V=1.05427, theta=11.051321 -> V=1.021155, theta=0.0
% INFO    : Bus 6617	: V=0.948733, theta=55.084968 -> V=1.0, theta=0.0
% INFO    : Bus 6618	: V=1.029351, theta=-23.363762 -> V=1.0, theta=0.0
% INFO    : Bus 6619	: V=0.95471, theta=-27.552372 -> V=1.0, theta=0.0
% INFO    : Bus 6620	: V=1.086105, theta=-40.254533 -> V=1.0149265, theta=0.0
% INFO    : Bus 6621	: V=1.00717, theta=-23.107833 -> V=1.0, theta=0.0
% INFO    : Bus 6622	: V=1.082306, theta=2.982109 -> V=1.0264035, theta=0.0
% INFO    : Bus 6623	: V=1.0437, theta=-30.204767 -> V=1.003107, theta=0.0
% INFO    : Bus 6624	: V=0.977764, theta=-28.563389 -> V=1.0, theta=0.0
% INFO    : Bus 6625	: V=0.953641, theta=-18.634138 -> V=1.0, theta=0.0
% INFO    : Bus 6626	: V=1.095931, theta=-11.242293 -> V=1.0343025, theta=0.0
% INFO    : Bus 6627	: V=1.085342, theta=-42.36031 -> V=1.01605, theta=0.0
% INFO    : Bus 6628	: V=1.037915, theta=-45.860113 -> V=1.0027305, theta=0.0
% INFO    : Bus 6629	: V=1.0256, theta=-43.925456 -> V=1.0, theta=0.0
% INFO    : Bus 6630	: V=1.097575, theta=-18.631623 -> V=1.039221, theta=0.0
% INFO    : Bus 6631	: V=1.072885, theta=-20.143996 -> V=1.0284665, theta=0.0
% INFO    : Bus 6632	: V=1.022345, theta=-31.503088 -> V=1.0, theta=0.0
% INFO    : Bus 6633	: V=1.071041, theta=-6.852285 -> V=1.0154225, theta=0.0
% INFO    : Bus 6634	: V=1.095109, theta=-3.498908 -> V=1.026322, theta=0.0
% INFO    : Bus 6635	: V=1.04675, theta=20.566718 -> V=1.0027575, theta=0.0
% INFO    : Bus 6636	: V=1.010766, theta=-19.540915 -> V=1.0, theta=0.0
% INFO    : Bus 6637	: V=1.061762, theta=-35.285625 -> V=1.0214105, theta=0.0
% INFO    : Bus 6638	: V=0.965703, theta=21.580102 -> V=1.0, theta=0.0
% INFO    : Bus 6639	: V=0.998712, theta=-23.907111 -> V=1.0, theta=0.0
% INFO    : Bus 6640	: V=0.972428, theta=-25.603048 -> V=1.0, theta=0.0
% INFO    : Bus 6641	: V=1.033389, theta=-4.161221 -> V=1.0, theta=0.0
% INFO    : Bus 6642	: V=1.048392, theta=-12.371918 -> V=1.016868, theta=0.0
% INFO    : Bus 6643	: V=1.059227, theta=-16.884821 -> V=1.0061985, theta=0.0
% INFO    : Bus 6644	: V=1.019289, theta=-13.828213 -> V=1.012351, theta=0.0
% INFO    : Bus 6645	: V=1.054727, theta=-30.041553 -> V=1.004937, theta=0.0
% INFO    : Bus 6646	: V=1.102079, theta=-14.470544 -> V=1.0415595, theta=0.0
% INFO    : Bus 6647	: V=1.079273, theta=-33.619526 -> V=1.0128815, theta=0.0
% INFO    : Bus 6648	: V=1.045036, theta=-0.982761 -> V=1.006423, theta=0.0
% INFO    : Bus 6649	: V=1.017132, theta=-23.760304 -> V=1.0, theta=0.0
% INFO    : Bus 6650	: V=1.011492, theta=-35.010805 -> V=1.0, theta=0.0
% INFO    : Bus 6651	: V=1.028194, theta=-4.424981 -> V=1.0, theta=0.0
% INFO    : Bus 6652	: V=0.994253, theta=-13.583593 -> V=1.0, theta=0.0
% INFO    : Bus 6653	: V=1.071805, theta=-13.815613 -> V=1.017743, theta=0.0
% INFO    : Bus 6654	: V=1.024384, theta=-23.126331 -> V=1.0, theta=0.0
% INFO    : Bus 6655	: V=1.038186, theta=-22.490885 -> V=1.016112, theta=0.0
% INFO    : Bus 6656	: V=1.085702, theta=-3.360929 -> V=1.0234915, theta=0.0
% INFO    : Bus 6657	: V=1.044474, theta=-14.960099 -> V=1.0038645, theta=0.0
% INFO    : Bus 6658	: V=1.085127, theta=-39.155943 -> V=1.021786, theta=0.0
% INFO    : Bus 6659	: V=0.995818, theta=-26.374075 -> V=1.0, theta=0.0
% INFO    : Bus 6660	: V=0.975272, theta=-27.839009 -> V=1.0, theta=0.0
% INFO    : Bus 6661	: V=1.068527, theta=15.370749 -> V=1.018772, theta=0.0
% INFO    : Bus 6662	: V=1.039294, theta=-44.348121 -> V=1.0, theta=0.0
% INFO    : Bus 6663	: V=1.095825, theta=-12.573332 -> V=1.030579, theta=0.0
% INFO    : Bus 6664	: V=1.035572, theta=-47.00775 -> V=1.0, theta=0.0
% INFO    : Bus 6665	: V=1.081568, theta=-3.828843 -> V=1.021298, theta=0.0
% INFO    : Bus 6666	: V=1.06286, theta=1.49577 -> V=1.009685, theta=0.0
% INFO    : Bus 6667	: V=1.018185, theta=-21.166702 -> V=1.0, theta=0.0
% INFO    : Bus 6668	: V=0.968367, theta=-25.37697 -> V=1.0, theta=0.0
% INFO    : Bus 6669	: V=0.97937, theta=-25.729316 -> V=1.0, theta=0.0
% INFO    : Bus 6670	: V=1.051209, theta=-22.829461 -> V=1.0, theta=0.0
% INFO    : Bus 6671	: V=1.033941, theta=-44.083559 -> V=1.0, theta=0.0
% INFO    : Bus 6672	: V=1.092395, theta=-24.093032 -> V=1.02449, theta=0.0
% INFO    : Bus 6673	: V=1.013739, theta=14.475313 -> V=1.0, theta=0.0
% INFO    : Bus 6674	: V=1.095176, theta=-14.771049 -> V=1.0312775, theta=0.0
% INFO    : Bus 6675	: V=1.077374, theta=-2.423541 -> V=1.0203325, theta=0.0
% INFO    : Bus 6676	: V=1.082013, theta=-19.140241 -> V=1.029087, theta=0.0
% INFO    : Bus 6677	: V=0.955502, theta=-23.249911 -> V=1.0, theta=0.0
% INFO    : Bus 6678	: V=1.052581, theta=-36.516164 -> V=1.003618, theta=0.0
% INFO    : Bus 6679	: V=1.055447, theta=-17.747716 -> V=1.006527, theta=0.0
% INFO    : Bus 6680	: V=1.03908, theta=-24.339985 -> V=1.0, theta=0.0
% INFO    : Bus 6681	: V=1.039473, theta=15.732709 -> V=1.0026345, theta=0.0
% INFO    : Bus 6682	: V=1.022106, theta=-15.973324 -> V=1.0, theta=0.0
% INFO    : Bus 6683	: V=1.073882, theta=-22.728551 -> V=1.030352, theta=0.0
% INFO    : Bus 6684	: V=1.063236, theta=-1.729047 -> V=1.019567, theta=0.0
% INFO    : Bus 6685	: V=1.053018, theta=-20.467315 -> V=1.005749, theta=0.0
% INFO    : Bus 6686	: V=1.020818, theta=4.408546 -> V=1.0, theta=0.0
% INFO    : Bus 6687	: V=1.059317, theta=-15.205138 -> V=1.0141275, theta=0.0
% INFO    : Bus 6688	: V=1.049818, theta=-13.948205 -> V=1.0087925, theta=0.0
% INFO    : Bus 6689	: V=0.958951, theta=-25.600778 -> V=1.0, theta=0.0
% INFO    : Bus 6690	: V=0.976904, theta=-22.764718 -> V=1.0, theta=0.0
% INFO    : Bus 6691	: V=1.017773, theta=-31.330217 -> V=1.0, theta=0.0
% INFO    : Bus 6692	: V=0.978544, theta=-18.146287 -> V=1.0, theta=0.0
% INFO    : Bus 6693	: V=1.008916, theta=-36.064813 -> V=1.0, theta=0.0
% INFO    : Bus 6694	: V=0.997572, theta=-24.754594 -> V=1.0, theta=0.0
% INFO    : Bus 6695	: V=1.041091, theta=25.762276 -> V=1.0155805, theta=0.0
% INFO    : Bus 6696	: V=1.03314, theta=-25.180792 -> V=1.0, theta=0.0
% INFO    : Bus 6697	: V=1.079262, theta=-31.346731 -> V=1.023777, theta=0.0
% INFO    : Bus 6698	: V=1.055215, theta=-14.522849 -> V=1.003242, theta=0.0
% INFO    : Bus 6699	: V=1.050667, theta=-49.755104 -> V=1.0, theta=0.0
% INFO    : Bus 6700	: V=1.067636, theta=-21.597753 -> V=1.0, theta=0.0
% INFO    : Bus 6701	: V=1.057297, theta=6.505594 -> V=1.012571, theta=0.0
% INFO    : Bus 6702	: V=1.071008, theta=-40.022594 -> V=1.0156615, theta=0.0
% INFO    : Bus 6703	: V=1.050606, theta=-18.311935 -> V=1.0081225, theta=0.0
% INFO    : Bus 6704	: V=0.951068, theta=-23.734961 -> V=1.0, theta=0.0
% INFO    : Bus 6705	: V=1.031545, theta=-46.259071 -> V=1.0, theta=0.0
% INFO    : Bus 6706	: V=1.033732, theta=17.127387 -> V=1.0, theta=0.0
% INFO    : Bus 6707	: V=1.008807, theta=-20.023367 -> V=1.0, theta=0.0
% INFO    : Bus 6708	: V=1.014955, theta=11.147918 -> V=1.0, theta=0.0
% INFO    : Bus 6709	: V=0.9751, theta=-23.973836 -> V=1.0, theta=0.0
% INFO    : Bus 6710	: V=1.016245, theta=-47.76275 -> V=1.0, theta=0.0
% INFO    : Bus 6711	: V=1.069676, theta=8.609245 -> V=1.0196205, theta=0.0
% INFO    : Bus 6712	: V=1.046511, theta=-21.588091 -> V=1.0, theta=0.0
% INFO    : Bus 6713	: V=1.062462, theta=-43.252427 -> V=1.007116, theta=0.0
% INFO    : Bus 6714	: V=1.072349, theta=-2.440198 -> V=1.0211725, theta=0.0
% INFO    : Bus 6715	: V=0.94171, theta=-32.292003 -> V=0.9693385, theta=0.0
% INFO    : Bus 6716	: V=1.037437, theta=-16.879842 -> V=1.0, theta=0.0
% INFO    : Bus 6717	: V=1.019821, theta=-34.891149 -> V=1.0, theta=0.0
% INFO    : Bus 6718	: V=1.028354, theta=65.17963 -> V=1.0, theta=0.0
% INFO    : Bus 6719	: V=1.052953, theta=-48.975647 -> V=1.005196, theta=0.0
% INFO    : Bus 6720	: V=0.982671, theta=-24.385099 -> V=1.0, theta=0.0
% INFO    : Bus 6721	: V=1.004182, theta=-21.992654 -> V=1.0, theta=0.0
% INFO    : Bus 6722	: V=1.078863, theta=67.176565 -> V=1.0, theta=0.0
% INFO    : Bus 6723	: V=1.038844, theta=-41.687266 -> V=1.0, theta=0.0
% INFO    : Bus 6724	: V=1.075504, theta=-15.951953 -> V=1.021699, theta=0.0
% INFO    : Bus 6725	: V=0.962369, theta=-21.031232 -> V=1.0, theta=0.0
% INFO    : Bus 6726	: V=1.056364, theta=-32.545422 -> V=1.009708, theta=0.0
% INFO    : Bus 6727	: V=1.057005, theta=-29.620525 -> V=1.010865, theta=0.0
% INFO    : Bus 6728	: V=1.074467, theta=-10.053005 -> V=1.0224385, theta=0.0
% INFO    : Bus 6729	: V=1.061338, theta=-36.461977 -> V=1.010258, theta=0.0
% INFO    : Bus 6730	: V=1.054192, theta=-11.134229 -> V=1.0111405, theta=0.0
% INFO    : Bus 6731	: V=1.087526, theta=0.753832 -> V=1.027174, theta=0.0
% INFO    : Bus 6732	: V=1.026235, theta=-14.935499 -> V=1.0, theta=0.0
% INFO    : Bus 6733	: V=1.0855, theta=-15.40087 -> V=1.011973, theta=0.0
% INFO    : Bus 6734	: V=1.08545, theta=-45.541927 -> V=1.0245365, theta=0.0
% INFO    : Bus 6735	: V=0.988159, theta=10.739767 -> V=1.0, theta=0.0
% INFO    : Bus 6736	: V=1.039182, theta=-29.715625 -> V=1.0, theta=0.0
% INFO    : Bus 6737	: V=1.041909, theta=-17.2289 -> V=1.0063215, theta=0.0
% INFO    : Bus 6738	: V=1.023853, theta=-27.475478 -> V=1.0, theta=0.0
% INFO    : Bus 6739	: V=0.988409, theta=-24.210444 -> V=1.0, theta=0.0
% INFO    : Bus 6740	: V=1.08842, theta=-44.931621 -> V=1.015313, theta=0.0
% INFO    : Bus 6741	: V=1.054837, theta=-24.707017 -> V=1.030127, theta=0.0
% INFO    : Bus 6742	: V=1.045106, theta=-12.69957 -> V=1.0086755, theta=0.0
% INFO    : Bus 6743	: V=0.946366, theta=-27.476428 -> V=1.0, theta=0.0
% INFO    : Bus 6744	: V=1.086583, theta=32.712269 -> V=1.009613, theta=0.0
% INFO    : Bus 6745	: V=1.027532, theta=-16.203875 -> V=1.0, theta=0.0
% INFO    : Bus 6746	: V=1.041554, theta=14.683138 -> V=1.0, theta=0.0
% INFO    : Bus 6747	: V=1.073057, theta=15.563948 -> V=1.0146445, theta=0.0
% INFO    : Bus 6748	: V=1.023803, theta=12.111666 -> V=1.0, theta=0.0
% INFO    : Bus 6749	: V=1.05189, theta=60.720146 -> V=1.0028795, theta=0.0
% INFO    : Bus 6750	: V=1.043773, theta=-41.705027 -> V=1.0, theta=0.0
% INFO    : Bus 6751	: V=1.101488, theta=-13.991306 -> V=1.0238835, theta=0.0
% INFO    : Bus 6752	: V=1.009791, theta=61.711396 -> V=1.0, theta=0.0
% INFO    : Bus 6753	: V=1.062562, theta=9.501026 -> V=1.0, theta=0.0
% INFO    : Bus 6754	: V=0.998059, theta=10.359685 -> V=1.0, theta=0.0
% INFO    : Bus 6755	: V=1.035502, theta=-35.143982 -> V=1.0, theta=0.0
% INFO    : Bus 6756	: V=0.96045, theta=-25.421932 -> V=1.0, theta=0.0
% INFO    : Bus 6757	: V=1.080204, theta=-6.871882 -> V=1.0181215, theta=0.0
% INFO    : Bus 6758	: V=1.105109, theta=-9.675955 -> V=1.031483, theta=0.0
% INFO    : Bus 6759	: V=1.047266, theta=-14.289962 -> V=1.020717, theta=0.0
% INFO    : Bus 6760	: V=1.033111, theta=-2.093061 -> V=1.0052575, theta=0.0
% INFO    : Bus 6761	: V=1.096501, theta=-20.015151 -> V=1.0218475, theta=0.0
% INFO    : Bus 6762	: V=1.075527, theta=-18.99976 -> V=1.0124765, theta=0.0
% INFO    : Bus 6763	: V=1.078761, theta=-41.834953 -> V=1.010058, theta=0.0
% INFO    : Bus 6764	: V=0.998989, theta=-18.953416 -> V=1.0, theta=0.0
% INFO    : Bus 6765	: V=1.053578, theta=-16.603797 -> V=1.0045365, theta=0.0
% INFO    : Bus 6766	: V=1.05506, theta=-48.889867 -> V=1.006314, theta=0.0
% INFO    : Bus 6767	: V=1.072679, theta=-11.702141 -> V=1.016224, theta=0.0
% INFO    : Bus 6768	: V=1.0432, theta=61.671732 -> V=1.0, theta=0.0
% INFO    : Bus 6769	: V=1.030409, theta=-33.128913 -> V=1.031767, theta=0.0
% INFO    : Bus 6770	: V=1.068287, theta=-21.359046 -> V=1.0110485, theta=0.0
% INFO    : Bus 6771	: V=0.943018, theta=-28.897304 -> V=1.0, theta=0.0
% INFO    : Bus 6772	: V=0.982044, theta=-17.832275 -> V=1.0, theta=0.0
% INFO    : Bus 6773	: V=1.015513, theta=-26.374751 -> V=1.0391775, theta=0.0
% INFO    : Bus 6774	: V=1.049596, theta=-5.649828 -> V=1.017259, theta=0.0
% INFO    : Bus 6775	: V=1.07549, theta=-15.487219 -> V=1.010751, theta=0.0
% INFO    : Bus 6776	: V=1.071462, theta=-14.443967 -> V=1.0137635, theta=0.0
% INFO    : Bus 6777	: V=1.022636, theta=-13.585203 -> V=1.0082355, theta=0.0
% INFO    : Bus 6778	: V=1.050213, theta=-49.44782 -> V=1.0057325, theta=0.0
% INFO    : Bus 6779	: V=1.073727, theta=4.551247 -> V=1.022153, theta=0.0
% INFO    : Bus 6780	: V=1.008887, theta=-21.685173 -> V=1.0, theta=0.0
% INFO    : Bus 6781	: V=0.965656, theta=-27.541312 -> V=1.0, theta=0.0
% INFO    : Bus 6782	: V=1.010652, theta=-48.380312 -> V=1.0, theta=0.0
% INFO    : Bus 6783	: V=1.048135, theta=15.415947 -> V=1.0, theta=0.0
% INFO    : Bus 6784	: V=1.030677, theta=-24.28051 -> V=1.0, theta=0.0
% INFO    : Bus 6785	: V=1.09072, theta=55.461606 -> V=1.0090975, theta=0.0
% INFO    : Bus 6786	: V=1.023354, theta=-20.876203 -> V=1.0087155, theta=0.0
% INFO    : Bus 6787	: V=1.05318, theta=-24.661371 -> V=1.0141475, theta=0.0
% INFO    : Bus 6788	: V=0.953366, theta=-23.598083 -> V=1.0, theta=0.0
% INFO    : Bus 6789	: V=1.056247, theta=-27.116514 -> V=1.009355, theta=0.0
% INFO    : Bus 6790	: V=1.024498, theta=15.617773 -> V=1.0, theta=0.0
% INFO    : Bus 6791	: V=1.039456, theta=-45.895051 -> V=1.0, theta=0.0
% INFO    : Bus 6792	: V=1.085289, theta=46.029963 -> V=1.0, theta=0.0
% INFO    : Bus 6793	: V=1.068929, theta=-20.202165 -> V=1.025645, theta=0.0
% INFO    : Bus 6794	: V=1.078699, theta=18.806409 -> V=1.0181655, theta=0.0
% INFO    : Bus 6795	: V=1.067575, theta=4.616673 -> V=1.0217115, theta=0.0
% INFO    : Bus 6796	: V=1.057061, theta=-36.152298 -> V=1.018886, theta=0.0
% INFO    : Bus 6797	: V=1.061091, theta=-14.099184 -> V=1.0121445, theta=0.0
% INFO    : Bus 6798	: V=1.017843, theta=-18.607511 -> V=1.0, theta=0.0
% INFO    : Bus 6799	: V=1.029282, theta=-35.178392 -> V=1.0, theta=0.0
% INFO    : Bus 6800	: V=0.986636, theta=-12.446407 -> V=1.0, theta=0.0
% INFO    : Bus 6801	: V=1.078257, theta=-13.263757 -> V=1.016936, theta=0.0
% INFO    : Bus 6802	: V=1.001454, theta=-26.883551 -> V=1.0, theta=0.0
% INFO    : Bus 6803	: V=1.065018, theta=20.6395 -> V=1.017525, theta=0.0
% INFO    : Bus 6804	: V=1.021659, theta=-38.912603 -> V=1.0, theta=0.0
% INFO    : Bus 6805	: V=1.055091, theta=-38.833387 -> V=1.0, theta=0.0
% INFO    : Bus 6806	: V=1.07103, theta=0.755545 -> V=1.0197925, theta=0.0
% INFO    : Bus 6807	: V=1.081508, theta=-18.716585 -> V=1.022444, theta=0.0
% INFO    : Bus 6808	: V=1.059594, theta=-22.956161 -> V=1.016771, theta=0.0
% INFO    : Bus 6809	: V=1.085053, theta=-35.935996 -> V=1.0177105, theta=0.0
% INFO    : Bus 6810	: V=1.093541, theta=-43.286912 -> V=1.0253055, theta=0.0
% INFO    : Bus 6811	: V=1.071949, theta=-42.366013 -> V=1.0101565, theta=0.0
% INFO    : Bus 6812	: V=1.052437, theta=1.364967 -> V=1.0134425, theta=0.0
% INFO    : Bus 6813	: V=1.059552, theta=4.040351 -> V=1.0085445, theta=0.0
% INFO    : Bus 6814	: V=1.057586, theta=-14.3481 -> V=1.0097345, theta=0.0
% INFO    : Bus 6815	: V=1.031217, theta=25.2997 -> V=1.0, theta=0.0
% INFO    : Bus 6816	: V=1.078295, theta=-12.756161 -> V=1.0167405, theta=0.0
% INFO    : Bus 6817	: V=0.973483, theta=-17.962011 -> V=1.0, theta=0.0
% INFO    : Bus 6818	: V=1.017082, theta=-19.098009 -> V=1.0, theta=0.0
% INFO    : Bus 6819	: V=0.966052, theta=-17.89012 -> V=1.0, theta=0.0
% INFO    : Bus 6820	: V=1.077045, theta=-10.046571 -> V=1.023686, theta=0.0
% INFO    : Bus 6821	: V=1.032711, theta=-8.844462 -> V=1.007461, theta=0.0
% INFO    : Bus 6822	: V=0.982769, theta=-25.079209 -> V=1.0, theta=0.0
% INFO    : Bus 6823	: V=1.040974, theta=-10.806154 -> V=1.003602, theta=0.0
% INFO    : Bus 6824	: V=1.090648, theta=-0.669768 -> V=1.0273835, theta=0.0
% INFO    : Bus 6825	: V=1.026626, theta=-7.590834 -> V=1.0, theta=0.0
% INFO    : Bus 6826	: V=1.050629, theta=15.255975 -> V=1.0, theta=0.0
% INFO    : Bus 6827	: V=1.039581, theta=6.347264 -> V=1.0, theta=0.0
% INFO    : Bus 6828	: V=0.988826, theta=-22.928882 -> V=1.0, theta=0.0
% INFO    : Bus 6829	: V=1.051401, theta=-22.940212 -> V=1.0, theta=0.0
% INFO    : Bus 6830	: V=1.059893, theta=-18.990432 -> V=1.024936, theta=0.0
% INFO    : Bus 6831	: V=0.966059, theta=-30.910296 -> V=1.0, theta=0.0
% INFO    : Bus 6832	: V=1.094221, theta=-17.138301 -> V=1.0523185, theta=0.0
% INFO    : Bus 6833	: V=1.03296, theta=-15.379405 -> V=1.0030595, theta=0.0
% INFO    : Bus 6834	: V=0.964941, theta=-26.462817 -> V=1.0, theta=0.0
% INFO    : Bus 6835	: V=0.984088, theta=-26.370497 -> V=1.0, theta=0.0
% INFO    : Bus 6836	: V=1.004211, theta=-24.167276 -> V=1.0, theta=0.0
% INFO    : Bus 6837	: V=1.036214, theta=-14.944421 -> V=1.0035545, theta=0.0
% INFO    : Bus 6838	: V=1.016542, theta=-47.353779 -> V=1.0, theta=0.0
% INFO    : Bus 6839	: V=1.052202, theta=-12.044753 -> V=1.0171265, theta=0.0
% INFO    : Bus 6840	: V=1.013032, theta=-47.569974 -> V=1.0, theta=0.0
% INFO    : Bus 6841	: V=1.065664, theta=-15.745233 -> V=1.027026, theta=0.0
% INFO    : Bus 6842	: V=1.027168, theta=-20.593467 -> V=1.0031015, theta=0.0
% INFO    : Bus 6843	: V=1.023321, theta=-27.887179 -> V=1.0, theta=0.0
% INFO    : Bus 6844	: V=0.957659, theta=66.516623 -> V=1.0, theta=0.0
% INFO    : Bus 6845	: V=1.099323, theta=35.801706 -> V=1.0148695, theta=0.0
% INFO    : Bus 6846	: V=0.956949, theta=-29.228607 -> V=0.996054, theta=0.0
% INFO    : Bus 6847	: V=1.077938, theta=-16.582514 -> V=1.016413, theta=0.0
% INFO    : Bus 6848	: V=1.048775, theta=-23.580018 -> V=1.0097405, theta=0.0
% INFO    : Bus 6849	: V=1.007689, theta=-15.538118 -> V=1.0, theta=0.0
% INFO    : Bus 6850	: V=1.03333, theta=-34.760191 -> V=1.0, theta=0.0
% INFO    : Bus 6851	: V=1.044003, theta=-3.613721 -> V=1.007403, theta=0.0
% INFO    : Bus 6852	: V=1.039703, theta=-25.070337 -> V=1.0, theta=0.0
% INFO    : Bus 6853	: V=1.066153, theta=10.834958 -> V=1.023284, theta=0.0
% INFO    : Bus 6854	: V=1.03743, theta=-20.556045 -> V=1.0, theta=0.0
% INFO    : Bus 6855	: V=1.003575, theta=-22.097961 -> V=1.0, theta=0.0
% INFO    : Bus 6856	: V=0.991828, theta=-17.297411 -> V=1.0036115, theta=0.0
% INFO    : Bus 6857	: V=0.999227, theta=-18.848247 -> V=1.0, theta=0.0
% INFO    : Bus 6858	: V=1.06807, theta=62.143387 -> V=1.0, theta=0.0
% INFO    : Bus 6859	: V=1.012804, theta=-16.862609 -> V=1.0055515, theta=0.0
% INFO    : Bus 6860	: V=1.034479, theta=-5.111942 -> V=1.0, theta=0.0
% INFO    : Bus 6861	: V=1.07427, theta=-12.803559 -> V=1.0195905, theta=0.0
% INFO    : Bus 6862	: V=1.077379, theta=-12.869674 -> V=1.020129, theta=0.0
% INFO    : Bus 6863	: V=1.013067, theta=-46.705296 -> V=1.0, theta=0.0
% INFO    : Bus 6864	: V=1.077535, theta=9.509833 -> V=1.023224, theta=0.0
% INFO    : Bus 6865	: V=0.973529, theta=-25.885712 -> V=1.0, theta=0.0
% INFO    : Bus 6866	: V=1.0385, theta=-26.275309 -> V=1.0, theta=0.0
% INFO    : Bus 6867	: V=1.007611, theta=-50.995608 -> V=1.0, theta=0.0
% INFO    : Bus 6868	: V=1.080578, theta=-13.784328 -> V=1.0263435, theta=0.0
% INFO    : Bus 6869	: V=1.089567, theta=-10.058833 -> V=1.020097, theta=0.0
% INFO    : Bus 6870	: V=1.053218, theta=-49.060948 -> V=1.005244, theta=0.0
% INFO    : Bus 6871	: V=1.062888, theta=-35.299027 -> V=1.0117635, theta=0.0
% INFO    : Bus 6872	: V=1.063459, theta=7.277026 -> V=1.0158805, theta=0.0
% INFO    : Bus 6873	: V=1.042404, theta=-12.134897 -> V=1.006954, theta=0.0
% INFO    : Bus 6874	: V=1.054699, theta=-10.692241 -> V=1.0120845, theta=0.0
% INFO    : Bus 6875	: V=1.002746, theta=-23.619608 -> V=1.0, theta=0.0
% INFO    : Bus 6876	: V=1.041024, theta=-25.7205 -> V=1.018997, theta=0.0
% INFO    : Bus 6877	: V=1.057062, theta=-11.614007 -> V=1.0182285, theta=0.0
% INFO    : Bus 6878	: V=1.067991, theta=-23.157733 -> V=1.026465, theta=0.0
% INFO    : Bus 6879	: V=1.078592, theta=-0.794236 -> V=1.0232935, theta=0.0
% INFO    : Bus 6880	: V=1.069395, theta=-1.799866 -> V=1.0233175, theta=0.0
% INFO    : Bus 6881	: V=0.958534, theta=-22.956879 -> V=1.0, theta=0.0
% INFO    : Bus 6882	: V=1.06958, theta=-2.768638 -> V=1.019765, theta=0.0
% INFO    : Bus 6883	: V=1.029279, theta=-25.709268 -> V=1.0, theta=0.0
% INFO    : Bus 6884	: V=0.973751, theta=-20.358038 -> V=1.0, theta=0.0
% INFO    : Bus 6885	: V=0.932012, theta=-34.988721 -> V=1.0, theta=0.0
% INFO    : Bus 6886	: V=0.960193, theta=-26.464873 -> V=1.0, theta=0.0
% INFO    : Bus 6887	: V=1.002893, theta=-29.83287 -> V=1.0, theta=0.0
% INFO    : Bus 6888	: V=1.08813, theta=2.747973 -> V=1.0250835, theta=0.0
% INFO    : Bus 6889	: V=1.04379, theta=-41.066667 -> V=1.0, theta=0.0
% INFO    : Bus 6890	: V=1.046618, theta=-4.828803 -> V=1.0114255, theta=0.0
% INFO    : Bus 6891	: V=0.953616, theta=-27.63711 -> V=1.0, theta=0.0
% INFO    : Bus 6892	: V=1.063911, theta=-1.637652 -> V=1.019859, theta=0.0
% INFO    : Bus 6893	: V=1.086952, theta=-26.306588 -> V=1.0246095, theta=0.0
% INFO    : Bus 6894	: V=0.935134, theta=-28.732453 -> V=1.0, theta=0.0
% INFO    : Bus 6895	: V=1.074055, theta=-6.618266 -> V=1.0200715, theta=0.0
% INFO    : Bus 6896	: V=1.034298, theta=-41.81864 -> V=1.0, theta=0.0
% INFO    : Bus 6897	: V=1.001299, theta=60.196423 -> V=1.0, theta=0.0
% INFO    : Bus 6898	: V=1.064548, theta=-18.593507 -> V=1.0, theta=0.0
% INFO    : Bus 6899	: V=0.989276, theta=-37.326531 -> V=1.0, theta=0.0
% INFO    : Bus 6900	: V=0.949883, theta=-27.129655 -> V=1.0, theta=0.0
% INFO    : Bus 6901	: V=1.026477, theta=-23.796331 -> V=1.0, theta=0.0
% INFO    : Bus 6902	: V=0.995579, theta=-26.448436 -> V=1.0, theta=0.0
% INFO    : Bus 6903	: V=1.062273, theta=-12.965436 -> V=1.007163, theta=0.0
% INFO    : Bus 6904	: V=0.963533, theta=-16.53255 -> V=1.0, theta=0.0
% INFO    : Bus 6905	: V=1.048571, theta=-1.02191 -> V=1.008384, theta=0.0
% INFO    : Bus 6906	: V=0.977764, theta=-28.563389 -> V=1.0, theta=0.0
% INFO    : Bus 6907	: V=1.072007, theta=-42.438226 -> V=1.009337, theta=0.0
% INFO    : Bus 6908	: V=1.053783, theta=-16.107268 -> V=1.0046145, theta=0.0
% INFO    : Bus 6909	: V=0.916307, theta=-29.64919 -> V=1.0, theta=0.0
% INFO    : Bus 6910	: V=1.018766, theta=-48.702548 -> V=1.0, theta=0.0
% INFO    : Bus 6911	: V=1.097184, theta=-14.664789 -> V=1.028818, theta=0.0
% INFO    : Bus 6912	: V=1.07295, theta=-15.214222 -> V=1.0122155, theta=0.0
% INFO    : Bus 6913	: V=1.055557, theta=-27.181328 -> V=1.009017, theta=0.0
% INFO    : Bus 6914	: V=1.067895, theta=-34.7104 -> V=1.0150155, theta=0.0
% INFO    : Bus 6915	: V=1.011068, theta=11.513101 -> V=1.0, theta=0.0
% INFO    : Bus 6916	: V=1.016222, theta=-26.56258 -> V=1.0, theta=0.0
% INFO    : Bus 6917	: V=1.083363, theta=-2.640205 -> V=1.0225185, theta=0.0
% INFO    : Bus 6918	: V=1.072265, theta=-19.68828 -> V=1.027102, theta=0.0
% INFO    : Bus 6919	: V=1.077468, theta=5.784078 -> V=1.025721, theta=0.0
% INFO    : Bus 6920	: V=1.038611, theta=-12.58932 -> V=1.004219, theta=0.0
% INFO    : Bus 6921	: V=1.016591, theta=-19.786578 -> V=1.0, theta=0.0
% INFO    : Bus 6922	: V=1.098999, theta=4.884085 -> V=1.0258195, theta=0.0
% INFO    : Bus 6923	: V=1.049085, theta=-50.113908 -> V=1.0, theta=0.0
% INFO    : Bus 6924	: V=1.014045, theta=-40.61911 -> V=1.0, theta=0.0
% INFO    : Bus 6925	: V=1.044602, theta=39.775528 -> V=1.0, theta=0.0
% INFO    : Bus 6926	: V=1.067443, theta=-51.189386 -> V=1.0, theta=0.0
% INFO    : Bus 6927	: V=1.064072, theta=-34.385493 -> V=1.0218955, theta=0.0
% INFO    : Bus 6928	: V=1.091218, theta=-7.346361 -> V=1.02969, theta=0.0
% INFO    : Bus 6929	: V=1.040065, theta=-18.730751 -> V=1.0, theta=0.0
% INFO    : Bus 6930	: V=1.062174, theta=2.482756 -> V=1.008771, theta=0.0
% INFO    : Bus 6931	: V=1.064726, theta=-22.358935 -> V=1.0053745, theta=0.0
% INFO    : Bus 6932	: V=1.044773, theta=-34.177538 -> V=1.0036225, theta=0.0
% INFO    : Bus 6933	: V=1.080309, theta=-5.811728 -> V=1.0220495, theta=0.0
% INFO    : Bus 6934	: V=1.0195, theta=-5.813566 -> V=1.0099195, theta=0.0
% INFO    : Bus 6935	: V=1.079473, theta=36.437439 -> V=1.011769, theta=0.0
% INFO    : Bus 6936	: V=1.036142, theta=-41.944096 -> V=1.0, theta=0.0
% INFO    : Bus 6937	: V=1.092782, theta=-10.565668 -> V=1.018089, theta=0.0
% INFO    : Bus 6938	: V=1.078196, theta=-19.440076 -> V=1.0408045, theta=0.0
% INFO    : Bus 6939	: V=1.000261, theta=-20.153353 -> V=1.0, theta=0.0
% INFO    : Bus 6940	: V=0.963672, theta=-13.148621 -> V=1.0, theta=0.0
% INFO    : Bus 6941	: V=1.081393, theta=46.114388 -> V=1.0, theta=0.0
% INFO    : Bus 6942	: V=1.03994, theta=-21.302399 -> V=1.0081925, theta=0.0
% INFO    : Bus 6943	: V=0.983962, theta=7.860721 -> V=1.0, theta=0.0
% INFO    : Bus 6944	: V=1.060853, theta=-21.749719 -> V=1.018992, theta=0.0
% INFO    : Bus 6945	: V=1.013352, theta=9.907876 -> V=1.0, theta=0.0
% INFO    : Bus 6946	: V=1.027864, theta=-30.996231 -> V=1.0, theta=0.0
% INFO    : Bus 6947	: V=1.078921, theta=-15.237345 -> V=1.0240285, theta=0.0
% INFO    : Bus 6948	: V=1.031091, theta=-36.660872 -> V=1.0, theta=0.0
% INFO    : Bus 6949	: V=1.057785, theta=-10.619402 -> V=1.0105575, theta=0.0
% INFO    : Bus 6950	: V=1.054727, theta=-30.048028 -> V=1.00492, theta=0.0
% INFO    : Bus 6951	: V=1.066194, theta=7.73301 -> V=1.007629, theta=0.0
% INFO    : Bus 6952	: V=1.051336, theta=-12.090049 -> V=1.0104115, theta=0.0
% INFO    : Bus 6953	: V=1.085574, theta=-21.094946 -> V=1.0376735, theta=0.0
% INFO    : Bus 6954	: V=1.036651, theta=-36.635298 -> V=1.0, theta=0.0
% INFO    : Bus 6955	: V=1.063578, theta=9.234591 -> V=1.0, theta=0.0
% INFO    : Bus 6956	: V=1.067664, theta=-0.692773 -> V=1.019529, theta=0.0
% INFO    : Bus 6957	: V=1.064554, theta=-44.100246 -> V=1.006606, theta=0.0
% INFO    : Bus 6958	: V=0.940267, theta=67.623133 -> V=1.0, theta=0.0
% INFO    : Bus 6959	: V=1.094227, theta=-8.289764 -> V=1.024331, theta=0.0
% INFO    : Bus 6960	: V=1.10027, theta=-13.976466 -> V=1.0278255, theta=0.0
% INFO    : Bus 6961	: V=1.09304, theta=-38.751734 -> V=1.016966, theta=0.0
% INFO    : Bus 6962	: V=1.084042, theta=-23.753324 -> V=1.0, theta=0.0
% INFO    : Bus 6963	: V=1.057901, theta=0.28342 -> V=1.010373, theta=0.0
% INFO    : Bus 6964	: V=1.089579, theta=38.036908 -> V=1.007498, theta=0.0
% INFO    : Bus 6965	: V=1.043993, theta=-8.95686 -> V=1.0078035, theta=0.0
% INFO    : Bus 6966	: V=1.075755, theta=-25.280549 -> V=1.0129795, theta=0.0
% INFO    : Bus 6967	: V=1.09413, theta=45.725227 -> V=1.002975, theta=0.0
% INFO    : Bus 6968	: V=1.063409, theta=-17.664682 -> V=1.0, theta=0.0
% INFO    : Bus 6969	: V=1.039563, theta=-15.831313 -> V=1.0, theta=0.0
% INFO    : Bus 6970	: V=1.036822, theta=61.14157 -> V=1.0, theta=0.0
% INFO    : Bus 6971	: V=1.053024, theta=-39.848025 -> V=1.0, theta=0.0
% INFO    : Bus 6972	: V=1.08782, theta=-24.540019 -> V=1.01982, theta=0.0
% INFO    : Bus 6973	: V=0.975909, theta=-25.143696 -> V=1.0, theta=0.0
% INFO    : Bus 6974	: V=1.08243, theta=-45.311822 -> V=1.0191365, theta=0.0
% INFO    : Bus 6975	: V=1.069203, theta=4.568016 -> V=1.013519, theta=0.0
% INFO    : Bus 6976	: V=1.07546, theta=-3.735455 -> V=1.018323, theta=0.0
% INFO    : Bus 6977	: V=1.034304, theta=-23.255188 -> V=1.0, theta=0.0
% INFO    : Bus 6978	: V=1.026159, theta=-24.472203 -> V=1.0, theta=0.0
% INFO    : Bus 6979	: V=1.070785, theta=-13.933045 -> V=1.0202045, theta=0.0
% INFO    : Bus 6980	: V=1.026272, theta=-27.007979 -> V=1.0, theta=0.0
% INFO    : Bus 6981	: V=0.973798, theta=-27.289807 -> V=1.0, theta=0.0
% INFO    : Bus 6982	: V=1.087182, theta=-3.617282 -> V=1.0199845, theta=0.0
% INFO    : Bus 6983	: V=1.062168, theta=-18.452467 -> V=1.0, theta=0.0
% INFO    : Bus 6984	: V=1.060768, theta=9.443089 -> V=1.0078245, theta=0.0
% INFO    : Bus 6985	: V=1.067331, theta=-9.73067 -> V=1.01739, theta=0.0
% INFO    : Bus 6986	: V=1.054659, theta=4.97652 -> V=1.00456, theta=0.0
% INFO    : Bus 6987	: V=1.081749, theta=-15.342099 -> V=1.0222835, theta=0.0
% INFO    : Bus 6988	: V=0.979545, theta=-22.120236 -> V=1.0, theta=0.0
% INFO    : Bus 6989	: V=0.973252, theta=-24.235149 -> V=1.0, theta=0.0
% INFO    : Bus 6990	: V=0.975459, theta=-27.222766 -> V=1.0, theta=0.0
% INFO    : Bus 6991	: V=1.079776, theta=-6.576424 -> V=1.0181285, theta=0.0
% INFO    : Bus 6992	: V=0.997045, theta=20.081505 -> V=1.0, theta=0.0
% INFO    : Bus 6993	: V=0.941618, theta=68.041102 -> V=1.0, theta=0.0
% INFO    : Bus 6994	: V=1.033791, theta=-37.338992 -> V=1.0, theta=0.0
% INFO    : Bus 6995	: V=0.950564, theta=-26.072262 -> V=1.0, theta=0.0
% INFO    : Bus 6996	: V=1.077674, theta=-1.771034 -> V=1.02231, theta=0.0
% INFO    : Bus 6997	: V=1.000264, theta=-22.280101 -> V=1.0, theta=0.0
% INFO    : Bus 6998	: V=0.990589, theta=-33.223626 -> V=1.0, theta=0.0
% INFO    : Bus 6999	: V=1.024302, theta=11.796701 -> V=1.0, theta=0.0
% INFO    : Bus 7000	: V=1.046525, theta=10.175765 -> V=1.0030035, theta=0.0
% INFO    : Bus 7001	: V=1.067086, theta=-8.325421 -> V=1.014624, theta=0.0
% INFO    : Bus 7002	: V=1.053864, theta=-36.117302 -> V=1.0182255, theta=0.0
% INFO    : Bus 7003	: V=1.045001, theta=-17.9902 -> V=1.0, theta=0.0
% INFO    : Bus 7004	: V=0.940228, theta=-31.944613 -> V=0.971897, theta=0.0
% INFO    : Bus 7005	: V=1.022742, theta=-29.884466 -> V=1.0, theta=0.0
% INFO    : Bus 7006	: V=0.985698, theta=-27.551281 -> V=1.0, theta=0.0
% INFO    : Bus 7007	: V=1.035914, theta=-27.498447 -> V=1.0, theta=0.0
% INFO    : Bus 7008	: V=1.034167, theta=-23.426603 -> V=1.0098295, theta=0.0
% INFO    : Bus 7009	: V=1.046085, theta=9.750951 -> V=1.0034135, theta=0.0
% INFO    : Bus 7010	: V=1.067117, theta=-9.698373 -> V=1.017219, theta=0.0
% INFO    : Bus 7011	: V=1.060477, theta=-31.367303 -> V=1.011849, theta=0.0
% INFO    : Bus 7012	: V=1.043514, theta=5.148487 -> V=1.0054605, theta=0.0
% INFO    : Bus 7013	: V=0.999367, theta=-23.854285 -> V=1.0, theta=0.0
% INFO    : Bus 7014	: V=1.050863, theta=-8.558965 -> V=1.0104745, theta=0.0
% INFO    : Bus 7015	: V=1.044503, theta=-23.637682 -> V=1.0, theta=0.0
% INFO    : Bus 7016	: V=0.9464, theta=-27.90981 -> V=1.0, theta=0.0
% INFO    : Bus 7017	: V=1.043343, theta=-15.729372 -> V=1.0, theta=0.0
% INFO    : Bus 7018	: V=1.06956, theta=-1.802965 -> V=1.023911, theta=0.0
% INFO    : Bus 7019	: V=1.073817, theta=-17.186738 -> V=1.0119325, theta=0.0
% INFO    : Bus 7020	: V=1.045312, theta=-21.493095 -> V=1.0156915, theta=0.0
% INFO    : Bus 7021	: V=0.970346, theta=-25.284915 -> V=1.0, theta=0.0
% INFO    : Bus 7022	: V=1.006122, theta=-25.019137 -> V=1.0, theta=0.0
% INFO    : Bus 7023	: V=0.980864, theta=43.59736 -> V=1.0, theta=0.0
% INFO    : Bus 7024	: V=0.982867, theta=61.927297 -> V=1.0, theta=0.0
% INFO    : Bus 7025	: V=1.018455, theta=-21.983016 -> V=1.0, theta=0.0
% INFO    : Bus 7026	: V=1.01927, theta=-20.86309 -> V=1.00408, theta=0.0
% INFO    : Bus 7027	: V=0.989144, theta=-24.869914 -> V=1.0, theta=0.0
% INFO    : Bus 7028	: V=1.025112, theta=-15.842941 -> V=1.0, theta=0.0
% INFO    : Bus 7029	: V=1.038411, theta=-4.981088 -> V=1.0, theta=0.0
% INFO    : Bus 7030	: V=1.078721, theta=-16.397852 -> V=1.019579, theta=0.0
% INFO    : Bus 7031	: V=1.078443, theta=-0.216923 -> V=1.0232585, theta=0.0
% INFO    : Bus 7032	: V=1.090243, theta=-17.400872 -> V=1.0317725, theta=0.0
% INFO    : Bus 7033	: V=1.026347, theta=-45.414167 -> V=1.0, theta=0.0
% INFO    : Bus 7034	: V=1.089737, theta=-37.888117 -> V=1.0171345, theta=0.0
% INFO    : Bus 7035	: V=0.986835, theta=-23.27976 -> V=1.0, theta=0.0
% INFO    : Bus 7036	: V=1.074406, theta=-13.200076 -> V=1.019684, theta=0.0
% INFO    : Bus 7037	: V=1.102, theta=-10.984823 -> V=1.0217565, theta=0.0
% INFO    : Bus 7038	: V=1.105763, theta=-11.639118 -> V=1.0433725, theta=0.0
% INFO    : Bus 7039	: V=0.986667, theta=-17.641829 -> V=1.0, theta=0.0
% INFO    : Bus 7040	: V=1.033864, theta=-37.31668 -> V=1.0, theta=0.0
% INFO    : Bus 7041	: V=1.034202, theta=-3.975882 -> V=1.0, theta=0.0
% INFO    : Bus 7042	: V=1.044734, theta=-22.312041 -> V=1.0, theta=0.0
% INFO    : Bus 7043	: V=1.074782, theta=-17.572839 -> V=1.0211785, theta=0.0
% INFO    : Bus 7044	: V=0.967959, theta=-26.250037 -> V=1.0, theta=0.0
% INFO    : Bus 7045	: V=1.042076, theta=-12.670272 -> V=1.007236, theta=0.0
% INFO    : Bus 7046	: V=1.067289, theta=-10.004155 -> V=1.017048, theta=0.0
% INFO    : Bus 7047	: V=1.036916, theta=-28.99692 -> V=1.0, theta=0.0
% INFO    : Bus 7048	: V=1.030014, theta=-41.833994 -> V=1.01049, theta=0.0
% INFO    : Bus 7049	: V=1.094708, theta=45.080976 -> V=1.008683, theta=0.0
% INFO    : Bus 7050	: V=1.047276, theta=-25.522367 -> V=1.013657, theta=0.0
% INFO    : Bus 7051	: V=1.043068, theta=-20.691062 -> V=1.0, theta=0.0
% INFO    : Bus 7052	: V=1.072246, theta=-23.050874 -> V=1.0, theta=0.0
% INFO    : Bus 7053	: V=1.068988, theta=-27.441829 -> V=1.032924, theta=0.0
% INFO    : Bus 7054	: V=1.102158, theta=5.615684 -> V=1.0200785, theta=0.0
% INFO    : Bus 7055	: V=1.077222, theta=-15.058076 -> V=1.0118465, theta=0.0
% INFO    : Bus 7056	: V=1.072576, theta=-15.858225 -> V=1.0254295, theta=0.0
% INFO    : Bus 7057	: V=1.0968, theta=8.66518 -> V=1.0285305, theta=0.0
% INFO    : Bus 7058	: V=1.037031, theta=9.681796 -> V=1.0, theta=0.0
% INFO    : Bus 7059	: V=1.048643, theta=-21.637845 -> V=1.0236355, theta=0.0
% INFO    : Bus 7060	: V=0.966934, theta=-26.980067 -> V=1.0, theta=0.0
% INFO    : Bus 7061	: V=0.991751, theta=-35.000203 -> V=1.0, theta=0.0
% INFO    : Bus 7062	: V=1.078, theta=-21.481135 -> V=1.0115525, theta=0.0
% INFO    : Bus 7063	: V=1.019095, theta=-4.701969 -> V=1.0, theta=0.0
% INFO    : Bus 7064	: V=1.035439, theta=-46.06124 -> V=1.0, theta=0.0
% INFO    : Bus 7065	: V=1.040516, theta=-17.079916 -> V=1.006729, theta=0.0
% INFO    : Bus 7066	: V=1.039662, theta=-12.933214 -> V=1.0063235, theta=0.0
% INFO    : Bus 7067	: V=1.025724, theta=-33.703825 -> V=1.0, theta=0.0
% INFO    : Bus 7068	: V=1.006991, theta=-18.053104 -> V=1.0, theta=0.0
% INFO    : Bus 7069	: V=1.069105, theta=-42.06113 -> V=1.008794, theta=0.0
% INFO    : Bus 7070	: V=1.065646, theta=-20.057669 -> V=1.0112325, theta=0.0
% INFO    : Bus 7071	: V=1.061558, theta=-22.965362 -> V=1.0178335, theta=0.0
% INFO    : Bus 7072	: V=1.031909, theta=-10.73565 -> V=1.0, theta=0.0
% INFO    : Bus 7073	: V=1.071638, theta=26.939087 -> V=1.0, theta=0.0
% INFO    : Bus 7074	: V=0.996273, theta=-25.767058 -> V=1.0, theta=0.0
% INFO    : Bus 7075	: V=1.004863, theta=-23.271618 -> V=1.0, theta=0.0
% INFO    : Bus 7076	: V=1.019315, theta=13.622221 -> V=1.0, theta=0.0
% INFO    : Bus 7077	: V=1.053829, theta=-35.41466 -> V=1.0171175, theta=0.0
% INFO    : Bus 7078	: V=1.054748, theta=-49.100485 -> V=1.0059325, theta=0.0
% INFO    : Bus 7079	: V=0.963356, theta=-13.277647 -> V=1.0, theta=0.0
% INFO    : Bus 7080	: V=1.100967, theta=-13.436012 -> V=1.022816, theta=0.0
% INFO    : Bus 7081	: V=1.092, theta=-0.661068 -> V=1.026526, theta=0.0
% INFO    : Bus 7082	: V=1.056609, theta=-10.642723 -> V=1.009778, theta=0.0
% INFO    : Bus 7083	: V=1.089309, theta=-45.27716 -> V=1.0224175, theta=0.0
% INFO    : Bus 7084	: V=1.051911, theta=60.74 -> V=1.002893, theta=0.0
% INFO    : Bus 7085	: V=1.020409, theta=-14.595189 -> V=1.0, theta=0.0
% INFO    : Bus 7086	: V=0.961349, theta=-18.477656 -> V=1.0, theta=0.0
% INFO    : Bus 7087	: V=1.047743, theta=-21.190113 -> V=1.0, theta=0.0
% INFO    : Bus 7088	: V=1.073504, theta=30.283226 -> V=1.0159875, theta=0.0
% INFO    : Bus 7089	: V=1.090865, theta=-21.723802 -> V=1.0205185, theta=0.0
% INFO    : Bus 7090	: V=1.053235, theta=-15.373644 -> V=1.0043945, theta=0.0
% INFO    : Bus 7091	: V=1.064681, theta=-36.33216 -> V=1.013508, theta=0.0
% INFO    : Bus 7092	: V=1.054494, theta=-49.44811 -> V=1.0, theta=0.0
% INFO    : Bus 7093	: V=1.085415, theta=-46.137996 -> V=1.013538, theta=0.0
% INFO    : Bus 7094	: V=0.914372, theta=-34.680605 -> V=0.9475, theta=0.0
% INFO    : Bus 7095	: V=1.018431, theta=-18.314488 -> V=1.0069745, theta=0.0
% INFO    : Bus 7096	: V=1.076097, theta=-5.913718 -> V=1.0178205, theta=0.0
% INFO    : Bus 7097	: V=0.989976, theta=-25.376837 -> V=1.0, theta=0.0
% INFO    : Bus 7098	: V=1.048163, theta=-15.484434 -> V=1.0, theta=0.0
% INFO    : Bus 7099	: V=1.072595, theta=-38.502302 -> V=1.0168135, theta=0.0
% INFO    : Bus 7100	: V=1.053455, theta=-24.692752 -> V=1.01302, theta=0.0
% INFO    : Bus 7101	: V=1.082921, theta=-5.922173 -> V=1.018333, theta=0.0
% INFO    : Bus 7102	: V=1.060454, theta=-20.768926 -> V=1.0186895, theta=0.0
% INFO    : Bus 7103	: V=1.068978, theta=-10.939093 -> V=1.0127215, theta=0.0
% INFO    : Bus 7104	: V=0.973661, theta=-25.897989 -> V=1.0, theta=0.0
% INFO    : Bus 7105	: V=1.039591, theta=-43.461851 -> V=1.008439, theta=0.0
% INFO    : Bus 7106	: V=1.037828, theta=-48.439945 -> V=1.0, theta=0.0
% INFO    : Bus 7107	: V=1.075227, theta=-29.933773 -> V=1.014363, theta=0.0
% INFO    : Bus 7108	: V=0.995, theta=-16.258164 -> V=1.0, theta=0.0
% INFO    : Bus 7109	: V=0.986864, theta=-24.173699 -> V=1.0, theta=0.0
% INFO    : Bus 7110	: V=0.958053, theta=-24.989793 -> V=1.0, theta=0.0
% INFO    : Bus 7111	: V=0.976402, theta=-27.769314 -> V=1.0, theta=0.0
% INFO    : Bus 7112	: V=1.090578, theta=-2.797451 -> V=1.024731, theta=0.0
% INFO    : Bus 7113	: V=1.060524, theta=-31.365126 -> V=1.012016, theta=0.0
% INFO    : Bus 7114	: V=1.072474, theta=-11.780965 -> V=1.013112, theta=0.0
% INFO    : Bus 7115	: V=1.049818, theta=-17.386768 -> V=1.0, theta=0.0
% INFO    : Bus 7116	: V=1.095383, theta=9.125973 -> V=1.024984, theta=0.0
% INFO    : Bus 7117	: V=1.051639, theta=-48.862652 -> V=1.0053915, theta=0.0
% INFO    : Bus 7118	: V=1.026192, theta=-24.47222 -> V=1.0, theta=0.0
% INFO    : Bus 7119	: V=1.021552, theta=-8.652584 -> V=1.00965, theta=0.0
% INFO    : Bus 7120	: V=0.972392, theta=-26.068567 -> V=1.0, theta=0.0
% INFO    : Bus 7121	: V=1.066859, theta=29.878114 -> V=1.0132345, theta=0.0
% INFO    : Bus 7122	: V=1.043136, theta=-18.538696 -> V=1.0, theta=0.0
% INFO    : Bus 7123	: V=1.059798, theta=-0.581511 -> V=1.0112805, theta=0.0
% INFO    : Bus 7124	: V=0.9939, theta=-23.027755 -> V=1.0, theta=0.0
% INFO    : Bus 7125	: V=0.94391, theta=31.499903 -> V=1.0, theta=0.0
% INFO    : Bus 7126	: V=1.04366, theta=-34.215288 -> V=1.0031855, theta=0.0
% INFO    : Bus 7127	: V=1.082486, theta=16.216207 -> V=1.013755, theta=0.0
% INFO    : Bus 7128	: V=1.075838, theta=0.279493 -> V=1.0255505, theta=0.0
% INFO    : Bus 7129	: V=1.026445, theta=-23.767126 -> V=1.0, theta=0.0
% INFO    : Bus 7130	: V=1.006458, theta=10.014592 -> V=1.0, theta=0.0
% INFO    : Bus 7131	: V=1.091763, theta=-36.40366 -> V=1.021621, theta=0.0
% INFO    : Bus 7132	: V=1.049973, theta=-37.023618 -> V=1.004816, theta=0.0
% INFO    : Bus 7133	: V=1.078148, theta=-20.065595 -> V=1.028622, theta=0.0
% INFO    : Bus 7134	: V=0.978855, theta=-26.750908 -> V=1.0, theta=0.0
% INFO    : Bus 7135	: V=0.989876, theta=-26.619696 -> V=1.0, theta=0.0
% INFO    : Bus 7136	: V=1.076304, theta=-25.487035 -> V=1.0331545, theta=0.0
% INFO    : Bus 7137	: V=0.974161, theta=-18.155217 -> V=1.0, theta=0.0
% INFO    : Bus 7138	: V=1.050823, theta=-19.781828 -> V=1.0, theta=0.0
% INFO    : Bus 7139	: V=1.033904, theta=-25.118203 -> V=1.0, theta=0.0
% INFO    : Bus 7140	: V=1.07208, theta=-42.176185 -> V=1.0090005, theta=0.0
% INFO    : Bus 7141	: V=1.075487, theta=-17.275574 -> V=1.023649, theta=0.0
% INFO    : Bus 7142	: V=0.987472, theta=-25.207427 -> V=1.0, theta=0.0
% INFO    : Bus 7143	: V=1.076682, theta=-17.420027 -> V=1.0076115, theta=0.0
% INFO    : Bus 7144	: V=1.064234, theta=-14.260181 -> V=1.017508, theta=0.0
% INFO    : Bus 7145	: V=1.028516, theta=16.675292 -> V=1.0, theta=0.0
% INFO    : Bus 7146	: V=1.007278, theta=-41.454021 -> V=1.0, theta=0.0
% INFO    : Bus 7147	: V=1.07998, theta=67.259738 -> V=1.0, theta=0.0
% INFO    : Bus 7148	: V=1.038913, theta=-45.949342 -> V=1.0, theta=0.0
% INFO    : Bus 7149	: V=1.074286, theta=0.702798 -> V=1.0248665, theta=0.0
% INFO    : Bus 7150	: V=1.007391, theta=-50.933435 -> V=1.0, theta=0.0
% INFO    : Bus 7151	: V=1.047868, theta=20.808588 -> V=1.0038895, theta=0.0
% INFO    : Bus 7152	: V=1.083129, theta=-14.793888 -> V=1.0310925, theta=0.0
% INFO    : Bus 7153	: V=1.025963, theta=-15.483788 -> V=1.007839, theta=0.0
% INFO    : Bus 7154	: V=1.032701, theta=-28.213048 -> V=1.0187935, theta=0.0
% INFO    : Bus 7155	: V=1.08353, theta=3.086707 -> V=1.0269805, theta=0.0
% INFO    : Bus 7156	: V=1.078274, theta=-20.096469 -> V=1.0205325, theta=0.0
% INFO    : Bus 7157	: V=1.049702, theta=-18.078204 -> V=1.007552, theta=0.0
% INFO    : Bus 7158	: V=0.986899, theta=63.936157 -> V=1.0, theta=0.0
% INFO    : Bus 7159	: V=1.067061, theta=-14.106802 -> V=1.015578, theta=0.0
% INFO    : Bus 7160	: V=1.064722, theta=-0.360925 -> V=1.0319895, theta=0.0
% INFO    : Bus 7161	: V=1.064521, theta=-35.795365 -> V=1.013425, theta=0.0
% INFO    : Bus 7162	: V=1.051053, theta=-10.982984 -> V=1.015855, theta=0.0
% INFO    : Bus 7163	: V=1.048829, theta=-44.680892 -> V=1.0, theta=0.0
% INFO    : Bus 7164	: V=1.078899, theta=-18.848241 -> V=1.0400185, theta=0.0
% INFO    : Bus 7165	: V=1.093273, theta=-11.105072 -> V=1.02169, theta=0.0
% INFO    : Bus 7166	: V=0.993622, theta=-24.438347 -> V=1.0, theta=0.0
% INFO    : Bus 7167	: V=1.062965, theta=23.326229 -> V=1.0, theta=0.0
% INFO    : Bus 7168	: V=0.978063, theta=-22.052468 -> V=1.0, theta=0.0
% INFO    : Bus 7169	: V=0.996028, theta=-22.428711 -> V=1.0, theta=0.0
% INFO    : Bus 7170	: V=1.008653, theta=-38.44521 -> V=1.0, theta=0.0
% INFO    : Bus 7171	: V=1.03984, theta=-11.497765 -> V=1.0, theta=0.0
% INFO    : Bus 7172	: V=1.050358, theta=-41.174225 -> V=1.0420945, theta=0.0
% INFO    : Bus 7173	: V=1.030031, theta=-22.502842 -> V=1.0, theta=0.0
% INFO    : Bus 7174	: V=1.059253, theta=-17.144593 -> V=1.0248985, theta=0.0
% INFO    : Bus 7175	: V=1.044792, theta=-22.264221 -> V=1.0, theta=0.0
% INFO    : Bus 7176	: V=1.015262, theta=-18.684439 -> V=1.0, theta=0.0
% INFO    : Bus 7177	: V=1.06991, theta=1.005972 -> V=1.0120645, theta=0.0
% INFO    : Bus 7178	: V=1.007429, theta=-27.604642 -> V=1.0465435, theta=0.0
% INFO    : Bus 7179	: V=1.006595, theta=-25.950033 -> V=1.0, theta=0.0
% INFO    : Bus 7180	: V=1.100789, theta=-8.698038 -> V=1.035705, theta=0.0
% INFO    : Bus 7181	: V=1.083769, theta=-6.709414 -> V=1.0251565, theta=0.0
% INFO    : Bus 7182	: V=1.043032, theta=14.666805 -> V=1.0, theta=0.0
% INFO    : Bus 7183	: V=1.018857, theta=-33.907754 -> V=1.0, theta=0.0
% INFO    : Bus 7184	: V=1.075024, theta=-15.566842 -> V=1.0111565, theta=0.0
% INFO    : Bus 7185	: V=1.088024, theta=-43.623718 -> V=1.0161445, theta=0.0
% INFO    : Bus 7186	: V=1.095453, theta=45.663249 -> V=1.0034675, theta=0.0
% INFO    : Bus 7187	: V=1.052007, theta=-7.599801 -> V=1.0107765, theta=0.0
% INFO    : Bus 7188	: V=1.056465, theta=-15.360872 -> V=1.004134, theta=0.0
% INFO    : Bus 7189	: V=1.09824, theta=-15.421677 -> V=1.0439825, theta=0.0
% INFO    : Bus 7190	: V=1.0626, theta=-21.149034 -> V=1.019827, theta=0.0
% INFO    : Bus 7191	: V=1.040701, theta=5.335823 -> V=1.0078385, theta=0.0
% INFO    : Bus 7192	: V=1.091541, theta=-38.815441 -> V=1.031984, theta=0.0
% INFO    : Bus 7193	: V=1.057157, theta=-29.962628 -> V=1.0058025, theta=0.0
% INFO    : Bus 7194	: V=1.083474, theta=-39.891533 -> V=1.012563, theta=0.0
% INFO    : Bus 7195	: V=0.969177, theta=-24.677143 -> V=1.0, theta=0.0
% INFO    : Bus 7196	: V=1.039859, theta=-19.227714 -> V=1.006268, theta=0.0
% INFO    : Bus 7197	: V=1.007912, theta=-18.859427 -> V=1.0, theta=0.0
% INFO    : Bus 7198	: V=0.999118, theta=-16.135873 -> V=1.0, theta=0.0
% INFO    : Bus 7199	: V=1.073026, theta=47.072896 -> V=1.0, theta=0.0
% INFO    : Bus 7200	: V=1.09384, theta=-43.293679 -> V=1.025464, theta=0.0
% INFO    : Bus 7201	: V=1.044709, theta=-13.062855 -> V=1.0, theta=0.0
% INFO    : Bus 7202	: V=1.064359, theta=-7.164324 -> V=1.0099645, theta=0.0
% INFO    : Bus 7203	: V=0.939324, theta=-28.10132 -> V=1.0, theta=0.0
% INFO    : Bus 7204	: V=1.001498, theta=-26.883562 -> V=1.0, theta=0.0
% INFO    : Bus 7205	: V=1.099132, theta=-15.350846 -> V=1.043799, theta=0.0
% INFO    : Bus 7206	: V=1.052471, theta=56.405779 -> V=1.0, theta=0.0
% INFO    : Bus 7207	: V=1.042449, theta=18.72672 -> V=1.0, theta=0.0
% INFO    : Bus 7208	: V=1.059649, theta=-15.0708 -> V=1.0061165, theta=0.0
% INFO    : Bus 7209	: V=1.043302, theta=-1.107156 -> V=1.0075515, theta=0.0
% INFO    : Bus 7210	: V=1.067596, theta=-5.775818 -> V=1.011533, theta=0.0
% INFO    : Bus 7211	: V=1.064938, theta=-20.948845 -> V=1.0177135, theta=0.0
% INFO    : Bus 7212	: V=1.057495, theta=-30.223747 -> V=1.0116675, theta=0.0
% INFO    : Bus 7213	: V=0.975574, theta=-23.053534 -> V=1.0, theta=0.0
% INFO    : Bus 7214	: V=1.048107, theta=-0.310559 -> V=1.0115135, theta=0.0
% INFO    : Bus 7215	: V=1.030024, theta=-25.175733 -> V=1.0, theta=0.0
% INFO    : Bus 7216	: V=1.056132, theta=-1.591374 -> V=1.0170125, theta=0.0
% INFO    : Bus 7217	: V=1.038283, theta=4.775676 -> V=1.0048315, theta=0.0
% INFO    : Bus 7218	: V=1.074809, theta=-22.773441 -> V=1.031396, theta=0.0
% INFO    : Bus 7219	: V=0.986855, theta=-9.591664 -> V=1.0, theta=0.0
% INFO    : Bus 7220	: V=1.055821, theta=-9.166194 -> V=1.0140965, theta=0.0
% INFO    : Bus 7221	: V=1.078153, theta=0.274482 -> V=1.0238055, theta=0.0
% INFO    : Bus 7222	: V=1.103538, theta=-16.242814 -> V=1.0316305, theta=0.0
% INFO    : Bus 7223	: V=1.086026, theta=1.571045 -> V=1.0175285, theta=0.0
% INFO    : Bus 7224	: V=1.077626, theta=-8.011946 -> V=1.0218915, theta=0.0
% INFO    : Bus 7225	: V=1.030372, theta=-25.114039 -> V=1.0, theta=0.0
% INFO    : Bus 7226	: V=1.097543, theta=-34.310796 -> V=1.03003, theta=0.0
% INFO    : Bus 7227	: V=1.073701, theta=-5.745494 -> V=1.0214895, theta=0.0
% INFO    : Bus 7228	: V=1.045444, theta=-11.499606 -> V=1.008479, theta=0.0
% INFO    : Bus 7229	: V=0.998642, theta=-29.559814 -> V=1.0, theta=0.0
% INFO    : Bus 7230	: V=1.075997, theta=-38.291036 -> V=1.0184445, theta=0.0
% INFO    : Bus 7231	: V=0.977604, theta=-24.596546 -> V=1.0, theta=0.0
% INFO    : Bus 7232	: V=1.040028, theta=7.268137 -> V=1.0070145, theta=0.0
% INFO    : Bus 7233	: V=1.050024, theta=-18.065682 -> V=1.0, theta=0.0
% INFO    : Bus 7234	: V=1.050682, theta=-49.319411 -> V=1.0063795, theta=0.0
% INFO    : Bus 7235	: V=1.069289, theta=-19.082173 -> V=1.0187605, theta=0.0
% INFO    : Bus 7236	: V=0.965598, theta=-21.358434 -> V=1.0, theta=0.0
% INFO    : Bus 7237	: V=0.940568, theta=-29.185387 -> V=0.995983, theta=0.0
% INFO    : Bus 7238	: V=1.002778, theta=-21.989824 -> V=1.0, theta=0.0
% INFO    : Bus 7239	: V=1.104789, theta=-18.769461 -> V=1.0225875, theta=0.0
% INFO    : Bus 7240	: V=1.071598, theta=-39.403259 -> V=1.0163745, theta=0.0
% INFO    : Bus 7241	: V=0.978805, theta=-22.629217 -> V=1.0, theta=0.0
% INFO    : Bus 7242	: V=1.061627, theta=-22.104434 -> V=1.019634, theta=0.0
% INFO    : Bus 7243	: V=1.04406, theta=-3.619901 -> V=1.0075705, theta=0.0
% INFO    : Bus 7244	: V=1.05168, theta=-21.501579 -> V=1.0, theta=0.0
% INFO    : Bus 7245	: V=1.07169, theta=-2.020785 -> V=1.0179825, theta=0.0
% INFO    : Bus 7246	: V=1.086488, theta=-3.75361 -> V=1.019706, theta=0.0
% INFO    : Bus 7247	: V=1.044944, theta=-20.907491 -> V=1.0, theta=0.0
% INFO    : Bus 7248	: V=1.037705, theta=-19.714048 -> V=1.0, theta=0.0
% INFO    : Bus 7249	: V=1.079497, theta=-24.475019 -> V=1.015798, theta=0.0
% INFO    : Bus 7250	: V=0.966154, theta=-19.655089 -> V=1.0, theta=0.0
% INFO    : Bus 7251	: V=1.054548, theta=-15.939933 -> V=1.0132515, theta=0.0
% INFO    : Bus 7252	: V=1.066983, theta=-2.473762 -> V=1.022681, theta=0.0
% INFO    : Bus 7253	: V=1.02704, theta=12.019811 -> V=1.0, theta=0.0
% INFO    : Bus 7254	: V=1.076053, theta=3.801855 -> V=1.0113605, theta=0.0
% INFO    : Bus 7255	: V=1.065278, theta=-43.867345 -> V=1.007191, theta=0.0
% INFO    : Bus 7256	: V=1.046839, theta=-15.762775 -> V=1.0, theta=0.0
% INFO    : Bus 7257	: V=0.951192, theta=63.781 -> V=1.0, theta=0.0
% INFO    : Bus 7258	: V=0.968094, theta=-24.771768 -> V=1.0, theta=0.0
% INFO    : Bus 7259	: V=1.058592, theta=-27.8238 -> V=1.0, theta=0.0
% INFO    : Bus 7260	: V=0.991895, theta=-25.112032 -> V=1.0, theta=0.0
% INFO    : Bus 7261	: V=1.07823, theta=-13.04085 -> V=1.022439, theta=0.0
% INFO    : Bus 7262	: V=1.085055, theta=32.549692 -> V=1.011299, theta=0.0
% INFO    : Bus 7263	: V=1.027148, theta=-50.925176 -> V=1.0, theta=0.0
% INFO    : Bus 7264	: V=1.082395, theta=-42.004033 -> V=1.022932, theta=0.0
% INFO    : Bus 7265	: V=0.994862, theta=-24.324268 -> V=1.0, theta=0.0
% INFO    : Bus 7266	: V=0.958132, theta=-29.694244 -> V=0.9918415, theta=0.0
% INFO    : Bus 7267	: V=1.091334, theta=-36.545337 -> V=1.0257055, theta=0.0
% INFO    : Bus 7268	: V=0.943563, theta=-26.277956 -> V=1.0, theta=0.0
% INFO    : Bus 7269	: V=1.05294, theta=-36.242686 -> V=1.017614, theta=0.0
% INFO    : Bus 7270	: V=0.978599, theta=-23.767561 -> V=1.0, theta=0.0
% INFO    : Bus 7271	: V=1.069206, theta=3.317991 -> V=1.019881, theta=0.0
% INFO    : Bus 7272	: V=1.068149, theta=9.782361 -> V=1.0, theta=0.0
% INFO    : Bus 7273	: V=0.987372, theta=-17.021451 -> V=1.0, theta=0.0
% INFO    : Bus 7274	: V=1.016272, theta=29.760965 -> V=1.0, theta=0.0
% INFO    : Bus 7275	: V=0.98583, theta=-18.022117 -> V=1.0, theta=0.0
% INFO    : Bus 7276	: V=1.010369, theta=-27.104249 -> V=1.0, theta=0.0
% INFO    : Bus 7277	: V=1.062241, theta=-10.341724 -> V=1.010793, theta=0.0
% INFO    : Bus 7278	: V=1.017139, theta=-26.263379 -> V=1.039698, theta=0.0
% INFO    : Bus 7279	: V=0.997525, theta=-25.844665 -> V=1.0, theta=0.0
% INFO    : Bus 7280	: V=0.96649, theta=-22.247036 -> V=1.0, theta=0.0
% INFO    : Bus 7281	: V=1.024771, theta=62.246746 -> V=1.0, theta=0.0
% INFO    : Bus 7282	: V=1.075795, theta=0.231624 -> V=1.01439, theta=0.0
% INFO    : Bus 7283	: V=1.036696, theta=-28.275684 -> V=1.0, theta=0.0
% INFO    : Bus 7284	: V=1.05064, theta=-4.743452 -> V=1.0130815, theta=0.0
% INFO    : Bus 7285	: V=1.073496, theta=-4.632062 -> V=1.020192, theta=0.0
% INFO    : Bus 7286	: V=0.931588, theta=-35.432278 -> V=1.0, theta=0.0
% INFO    : Bus 7287	: V=0.943347, theta=65.005995 -> V=1.0, theta=0.0
% INFO    : Bus 7288	: V=1.030319, theta=11.808679 -> V=1.0, theta=0.0
% INFO    : Bus 7289	: V=1.083362, theta=-45.468661 -> V=1.0241125, theta=0.0
% INFO    : Bus 7290	: V=1.081068, theta=-15.386625 -> V=1.0216945, theta=0.0
% INFO    : Bus 7291	: V=1.059864, theta=-44.810705 -> V=1.0078685, theta=0.0
% INFO    : Bus 7292	: V=1.084771, theta=7.89377 -> V=1.0195805, theta=0.0
% INFO    : Bus 7293	: V=0.915847, theta=-26.450034 -> V=1.0, theta=0.0
% INFO    : Bus 7294	: V=0.989613, theta=-25.883988 -> V=1.0, theta=0.0
% INFO    : Bus 7295	: V=1.100181, theta=-14.669544 -> V=1.0413875, theta=0.0
% INFO    : Bus 7296	: V=1.04045, theta=-19.934266 -> V=1.0100095, theta=0.0
% INFO    : Bus 7297	: V=1.066182, theta=-10.712501 -> V=1.021336, theta=0.0
% INFO    : Bus 7298	: V=1.072727, theta=22.538622 -> V=1.0088585, theta=0.0
% INFO    : Bus 7299	: V=1.003909, theta=-35.336982 -> V=1.0, theta=0.0
% INFO    : Bus 7300	: V=1.043654, theta=-21.334026 -> V=1.002737, theta=0.0
% INFO    : Bus 7301	: V=0.999861, theta=-23.664782 -> V=1.0, theta=0.0
% INFO    : Bus 7302	: V=1.099781, theta=-17.1543 -> V=1.034056, theta=0.0
% INFO    : Bus 7303	: V=0.967256, theta=-20.737696 -> V=1.0, theta=0.0
% INFO    : Bus 7304	: V=0.978362, theta=-23.354553 -> V=1.0, theta=0.0
% INFO    : Bus 7305	: V=1.06625, theta=-19.327155 -> V=1.0, theta=0.0
% INFO    : Bus 7306	: V=1.027512, theta=-25.796708 -> V=1.0, theta=0.0
% INFO    : Bus 7307	: V=1.009701, theta=-30.79746 -> V=1.0, theta=0.0
% INFO    : Bus 7308	: V=1.010357, theta=-36.439182 -> V=1.0, theta=0.0
% INFO    : Bus 7309	: V=1.082409, theta=-8.528567 -> V=1.026275, theta=0.0
% INFO    : Bus 7310	: V=1.067222, theta=9.766752 -> V=1.0, theta=0.0
% INFO    : Bus 7311	: V=1.008924, theta=-19.483087 -> V=1.0, theta=0.0
% INFO    : Bus 7312	: V=1.0468, theta=-13.06294 -> V=1.0161865, theta=0.0
% INFO    : Bus 7313	: V=0.986843, theta=-17.234553 -> V=1.0, theta=0.0
% INFO    : Bus 7314	: V=1.004639, theta=-19.753918 -> V=1.0, theta=0.0
% INFO    : Bus 7315	: V=1.016428, theta=-30.02403 -> V=1.0, theta=0.0
% INFO    : Bus 7316	: V=1.099842, theta=-19.478075 -> V=1.022433, theta=0.0
% INFO    : Bus 7317	: V=1.003182, theta=-43.017392 -> V=1.0, theta=0.0
% INFO    : Bus 7318	: V=1.041587, theta=-11.432247 -> V=1.0089805, theta=0.0
% INFO    : Bus 7319	: V=1.054729, theta=-48.853168 -> V=1.005759, theta=0.0
% INFO    : Bus 7320	: V=1.043601, theta=-45.249468 -> V=1.005257, theta=0.0
% INFO    : Bus 7321	: V=0.97364, theta=-25.769326 -> V=1.0, theta=0.0
% INFO    : Bus 7322	: V=0.989795, theta=-17.165993 -> V=1.0, theta=0.0
% INFO    : Bus 7323	: V=1.086039, theta=-2.972324 -> V=1.022839, theta=0.0
% INFO    : Bus 7324	: V=1.044052, theta=-3.980561 -> V=1.0, theta=0.0
% INFO    : Bus 7325	: V=1.008188, theta=-21.944848 -> V=1.0, theta=0.0
% INFO    : Bus 7326	: V=0.99369, theta=-23.398187 -> V=1.0, theta=0.0
% INFO    : Bus 7327	: V=1.020962, theta=-20.978968 -> V=1.0, theta=0.0
% INFO    : Bus 7328	: V=1.0394, theta=-44.329828 -> V=1.0, theta=0.0
% INFO    : Bus 7329	: V=1.038995, theta=-22.498736 -> V=1.0, theta=0.0
% INFO    : Bus 7330	: V=1.010096, theta=-23.832967 -> V=1.0, theta=0.0
% INFO    : Bus 7331	: V=1.016359, theta=-26.868392 -> V=1.042918, theta=0.0
% INFO    : Bus 7332	: V=1.017816, theta=-36.440402 -> V=1.0, theta=0.0
% INFO    : Bus 7333	: V=1.066041, theta=11.922022 -> V=1.00857, theta=0.0
% INFO    : Bus 7334	: V=1.026682, theta=-34.588015 -> V=1.0, theta=0.0
% INFO    : Bus 7335	: V=1.079488, theta=-47.003549 -> V=1.018179, theta=0.0
% INFO    : Bus 7336	: V=0.96616, theta=-25.110965 -> V=1.0, theta=0.0
% INFO    : Bus 7337	: V=0.980678, theta=-18.403818 -> V=1.0, theta=0.0
% INFO    : Bus 7338	: V=0.992287, theta=-16.750701 -> V=1.0, theta=0.0
% INFO    : Bus 7339	: V=1.054939, theta=-3.541927 -> V=1.0142515, theta=0.0
% INFO    : Bus 7340	: V=1.008222, theta=-21.944875 -> V=1.0, theta=0.0
% INFO    : Bus 7341	: V=0.981917, theta=62.517424 -> V=1.0, theta=0.0
% INFO    : Bus 7342	: V=1.043636, theta=-20.348152 -> V=1.0, theta=0.0
% INFO    : Bus 7343	: V=0.91536, theta=-26.565359 -> V=1.0, theta=0.0
% INFO    : Bus 7344	: V=1.025583, theta=-45.498818 -> V=1.0, theta=0.0
% INFO    : Bus 7345	: V=1.06814, theta=5.260044 -> V=1.013187, theta=0.0
% INFO    : Bus 7346	: V=1.069409, theta=-20.36507 -> V=1.005158, theta=0.0
% INFO    : Bus 7347	: V=0.975062, theta=-25.660261 -> V=1.0, theta=0.0
% INFO    : Bus 7348	: V=1.045868, theta=-4.172344 -> V=1.0, theta=0.0
% INFO    : Bus 7349	: V=1.072915, theta=-24.30099 -> V=1.030711, theta=0.0
% INFO    : Bus 7350	: V=1.060304, theta=-22.324592 -> V=1.019047, theta=0.0
% INFO    : Bus 7351	: V=1.04197, theta=-20.022602 -> V=1.0, theta=0.0
% INFO    : Bus 7352	: V=1.052974, theta=-20.392315 -> V=1.01913, theta=0.0
% INFO    : Bus 7353	: V=1.033245, theta=-25.20708 -> V=1.0, theta=0.0
% INFO    : Bus 7354	: V=1.075831, theta=-4.470419 -> V=1.0185865, theta=0.0
% INFO    : Bus 7355	: V=1.033921, theta=-5.408596 -> V=1.0043375, theta=0.0
% INFO    : Bus 7356	: V=1.030167, theta=9.800946 -> V=1.0, theta=0.0
% INFO    : Bus 7357	: V=0.960477, theta=-13.579467 -> V=1.0, theta=0.0
% INFO    : Bus 7358	: V=1.068816, theta=-37.996206 -> V=1.01811, theta=0.0
% INFO    : Bus 7359	: V=0.982896, theta=-30.124397 -> V=1.0, theta=0.0
% INFO    : Bus 7360	: V=1.021818, theta=-16.696237 -> V=1.0, theta=0.0
% INFO    : Bus 7361	: V=1.058247, theta=-43.767572 -> V=1.0130195, theta=0.0
% INFO    : Bus 7362	: V=1.018818, theta=14.10792 -> V=1.0, theta=0.0
% INFO    : Bus 7363	: V=1.0565, theta=-54.901983 -> V=1.0, theta=0.0
% INFO    : Bus 7364	: V=1.084619, theta=-2.261476 -> V=1.0225615, theta=0.0
% INFO    : Bus 7365	: V=1.084236, theta=-12.691052 -> V=1.014278, theta=0.0
% INFO    : Bus 7366	: V=0.943406, theta=-25.101453 -> V=1.0, theta=0.0
% INFO    : Bus 7367	: V=1.086363, theta=-8.942888 -> V=1.0392065, theta=0.0
% INFO    : Bus 7368	: V=1.013493, theta=61.701025 -> V=1.0, theta=0.0
% INFO    : Bus 7369	: V=0.919681, theta=-29.100332 -> V=0.9844065, theta=0.0
% INFO    : Bus 7370	: V=1.03045, theta=-26.48896 -> V=1.0, theta=0.0
% INFO    : Bus 7371	: V=1.082824, theta=-2.478966 -> V=1.0220685, theta=0.0
% INFO    : Bus 7372	: V=1.018773, theta=14.125259 -> V=1.0, theta=0.0
% INFO    : Bus 7373	: V=1.07591, theta=-19.564358 -> V=1.024942, theta=0.0
% INFO    : Bus 7374	: V=1.061345, theta=-39.084359 -> V=1.011656, theta=0.0
% INFO    : Bus 7375	: V=1.078434, theta=-31.462863 -> V=1.026388, theta=0.0
% INFO    : Bus 7376	: V=1.01355, theta=-31.844116 -> V=1.0, theta=0.0
% INFO    : Bus 7377	: V=1.085043, theta=2.138944 -> V=1.0286955, theta=0.0
% INFO    : Bus 7378	: V=1.050293, theta=-28.923613 -> V=1.010254, theta=0.0
% INFO    : Bus 7379	: V=1.03448, theta=-30.394998 -> V=1.0, theta=0.0
% INFO    : Bus 7380	: V=1.056508, theta=-3.235638 -> V=1.0146195, theta=0.0
% INFO    : Bus 7381	: V=1.048327, theta=-33.406028 -> V=1.0, theta=0.0
% INFO    : Bus 7382	: V=0.988287, theta=-24.112735 -> V=1.0, theta=0.0
% INFO    : Bus 7383	: V=1.044596, theta=-43.768766 -> V=1.00732, theta=0.0
% INFO    : Bus 7384	: V=1.022873, theta=-15.336259 -> V=1.0, theta=0.0
% INFO    : Bus 7385	: V=1.024915, theta=-42.062156 -> V=1.0, theta=0.0
% INFO    : Bus 7386	: V=1.055031, theta=-24.416808 -> V=1.0148925, theta=0.0
% INFO    : Bus 7387	: V=0.975882, theta=-30.33119 -> V=1.0, theta=0.0
% INFO    : Bus 7388	: V=1.007229, theta=-19.866171 -> V=1.0, theta=0.0
% INFO    : Bus 7389	: V=1.076978, theta=-17.688167 -> V=1.0, theta=0.0
% INFO    : Bus 7390	: V=1.08421, theta=7.867258 -> V=1.0197125, theta=0.0
% INFO    : Bus 7391	: V=1.092421, theta=9.512841 -> V=1.013263, theta=0.0
% INFO    : Bus 7392	: V=1.068658, theta=-37.065184 -> V=1.0159995, theta=0.0
% INFO    : Bus 7393	: V=1.091182, theta=-0.520256 -> V=1.027563, theta=0.0
% INFO    : Bus 7394	: V=1.086079, theta=-36.434836 -> V=1.0147605, theta=0.0
% INFO    : Bus 7395	: V=1.011539, theta=-24.859836 -> V=1.0, theta=0.0
% INFO    : Bus 7396	: V=1.082249, theta=-42.003331 -> V=1.0228555, theta=0.0
% INFO    : Bus 7397	: V=1.031597, theta=-22.320669 -> V=1.0, theta=0.0
% INFO    : Bus 7398	: V=1.05464, theta=-49.049606 -> V=1.0051425, theta=0.0
% INFO    : Bus 7399	: V=1.056095, theta=5.507076 -> V=1.004883, theta=0.0
% INFO    : Bus 7400	: V=1.087922, theta=-3.436366 -> V=1.020743, theta=0.0
% INFO    : Bus 7401	: V=1.057017, theta=-22.355401 -> V=1.012468, theta=0.0
% INFO    : Bus 7402	: V=1.053136, theta=3.799813 -> V=1.00461, theta=0.0
% INFO    : Bus 7403	: V=1.011946, theta=-17.894096 -> V=1.006029, theta=0.0
% INFO    : Bus 7404	: V=1.02933, theta=-23.360155 -> V=1.0, theta=0.0
% INFO    : Bus 7405	: V=1.094034, theta=-29.027059 -> V=1.0228475, theta=0.0
% INFO    : Bus 7406	: V=1.095042, theta=-14.731238 -> V=1.027801, theta=0.0
% INFO    : Bus 7407	: V=1.036956, theta=-24.239868 -> V=1.0, theta=0.0
% INFO    : Bus 7408	: V=1.025264, theta=-23.321501 -> V=1.0, theta=0.0
% INFO    : Bus 7409	: V=1.058858, theta=-20.840179 -> V=1.009614, theta=0.0
% INFO    : Bus 7410	: V=1.061668, theta=-7.191828 -> V=1.009918, theta=0.0
% INFO    : Bus 7411	: V=0.938336, theta=-34.936179 -> V=1.0, theta=0.0
% INFO    : Bus 7412	: V=1.00239, theta=-20.015909 -> V=1.0, theta=0.0
% INFO    : Bus 7413	: V=1.027598, theta=-4.990479 -> V=1.0, theta=0.0
% INFO    : Bus 7414	: V=1.06727, theta=-29.900429 -> V=1.0462985, theta=0.0
% INFO    : Bus 7415	: V=1.028341, theta=-4.857575 -> V=1.0, theta=0.0
% INFO    : Bus 7416	: V=1.05914, theta=-18.830154 -> V=1.006951, theta=0.0
% INFO    : Bus 7417	: V=1.101209, theta=-43.269618 -> V=1.028465, theta=0.0
% INFO    : Bus 7418	: V=1.033584, theta=-25.139205 -> V=1.0, theta=0.0
% INFO    : Bus 7419	: V=1.052053, theta=-35.414382 -> V=1.0089015, theta=0.0
% INFO    : Bus 7420	: V=1.053, theta=-49.113901 -> V=1.0051935, theta=0.0
% INFO    : Bus 7421	: V=1.029, theta=3.15799 -> V=1.0, theta=0.0
% INFO    : Bus 7422	: V=0.969584, theta=45.39224 -> V=1.0, theta=0.0
% INFO    : Bus 7423	: V=1.058643, theta=-16.954948 -> V=1.006131, theta=0.0
% INFO    : Bus 7424	: V=1.050246, theta=-10.468262 -> V=1.01022, theta=0.0
% INFO    : Bus 7425	: V=1.045191, theta=-14.970076 -> V=1.0160315, theta=0.0
% INFO    : Bus 7426	: V=0.946135, theta=-26.77586 -> V=1.0, theta=0.0
% INFO    : Bus 7427	: V=1.078405, theta=42.899591 -> V=1.007219, theta=0.0
% INFO    : Bus 7428	: V=1.065427, theta=9.498358 -> V=1.0, theta=0.0
% INFO    : Bus 7429	: V=1.046293, theta=-15.946321 -> V=1.0, theta=0.0
% INFO    : Bus 7430	: V=1.023046, theta=-34.057581 -> V=1.0, theta=0.0
% INFO    : Bus 7431	: V=1.032707, theta=25.138987 -> V=1.0, theta=0.0
% INFO    : Bus 7432	: V=1.043895, theta=-13.725475 -> V=1.0037565, theta=0.0
% INFO    : Bus 7433	: V=1.049795, theta=-5.537043 -> V=1.017391, theta=0.0
% INFO    : Bus 7434	: V=0.951192, theta=63.781 -> V=1.0, theta=0.0
% INFO    : Bus 7435	: V=1.086666, theta=0.705652 -> V=1.0267685, theta=0.0
% INFO    : Bus 7436	: V=0.979585, theta=-33.930043 -> V=1.0, theta=0.0
% INFO    : Bus 7437	: V=0.988674, theta=66.037364 -> V=1.0, theta=0.0
% INFO    : Bus 7438	: V=1.020364, theta=-38.191099 -> V=1.0, theta=0.0
% INFO    : Bus 7439	: V=0.946857, theta=-27.169564 -> V=1.0, theta=0.0
% INFO    : Bus 7440	: V=1.068815, theta=-19.1578 -> V=1.0185535, theta=0.0
% INFO    : Bus 7441	: V=1.086553, theta=-34.061549 -> V=1.024168, theta=0.0
% INFO    : Bus 7442	: V=1.042113, theta=15.943032 -> V=1.0053535, theta=0.0
% INFO    : Bus 7443	: V=0.976364, theta=-23.167276 -> V=1.0, theta=0.0
% INFO    : Bus 7444	: V=1.034428, theta=-42.057824 -> V=1.0, theta=0.0
% INFO    : Bus 7445	: V=1.045028, theta=-11.552767 -> V=1.00828, theta=0.0
% INFO    : Bus 7446	: V=1.075773, theta=-34.056762 -> V=1.028077, theta=0.0
% INFO    : Bus 7447	: V=1.032464, theta=-4.605038 -> V=1.006781, theta=0.0
% INFO    : Bus 7448	: V=0.981805, theta=-25.683128 -> V=1.0, theta=0.0
% INFO    : Bus 7449	: V=1.031778, theta=-16.150622 -> V=1.015905, theta=0.0
% INFO    : Bus 7450	: V=1.070809, theta=-14.452301 -> V=1.0116935, theta=0.0
% INFO    : Bus 7451	: V=1.040092, theta=-18.623313 -> V=1.0, theta=0.0
% INFO    : Bus 7452	: V=0.995385, theta=-22.744437 -> V=1.0, theta=0.0
% INFO    : Bus 7453	: V=1.023316, theta=-10.201438 -> V=1.004139, theta=0.0
% INFO    : Bus 7454	: V=1.089237, theta=15.535813 -> V=1.016597, theta=0.0
% INFO    : Bus 7455	: V=1.079148, theta=-37.791928 -> V=1.018559, theta=0.0
% INFO    : Bus 7456	: V=1.071136, theta=-11.023303 -> V=1.025185, theta=0.0
% INFO    : Bus 7457	: V=1.083203, theta=-30.001501 -> V=1.0122455, theta=0.0
% INFO    : Bus 7458	: V=1.077234, theta=-8.979349 -> V=1.011999, theta=0.0
% INFO    : Bus 7459	: V=1.057628, theta=10.061056 -> V=1.005754, theta=0.0
% INFO    : Bus 7460	: V=0.992206, theta=-25.088203 -> V=1.0, theta=0.0
% INFO    : Bus 7461	: V=1.042001, theta=-16.273815 -> V=1.0, theta=0.0
% INFO    : Bus 7462	: V=1.006568, theta=-20.152812 -> V=1.0, theta=0.0
% INFO    : Bus 7463	: V=1.040772, theta=-25.025005 -> V=1.0, theta=0.0
% INFO    : Bus 7464	: V=1.061377, theta=-12.921398 -> V=1.012563, theta=0.0
% INFO    : Bus 7465	: V=1.052842, theta=-49.163713 -> V=1.0056075, theta=0.0
% INFO    : Bus 7466	: V=1.082402, theta=-39.625228 -> V=1.026141, theta=0.0
% INFO    : Bus 7467	: V=1.077479, theta=-17.685252 -> V=1.0, theta=0.0
% INFO    : Bus 7468	: V=1.018958, theta=-35.920482 -> V=1.0, theta=0.0
% INFO    : Bus 7469	: V=1.097921, theta=-35.204136 -> V=1.023044, theta=0.0
% INFO    : Bus 7470	: V=1.066356, theta=-13.279193 -> V=1.01548, theta=0.0
% INFO    : Bus 7471	: V=1.034909, theta=-42.172747 -> V=1.0, theta=0.0
% INFO    : Bus 7472	: V=0.958749, theta=-25.493894 -> V=1.0, theta=0.0
% INFO    : Bus 7473	: V=1.074468, theta=1.596591 -> V=1.0141165, theta=0.0
% INFO    : Bus 7474	: V=0.95113, theta=-23.731422 -> V=1.0, theta=0.0
% INFO    : Bus 7475	: V=1.092549, theta=-16.633678 -> V=1.0260655, theta=0.0
% INFO    : Bus 7476	: V=1.055573, theta=-27.184742 -> V=1.0090775, theta=0.0
% INFO    : Bus 7477	: V=1.085237, theta=-36.747971 -> V=1.0249935, theta=0.0
% INFO    : Bus 7478	: V=1.042314, theta=9.505492 -> V=1.0, theta=0.0
% INFO    : Bus 7479	: V=1.006694, theta=-26.231003 -> V=1.0, theta=0.0
% INFO    : Bus 7480	: V=0.944551, theta=-24.127927 -> V=1.0, theta=0.0
% INFO    : Bus 7481	: V=1.059789, theta=-40.87026 -> V=1.015533, theta=0.0
% INFO    : Bus 7482	: V=1.046427, theta=-22.327748 -> V=1.0, theta=0.0
% INFO    : Bus 7483	: V=1.071949, theta=-13.13778 -> V=1.019259, theta=0.0
% INFO    : Bus 7484	: V=1.082251, theta=19.554224 -> V=1.019112, theta=0.0
% INFO    : Bus 7485	: V=0.985443, theta=-25.578358 -> V=1.0, theta=0.0
% INFO    : Bus 7486	: V=1.095833, theta=-18.484352 -> V=1.038844, theta=0.0
% INFO    : Bus 7487	: V=1.085791, theta=-45.353619 -> V=1.021034, theta=0.0
% INFO    : Bus 7488	: V=0.986791, theta=-24.0981 -> V=1.0, theta=0.0
% INFO    : Bus 7489	: V=1.063255, theta=-37.627627 -> V=1.008817, theta=0.0
% INFO    : Bus 7490	: V=1.042129, theta=15.939173 -> V=1.0053775, theta=0.0
% INFO    : Bus 7491	: V=1.075706, theta=-23.225412 -> V=1.0323015, theta=0.0
% INFO    : Bus 7492	: V=1.034901, theta=-46.113476 -> V=1.0, theta=0.0
% INFO    : Bus 7493	: V=1.090553, theta=-9.884281 -> V=1.0273775, theta=0.0
% INFO    : Bus 7494	: V=1.090434, theta=-21.116068 -> V=1.033101, theta=0.0
% INFO    : Bus 7495	: V=1.015636, theta=-16.61729 -> V=1.0037865, theta=0.0
% INFO    : Bus 7496	: V=1.043922, theta=18.322967 -> V=1.0029385, theta=0.0
% INFO    : Bus 7497	: V=0.954854, theta=-30.624521 -> V=1.0, theta=0.0
% INFO    : Bus 7498	: V=1.069086, theta=-20.015739 -> V=1.014067, theta=0.0
% INFO    : Bus 7499	: V=1.054451, theta=-32.963655 -> V=1.0082545, theta=0.0
% INFO    : Bus 7500	: V=1.037477, theta=-20.06872 -> V=1.0, theta=0.0
% INFO    : Bus 7501	: V=1.012957, theta=-47.504066 -> V=1.0, theta=0.0
% INFO    : Bus 7502	: V=1.040387, theta=-22.163206 -> V=1.0, theta=0.0
% INFO    : Bus 7503	: V=1.028624, theta=16.621691 -> V=1.0, theta=0.0
% INFO    : Bus 7504	: V=1.025867, theta=-28.489218 -> V=1.0, theta=0.0
% INFO    : Bus 7505	: V=1.091193, theta=-8.22951 -> V=1.0139815, theta=0.0
% INFO    : Bus 7506	: V=0.970742, theta=-37.942295 -> V=1.0, theta=0.0
% INFO    : Bus 7507	: V=1.03423, theta=-25.001431 -> V=1.0, theta=0.0
% INFO    : Bus 7508	: V=1.107788, theta=-9.080277 -> V=1.030161, theta=0.0
% INFO    : Bus 7509	: V=0.95972, theta=-30.260309 -> V=1.0, theta=0.0
% INFO    : Bus 7510	: V=1.041081, theta=25.766699 -> V=1.015513, theta=0.0
% INFO    : Bus 7511	: V=1.051735, theta=-49.264396 -> V=1.0, theta=0.0
% INFO    : Bus 7512	: V=1.015569, theta=-12.199598 -> V=1.0, theta=0.0
% INFO    : Bus 7513	: V=1.055733, theta=-21.451281 -> V=1.003082, theta=0.0
% INFO    : Bus 7514	: V=1.069485, theta=8.050012 -> V=1.0195285, theta=0.0
% INFO    : Bus 7515	: V=1.056507, theta=5.933749 -> V=1.02239, theta=0.0
% INFO    : Bus 7516	: V=0.973638, theta=-25.718869 -> V=1.0, theta=0.0
% INFO    : Bus 7517	: V=1.083886, theta=-7.151518 -> V=1.025128, theta=0.0
% INFO    : Bus 7518	: V=1.052698, theta=-15.383663 -> V=1.009262, theta=0.0
% INFO    : Bus 7519	: V=1.058645, theta=-23.660755 -> V=1.016389, theta=0.0
% INFO    : Bus 7520	: V=1.053297, theta=-11.986612 -> V=1.011297, theta=0.0
% INFO    : Bus 7521	: V=1.077359, theta=-18.278899 -> V=1.0097745, theta=0.0
% INFO    : Bus 7522	: V=1.04038, theta=-29.187544 -> V=1.0, theta=0.0
% INFO    : Bus 7523	: V=1.041174, theta=25.746391 -> V=1.015676, theta=0.0
% INFO    : Bus 7524	: V=1.002881, theta=-23.202064 -> V=1.0, theta=0.0
% INFO    : Bus 7525	: V=1.087345, theta=28.19803 -> V=1.0237395, theta=0.0
% INFO    : Bus 7526	: V=1.059983, theta=-47.024751 -> V=1.0067165, theta=0.0
% INFO    : Bus 7527	: V=0.978627, theta=-25.958771 -> V=1.0, theta=0.0
% INFO    : Bus 7528	: V=1.02638, theta=-17.695222 -> V=1.0, theta=0.0
% INFO    : Bus 7529	: V=1.099184, theta=-15.417402 -> V=1.0437925, theta=0.0
% INFO    : Bus 7530	: V=0.98737, theta=-24.009306 -> V=1.0, theta=0.0
% INFO    : Bus 7531	: V=1.078866, theta=-3.883265 -> V=1.01599, theta=0.0
% INFO    : Bus 7532	: V=0.978674, theta=-21.972797 -> V=1.0, theta=0.0
% INFO    : Bus 7533	: V=1.059236, theta=-8.216139 -> V=1.008294, theta=0.0
% INFO    : Bus 7534	: V=1.073455, theta=-13.981342 -> V=1.0146855, theta=0.0
% INFO    : Bus 7535	: V=1.087079, theta=-11.571665 -> V=1.03452, theta=0.0
% INFO    : Bus 7536	: V=1.032678, theta=-15.886812 -> V=1.0, theta=0.0
% INFO    : Bus 7537	: V=0.984714, theta=-17.422043 -> V=1.0, theta=0.0
% INFO    : Bus 7538	: V=1.005985, theta=-22.550643 -> V=1.0, theta=0.0
% INFO    : Bus 7539	: V=1.051126, theta=-25.843931 -> V=1.030499, theta=0.0
% INFO    : Bus 7540	: V=1.082643, theta=16.352349 -> V=1.013777, theta=0.0
% INFO    : Bus 7541	: V=1.054067, theta=-21.066519 -> V=1.028761, theta=0.0
% INFO    : Bus 7542	: V=1.006731, theta=-48.524321 -> V=1.0, theta=0.0
% INFO    : Bus 7543	: V=1.014007, theta=-36.810376 -> V=1.0, theta=0.0
% INFO    : Bus 7544	: V=1.077548, theta=-8.832521 -> V=1.0060435, theta=0.0
% INFO    : Bus 7545	: V=1.029332, theta=-21.484298 -> V=1.0, theta=0.0
% INFO    : Bus 7546	: V=1.0212, theta=-33.805391 -> V=1.0, theta=0.0
% INFO    : Bus 7547	: V=1.01083, theta=-27.349194 -> V=1.0, theta=0.0
% INFO    : Bus 7548	: V=1.073234, theta=-23.210416 -> V=1.019178, theta=0.0
% INFO    : Bus 7549	: V=1.07856, theta=0.918793 -> V=1.0142055, theta=0.0
% INFO    : Bus 7550	: V=1.037295, theta=2.458746 -> V=1.006198, theta=0.0
% INFO    : Bus 7551	: V=1.06035, theta=-12.521323 -> V=1.0220795, theta=0.0
% INFO    : Bus 7552	: V=1.089388, theta=54.328218 -> V=1.0070645, theta=0.0
% INFO    : Bus 7553	: V=1.100982, theta=57.873214 -> V=1.0101125, theta=0.0
% INFO    : Bus 7554	: V=1.059373, theta=-13.671668 -> V=1.0059035, theta=0.0
% INFO    : Bus 7555	: V=1.060754, theta=-11.335388 -> V=1.006482, theta=0.0
% INFO    : Bus 7556	: V=1.076169, theta=0.558076 -> V=1.014145, theta=0.0
% INFO    : Bus 7557	: V=1.074478, theta=-38.749191 -> V=1.0112855, theta=0.0
% INFO    : Bus 7558	: V=1.018404, theta=-40.011149 -> V=1.0, theta=0.0
% INFO    : Bus 7559	: V=0.984427, theta=-24.998416 -> V=1.0, theta=0.0
% INFO    : Bus 7560	: V=1.041467, theta=-24.684337 -> V=1.0, theta=0.0
% INFO    : Bus 7561	: V=1.071714, theta=17.280251 -> V=1.0207585, theta=0.0
% INFO    : Bus 7562	: V=0.937106, theta=-26.705923 -> V=1.0, theta=0.0
% INFO    : Bus 7563	: V=1.088875, theta=-16.361627 -> V=1.032012, theta=0.0
% INFO    : Bus 7564	: V=1.076875, theta=-15.711893 -> V=1.012631, theta=0.0
% INFO    : Bus 7565	: V=1.025917, theta=9.790606 -> V=1.0, theta=0.0
% INFO    : Bus 7566	: V=1.043683, theta=-17.615243 -> V=1.006158, theta=0.0
% INFO    : Bus 7567	: V=0.97596, theta=-20.171897 -> V=1.0, theta=0.0
% INFO    : Bus 7568	: V=1.042665, theta=39.43861 -> V=1.0, theta=0.0
% INFO    : Bus 7569	: V=1.02724, theta=-14.662565 -> V=1.0, theta=0.0
% INFO    : Bus 7570	: V=1.059217, theta=-35.548537 -> V=1.0039215, theta=0.0
% INFO    : Bus 7571	: V=1.068386, theta=-50.905834 -> V=1.0, theta=0.0
% INFO    : Bus 7572	: V=1.052178, theta=-19.924975 -> V=1.002824, theta=0.0
% INFO    : Bus 7573	: V=1.035005, theta=3.901435 -> V=1.0031955, theta=0.0
% INFO    : Bus 7574	: V=1.067355, theta=1.023788 -> V=1.014901, theta=0.0
% INFO    : Bus 7575	: V=0.972834, theta=-25.109377 -> V=1.0, theta=0.0
% INFO    : Bus 7576	: V=1.058032, theta=-18.846545 -> V=1.0219625, theta=0.0
% INFO    : Bus 7577	: V=1.031115, theta=-15.471309 -> V=1.0123135, theta=0.0
% INFO    : Bus 7578	: V=1.075661, theta=-25.540736 -> V=1.0328645, theta=0.0
% INFO    : Bus 7579	: V=1.072818, theta=-8.962601 -> V=1.0155325, theta=0.0
% INFO    : Bus 7580	: V=0.957827, theta=-24.97398 -> V=1.0, theta=0.0
% INFO    : Bus 7581	: V=0.917387, theta=-29.529842 -> V=1.0, theta=0.0
% INFO    : Bus 7582	: V=1.075018, theta=-6.226738 -> V=1.020274, theta=0.0
% INFO    : Bus 7583	: V=1.032482, theta=-25.568709 -> V=1.0, theta=0.0
% INFO    : Bus 7584	: V=1.058465, theta=-8.600663 -> V=1.010474, theta=0.0
% INFO    : Bus 7585	: V=1.051788, theta=33.745546 -> V=1.0, theta=0.0
% INFO    : Bus 7586	: V=1.101632, theta=-25.12639 -> V=1.0286125, theta=0.0
% INFO    : Bus 7587	: V=1.009862, theta=-22.463264 -> V=1.0035935, theta=0.0
% INFO    : Bus 7588	: V=1.037847, theta=-47.617195 -> V=1.0332175, theta=0.0
% INFO    : Bus 7589	: V=1.083492, theta=-38.093723 -> V=1.028106, theta=0.0
% INFO    : Bus 7590	: V=1.053316, theta=-34.653485 -> V=1.0080785, theta=0.0
% INFO    : Bus 7591	: V=1.102702, theta=-10.257034 -> V=1.016452, theta=0.0
% INFO    : Bus 7592	: V=0.982818, theta=-21.606809 -> V=1.0, theta=0.0
% INFO    : Bus 7593	: V=1.074136, theta=-34.708658 -> V=1.014641, theta=0.0
% INFO    : Bus 7594	: V=0.978297, theta=-27.062887 -> V=1.0, theta=0.0
% INFO    : Bus 7595	: V=1.04598, theta=14.035313 -> V=1.011206, theta=0.0
% INFO    : Bus 7596	: V=1.101023, theta=-40.683725 -> V=1.03058, theta=0.0
% INFO    : Bus 7597	: V=0.978973, theta=-25.674713 -> V=1.0, theta=0.0
% INFO    : Bus 7598	: V=0.994318, theta=-17.310977 -> V=1.0, theta=0.0
% INFO    : Bus 7599	: V=1.062528, theta=-15.31383 -> V=1.010248, theta=0.0
% INFO    : Bus 7600	: V=1.04074, theta=-25.025055 -> V=1.0, theta=0.0
% INFO    : Bus 7601	: V=1.04305, theta=9.325779 -> V=1.011033, theta=0.0
% INFO    : Bus 7602	: V=1.051191, theta=32.290884 -> V=1.0038175, theta=0.0
% INFO    : Bus 7603	: V=1.047583, theta=15.045171 -> V=1.0, theta=0.0
% INFO    : Bus 7604	: V=1.079078, theta=5.560329 -> V=1.024233, theta=0.0
% INFO    : Bus 7605	: V=1.037013, theta=14.559277 -> V=1.0, theta=0.0
% INFO    : Bus 7606	: V=1.001996, theta=-23.702615 -> V=1.0, theta=0.0
% INFO    : Bus 7607	: V=1.056173, theta=-20.578179 -> V=1.0, theta=0.0
% INFO    : Bus 7608	: V=1.092365, theta=-36.974748 -> V=1.027649, theta=0.0
% INFO    : Bus 7609	: V=1.046565, theta=-25.128289 -> V=1.0140755, theta=0.0
% INFO    : Bus 7610	: V=1.060909, theta=-29.429313 -> V=1.012722, theta=0.0
% INFO    : Bus 7611	: V=1.094682, theta=-38.343434 -> V=1.0301345, theta=0.0
% INFO    : Bus 7612	: V=0.989113, theta=-23.768427 -> V=1.0, theta=0.0
% INFO    : Bus 7613	: V=1.076711, theta=5.772751 -> V=1.025647, theta=0.0
% INFO    : Bus 7614	: V=0.985142, theta=-20.54627 -> V=1.0, theta=0.0
% INFO    : Bus 7615	: V=0.99592, theta=-26.370981 -> V=1.0, theta=0.0
% INFO    : Bus 7616	: V=1.095494, theta=57.00054 -> V=1.0076315, theta=0.0
% INFO    : Bus 7617	: V=1.047959, theta=-12.304077 -> V=1.010285, theta=0.0
% INFO    : Bus 7618	: V=1.061317, theta=-23.986739 -> V=1.0177685, theta=0.0
% INFO    : Bus 7619	: V=0.908866, theta=-31.88013 -> V=1.0, theta=0.0
% INFO    : Bus 7620	: V=1.024481, theta=-19.443432 -> V=1.006844, theta=0.0
% INFO    : Bus 7621	: V=1.038831, theta=-25.42002 -> V=1.015076, theta=0.0
% INFO    : Bus 7622	: V=1.049601, theta=-21.379361 -> V=1.0, theta=0.0
% INFO    : Bus 7623	: V=1.05339, theta=-24.639847 -> V=1.0141465, theta=0.0
% INFO    : Bus 7624	: V=1.046555, theta=-30.525491 -> V=1.006097, theta=0.0
% INFO    : Bus 7625	: V=1.095579, theta=-37.054832 -> V=1.030775, theta=0.0
% INFO    : Bus 7626	: V=1.091001, theta=28.621944 -> V=1.052486, theta=0.0
% INFO    : Bus 7627	: V=1.099211, theta=54.075078 -> V=1.0051165, theta=0.0
% INFO    : Bus 7628	: V=1.104595, theta=-18.848715 -> V=1.0383885, theta=0.0
% INFO    : Bus 7629	: V=1.028701, theta=-43.805283 -> V=1.0, theta=0.0
% INFO    : Bus 7630	: V=0.985028, theta=-25.139552 -> V=1.0, theta=0.0
% INFO    : Bus 7631	: V=1.057575, theta=-54.651461 -> V=1.0, theta=0.0
% INFO    : Bus 7632	: V=1.081133, theta=-8.966174 -> V=1.025249, theta=0.0
% INFO    : Bus 7633	: V=1.067078, theta=26.534507 -> V=1.006045, theta=0.0
% INFO    : Bus 7634	: V=0.983248, theta=-24.343244 -> V=1.0, theta=0.0
% INFO    : Bus 7635	: V=0.963675, theta=-18.286304 -> V=1.0, theta=0.0
% INFO    : Bus 7636	: V=0.992107, theta=-20.354002 -> V=1.0, theta=0.0
% INFO    : Bus 7637	: V=1.042144, theta=-39.856233 -> V=1.0, theta=0.0
% INFO    : Bus 7638	: V=1.044237, theta=22.308586 -> V=1.0049395, theta=0.0
% INFO    : Bus 7639	: V=1.065797, theta=-12.109524 -> V=1.012379, theta=0.0
% INFO    : Bus 7640	: V=1.064764, theta=19.989184 -> V=1.014306, theta=0.0
% INFO    : Bus 7641	: V=0.960132, theta=-26.469884 -> V=1.0, theta=0.0
% INFO    : Bus 7642	: V=0.937168, theta=38.013814 -> V=1.0, theta=0.0
% INFO    : Bus 7643	: V=1.053252, theta=9.782193 -> V=1.0062825, theta=0.0
% INFO    : Bus 7644	: V=1.093026, theta=-29.758002 -> V=1.015944, theta=0.0
% INFO    : Bus 7645	: V=0.958631, theta=-25.509455 -> V=1.0, theta=0.0
% INFO    : Bus 7646	: V=0.983324, theta=-24.610896 -> V=1.0, theta=0.0
% INFO    : Bus 7647	: V=0.950821, theta=-29.314368 -> V=1.0, theta=0.0
% INFO    : Bus 7648	: V=1.040688, theta=-43.719323 -> V=1.008526, theta=0.0
% INFO    : Bus 7649	: V=1.0694, theta=-21.852468 -> V=1.022158, theta=0.0
% INFO    : Bus 7650	: V=1.080422, theta=2.020897 -> V=1.025792, theta=0.0
% INFO    : Bus 7651	: V=1.020084, theta=-46.650173 -> V=1.0, theta=0.0
% INFO    : Bus 7652	: V=1.005994, theta=-22.840332 -> V=1.0, theta=0.0
% INFO    : Bus 7653	: V=0.999227, theta=-16.806682 -> V=1.0, theta=0.0
% INFO    : Bus 7654	: V=1.040382, theta=-22.909294 -> V=1.021963, theta=0.0
% INFO    : Bus 7655	: V=0.958293, theta=-29.384389 -> V=1.0, theta=0.0
% INFO    : Bus 7656	: V=1.074238, theta=-19.410514 -> V=1.0279825, theta=0.0
% INFO    : Bus 7657	: V=1.04043, theta=9.060658 -> V=1.015928, theta=0.0
% INFO    : Bus 7658	: V=1.016903, theta=-34.249377 -> V=1.0, theta=0.0
% INFO    : Bus 7659	: V=1.033364, theta=19.78063 -> V=1.0, theta=0.0
% INFO    : Bus 7660	: V=1.000692, theta=-23.282087 -> V=1.0, theta=0.0
% INFO    : Bus 7661	: V=1.010385, theta=-16.735239 -> V=1.0, theta=0.0
% INFO    : Bus 7662	: V=1.052603, theta=-15.382834 -> V=1.0086445, theta=0.0
% INFO    : Bus 7663	: V=0.963324, theta=-13.515136 -> V=1.0, theta=0.0
% INFO    : Bus 7664	: V=1.041729, theta=61.691954 -> V=1.0, theta=0.0
% INFO    : Bus 7665	: V=1.038232, theta=-21.067465 -> V=1.0, theta=0.0
% INFO    : Bus 7666	: V=1.092553, theta=-9.409611 -> V=1.026683, theta=0.0
% INFO    : Bus 7667	: V=0.984937, theta=-39.350744 -> V=1.0, theta=0.0
% INFO    : Bus 7668	: V=1.044122, theta=-23.317811 -> V=1.0, theta=0.0
% INFO    : Bus 7669	: V=1.033407, theta=-16.835714 -> V=1.0, theta=0.0
% INFO    : Bus 7670	: V=1.074164, theta=4.307358 -> V=1.022457, theta=0.0
% INFO    : Bus 7671	: V=1.027909, theta=-16.225632 -> V=1.0, theta=0.0
% INFO    : Bus 7672	: V=1.087595, theta=66.700021 -> V=1.0, theta=0.0
% INFO    : Bus 7673	: V=1.075929, theta=-4.465259 -> V=1.01475, theta=0.0
% INFO    : Bus 7674	: V=1.03522, theta=-21.64483 -> V=1.0, theta=0.0
% INFO    : Bus 7675	: V=1.061946, theta=-14.159811 -> V=1.01173, theta=0.0
% INFO    : Bus 7676	: V=1.034189, theta=-15.215318 -> V=1.003644, theta=0.0
% INFO    : Bus 7677	: V=0.981922, theta=-23.577363 -> V=1.0, theta=0.0
% INFO    : Bus 7678	: V=1.025192, theta=-21.432963 -> V=1.0, theta=0.0
% INFO    : Bus 7679	: V=1.0795, theta=-8.240382 -> V=1.023019, theta=0.0
% INFO    : Bus 7680	: V=1.065447, theta=-17.147078 -> V=1.026004, theta=0.0
% INFO    : Bus 7681	: V=1.038563, theta=-47.307162 -> V=1.0335215, theta=0.0
% INFO    : Bus 7682	: V=0.969371, theta=-17.765795 -> V=1.0, theta=0.0
% INFO    : Bus 7683	: V=1.083334, theta=-9.560669 -> V=1.027108, theta=0.0
% INFO    : Bus 7684	: V=1.08444, theta=-8.385942 -> V=1.0272865, theta=0.0
% INFO    : Bus 7685	: V=0.992362, theta=11.001852 -> V=1.0, theta=0.0
% INFO    : Bus 7686	: V=1.066734, theta=10.142689 -> V=1.022913, theta=0.0
% INFO    : Bus 7687	: V=0.998636, theta=-24.288343 -> V=1.0, theta=0.0
% INFO    : Bus 7688	: V=0.991609, theta=-16.600289 -> V=1.0, theta=0.0
% INFO    : Bus 7689	: V=1.082959, theta=16.353661 -> V=1.01393, theta=0.0
% INFO    : Bus 7690	: V=1.061944, theta=-35.266445 -> V=1.0214855, theta=0.0
% INFO    : Bus 7691	: V=1.008193, theta=-7.010549 -> V=1.004773, theta=0.0
% INFO    : Bus 7692	: V=1.060683, theta=-18.70645 -> V=1.0251785, theta=0.0
% INFO    : Bus 7693	: V=1.051092, theta=-4.634811 -> V=1.0043895, theta=0.0
% INFO    : Bus 7694	: V=1.050017, theta=-21.866158 -> V=1.0, theta=0.0
% INFO    : Bus 7695	: V=1.038849, theta=-25.396036 -> V=1.0109655, theta=0.0
% INFO    : Bus 7696	: V=1.063342, theta=-1.709091 -> V=1.0196125, theta=0.0
% INFO    : Bus 7697	: V=1.072042, theta=-2.547997 -> V=1.0210855, theta=0.0
% INFO    : Bus 7698	: V=0.983217, theta=-32.700469 -> V=1.0, theta=0.0
% INFO    : Bus 7699	: V=1.085263, theta=-9.128122 -> V=1.0386785, theta=0.0
% INFO    : Bus 7700	: V=0.998665, theta=-16.233295 -> V=1.0, theta=0.0
% INFO    : Bus 7701	: V=1.040495, theta=-24.067803 -> V=1.0, theta=0.0
% INFO    : Bus 7702	: V=1.077013, theta=-14.061133 -> V=1.026355, theta=0.0
% INFO    : Bus 7703	: V=1.060776, theta=53.476393 -> V=1.0035115, theta=0.0
% INFO    : Bus 7704	: V=0.998578, theta=-16.322326 -> V=1.0, theta=0.0
% INFO    : Bus 7705	: V=1.052269, theta=-33.116498 -> V=1.009734, theta=0.0
% INFO    : Bus 7706	: V=0.930845, theta=-28.345129 -> V=1.0, theta=0.0
% INFO    : Bus 7707	: V=0.985505, theta=-25.571139 -> V=1.0, theta=0.0
% INFO    : Bus 7708	: V=1.03098, theta=-4.916672 -> V=1.0, theta=0.0
% INFO    : Bus 7709	: V=1.102807, theta=-34.618691 -> V=1.028734, theta=0.0
% INFO    : Bus 7710	: V=1.011318, theta=-17.158024 -> V=1.004706, theta=0.0
% INFO    : Bus 7711	: V=0.992019, theta=-20.288129 -> V=1.0, theta=0.0
% INFO    : Bus 7712	: V=1.076422, theta=-25.465226 -> V=1.033212, theta=0.0
% INFO    : Bus 7713	: V=1.058578, theta=15.102452 -> V=1.0, theta=0.0
% INFO    : Bus 7714	: V=1.074981, theta=-28.168673 -> V=1.0176165, theta=0.0
% INFO    : Bus 7715	: V=1.019667, theta=11.45253 -> V=1.0, theta=0.0
% INFO    : Bus 7716	: V=1.072978, theta=-23.295778 -> V=1.0190745, theta=0.0
% INFO    : Bus 7717	: V=1.026879, theta=-43.344842 -> V=1.0, theta=0.0
% INFO    : Bus 7718	: V=0.975933, theta=-21.575455 -> V=1.0, theta=0.0
% INFO    : Bus 7719	: V=1.024666, theta=-16.825005 -> V=1.013527, theta=0.0
% INFO    : Bus 7720	: V=1.073909, theta=-12.030538 -> V=1.026964, theta=0.0
% INFO    : Bus 7721	: V=1.017643, theta=9.255273 -> V=1.0, theta=0.0
% INFO    : Bus 7722	: V=1.049345, theta=9.179725 -> V=1.012533, theta=0.0
% INFO    : Bus 7723	: V=1.047017, theta=-21.576427 -> V=1.003464, theta=0.0
% INFO    : Bus 7724	: V=1.066723, theta=-9.277771 -> V=1.0188645, theta=0.0
% INFO    : Bus 7725	: V=1.062602, theta=-31.408036 -> V=1.013027, theta=0.0
% INFO    : Bus 7726	: V=1.062692, theta=-14.201439 -> V=1.0094715, theta=0.0
% INFO    : Bus 7727	: V=1.085557, theta=-36.891738 -> V=1.0239445, theta=0.0
% INFO    : Bus 7728	: V=1.06246, theta=21.122539 -> V=1.0070925, theta=0.0
% INFO    : Bus 7729	: V=1.07926, theta=-19.157083 -> V=1.017953, theta=0.0
% INFO    : Bus 7730	: V=0.978386, theta=-18.246427 -> V=1.0, theta=0.0
% INFO    : Bus 7731	: V=1.013109, theta=54.199303 -> V=1.0, theta=0.0
% INFO    : Bus 7732	: V=1.033076, theta=-42.791022 -> V=1.0, theta=0.0
% INFO    : Bus 7733	: V=1.0342, theta=-42.450979 -> V=1.0, theta=0.0
% INFO    : Bus 7734	: V=1.037317, theta=-17.632362 -> V=1.0, theta=0.0
% INFO    : Bus 7735	: V=1.097605, theta=-15.940599 -> V=1.043488, theta=0.0
% INFO    : Bus 7736	: V=0.987353, theta=-16.973183 -> V=1.0, theta=0.0
% INFO    : Bus 7737	: V=1.048142, theta=-39.121414 -> V=1.0, theta=0.0
% INFO    : Bus 7738	: V=1.074112, theta=-20.820286 -> V=1.0268285, theta=0.0
% INFO    : Bus 7739	: V=1.024544, theta=-23.904322 -> V=1.0, theta=0.0
% INFO    : Bus 7740	: V=1.067722, theta=8.383125 -> V=1.023957, theta=0.0
% INFO    : Bus 7741	: V=1.032295, theta=-25.224724 -> V=1.0, theta=0.0
% INFO    : Bus 7742	: V=1.093161, theta=-30.294538 -> V=1.0168735, theta=0.0
% INFO    : Bus 7743	: V=1.030584, theta=-24.499978 -> V=1.0, theta=0.0
% INFO    : Bus 7744	: V=1.035773, theta=11.357558 -> V=1.0, theta=0.0
% INFO    : Bus 7745	: V=1.074933, theta=-20.007611 -> V=1.019892, theta=0.0
% INFO    : Bus 7746	: V=0.985687, theta=8.227515 -> V=1.0, theta=0.0
% INFO    : Bus 7747	: V=1.016979, theta=-35.487098 -> V=1.0, theta=0.0
% INFO    : Bus 7748	: V=1.087215, theta=-11.175905 -> V=1.0263025, theta=0.0
% INFO    : Bus 7749	: V=1.028102, theta=-47.701115 -> V=1.0, theta=0.0
% INFO    : Bus 7750	: V=1.008807, theta=-20.023367 -> V=1.0, theta=0.0
% INFO    : Bus 7751	: V=1.007328, theta=-19.452709 -> V=1.0, theta=0.0
% INFO    : Bus 7752	: V=1.032584, theta=-23.222153 -> V=1.0, theta=0.0
% INFO    : Bus 7753	: V=0.972194, theta=-16.681909 -> V=1.0, theta=0.0
% INFO    : Bus 7754	: V=1.015992, theta=10.094606 -> V=1.0, theta=0.0
% INFO    : Bus 7755	: V=1.102263, theta=62.220893 -> V=1.0092695, theta=0.0
% INFO    : Bus 7756	: V=1.040048, theta=-21.315741 -> V=1.008264, theta=0.0
% INFO    : Bus 7757	: V=1.034305, theta=-36.594127 -> V=1.0, theta=0.0
% INFO    : Bus 7758	: V=1.074058, theta=-36.482065 -> V=1.01054, theta=0.0
% INFO    : Bus 7759	: V=0.956986, theta=-34.801477 -> V=1.0, theta=0.0
% INFO    : Bus 7760	: V=0.961833, theta=-30.882426 -> V=1.0, theta=0.0
% INFO    : Bus 7761	: V=1.004116, theta=-23.318365 -> V=1.0, theta=0.0
% INFO    : Bus 7762	: V=1.032176, theta=-17.256556 -> V=1.0044305, theta=0.0
% INFO    : Bus 7763	: V=1.079872, theta=-38.907709 -> V=1.031531, theta=0.0
% INFO    : Bus 7764	: V=1.071035, theta=-18.616061 -> V=1.020767, theta=0.0
% INFO    : Bus 7765	: V=1.050591, theta=-18.311743 -> V=1.00811, theta=0.0
% INFO    : Bus 7766	: V=1.081016, theta=5.911702 -> V=1.0250195, theta=0.0
% INFO    : Bus 7767	: V=0.979309, theta=-23.183979 -> V=1.0, theta=0.0
% INFO    : Bus 7768	: V=1.022399, theta=-34.351959 -> V=1.0, theta=0.0
% INFO    : Bus 7769	: V=1.064869, theta=-6.053825 -> V=1.0102675, theta=0.0
% INFO    : Bus 7770	: V=1.068079, theta=-34.68332 -> V=1.015402, theta=0.0
% INFO    : Bus 7771	: V=0.957449, theta=-27.292495 -> V=1.0, theta=0.0
% INFO    : Bus 7772	: V=1.056119, theta=-49.060158 -> V=1.0069795, theta=0.0
% INFO    : Bus 7773	: V=0.99403, theta=-22.839948 -> V=1.0, theta=0.0
% INFO    : Bus 7774	: V=1.056489, theta=-44.266306 -> V=1.012595, theta=0.0
% INFO    : Bus 7775	: V=1.033277, theta=-4.811887 -> V=1.0, theta=0.0
% INFO    : Bus 7776	: V=1.054125, theta=-49.281455 -> V=1.006043, theta=0.0
% INFO    : Bus 7777	: V=1.084448, theta=-27.138586 -> V=1.02552, theta=0.0
% INFO    : Bus 7778	: V=1.036381, theta=-22.198555 -> V=1.0132145, theta=0.0
% INFO    : Bus 7779	: V=1.036267, theta=-31.415666 -> V=1.0, theta=0.0
% INFO    : Bus 7780	: V=1.090937, theta=-21.656182 -> V=1.0268355, theta=0.0
% INFO    : Bus 7781	: V=1.048604, theta=7.335342 -> V=1.00254, theta=0.0
% INFO    : Bus 7782	: V=1.058014, theta=-47.036607 -> V=1.0049635, theta=0.0
% INFO    : Bus 7783	: V=1.074551, theta=-9.013996 -> V=1.027238, theta=0.0
% INFO    : Bus 7784	: V=1.020021, theta=14.051093 -> V=1.0, theta=0.0
% INFO    : Bus 7785	: V=1.012091, theta=-22.37398 -> V=1.0, theta=0.0
% INFO    : Bus 7786	: V=1.026278, theta=-17.977972 -> V=1.0, theta=0.0
% INFO    : Bus 7787	: V=1.036855, theta=-46.062487 -> V=1.0, theta=0.0
% INFO    : Bus 7788	: V=0.984884, theta=-25.553026 -> V=1.0, theta=0.0
% INFO    : Bus 7789	: V=1.068557, theta=-17.690625 -> V=1.0, theta=0.0
% INFO    : Bus 7790	: V=1.070867, theta=-14.367371 -> V=1.0111525, theta=0.0
% INFO    : Bus 7791	: V=1.083394, theta=-3.783849 -> V=1.0182315, theta=0.0
% INFO    : Bus 7792	: V=1.083389, theta=46.039212 -> V=1.0, theta=0.0
% INFO    : Bus 7793	: V=0.950523, theta=-26.91671 -> V=1.0, theta=0.0
% INFO    : Bus 7794	: V=0.919592, theta=-29.123533 -> V=0.984359, theta=0.0
% INFO    : Bus 7795	: V=1.065199, theta=-18.958934 -> V=1.0, theta=0.0
% INFO    : Bus 7796	: V=1.006253, theta=-19.193975 -> V=1.0, theta=0.0
% INFO    : Bus 7797	: V=1.073105, theta=-34.385266 -> V=1.026807, theta=0.0
% INFO    : Bus 7798	: V=1.07952, theta=-47.003678 -> V=1.0181955, theta=0.0
% INFO    : Bus 7799	: V=0.998159, theta=10.927225 -> V=1.0, theta=0.0
% INFO    : Bus 7800	: V=1.050133, theta=-14.964503 -> V=1.0, theta=0.0
% INFO    : Bus 7801	: V=1.04283, theta=12.552693 -> V=1.005098, theta=0.0
% INFO    : Bus 7802	: V=1.061184, theta=-2.463511 -> V=1.0096485, theta=0.0
% INFO    : Bus 7803	: V=1.020329, theta=-23.565523 -> V=1.0, theta=0.0
% INFO    : Bus 7804	: V=0.986269, theta=-27.842525 -> V=1.0, theta=0.0
% INFO    : Bus 7805	: V=1.084263, theta=-34.852165 -> V=1.0293285, theta=0.0
% INFO    : Bus 7806	: V=1.053621, theta=-21.252085 -> V=1.0, theta=0.0
% INFO    : Bus 7807	: V=1.071227, theta=7.598945 -> V=1.028236, theta=0.0
% INFO    : Bus 7808	: V=1.0848, theta=63.181359 -> V=1.0, theta=0.0
% INFO    : Bus 7809	: V=0.98565, theta=-30.123712 -> V=1.0, theta=0.0
% INFO    : Bus 7810	: V=1.0614, theta=1.716269 -> V=1.010964, theta=0.0
% INFO    : Bus 7811	: V=1.085775, theta=45.465418 -> V=1.008608, theta=0.0
% INFO    : Bus 7812	: V=1.054127, theta=-16.034795 -> V=1.0047515, theta=0.0
% INFO    : Bus 7813	: V=1.03055, theta=-24.303096 -> V=1.0, theta=0.0
% INFO    : Bus 7814	: V=0.937072, theta=-27.775559 -> V=1.0, theta=0.0
% INFO    : Bus 7815	: V=0.985647, theta=-22.902526 -> V=1.0, theta=0.0
% INFO    : Bus 7816	: V=1.052079, theta=-15.811523 -> V=1.0, theta=0.0
% INFO    : Bus 7817	: V=1.068006, theta=-9.009397 -> V=1.017606, theta=0.0
% INFO    : Bus 7818	: V=1.048247, theta=15.429631 -> V=1.0, theta=0.0
% INFO    : Bus 7819	: V=0.955, theta=-31.167894 -> V=1.0, theta=0.0
% INFO    : Bus 7820	: V=1.076633, theta=-20.34272 -> V=1.019648, theta=0.0
% INFO    : Bus 7821	: V=0.99527, theta=10.383534 -> V=1.0, theta=0.0
% INFO    : Bus 7822	: V=1.087632, theta=-37.204024 -> V=1.015225, theta=0.0
% INFO    : Bus 7823	: V=1.045188, theta=-17.016093 -> V=1.0076125, theta=0.0
% INFO    : Bus 7824	: V=1.051587, theta=-25.547649 -> V=1.030148, theta=0.0
% INFO    : Bus 7825	: V=1.078744, theta=-22.355862 -> V=1.031886, theta=0.0
% INFO    : Bus 7826	: V=0.992136, theta=-39.127026 -> V=1.0, theta=0.0
% INFO    : Bus 7827	: V=1.101579, theta=-42.912 -> V=1.0284195, theta=0.0
% INFO    : Bus 7828	: V=0.942789, theta=-29.028903 -> V=0.9971615, theta=0.0
% INFO    : Bus 7829	: V=1.07704, theta=-17.728436 -> V=1.0, theta=0.0
% INFO    : Bus 7830	: V=1.030547, theta=-12.451076 -> V=1.0, theta=0.0
% INFO    : Bus 7831	: V=1.05471, theta=-27.052061 -> V=1.008667, theta=0.0
% INFO    : Bus 7832	: V=1.036206, theta=-44.684746 -> V=1.0, theta=0.0
% INFO    : Bus 7833	: V=1.017205, theta=-21.177503 -> V=1.0139985, theta=0.0
% INFO    : Bus 7834	: V=1.031023, theta=-24.244365 -> V=1.0, theta=0.0
% INFO    : Bus 7835	: V=1.023911, theta=11.766114 -> V=1.0, theta=0.0
% INFO    : Bus 7836	: V=1.027528, theta=-4.457385 -> V=1.0, theta=0.0
% INFO    : Bus 7837	: V=1.104947, theta=-12.711993 -> V=1.0432635, theta=0.0
% INFO    : Bus 7838	: V=1.091011, theta=-24.281821 -> V=1.0286825, theta=0.0
% INFO    : Bus 7839	: V=1.081643, theta=7.248169 -> V=1.0181225, theta=0.0
% INFO    : Bus 7840	: V=0.990753, theta=-24.285592 -> V=1.0, theta=0.0
% INFO    : Bus 7841	: V=1.103186, theta=-15.328867 -> V=1.0422235, theta=0.0
% INFO    : Bus 7842	: V=0.975256, theta=-20.511296 -> V=1.0, theta=0.0
% INFO    : Bus 7843	: V=1.063238, theta=-19.994161 -> V=1.010815, theta=0.0
% INFO    : Bus 7844	: V=1.07209, theta=2.783715 -> V=1.0138495, theta=0.0
% INFO    : Bus 7845	: V=1.031512, theta=-21.814447 -> V=1.0042555, theta=0.0
% INFO    : Bus 7846	: V=1.035094, theta=-36.397918 -> V=1.0, theta=0.0
% INFO    : Bus 7847	: V=1.061374, theta=-15.646952 -> V=1.009005, theta=0.0
% INFO    : Bus 7848	: V=1.069616, theta=5.164497 -> V=1.022753, theta=0.0
% INFO    : Bus 7849	: V=1.075277, theta=-15.130769 -> V=1.0186655, theta=0.0
% INFO    : Bus 7850	: V=1.024598, theta=-23.214106 -> V=1.0, theta=0.0
% INFO    : Bus 7851	: V=1.052118, theta=-9.684101 -> V=1.013637, theta=0.0
% INFO    : Bus 7852	: V=1.052583, theta=-49.288859 -> V=1.0050495, theta=0.0
% INFO    : Bus 7853	: V=1.0065, theta=-18.297165 -> V=1.0, theta=0.0
% INFO    : Bus 7854	: V=1.037429, theta=-29.288299 -> V=1.0, theta=0.0
% INFO    : Bus 7855	: V=1.065098, theta=-43.731442 -> V=1.007516, theta=0.0
% INFO    : Bus 7856	: V=1.041657, theta=25.747878 -> V=1.0158995, theta=0.0
% INFO    : Bus 7857	: V=1.055789, theta=-14.272739 -> V=1.012195, theta=0.0
% INFO    : Bus 7858	: V=1.085379, theta=-42.095104 -> V=1.0290935, theta=0.0
% INFO    : Bus 7859	: V=0.936675, theta=-26.392245 -> V=1.0, theta=0.0
% INFO    : Bus 7860	: V=0.979065, theta=-17.456048 -> V=1.0, theta=0.0
% INFO    : Bus 7861	: V=0.953332, theta=-35.121241 -> V=1.0, theta=0.0
% INFO    : Bus 7862	: V=1.040882, theta=9.340861 -> V=1.0101945, theta=0.0
% INFO    : Bus 7863	: V=1.044281, theta=-14.977518 -> V=1.0155425, theta=0.0
% INFO    : Bus 7864	: V=1.050455, theta=-6.184885 -> V=1.019362, theta=0.0
% INFO    : Bus 7865	: V=1.054378, theta=-46.390576 -> V=1.0, theta=0.0
% INFO    : Bus 7866	: V=1.054294, theta=-20.799581 -> V=1.0128895, theta=0.0
% INFO    : Bus 7867	: V=0.985669, theta=-28.277429 -> V=1.0, theta=0.0
% INFO    : Bus 7868	: V=1.056863, theta=-21.916708 -> V=1.0, theta=0.0
% INFO    : Bus 7869	: V=1.078409, theta=-21.324325 -> V=1.010602, theta=0.0
% INFO    : Bus 7870	: V=1.026955, theta=-20.45425 -> V=1.0, theta=0.0
% INFO    : Bus 7871	: V=1.064169, theta=-9.488505 -> V=1.0158275, theta=0.0
% INFO    : Bus 7872	: V=1.033686, theta=-21.485099 -> V=1.0, theta=0.0
% INFO    : Bus 7873	: V=0.994151, theta=-49.60977 -> V=1.0, theta=0.0
% INFO    : Bus 7874	: V=1.073818, theta=-23.076418 -> V=1.019428, theta=0.0
% INFO    : Bus 7875	: V=0.964715, theta=-30.548346 -> V=1.0, theta=0.0
% INFO    : Bus 7876	: V=1.033702, theta=-2.709709 -> V=1.00957, theta=0.0
% INFO    : Bus 7877	: V=1.041174, theta=-25.056668 -> V=1.0, theta=0.0
% INFO    : Bus 7878	: V=1.041474, theta=16.522751 -> V=1.003282, theta=0.0
% INFO    : Bus 7879	: V=1.03994, theta=-21.302399 -> V=1.0081925, theta=0.0
% INFO    : Bus 7880	: V=1.074883, theta=-19.69327 -> V=1.0194825, theta=0.0
% INFO    : Bus 7881	: V=1.071714, theta=-15.115319 -> V=1.0107735, theta=0.0
% INFO    : Bus 7882	: V=1.033472, theta=-33.351433 -> V=1.0201535, theta=0.0
% INFO    : Bus 7883	: V=1.068941, theta=-13.056266 -> V=1.014324, theta=0.0
% INFO    : Bus 7884	: V=1.100605, theta=62.012482 -> V=1.0086915, theta=0.0
% INFO    : Bus 7885	: V=0.974223, theta=-25.809337 -> V=1.0, theta=0.0
% INFO    : Bus 7886	: V=1.062038, theta=-11.039225 -> V=1.012104, theta=0.0
% INFO    : Bus 7887	: V=1.050039, theta=-28.956716 -> V=1.0101155, theta=0.0
% INFO    : Bus 7888	: V=0.997892, theta=10.50336 -> V=1.0, theta=0.0
% INFO    : Bus 7889	: V=1.015465, theta=11.072444 -> V=1.0, theta=0.0
% INFO    : Bus 7890	: V=1.032769, theta=-25.345353 -> V=1.0, theta=0.0
% INFO    : Bus 7891	: V=1.012719, theta=-39.896648 -> V=1.0, theta=0.0
% INFO    : Bus 7892	: V=1.049227, theta=-34.258772 -> V=1.0072525, theta=0.0
% INFO    : Bus 7893	: V=1.032622, theta=-25.38479 -> V=1.0, theta=0.0
% INFO    : Bus 7894	: V=1.065912, theta=-7.510331 -> V=1.013003, theta=0.0
% INFO    : Bus 7895	: V=0.992578, theta=-23.037494 -> V=1.0, theta=0.0
% INFO    : Bus 7896	: V=1.063139, theta=3.422897 -> V=1.0169935, theta=0.0
% INFO    : Bus 7897	: V=1.096436, theta=-11.291024 -> V=1.026697, theta=0.0
% INFO    : Bus 7898	: V=1.074177, theta=-33.734182 -> V=1.0256895, theta=0.0
% INFO    : Bus 7899	: V=1.031708, theta=-18.753941 -> V=1.0093015, theta=0.0
% INFO    : Bus 7900	: V=1.060386, theta=-43.461523 -> V=1.0060655, theta=0.0
% INFO    : Bus 7901	: V=1.042928, theta=-12.188219 -> V=1.0071885, theta=0.0
% INFO    : Bus 7902	: V=0.99443, theta=-25.426334 -> V=1.0, theta=0.0
% INFO    : Bus 7903	: V=1.030829, theta=17.054451 -> V=1.0, theta=0.0
% INFO    : Bus 7904	: V=1.099799, theta=-19.585548 -> V=1.027361, theta=0.0
% INFO    : Bus 7905	: V=1.071995, theta=26.970992 -> V=1.0, theta=0.0
% INFO    : Bus 7906	: V=1.049708, theta=-14.572188 -> V=1.0219235, theta=0.0
% INFO    : Bus 7907	: V=1.056818, theta=-30.009091 -> V=1.010971, theta=0.0
% INFO    : Bus 7908	: V=1.034608, theta=-46.904379 -> V=1.0, theta=0.0
% INFO    : Bus 7909	: V=0.949867, theta=-24.250246 -> V=1.0, theta=0.0
% INFO    : Bus 7910	: V=1.086, theta=-15.920372 -> V=1.024947, theta=0.0
% INFO    : Bus 7911	: V=1.074159, theta=-24.168054 -> V=1.031287, theta=0.0
% INFO    : Bus 7912	: V=1.090118, theta=-16.317473 -> V=1.038872, theta=0.0
% INFO    : Bus 7913	: V=1.07014, theta=-20.103597 -> V=1.0216075, theta=0.0
% INFO    : Bus 7914	: V=1.032163, theta=8.878969 -> V=1.0, theta=0.0
% INFO    : Bus 7915	: V=1.029708, theta=-20.505209 -> V=1.0, theta=0.0
% INFO    : Bus 7916	: V=0.97316, theta=-27.816597 -> V=1.0, theta=0.0
% INFO    : Bus 7917	: V=1.045088, theta=4.09307 -> V=1.0, theta=0.0
% INFO    : Bus 7918	: V=1.061501, theta=-34.538616 -> V=1.0079845, theta=0.0
% INFO    : Bus 7919	: V=1.052147, theta=-19.967 -> V=1.002871, theta=0.0
% INFO    : Bus 7920	: V=1.063818, theta=-36.693187 -> V=1.0177315, theta=0.0
% INFO    : Bus 7921	: V=1.078495, theta=-20.133188 -> V=1.020656, theta=0.0
% INFO    : Bus 7922	: V=0.976602, theta=-24.39641 -> V=1.0, theta=0.0
% INFO    : Bus 7923	: V=0.983082, theta=-25.559044 -> V=1.0, theta=0.0
% INFO    : Bus 7924	: V=0.998013, theta=-23.701566 -> V=1.0, theta=0.0
% INFO    : Bus 7925	: V=1.065867, theta=-21.376259 -> V=1.0, theta=0.0
% INFO    : Bus 7926	: V=1.070822, theta=4.709742 -> V=1.020368, theta=0.0
% INFO    : Bus 7927	: V=1.01751, theta=-29.802069 -> V=1.0, theta=0.0
% INFO    : Bus 7928	: V=0.986168, theta=-24.510276 -> V=1.0, theta=0.0
% INFO    : Bus 7929	: V=1.094706, theta=-38.343507 -> V=1.0301475, theta=0.0
% INFO    : Bus 7930	: V=1.078208, theta=-8.950081 -> V=1.015846, theta=0.0
% INFO    : Bus 7931	: V=1.025674, theta=-35.332123 -> V=1.0174965, theta=0.0
% INFO    : Bus 7932	: V=0.96916, theta=-30.439998 -> V=1.0, theta=0.0
% INFO    : Bus 7933	: V=0.997961, theta=-23.67409 -> V=1.0, theta=0.0
% INFO    : Bus 7934	: V=1.010227, theta=-17.557332 -> V=1.0035765, theta=0.0
% INFO    : Bus 7935	: V=1.07562, theta=-17.781983 -> V=1.0, theta=0.0
% INFO    : Bus 7936	: V=1.033185, theta=-49.206309 -> V=1.031223, theta=0.0
% INFO    : Bus 7937	: V=0.96026, theta=-26.585304 -> V=1.0, theta=0.0
% INFO    : Bus 7938	: V=1.014166, theta=-23.33878 -> V=1.0, theta=0.0
% INFO    : Bus 7939	: V=1.079857, theta=-15.596473 -> V=1.0185825, theta=0.0
% INFO    : Bus 7940	: V=1.028695, theta=-23.034352 -> V=1.0, theta=0.0
% INFO    : Bus 7941	: V=1.069492, theta=-10.02076 -> V=1.018039, theta=0.0
% INFO    : Bus 7942	: V=0.980846, theta=-21.936546 -> V=1.0, theta=0.0
% INFO    : Bus 7943	: V=0.91795, theta=-26.310644 -> V=1.0, theta=0.0
% INFO    : Bus 7944	: V=1.055155, theta=-54.394187 -> V=1.0, theta=0.0
% INFO    : Bus 7945	: V=0.997571, theta=-23.697211 -> V=1.0, theta=0.0
% INFO    : Bus 7946	: V=1.089318, theta=11.826055 -> V=1.0326605, theta=0.0
% INFO    : Bus 7947	: V=1.019908, theta=14.419382 -> V=1.0, theta=0.0
% INFO    : Bus 7948	: V=0.953979, theta=-19.885643 -> V=1.0, theta=0.0
% INFO    : Bus 7949	: V=0.952927, theta=63.146319 -> V=1.0, theta=0.0
% INFO    : Bus 7950	: V=1.074316, theta=50.229719 -> V=1.0103895, theta=0.0
% INFO    : Bus 7951	: V=1.081457, theta=1.127226 -> V=1.0162885, theta=0.0
% INFO    : Bus 7952	: V=1.000364, theta=-1.227439 -> V=1.0, theta=0.0
% INFO    : Bus 7953	: V=1.044495, theta=-14.963367 -> V=1.0156555, theta=0.0
% INFO    : Bus 7954	: V=0.983, theta=-21.131124 -> V=1.0, theta=0.0
% INFO    : Bus 7955	: V=1.038067, theta=-19.620026 -> V=1.0, theta=0.0
% INFO    : Bus 7956	: V=1.056465, theta=-15.360872 -> V=1.004134, theta=0.0
% INFO    : Bus 7957	: V=1.025733, theta=-33.701191 -> V=1.0, theta=0.0
% INFO    : Bus 7958	: V=1.060377, theta=7.03155 -> V=1.006021, theta=0.0
% INFO    : Bus 7959	: V=1.030176, theta=9.798721 -> V=1.0, theta=0.0
% INFO    : Bus 7960	: V=1.065395, theta=-31.185137 -> V=1.014234, theta=0.0
% INFO    : Bus 7961	: V=1.008244, theta=7.364908 -> V=1.0, theta=0.0
% INFO    : Bus 7962	: V=1.02166, theta=-34.02022 -> V=1.0, theta=0.0
% INFO    : Bus 7963	: V=0.970825, theta=-24.835647 -> V=1.0, theta=0.0
% INFO    : Bus 7964	: V=1.041703, theta=-1.023587 -> V=1.006569, theta=0.0
% INFO    : Bus 7965	: V=1.079587, theta=15.977341 -> V=1.01711, theta=0.0
% INFO    : Bus 7966	: V=1.000852, theta=-16.223379 -> V=1.0, theta=0.0
% INFO    : Bus 7967	: V=1.002374, theta=-36.772954 -> V=1.0, theta=0.0
% INFO    : Bus 7968	: V=1.040943, theta=-22.019814 -> V=1.020593, theta=0.0
% INFO    : Bus 7969	: V=0.965797, theta=-28.169504 -> V=1.0, theta=0.0
% INFO    : Bus 7970	: V=1.065165, theta=9.501807 -> V=1.0, theta=0.0
% INFO    : Bus 7971	: V=1.085509, theta=-2.640478 -> V=1.023097, theta=0.0
% INFO    : Bus 7972	: V=0.995444, theta=-25.923321 -> V=1.0, theta=0.0
% INFO    : Bus 7973	: V=1.090603, theta=-16.358197 -> V=1.043643, theta=0.0
% INFO    : Bus 7974	: V=1.069628, theta=-5.775412 -> V=1.0121735, theta=0.0
% INFO    : Bus 7975	: V=1.024867, theta=-42.158637 -> V=1.0, theta=0.0
% INFO    : Bus 7976	: V=1.071238, theta=-21.462865 -> V=1.031842, theta=0.0
% INFO    : Bus 7977	: V=1.065801, theta=2.272319 -> V=1.01924, theta=0.0
% INFO    : Bus 7978	: V=1.036497, theta=-11.81928 -> V=1.0, theta=0.0
% INFO    : Bus 7979	: V=1.094409, theta=-0.147898 -> V=1.0287695, theta=0.0
% INFO    : Bus 7980	: V=1.024545, theta=-27.438145 -> V=1.0, theta=0.0
% INFO    : Bus 7981	: V=1.038163, theta=-4.602183 -> V=1.0037855, theta=0.0
% INFO    : Bus 7982	: V=1.011276, theta=-27.557302 -> V=1.0, theta=0.0
% INFO    : Bus 7983	: V=1.001546, theta=-39.259042 -> V=1.0, theta=0.0
% INFO    : Bus 7984	: V=1.067962, theta=-13.226561 -> V=1.016375, theta=0.0
% INFO    : Bus 7985	: V=1.087148, theta=66.625518 -> V=1.0, theta=0.0
% INFO    : Bus 7986	: V=1.042342, theta=-22.080817 -> V=1.02119, theta=0.0
% INFO    : Bus 7987	: V=1.051726, theta=-9.519561 -> V=1.011383, theta=0.0
% INFO    : Bus 7988	: V=1.031233, theta=-31.097442 -> V=1.0, theta=0.0
% INFO    : Bus 7989	: V=1.089345, theta=-39.544751 -> V=1.033129, theta=0.0
% INFO    : Bus 7990	: V=1.078864, theta=-3.883273 -> V=1.0159895, theta=0.0
% INFO    : Bus 7991	: V=1.074093, theta=-25.095199 -> V=1.0323905, theta=0.0
% INFO    : Bus 7992	: V=1.034579, theta=-32.362074 -> V=1.016942, theta=0.0
% INFO    : Bus 7993	: V=1.0736, theta=0.708263 -> V=1.024545, theta=0.0
% INFO    : Bus 7994	: V=1.036382, theta=-36.471747 -> V=1.0, theta=0.0
% INFO    : Bus 7995	: V=0.978502, theta=-21.030806 -> V=1.0, theta=0.0
% INFO    : Bus 7996	: V=0.977343, theta=-27.137047 -> V=1.0, theta=0.0
% INFO    : Bus 7997	: V=1.067649, theta=3.054146 -> V=1.0136205, theta=0.0
% INFO    : Bus 7998	: V=0.935847, theta=-25.027893 -> V=1.0, theta=0.0
% INFO    : Bus 7999	: V=1.025375, theta=9.794922 -> V=1.0, theta=0.0
% INFO    : Bus 8000	: V=1.080636, theta=0.673375 -> V=1.0245485, theta=0.0
% INFO    : Bus 8001	: V=1.05607, theta=-48.454129 -> V=1.006316, theta=0.0
% INFO    : Bus 8002	: V=1.045818, theta=-17.262589 -> V=1.0099905, theta=0.0
% INFO    : Bus 8003	: V=1.050056, theta=-21.075801 -> V=1.02542, theta=0.0
% INFO    : Bus 8004	: V=1.080474, theta=3.89002 -> V=1.025878, theta=0.0
% INFO    : Bus 8005	: V=0.99153, theta=-25.177518 -> V=1.0, theta=0.0
% INFO    : Bus 8006	: V=1.047984, theta=-3.535117 -> V=1.004394, theta=0.0
% INFO    : Bus 8007	: V=1.017321, theta=-21.973398 -> V=1.0, theta=0.0
% INFO    : Bus 8008	: V=1.003204, theta=-24.362746 -> V=1.0, theta=0.0
% INFO    : Bus 8009	: V=1.054681, theta=4.984542 -> V=1.004568, theta=0.0
% INFO    : Bus 8010	: V=1.02052, theta=-20.651688 -> V=1.0154885, theta=0.0
% INFO    : Bus 8011	: V=1.0715, theta=-19.566487 -> V=1.013913, theta=0.0
% INFO    : Bus 8012	: V=0.911886, theta=-29.617218 -> V=1.0, theta=0.0
% INFO    : Bus 8013	: V=1.062625, theta=-1.767803 -> V=1.019284, theta=0.0
% INFO    : Bus 8014	: V=1.037675, theta=-29.396728 -> V=1.0, theta=0.0
% INFO    : Bus 8015	: V=1.060812, theta=-21.1531 -> V=1.0219115, theta=0.0
% INFO    : Bus 8016	: V=1.062666, theta=-21.890087 -> V=1.0200625, theta=0.0
% INFO    : Bus 8017	: V=0.969425, theta=-20.557007 -> V=1.0, theta=0.0
% INFO    : Bus 8018	: V=1.063941, theta=-32.0004 -> V=1.0162915, theta=0.0
% INFO    : Bus 8019	: V=0.964642, theta=-30.559805 -> V=1.0, theta=0.0
% INFO    : Bus 8020	: V=1.013479, theta=-27.244362 -> V=1.0, theta=0.0
% INFO    : Bus 8021	: V=0.981495, theta=-25.800237 -> V=1.0, theta=0.0
% INFO    : Bus 8022	: V=0.948422, theta=-32.347301 -> V=1.0, theta=0.0
% INFO    : Bus 8023	: V=0.995949, theta=-22.378624 -> V=1.0, theta=0.0
% INFO    : Bus 8024	: V=1.052087, theta=-10.852874 -> V=1.0159305, theta=0.0
% INFO    : Bus 8025	: V=0.950547, theta=-26.909288 -> V=1.0, theta=0.0
% INFO    : Bus 8026	: V=1.084076, theta=-17.818149 -> V=1.0160525, theta=0.0
% INFO    : Bus 8027	: V=1.044537, theta=8.12219 -> V=1.0089595, theta=0.0
% INFO    : Bus 8028	: V=1.054534, theta=-3.186033 -> V=1.0044955, theta=0.0
% INFO    : Bus 8029	: V=0.935328, theta=-28.779899 -> V=0.9898635, theta=0.0
% INFO    : Bus 8030	: V=1.007001, theta=-35.27348 -> V=1.0, theta=0.0
% INFO    : Bus 8031	: V=1.031978, theta=-27.670676 -> V=1.0, theta=0.0
% INFO    : Bus 8032	: V=1.094263, theta=64.204498 -> V=1.0035765, theta=0.0
% INFO    : Bus 8033	: V=1.02125, theta=-23.626294 -> V=1.0103835, theta=0.0
% INFO    : Bus 8034	: V=1.049564, theta=-35.900593 -> V=1.027873, theta=0.0
% INFO    : Bus 8035	: V=1.025821, theta=-42.016464 -> V=1.0088475, theta=0.0
% INFO    : Bus 8036	: V=1.068084, theta=-12.27681 -> V=1.0113665, theta=0.0
% INFO    : Bus 8037	: V=1.044737, theta=-22.311979 -> V=1.0, theta=0.0
% INFO    : Bus 8038	: V=1.05306, theta=-44.281193 -> V=1.0029815, theta=0.0
% INFO    : Bus 8039	: V=1.068682, theta=-39.334757 -> V=1.0074615, theta=0.0
% INFO    : Bus 8040	: V=1.023521, theta=-17.638061 -> V=1.0, theta=0.0
% INFO    : Bus 8041	: V=1.069108, theta=-9.42227 -> V=1.0181475, theta=0.0
% INFO    : Bus 8042	: V=1.029005, theta=-49.632939 -> V=1.0, theta=0.0
% INFO    : Bus 8043	: V=1.053324, theta=9.692441 -> V=1.0178535, theta=0.0
% INFO    : Bus 8044	: V=0.999928, theta=-23.123736 -> V=1.0, theta=0.0
% INFO    : Bus 8045	: V=1.050466, theta=-31.190276 -> V=1.019312, theta=0.0
% INFO    : Bus 8046	: V=0.961147, theta=-26.670409 -> V=1.0, theta=0.0
% INFO    : Bus 8047	: V=1.067086, theta=-8.324229 -> V=1.0146235, theta=0.0
% INFO    : Bus 8048	: V=1.064667, theta=-44.102968 -> V=1.0066825, theta=0.0
% INFO    : Bus 8049	: V=1.060015, theta=2.362681 -> V=1.007645, theta=0.0
% INFO    : Bus 8050	: V=1.095868, theta=-38.146922 -> V=1.030673, theta=0.0
% INFO    : Bus 8051	: V=1.092439, theta=-43.647235 -> V=1.023357, theta=0.0
% INFO    : Bus 8052	: V=1.059636, theta=-47.870938 -> V=1.0075665, theta=0.0
% INFO    : Bus 8053	: V=1.085789, theta=-15.942866 -> V=1.0248415, theta=0.0
% INFO    : Bus 8054	: V=1.077931, theta=-26.448027 -> V=1.0430475, theta=0.0
% INFO    : Bus 8055	: V=1.047472, theta=-20.467454 -> V=1.0180755, theta=0.0
% INFO    : Bus 8056	: V=1.095, theta=15.496741 -> V=1.020876, theta=0.0
% INFO    : Bus 8057	: V=1.064729, theta=-38.431376 -> V=1.014848, theta=0.0
% INFO    : Bus 8058	: V=1.078881, theta=-19.654388 -> V=1.021142, theta=0.0
% INFO    : Bus 8059	: V=1.042939, theta=17.311515 -> V=1.0058935, theta=0.0
% INFO    : Bus 8060	: V=1.072496, theta=-21.590631 -> V=1.027843, theta=0.0
% INFO    : Bus 8061	: V=1.057372, theta=-14.890969 -> V=1.0080075, theta=0.0
% INFO    : Bus 8062	: V=1.078443, theta=-0.216923 -> V=1.0232585, theta=0.0
% INFO    : Bus 8063	: V=1.069696, theta=8.608812 -> V=1.0196305, theta=0.0
% INFO    : Bus 8064	: V=1.095527, theta=-28.581964 -> V=1.024006, theta=0.0
% INFO    : Bus 8065	: V=0.91545, theta=-26.556458 -> V=1.0, theta=0.0
% INFO    : Bus 8066	: V=1.105762, theta=-9.663358 -> V=1.0319625, theta=0.0
% INFO    : Bus 8067	: V=1.011466, theta=-3.800408 -> V=1.0, theta=0.0
% INFO    : Bus 8068	: V=1.072842, theta=1.035004 -> V=1.010669, theta=0.0
% INFO    : Bus 8069	: V=1.095752, theta=-40.374829 -> V=1.026471, theta=0.0
% INFO    : Bus 8070	: V=1.081905, theta=5.962573 -> V=1.0254325, theta=0.0
% INFO    : Bus 8071	: V=1.011218, theta=-18.984452 -> V=1.0, theta=0.0
% INFO    : Bus 8072	: V=1.080389, theta=-17.70468 -> V=1.0112065, theta=0.0
% INFO    : Bus 8073	: V=1.010388, theta=-19.589756 -> V=1.0, theta=0.0
% INFO    : Bus 8074	: V=1.044626, theta=-14.868073 -> V=1.015674, theta=0.0
% INFO    : Bus 8075	: V=1.093, theta=-24.810567 -> V=1.028277, theta=0.0
% INFO    : Bus 8076	: V=1.064532, theta=-2.42322 -> V=1.0212035, theta=0.0
% INFO    : Bus 8077	: V=1.060545, theta=-20.586915 -> V=1.0089365, theta=0.0
% INFO    : Bus 8078	: V=1.082684, theta=16.349883 -> V=1.0137925, theta=0.0
% INFO    : Bus 8079	: V=1.074535, theta=-15.644916 -> V=1.0115425, theta=0.0
% INFO    : Bus 8080	: V=1.076886, theta=-22.486738 -> V=1.031134, theta=0.0
% INFO    : Bus 8081	: V=0.971733, theta=-24.413773 -> V=1.0, theta=0.0
% INFO    : Bus 8082	: V=1.037351, theta=-29.982488 -> V=1.0, theta=0.0
% INFO    : Bus 8083	: V=1.071053, theta=-9.61605 -> V=1.009823, theta=0.0
% INFO    : Bus 8084	: V=1.038232, theta=-21.067465 -> V=1.0, theta=0.0
% INFO    : Bus 8085	: V=1.063665, theta=-14.756731 -> V=1.007119, theta=0.0
% INFO    : Bus 8086	: V=1.060341, theta=-22.031311 -> V=1.018958, theta=0.0
% INFO    : Bus 8087	: V=1.062144, theta=-24.695257 -> V=1.0134495, theta=0.0
% INFO    : Bus 8088	: V=1.023286, theta=-21.143715 -> V=1.0, theta=0.0
% INFO    : Bus 8089	: V=1.05662, theta=-3.573828 -> V=1.015276, theta=0.0
% INFO    : Bus 8090	: V=1.042268, theta=-16.539218 -> V=1.0, theta=0.0
% INFO    : Bus 8091	: V=1.077564, theta=-19.549069 -> V=1.0206655, theta=0.0
% INFO    : Bus 8092	: V=0.956818, theta=-29.259213 -> V=1.0, theta=0.0
% INFO    : Bus 8093	: V=0.998475, theta=10.35515 -> V=1.0, theta=0.0
% INFO    : Bus 8094	: V=1.075364, theta=-9.355022 -> V=1.0223945, theta=0.0
% INFO    : Bus 8095	: V=1.010281, theta=2.059626 -> V=1.0, theta=0.0
% INFO    : Bus 8096	: V=1.009649, theta=-19.200664 -> V=1.0, theta=0.0
% INFO    : Bus 8097	: V=1.053731, theta=62.38817 -> V=1.0, theta=0.0
% INFO    : Bus 8098	: V=1.014909, theta=-36.682899 -> V=1.0, theta=0.0
% INFO    : Bus 8099	: V=1.039718, theta=-4.363515 -> V=1.0, theta=0.0
% INFO    : Bus 8100	: V=0.992026, theta=-16.446788 -> V=1.0, theta=0.0
% INFO    : Bus 8101	: V=1.030875, theta=-22.924726 -> V=1.016095, theta=0.0
% INFO    : Bus 8102	: V=1.074792, theta=-5.68719 -> V=1.0159925, theta=0.0
% INFO    : Bus 8103	: V=1.011733, theta=-17.159783 -> V=1.004826, theta=0.0
% INFO    : Bus 8104	: V=1.031156, theta=-51.268939 -> V=1.0, theta=0.0
% INFO    : Bus 8105	: V=1.0132, theta=-30.7442 -> V=1.0, theta=0.0
% INFO    : Bus 8106	: V=1.029489, theta=-2.444312 -> V=1.0037415, theta=0.0
% INFO    : Bus 8107	: V=1.041968, theta=-17.942946 -> V=1.0062025, theta=0.0
% INFO    : Bus 8108	: V=1.08598, theta=-8.94169 -> V=1.039, theta=0.0
% INFO    : Bus 8109	: V=1.005429, theta=-23.167425 -> V=1.0, theta=0.0
% INFO    : Bus 8110	: V=1.013028, theta=-46.709563 -> V=1.0, theta=0.0
% INFO    : Bus 8111	: V=0.98531, theta=38.285983 -> V=1.0, theta=0.0
% INFO    : Bus 8112	: V=1.084586, theta=-12.689974 -> V=1.014424, theta=0.0
% INFO    : Bus 8113	: V=1.056554, theta=-48.659741 -> V=1.007253, theta=0.0
% INFO    : Bus 8114	: V=1.000447, theta=57.085217 -> V=1.0, theta=0.0
% INFO    : Bus 8115	: V=1.051129, theta=-49.822438 -> V=1.0, theta=0.0
% INFO    : Bus 8116	: V=1.002844, theta=-24.28335 -> V=1.0, theta=0.0
% INFO    : Bus 8117	: V=0.989132, theta=-28.609077 -> V=1.0, theta=0.0
% INFO    : Bus 8118	: V=0.945036, theta=-27.143723 -> V=1.0, theta=0.0
% INFO    : Bus 8119	: V=0.940679, theta=-23.49502 -> V=1.0, theta=0.0
% INFO    : Bus 8120	: V=1.096545, theta=60.64197 -> V=1.002731, theta=0.0
% INFO    : Bus 8121	: V=1.087868, theta=-37.44758 -> V=1.014126, theta=0.0
% INFO    : Bus 8122	: V=1.044678, theta=-11.48146 -> V=1.008475, theta=0.0
% INFO    : Bus 8123	: V=1.064686, theta=4.528 -> V=1.006106, theta=0.0
% INFO    : Bus 8124	: V=1.001838, theta=-23.378143 -> V=1.0, theta=0.0
% INFO    : Bus 8125	: V=1.051227, theta=-14.017195 -> V=1.0027885, theta=0.0
% INFO    : Bus 8126	: V=1.001813, theta=-48.215202 -> V=1.0, theta=0.0
% INFO    : Bus 8127	: V=1.024892, theta=24.648782 -> V=1.0, theta=0.0
% INFO    : Bus 8128	: V=1.035583, theta=-36.288156 -> V=1.0, theta=0.0
% INFO    : Bus 8129	: V=1.047183, theta=-21.614604 -> V=1.00402, theta=0.0
% INFO    : Bus 8130	: V=1.011186, theta=7.885466 -> V=1.0, theta=0.0
% INFO    : Bus 8131	: V=1.099658, theta=20.464932 -> V=1.0184535, theta=0.0
% INFO    : Bus 8132	: V=1.029104, theta=-49.564321 -> V=1.0, theta=0.0
% INFO    : Bus 8133	: V=1.038627, theta=-24.436385 -> V=1.0, theta=0.0
% INFO    : Bus 8134	: V=0.989566, theta=-24.003447 -> V=1.0, theta=0.0
% INFO    : Bus 8135	: V=1.046134, theta=20.389885 -> V=1.00258, theta=0.0
% INFO    : Bus 8136	: V=1.081545, theta=-12.826258 -> V=1.017764, theta=0.0
% INFO    : Bus 8137	: V=1.013844, theta=-47.890567 -> V=1.0, theta=0.0
% INFO    : Bus 8138	: V=1.035293, theta=-36.30173 -> V=1.0, theta=0.0
% INFO    : Bus 8139	: V=1.071689, theta=-12.898043 -> V=1.0219835, theta=0.0
% INFO    : Bus 8140	: V=1.029273, theta=-31.122251 -> V=1.0, theta=0.0
% INFO    : Bus 8141	: V=1.104632, theta=43.061304 -> V=1.009585, theta=0.0
% INFO    : Bus 8142	: V=1.00713, theta=-19.855801 -> V=1.0, theta=0.0
% INFO    : Bus 8143	: V=1.059399, theta=-10.106515 -> V=1.013436, theta=0.0
% INFO    : Bus 8144	: V=0.997589, theta=-26.478235 -> V=1.0, theta=0.0
% INFO    : Bus 8145	: V=1.01087, theta=-21.971601 -> V=1.0, theta=0.0
% INFO    : Bus 8146	: V=1.050409, theta=1.041234 -> V=1.0125105, theta=0.0
% INFO    : Bus 8147	: V=0.982545, theta=-28.584165 -> V=1.0, theta=0.0
% INFO    : Bus 8148	: V=1.096921, theta=-32.610613 -> V=1.017795, theta=0.0
% INFO    : Bus 8149	: V=1.087024, theta=-30.413379 -> V=1.0195235, theta=0.0
% INFO    : Bus 8150	: V=1.074101, theta=-23.078964 -> V=1.0195775, theta=0.0
% INFO    : Bus 8151	: V=1.061364, theta=-15.912717 -> V=1.0066495, theta=0.0
% INFO    : Bus 8152	: V=1.063173, theta=0.743397 -> V=1.0128025, theta=0.0
% INFO    : Bus 8153	: V=1.059364, theta=-3.580923 -> V=1.017373, theta=0.0
% INFO    : Bus 8154	: V=0.991526, theta=-25.179296 -> V=1.0, theta=0.0
% INFO    : Bus 8155	: V=1.046298, theta=-11.104949 -> V=1.0089955, theta=0.0
% INFO    : Bus 8156	: V=1.044682, theta=-38.334545 -> V=1.0, theta=0.0
% INFO    : Bus 8157	: V=1.018874, theta=14.12435 -> V=1.0, theta=0.0
% INFO    : Bus 8158	: V=1.037368, theta=-18.535832 -> V=1.0113395, theta=0.0
% INFO    : Bus 8159	: V=1.024776, theta=-24.481037 -> V=1.0, theta=0.0
% INFO    : Bus 8160	: V=1.031048, theta=-24.244347 -> V=1.0, theta=0.0
% INFO    : Bus 8161	: V=1.064739, theta=-19.569367 -> V=1.0, theta=0.0
% INFO    : Bus 8162	: V=1.094211, theta=-37.531797 -> V=1.027547, theta=0.0
% INFO    : Bus 8163	: V=1.053885, theta=-24.414641 -> V=1.013934, theta=0.0
% INFO    : Bus 8164	: V=1.014227, theta=-21.513386 -> V=1.0, theta=0.0
% INFO    : Bus 8165	: V=1.054081, theta=2.726228 -> V=1.0057365, theta=0.0
% INFO    : Bus 8166	: V=1.08043, theta=-3.800409 -> V=1.016764, theta=0.0
% INFO    : Bus 8167	: V=1.07709, theta=-34.232316 -> V=1.014884, theta=0.0
% INFO    : Bus 8168	: V=1.073591, theta=4.470344 -> V=1.022127, theta=0.0
% INFO    : Bus 8169	: V=1.071605, theta=-13.681846 -> V=1.014132, theta=0.0
% INFO    : Bus 8170	: V=0.986882, theta=-39.01979 -> V=1.0, theta=0.0
% INFO    : Bus 8171	: V=1.0507, theta=-20.628728 -> V=1.010117, theta=0.0
% INFO    : Bus 8172	: V=1.066579, theta=-38.174065 -> V=1.0173695, theta=0.0
% INFO    : Bus 8173	: V=1.052226, theta=-37.430032 -> V=1.0, theta=0.0
% INFO    : Bus 8174	: V=1.069094, theta=-9.737902 -> V=1.018207, theta=0.0
% INFO    : Bus 8175	: V=1.063716, theta=41.03181 -> V=1.010847, theta=0.0
% INFO    : Bus 8176	: V=1.058372, theta=-21.152208 -> V=1.0, theta=0.0
% INFO    : Bus 8177	: V=1.047705, theta=-19.018944 -> V=1.008626, theta=0.0
% INFO    : Bus 8178	: V=1.058271, theta=-43.759826 -> V=1.013068, theta=0.0
% INFO    : Bus 8179	: V=1.058203, theta=0.803908 -> V=1.009764, theta=0.0
% INFO    : Bus 8180	: V=1.009885, theta=-26.520065 -> V=1.0, theta=0.0
% INFO    : Bus 8181	: V=1.074189, theta=-33.366814 -> V=1.025634, theta=0.0
% INFO    : Bus 8182	: V=1.083008, theta=-15.730141 -> V=1.017514, theta=0.0
% INFO    : Bus 8183	: V=1.062003, theta=-22.003471 -> V=1.019799, theta=0.0
% INFO    : Bus 8184	: V=1.079411, theta=1.100004 -> V=1.0260985, theta=0.0
% INFO    : Bus 8185	: V=1.057409, theta=-43.805072 -> V=1.004259, theta=0.0
% INFO    : Bus 8186	: V=1.096386, theta=-6.272965 -> V=1.031817, theta=0.0
% INFO    : Bus 8187	: V=0.993061, theta=-23.211833 -> V=1.0, theta=0.0
% INFO    : Bus 8188	: V=1.04871, theta=-20.663115 -> V=1.01654, theta=0.0
% INFO    : Bus 8189	: V=0.994078, theta=-23.711618 -> V=1.0, theta=0.0
% INFO    : Bus 8190	: V=1.038574, theta=-6.218962 -> V=1.0125905, theta=0.0
% INFO    : Bus 8191	: V=1.07238, theta=-23.457163 -> V=1.018812, theta=0.0
% INFO    : Bus 8192	: V=0.937092, theta=-25.78259 -> V=1.0, theta=0.0
% INFO    : Bus 8193	: V=1.06336, theta=-7.235824 -> V=1.0155585, theta=0.0
% INFO    : Bus 8194	: V=1.014056, theta=-18.538633 -> V=1.0, theta=0.0
% INFO    : Bus 8195	: V=1.093078, theta=-0.707594 -> V=1.021639, theta=0.0
% INFO    : Bus 8196	: V=1.028243, theta=-4.853285 -> V=1.0, theta=0.0
% INFO    : Bus 8197	: V=1.067656, theta=-19.81109 -> V=1.013017, theta=0.0
% INFO    : Bus 8198	: V=1.085211, theta=5.318795 -> V=1.027484, theta=0.0
% INFO    : Bus 8199	: V=1.060651, theta=-48.074084 -> V=1.008945, theta=0.0
% INFO    : Bus 8200	: V=1.043028, theta=14.666794 -> V=1.0, theta=0.0
% INFO    : Bus 8201	: V=1.07445, theta=-12.743261 -> V=1.0199595, theta=0.0
% INFO    : Bus 8202	: V=1.101192, theta=-43.269517 -> V=1.028456, theta=0.0
% INFO    : Bus 8203	: V=1.049195, theta=-26.22954 -> V=1.014217, theta=0.0
% INFO    : Bus 8204	: V=1.011273, theta=-14.597546 -> V=1.0, theta=0.0
% INFO    : Bus 8205	: V=1.024332, theta=-21.820854 -> V=1.0, theta=0.0
% INFO    : Bus 8206	: V=1.122614, theta=58.578636 -> V=1.040069, theta=0.0
% INFO    : Bus 8207	: V=1.067096, theta=-14.605988 -> V=1.0092855, theta=0.0
% INFO    : Bus 8208	: V=1.050818, theta=-38.327103 -> V=1.002674, theta=0.0
% INFO    : Bus 8209	: V=1.04259, theta=3.013761 -> V=1.017152, theta=0.0
% INFO    : Bus 8210	: V=0.966304, theta=-25.099908 -> V=1.0, theta=0.0
% INFO    : Bus 8211	: V=1.078763, theta=-18.798191 -> V=1.0202465, theta=0.0
% INFO    : Bus 8212	: V=1.064364, theta=-36.381225 -> V=1.013235, theta=0.0
% INFO    : Bus 8213	: V=1.034491, theta=-28.952818 -> V=1.0, theta=0.0
% INFO    : Bus 8214	: V=1.071869, theta=-23.412372 -> V=1.017941, theta=0.0
% INFO    : Bus 8215	: V=1.095079, theta=45.243438 -> V=1.0083465, theta=0.0
% INFO    : Bus 8216	: V=1.005474, theta=66.939571 -> V=1.0, theta=0.0
% INFO    : Bus 8217	: V=1.082909, theta=-11.177499 -> V=1.0188895, theta=0.0
% INFO    : Bus 8218	: V=1.057766, theta=-36.59422 -> V=1.0029655, theta=0.0
% INFO    : Bus 8219	: V=0.950061, theta=-31.621698 -> V=0.97349, theta=0.0
% INFO    : Bus 8220	: V=1.088469, theta=-0.354946 -> V=1.0244205, theta=0.0
% INFO    : Bus 8221	: V=1.049868, theta=57.886868 -> V=1.0, theta=0.0
% INFO    : Bus 8222	: V=1.082184, theta=-18.818858 -> V=1.02978, theta=0.0
% INFO    : Bus 8223	: V=1.033909, theta=-45.163717 -> V=1.0, theta=0.0
% INFO    : Bus 8224	: V=1.013411, theta=-22.130474 -> V=1.0, theta=0.0
% INFO    : Bus 8225	: V=1.063822, theta=-43.892268 -> V=1.0064995, theta=0.0
% INFO    : Bus 8226	: V=0.952933, theta=63.823203 -> V=1.0, theta=0.0
% INFO    : Bus 8227	: V=1.079275, theta=-26.357005 -> V=1.043716, theta=0.0
% INFO    : Bus 8228	: V=1.040684, theta=1.603051 -> V=1.0, theta=0.0
% INFO    : Bus 8229	: V=1.032264, theta=-21.776765 -> V=1.0046025, theta=0.0
% INFO    : Bus 8230	: V=1.077674, theta=10.049499 -> V=1.015704, theta=0.0
% INFO    : Bus 8231	: V=1.032217, theta=-4.652475 -> V=1.0, theta=0.0
% INFO    : Bus 8232	: V=1.081054, theta=0.960033 -> V=1.016068, theta=0.0
% INFO    : Bus 8233	: V=1.04416, theta=-19.575934 -> V=1.0, theta=0.0
% INFO    : Bus 8234	: V=1.093636, theta=0.519822 -> V=1.026311, theta=0.0
% INFO    : Bus 8235	: V=1.045899, theta=-44.79094 -> V=1.007594, theta=0.0
% INFO    : Bus 8236	: V=1.008849, theta=-20.013564 -> V=1.0, theta=0.0
% INFO    : Bus 8237	: V=1.081385, theta=3.916054 -> V=1.024743, theta=0.0
% INFO    : Bus 8238	: V=0.966122, theta=-33.947664 -> V=1.0, theta=0.0
% INFO    : Bus 8239	: V=1.080007, theta=-41.441262 -> V=1.025766, theta=0.0
% INFO    : Bus 8240	: V=0.967309, theta=-27.980684 -> V=1.0, theta=0.0
% INFO    : Bus 8241	: V=0.961361, theta=20.813525 -> V=1.0, theta=0.0
% INFO    : Bus 8242	: V=0.956998, theta=-25.096292 -> V=1.0, theta=0.0
% INFO    : Bus 8243	: V=0.99237, theta=-23.526985 -> V=1.0, theta=0.0
% INFO    : Bus 8244	: V=1.066257, theta=-11.958341 -> V=1.016247, theta=0.0
% INFO    : Bus 8245	: V=1.056455, theta=-15.363437 -> V=1.004099, theta=0.0
% INFO    : Bus 8246	: V=1.0834, theta=0.054101 -> V=1.026196, theta=0.0
% INFO    : Bus 8247	: V=1.062113, theta=21.417942 -> V=1.0153385, theta=0.0
% INFO    : Bus 8248	: V=1.049284, theta=-12.544159 -> V=1.0070785, theta=0.0
% INFO    : Bus 8249	: V=1.063629, theta=36.415633 -> V=1.0106495, theta=0.0
% INFO    : Bus 8250	: V=0.970616, theta=53.860989 -> V=1.0, theta=0.0
% INFO    : Bus 8251	: V=1.075332, theta=-9.043212 -> V=1.02102, theta=0.0
% INFO    : Bus 8252	: V=0.988461, theta=-23.641662 -> V=1.0, theta=0.0
% INFO    : Bus 8253	: V=1.029457, theta=-12.369751 -> V=1.0, theta=0.0
% INFO    : Bus 8254	: V=1.07285, theta=4.058076 -> V=1.021912, theta=0.0
% INFO    : Bus 8255	: V=0.98992, theta=10.850414 -> V=1.0, theta=0.0
% INFO    : Bus 8256	: V=1.055409, theta=-35.999143 -> V=1.0042565, theta=0.0
% INFO    : Bus 8257	: V=1.002812, theta=-26.075246 -> V=1.0, theta=0.0
% INFO    : Bus 8258	: V=1.098421, theta=62.813841 -> V=1.007064, theta=0.0
% INFO    : Bus 8259	: V=1.052447, theta=-22.814783 -> V=1.0084785, theta=0.0
% INFO    : Bus 8260	: V=0.995816, theta=-22.6443 -> V=1.0, theta=0.0
% INFO    : Bus 8261	: V=1.100091, theta=-12.432246 -> V=1.032716, theta=0.0
% INFO    : Bus 8262	: V=1.029746, theta=-46.548332 -> V=1.0, theta=0.0
% INFO    : Bus 8263	: V=1.082951, theta=-16.206345 -> V=1.025342, theta=0.0
% INFO    : Bus 8264	: V=1.058727, theta=-15.293683 -> V=1.005648, theta=0.0
% INFO    : Bus 8265	: V=1.088472, theta=-0.354998 -> V=1.0244215, theta=0.0
% INFO    : Bus 8266	: V=1.095105, theta=-14.491761 -> V=1.027411, theta=0.0
% INFO    : Bus 8267	: V=1.020789, theta=-15.470646 -> V=1.0107815, theta=0.0
% INFO    : Bus 8268	: V=1.06035, theta=-12.521323 -> V=1.022079, theta=0.0
% INFO    : Bus 8269	: V=1.060455, theta=-35.317994 -> V=1.021088, theta=0.0
% INFO    : Bus 8270	: V=1.050516, theta=-28.312129 -> V=1.006392, theta=0.0
% INFO    : Bus 8271	: V=1.054259, theta=-12.368299 -> V=1.011606, theta=0.0
% INFO    : Bus 8272	: V=1.082202, theta=-47.458259 -> V=1.009917, theta=0.0
% INFO    : Bus 8273	: V=1.068143, theta=3.051821 -> V=1.0138555, theta=0.0
% INFO    : Bus 8274	: V=1.077513, theta=-19.53412 -> V=1.02087, theta=0.0
% INFO    : Bus 8275	: V=1.058624, theta=2.100167 -> V=1.009141, theta=0.0
% INFO    : Bus 8276	: V=1.060169, theta=-42.331484 -> V=1.0144755, theta=0.0
% INFO    : Bus 8277	: V=1.095592, theta=-21.484045 -> V=1.0, theta=0.0
% INFO    : Bus 8278	: V=1.010927, theta=-17.766758 -> V=1.0, theta=0.0
% INFO    : Bus 8279	: V=1.041182, theta=-17.102385 -> V=1.0064725, theta=0.0
% INFO    : Bus 8280	: V=1.050444, theta=-32.049573 -> V=1.011754, theta=0.0
% INFO    : Bus 8281	: V=1.026687, theta=16.067632 -> V=1.0, theta=0.0
% INFO    : Bus 8282	: V=1.081366, theta=-3.662194 -> V=1.0174185, theta=0.0
% INFO    : Bus 8283	: V=1.050377, theta=-30.360076 -> V=1.021791, theta=0.0
% INFO    : Bus 8284	: V=1.061598, theta=-22.96586 -> V=1.0178375, theta=0.0
% INFO    : Bus 8285	: V=1.089921, theta=-27.715846 -> V=1.040634, theta=0.0
% INFO    : Bus 8286	: V=1.060836, theta=-40.06031 -> V=1.0067315, theta=0.0
% INFO    : Bus 8287	: V=1.020236, theta=-17.246564 -> V=1.0, theta=0.0
% INFO    : Bus 8288	: V=1.002942, theta=-49.292834 -> V=1.0, theta=0.0
% INFO    : Bus 8289	: V=1.033673, theta=-49.283158 -> V=1.0, theta=0.0
% INFO    : Bus 8290	: V=1.041591, theta=-29.35046 -> V=1.0047895, theta=0.0
% INFO    : Bus 8291	: V=1.035947, theta=-46.107892 -> V=1.0, theta=0.0
% INFO    : Bus 8292	: V=1.052273, theta=-4.904432 -> V=1.020602, theta=0.0
% INFO    : Bus 8293	: V=1.023365, theta=-27.887148 -> V=1.0, theta=0.0
% INFO    : Bus 8294	: V=1.028044, theta=-17.562426 -> V=1.0, theta=0.0
% INFO    : Bus 8295	: V=1.045777, theta=9.749847 -> V=1.0025465, theta=0.0
% INFO    : Bus 8296	: V=1.042538, theta=-10.035334 -> V=1.0390605, theta=0.0
% INFO    : Bus 8297	: V=1.075223, theta=-17.126714 -> V=1.0125425, theta=0.0
% INFO    : Bus 8298	: V=1.041688, theta=4.767588 -> V=1.0035345, theta=0.0
% INFO    : Bus 8299	: V=1.026573, theta=-23.587433 -> V=1.0, theta=0.0
% INFO    : Bus 8300	: V=1.090398, theta=-12.643457 -> V=1.027749, theta=0.0
% INFO    : Bus 8301	: V=0.978165, theta=-24.260489 -> V=1.0, theta=0.0
% INFO    : Bus 8302	: V=1.079368, theta=-12.725638 -> V=1.0255155, theta=0.0
% INFO    : Bus 8303	: V=1.068566, theta=15.373576 -> V=1.0187845, theta=0.0
% INFO    : Bus 8304	: V=1.021591, theta=-34.200998 -> V=1.0, theta=0.0
% INFO    : Bus 8305	: V=1.03978, theta=18.071349 -> V=1.0, theta=0.0
% INFO    : Bus 8306	: V=1.048081, theta=-19.630212 -> V=1.0034815, theta=0.0
% INFO    : Bus 8307	: V=1.04852, theta=-20.896839 -> V=1.0, theta=0.0
% INFO    : Bus 8308	: V=1.024191, theta=-25.664082 -> V=1.0, theta=0.0
% INFO    : Bus 8309	: V=1.087296, theta=-13.811918 -> V=1.023382, theta=0.0
% INFO    : Bus 8310	: V=1.090956, theta=-39.526529 -> V=1.0270065, theta=0.0
% INFO    : Bus 8311	: V=1.055714, theta=0.620613 -> V=1.0062405, theta=0.0
% INFO    : Bus 8312	: V=1.062091, theta=-19.238092 -> V=1.0, theta=0.0
% INFO    : Bus 8313	: V=1.05684, theta=-55.008171 -> V=1.0, theta=0.0
% INFO    : Bus 8314	: V=1.043936, theta=-23.359098 -> V=1.0, theta=0.0
% INFO    : Bus 8315	: V=1.037159, theta=-18.357961 -> V=1.0, theta=0.0
% INFO    : Bus 8316	: V=1.023849, theta=-16.414638 -> V=1.0, theta=0.0
% INFO    : Bus 8317	: V=1.012705, theta=-22.246851 -> V=1.0, theta=0.0
% INFO    : Bus 8318	: V=1.093316, theta=-23.769098 -> V=1.0247565, theta=0.0
% INFO    : Bus 8319	: V=1.054273, theta=-14.551096 -> V=1.011482, theta=0.0
% INFO    : Bus 8320	: V=1.081298, theta=-16.854834 -> V=1.0103495, theta=0.0
% INFO    : Bus 8321	: V=1.03078, theta=-24.13502 -> V=1.0, theta=0.0
% INFO    : Bus 8322	: V=1.037232, theta=-20.045549 -> V=1.0, theta=0.0
% INFO    : Bus 8323	: V=0.970908, theta=-27.421821 -> V=1.0, theta=0.0
% INFO    : Bus 8324	: V=1.068256, theta=-19.219378 -> V=1.018292, theta=0.0
% INFO    : Bus 8325	: V=1.048053, theta=-30.655625 -> V=1.016233, theta=0.0
% INFO    : Bus 8326	: V=1.003446, theta=-29.805364 -> V=1.0, theta=0.0
% INFO    : Bus 8327	: V=1.060584, theta=-12.523938 -> V=1.022205, theta=0.0
% INFO    : Bus 8328	: V=1.013882, theta=-31.626891 -> V=1.0, theta=0.0
% INFO    : Bus 8329	: V=1.040546, theta=-16.246448 -> V=1.004467, theta=0.0
% INFO    : Bus 8330	: V=1.002513, theta=-23.21089 -> V=1.0, theta=0.0
% INFO    : Bus 8331	: V=1.094545, theta=-8.235816 -> V=1.0280805, theta=0.0
% INFO    : Bus 8332	: V=1.05987, theta=-8.820727 -> V=1.0101865, theta=0.0
% INFO    : Bus 8333	: V=1.097858, theta=-25.438895 -> V=1.024108, theta=0.0
% INFO    : Bus 8334	: V=1.057413, theta=-19.408473 -> V=1.004316, theta=0.0
% INFO    : Bus 8335	: V=1.097086, theta=-6.218882 -> V=1.03214, theta=0.0
% INFO    : Bus 8336	: V=1.00693, theta=-23.441528 -> V=1.0, theta=0.0
% INFO    : Bus 8337	: V=1.054455, theta=-26.939908 -> V=1.0085265, theta=0.0
% INFO    : Bus 8338	: V=1.058564, theta=-23.873119 -> V=1.01654, theta=0.0
% INFO    : Bus 8339	: V=1.032749, theta=12.769564 -> V=1.0, theta=0.0
% INFO    : Bus 8340	: V=1.075648, theta=-23.931953 -> V=1.0319465, theta=0.0
% INFO    : Bus 8341	: V=1.074698, theta=-10.969203 -> V=1.022828, theta=0.0
% INFO    : Bus 8342	: V=1.016285, theta=-21.508683 -> V=1.0, theta=0.0
% INFO    : Bus 8343	: V=1.061978, theta=-14.473086 -> V=1.0, theta=0.0
% INFO    : Bus 8344	: V=1.026364, theta=-23.315703 -> V=1.0, theta=0.0
% INFO    : Bus 8345	: V=1.019769, theta=-37.65866 -> V=1.0, theta=0.0
% INFO    : Bus 8346	: V=1.050545, theta=-44.538257 -> V=1.0, theta=0.0
% INFO    : Bus 8347	: V=0.987658, theta=11.111357 -> V=1.0, theta=0.0
% INFO    : Bus 8348	: V=0.906258, theta=-32.501794 -> V=1.0, theta=0.0
% INFO    : Bus 8349	: V=1.036136, theta=11.403902 -> V=1.0, theta=0.0
% INFO    : Bus 8350	: V=1.008321, theta=-39.126182 -> V=1.0, theta=0.0
% INFO    : Bus 8351	: V=1.021896, theta=-34.467865 -> V=1.0, theta=0.0
% INFO    : Bus 8352	: V=1.072181, theta=-11.842489 -> V=1.0129505, theta=0.0
% INFO    : Bus 8353	: V=0.999188, theta=-22.496658 -> V=1.0, theta=0.0
% INFO    : Bus 8354	: V=1.041686, theta=9.135988 -> V=1.0116145, theta=0.0
% INFO    : Bus 8355	: V=1.070636, theta=2.368796 -> V=1.0213965, theta=0.0
% INFO    : Bus 8356	: V=1.073607, theta=0.708259 -> V=1.024548, theta=0.0
% INFO    : Bus 8357	: V=0.988967, theta=-23.281738 -> V=1.0, theta=0.0
% INFO    : Bus 8358	: V=0.950757, theta=-18.035931 -> V=1.0, theta=0.0
% INFO    : Bus 8359	: V=1.059573, theta=6.001438 -> V=1.0122045, theta=0.0
% INFO    : Bus 8360	: V=1.046554, theta=-21.578615 -> V=1.0, theta=0.0
% INFO    : Bus 8361	: V=1.071313, theta=-4.366309 -> V=1.016652, theta=0.0
% INFO    : Bus 8362	: V=0.93279, theta=-29.207007 -> V=1.0, theta=0.0
% INFO    : Bus 8363	: V=0.926182, theta=33.151862 -> V=1.0, theta=0.0
% INFO    : Bus 8364	: V=1.065035, theta=-43.922407 -> V=1.0068065, theta=0.0
% INFO    : Bus 8365	: V=1.021215, theta=-8.650177 -> V=1.009466, theta=0.0
% INFO    : Bus 8366	: V=1.043021, theta=-19.618724 -> V=1.0070715, theta=0.0
% INFO    : Bus 8367	: V=0.936897, theta=-28.577632 -> V=1.0, theta=0.0
% INFO    : Bus 8368	: V=1.031955, theta=12.609782 -> V=1.0, theta=0.0
% INFO    : Bus 8369	: V=1.084862, theta=-16.115269 -> V=1.023336, theta=0.0
% INFO    : Bus 8370	: V=1.026656, theta=3.68985 -> V=1.0, theta=0.0
% INFO    : Bus 8371	: V=1.039053, theta=-4.159838 -> V=1.0027465, theta=0.0
% INFO    : Bus 8372	: V=1.052202, theta=-19.925009 -> V=1.002824, theta=0.0
% INFO    : Bus 8373	: V=1.031138, theta=-13.821291 -> V=1.003366, theta=0.0
% INFO    : Bus 8374	: V=1.033054, theta=66.109598 -> V=1.0, theta=0.0
% INFO    : Bus 8375	: V=1.057549, theta=-29.735084 -> V=1.0111935, theta=0.0
% INFO    : Bus 8376	: V=1.006409, theta=-6.553767 -> V=1.0, theta=0.0
% INFO    : Bus 8377	: V=1.076407, theta=-18.154082 -> V=1.0207425, theta=0.0
% INFO    : Bus 8378	: V=1.049423, theta=-28.756936 -> V=1.0, theta=0.0
% INFO    : Bus 8379	: V=1.082508, theta=-2.447694 -> V=1.021884, theta=0.0
% INFO    : Bus 8380	: V=1.057568, theta=0.748584 -> V=1.01316, theta=0.0
% INFO    : Bus 8381	: V=1.083789, theta=-20.896509 -> V=1.0221055, theta=0.0
% INFO    : Bus 8382	: V=1.08234, theta=-37.978446 -> V=1.0274035, theta=0.0
% INFO    : Bus 8383	: V=1.042532, theta=-18.820599 -> V=1.014088, theta=0.0
% INFO    : Bus 8384	: V=1.104105, theta=16.485935 -> V=1.034544, theta=0.0
% INFO    : Bus 8385	: V=1.086053, theta=1.575069 -> V=1.0175365, theta=0.0
% INFO    : Bus 8386	: V=1.026495, theta=-24.551994 -> V=1.0, theta=0.0
% INFO    : Bus 8387	: V=1.051742, theta=-9.519694 -> V=1.0113915, theta=0.0
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
